@@ -26,7 +26,9 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObject;
+import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IReaction;
+import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.layout.StructureDiagramGenerator;
 import org.openscience.cdk.renderer.RendererModel;
 import org.openscience.cdk.renderer.SymbolVisibility;
@@ -45,6 +47,8 @@ import org.openscience.cdk.renderer.generators.standard.StandardGenerator;
 import org.openscience.cdk.renderer.generators.standard.StandardGenerator.DelocalisedDonutsBondDisplay;
 import org.openscience.cdk.renderer.generators.standard.StandardGenerator.ForceDelocalisedBondDisplay;
 import org.openscience.cdk.tools.LoggingToolFactory;
+import org.openscience.cdk.tools.manipulator.ReactionManipulator;
+import org.openscience.cdk.tools.manipulator.ReactionSetManipulator;
 
 import javax.vecmath.Point2d;
 import java.awt.Color;
@@ -88,19 +92,19 @@ import java.util.stream.StreamSupport;
  * through a variety of API calls.
  * <pre>{@code
  * Depiction depiction = new DepictionGenerator().depict(mol);
- * 
+ *
  * // quick use, format determined by name by path
  * depiction.writeTo("~/mol.png");
  * depiction.writeTo("~/mol.svg");
  * depiction.writeTo("~/mol.pdf");
  * depiction.writeTo("~/mol.jpg");
- * 
+ *
  * // manually specify the format
  * depiction.writeTo(Depiction.SVG_FMT, "~/mol");
- * 
+ *
  * // convert to a Java buffered image
  * BufferedImage img = depiction.toImg();
- * 
+ *
  * // get the SVG XML string
  * String svg = depiction.toSvgStr();
  * }</pre>
@@ -215,6 +219,7 @@ public final class DepictionGenerator {
      */
     private final Map<IChemObject, Color> highlight = new HashMap<>();
 
+
     /**
      * Create a depiction generator using the standard sans-serif
      * system font.
@@ -272,8 +277,7 @@ public final class DepictionGenerator {
     }
 
     private <U, T extends IGeneratorParameter<U>> U getParameterValue(Class<T> key) {
-        @SuppressWarnings("unchecked")
-        final T param = (T) params.get(key);
+        @SuppressWarnings("unchecked") final T param = (T) params.get(key);
         if (param == null)
             throw new IllegalArgumentException("No parameter registered: " + key + " " + params.keySet());
         return param.getValue();
@@ -365,7 +369,7 @@ public final class DepictionGenerator {
 
         // generate bound rendering elements
         final RendererModel model = copy.getModel();
-        final List<Bounds> molElems = copy.generate(molList, model, 1);
+        final List<Bounds> molElems = copy.generate(molList, model, new AtomNumbering());
 
         // reset molecule coordinates
         for (LayoutBackup backup : layoutBackups)
@@ -409,6 +413,10 @@ public final class DepictionGenerator {
             chemObject.setProperty(key, val);
     }
 
+    private Color getForgroundColor(IChemObjectBuilder builder) {
+        return getParameterValue(StandardGenerator.AtomColor.class).getAtomColor(builder.newInstance(IAtom.class, "C"));
+    }
+
     /**
      * Depict a reaction.
      *
@@ -420,9 +428,62 @@ public final class DepictionGenerator {
 
         ensure2dLayout(rxn); // can reorder components if align is enabled!
 
-        final Color fgcol = getParameterValue(StandardGenerator.AtomColor.class).getAtomColor(rxn.getBuilder()
-                                                                                                 .newInstance(IAtom.class, "C"));
+        final Color fgcol = getForgroundColor(rxn.getBuilder());
 
+        ReactionBounds reactionBounds = getReactionBounds(rxn, fgcol, new AtomNumbering());
+        highlight.clear();
+        return new ReactionDepiction(reactionBounds,
+                                     dimensions,
+                                     fgcol);
+    }
+
+    public Depiction depict(IReactionSet rxns) throws CDKException {
+
+        for (IReaction rxn : rxns.reactions())
+            ensure2dLayout(rxn);
+
+        // n.b. we may want to scale bonds consistently across the whole reaction
+
+        final Color fgcol = getForgroundColor(rxns.getBuilder());
+        List<ReactionBounds> reactionSetBounds = new ArrayList<>();
+
+        IAtomContainerSet prev = null;
+        boolean isSequence = rxns.getReactionCount() > 1;
+        for (IReaction rxn : rxns.reactions()) {
+            if (prev != null && !equals(prev, rxn.getReactants()))
+                isSequence = false;
+            prev = rxn.getProducts();
+        }
+
+        AtomNumbering atomNumbering = new AtomNumbering();
+        for (IReaction rxn : rxns.reactions()) {
+            reactionSetBounds.add(getReactionBounds(rxn, fgcol, atomNumbering));
+            if (isSequence) {
+                for (IAtomContainer mol : rxn.getProducts().atomContainers())
+                    atomNumbering.id -= mol.getAtomCount();
+            }
+        }
+        highlight.clear();
+
+        return new ReactionSetDepiction(reactionSetBounds.get(0).model,
+                                        reactionSetBounds,
+                                        dimensions,
+                                        isSequence,
+                                        fgcol);
+    }
+
+    private boolean equals(IAtomContainerSet as, IAtomContainerSet bs) {
+        if (as.getAtomContainerCount() != bs.getAtomContainerCount())
+            return false;
+        for (int i = 0; i < as.getAtomContainerCount(); i++) {
+            // deliberate reference comparison
+            if (as.getAtomContainer(i) != bs.getAtomContainer(i))
+                return false;
+        }
+        return true;
+    }
+
+    private ReactionBounds getReactionBounds(IReaction rxn, Color fgcol, AtomNumbering atomNumbering) throws CDKException {
         final List<IAtomContainer> reactants = toList(rxn.getReactants());
         final List<IAtomContainer> products = toList(rxn.getProducts());
         final List<IAtomContainer> agents = toList(rxn.getAgents());
@@ -430,55 +491,43 @@ public final class DepictionGenerator {
 
         // set ids for tagging elements
         int molId = 0;
-        for (IAtomContainer mol : reactants) {
+        for (IAtomContainer mol : ReactionManipulator.getAllAtomContainers(rxn)) {
             setIfMissing(mol, MarkedElement.ID_KEY, "mol" + ++molId);
             setIfMissing(mol, MarkedElement.CLASS_KEY, "reactant");
             layoutBackups.add(new LayoutBackup(mol));
         }
-        for (IAtomContainer mol : products) {
-            setIfMissing(mol, MarkedElement.ID_KEY, "mol" + ++molId);
-            setIfMissing(mol, MarkedElement.CLASS_KEY, "product");
-            layoutBackups.add(new LayoutBackup(mol));
-        }
-        for (IAtomContainer mol : agents) {
-            setIfMissing(mol, MarkedElement.ID_KEY, "mol" + ++molId);
-            setIfMissing(mol, MarkedElement.CLASS_KEY, "agent");
-            layoutBackups.add(new LayoutBackup(mol));
-        }
-
-        final Map<IChemObject, Color> myHighlight = new HashMap<>();
-        if (highlightAtomMap) {
-            myHighlight.putAll(makeHighlightAtomMap(reactants, products));
-        }
-        // user highlight buffer pushes out the atom-map highlight if provided
-        myHighlight.putAll(highlight);
-        highlight.clear();
 
         prepareCoords(reactants);
         prepareCoords(products);
         prepareCoords(agents);
 
-        // highlight parts
-        for (Map.Entry<IChemObject, Color> e : myHighlight.entrySet())
+        // highlighting
+        final Map<IChemObject, Color> mappingHighlight = new HashMap<>();
+        if (highlightAtomMap)
+            mappingHighlight.putAll(makeHighlightAtomMap(rxn));
+
+        // user highlight buffer pushes out the atom-map highlight if provided
+        mappingHighlight.putAll(highlight);
+        for (Map.Entry<IChemObject, Color> e : mappingHighlight.entrySet())
             e.getKey().setProperty(StandardGenerator.HIGHLIGHT_COLOR, e.getValue());
 
-        // setup the model scale based on bond length
+        // set up the model scale based on bond length
         final double scale = this.caclModelScale(rxn);
         final DepictionGenerator copy = this.withParam(BasicSceneGenerator.Scale.class, scale);
         final RendererModel model = copy.getModel();
 
         // reactant/product/agent element generation, we number the reactants, then products then agents
-        List<Bounds> reactantBounds = copy.generate(reactants, model, 1);
-        List<Bounds> productBounds = copy.generate(toList(rxn.getProducts()), model, rxn.getReactantCount());
-        List<Bounds> agentBounds = copy.generate(toList(rxn.getAgents()), model, rxn.getReactantCount() + rxn.getProductCount());
-
-        // remove current highlight buffer
-        for (IChemObject obj : myHighlight.keySet())
-            obj.removeProperty(StandardGenerator.HIGHLIGHT_COLOR);
+        List<Bounds> reactantBounds = copy.generate(reactants, model, atomNumbering);
+        List<Bounds> agentBounds = copy.generate(toList(rxn.getAgents()), model, atomNumbering);
+        List<Bounds> productBounds = copy.generate(toList(rxn.getProducts()), model, atomNumbering);
 
         // generate a 'plus' element
         Bounds plus = copy.generatePlusSymbol(scale, fgcol);
 
+        // remove current highlight buffer
+        for (IChemObject obj : mappingHighlight.keySet())
+            obj.removeProperty(StandardGenerator.HIGHLIGHT_COLOR);
+
         // reset the coordinates to how they were before we invoked depict
         for (LayoutBackup backup : layoutBackups)
             backup.reset();
@@ -496,14 +545,23 @@ public final class DepictionGenerator {
 
         final Bounds conditions = generateReactionConditions(rxn, fgcol, model.get(BasicSceneGenerator.Scale.class));
 
-        return new ReactionDepiction(model,
-                                     reactantBounds, productBounds, agentBounds,
-                                     plus, rxn.getDirection(), dimensions,
-                                     reactantTitles,
-                                     productTitles,
-                                     title,
-                                     conditions,
-                                     fgcol);
+        ReactionBounds reactionBounds = new ReactionBounds();
+        reactionBounds.model = model;
+        reactionBounds.plus = plus;
+        reactionBounds.reactants.addAll(reactantBounds);
+        reactionBounds.products.addAll(productBounds);
+        reactionBounds.aboveArrow.addAll(agentBounds);
+        reactionBounds.title = title;
+        reactionBounds.reactantLabels.addAll(reactantTitles);
+        reactionBounds.productLabels.addAll(productTitles);
+        reactionBounds.belowArrow.add(conditions);
+        reactionBounds.direction = rxn.getDirection();
+        return reactionBounds;
+    }
+
+    private Map<IChemObject, Color> makeHighlightAtomMap(IReaction reaction) {
+        return makeHighlightAtomMap(reaction.getReactants().atomContainers(),
+                                    reaction.getProducts().atomContainers());
     }
 
     /**
@@ -513,8 +571,8 @@ public final class DepictionGenerator {
      * @param products  reaction products
      * @return the highlight map
      */
-    private Map<IChemObject, Color> makeHighlightAtomMap(List<IAtomContainer> reactants,
-                                                         List<IAtomContainer> products) {
+    private Map<IChemObject, Color> makeHighlightAtomMap(Iterable<IAtomContainer> reactants,
+                                                         Iterable<IAtomContainer> products) {
 
         // only highlight atom-maps that appear in both the reactant+product
         Set<Integer> reactantMapIdxs = new HashSet<>();
@@ -578,8 +636,8 @@ public final class DepictionGenerator {
                     if (rBeg != null && rEnd != null) {
                         IBond rBnd = rBeg.getBond(rEnd);
                         if (rBnd != null &&
-                            ((pBnd.isAromatic() && rBnd.isAromatic()) ||
-                              rBnd.getOrder() == pBnd.getOrder())) {
+                                ((pBnd.isAromatic() && rBnd.isAromatic()) ||
+                                        rBnd.getOrder() == pBnd.getOrder())) {
                             colorMap.put(pBnd, c1);
                         } else {
                             colorMap.remove(rBnd);
@@ -609,7 +667,15 @@ public final class DepictionGenerator {
         return mols;
     }
 
-    private IRenderingElement generate(IAtomContainer molecule, RendererModel model, int atomNum) throws CDKException {
+    private final class AtomNumbering {
+        private int id = 1;
+
+        int nextId() {
+            return id++;
+        }
+    }
+
+    private IRenderingElement generate(IAtomContainer molecule, RendererModel model, AtomNumbering atomNumbering) throws CDKException {
 
         // tag the atom and bond ids
         String molId = molecule.getProperty(MarkedElement.ID_KEY);
@@ -626,7 +692,7 @@ public final class DepictionGenerator {
                 if (atom.getProperty(StandardGenerator.ANNOTATION_LABEL) != null)
                     throw new UnsupportedOperationException("Multiple annotation labels are not supported.");
                 atom.setProperty(StandardGenerator.ANNOTATION_LABEL,
-                                 Integer.toString(atomNum++));
+                                 Integer.toString(atomNumbering.nextId()));
             }
         } else if (annotateAtomVal) {
             for (IAtom atom : molecule.atoms()) {
@@ -660,12 +726,11 @@ public final class DepictionGenerator {
         return grp;
     }
 
-    private List<Bounds> generate(List<IAtomContainer> mols, RendererModel model, int atomNum) throws CDKException {
+      private List<Bounds> generate(List<IAtomContainer> mols, RendererModel model, AtomNumbering atomNumbering) throws CDKException {
         List<Bounds> elems = new ArrayList<>();
         int num = 0;
         for (IAtomContainer mol : mols) {
-            elems.add(new Bounds(generate(mol, model, atomNum)));
-            atomNum += mol.getAtomCount();
+            elems.add(new Bounds(generate(mol, model, atomNumbering)));
         }
         return elems;
     }
@@ -682,15 +747,17 @@ public final class DepictionGenerator {
         if (title == null || title.isEmpty())
             return new Bounds();
         scale = 1 / scale * getParameterValue(RendererModel.TitleFontScale.class);
+        String refId = chemObj.getProperty(MarkedElement.ID_KEY);
+        String classStr = refId != null ? ("title " + refId) : "title";
         return new Bounds(MarkedElement.markup(StandardGenerator.embedText(font, title, getParameterValue(RendererModel.TitleColor.class), scale),
-                                               "title"));
+                                               classStr));
     }
 
     private Bounds generateReactionConditions(IReaction chemObj, Color fg, double scale) {
         String title = chemObj.getProperty(CDKConstants.REACTION_CONDITIONS);
         if (title == null || title.isEmpty())
             return new Bounds();
-        return new Bounds(MarkedElement.markup(StandardGenerator.embedText(font, title, fg, 1/scale),
+        return new Bounds(MarkedElement.markup(StandardGenerator.embedText(font, title, fg, 1 / scale),
                                                "conditions"));
     }
 
@@ -797,7 +864,7 @@ public final class DepictionGenerator {
      * Display atom numbers on the molecule or reaction. The numbers are based on the
      * ordering of atoms in the molecule data structure and not a systematic system
      * such as IUPAC numbering.
-     * 
+     * <p>
      * Note: A depiction can not have both atom numbers and atom maps visible
      * (but this can be achieved by manually setting the annotation).
      *
@@ -814,12 +881,12 @@ public final class DepictionGenerator {
     }
 
     /**
-     * Display atom values on the molecule or reaction. The values need to be assigned by 
-     * 
+     * Display atom values on the molecule or reaction. The values need to be assigned by
+     *
      * <pre>{@code
      * atom.setProperty(CDKConstants.COMMENT, myValueToBeDisplayedNextToAtom);
      * }</pre>
-     *
+     * <p>
      * Note: A depiction can not have both atom numbers and atom maps visible
      * (but this can be achieved by manually setting the annotation).
      *
@@ -838,7 +905,7 @@ public final class DepictionGenerator {
     /**
      * Display atom-atom mapping numbers on a reaction. Each atom map index
      * is loaded from the property {@link CDKConstants#ATOM_ATOM_MAPPING}.
-     * 
+     * <p>
      * Note: A depiction can not have both atom numbers and atom
      * maps visible (but this can be achieved by manually setting
      * the annotation).
@@ -1003,7 +1070,7 @@ public final class DepictionGenerator {
     /**
      * Highlight the provided set of atoms and bonds in the depiction in the
      * specified color.
-     * 
+     * <p>
      * Calling this methods appends to the current highlight buffer. The buffer
      * is cleared after each depiction is generated (e.g. {@link #depict(IAtomContainer)}).
      *
@@ -1020,8 +1087,7 @@ public final class DepictionGenerator {
                     copy.highlight.put(atom, color);
                 for (IBond bond : ((IAtomContainer) chemObj).bonds())
                     copy.highlight.put(bond, color);
-            }
-            else copy.highlight.put(chemObj, color);
+            } else copy.highlight.put(chemObj, color);
         }
         return copy;
     }
@@ -1030,8 +1096,8 @@ public final class DepictionGenerator {
      * Specify a desired size of depiction. The units depend on the output format with
      * raster images using pixels and vector graphics using millimeters. By default depictions
      * are only ever made smaller if you would also like to make depictions fill all available
-     * space use the {@link #withFillToFit()} option. 
-     * 
+     * space use the {@link #withFillToFit()} option.
+     * <p>
      * Currently the size must either both be precisely specified (e.g. 256x256) or
      * automatic (e.g. {@link #AUTOMATIC}x{@link #AUTOMATIC}) you cannot for example
      * specify a fixed height and automatic width.
@@ -1081,7 +1147,7 @@ public final class DepictionGenerator {
      * depiction and is used for uniformly making depictions bigger. If
      * you would like to simply fill all available space (not recommended)
      * use {@link #withFillToFit()}.
-     * 
+     * <p>
      * The zoom is a scaling factor, specifying a zoom of 2 is double size,
      * 0.5 half size, etc.
      *
@@ -1129,6 +1195,7 @@ public final class DepictionGenerator {
 
     /**
      * Indicate whether <sup>2</sup>H should be rendered as 'D'. Default: true.
+     *
      * @param v the value
      * @return new generator for method chaining
      */
@@ -1163,14 +1230,7 @@ public final class DepictionGenerator {
     }
 
     private double caclModelScale(IReaction rxn) {
-        List<IAtomContainer> mols = new ArrayList<>();
-        for (IAtomContainer mol : rxn.getReactants().atomContainers())
-            mols.add(mol);
-        for (IAtomContainer mol : rxn.getProducts().atomContainers())
-            mols.add(mol);
-        for (IAtomContainer mol : rxn.getAgents().atomContainers())
-            mols.add(mol);
-        return caclModelScale(mols);
+        return caclModelScale(ReactionManipulator.getAllAtomContainers(rxn));
     }
 
     private double medianBondLength(Collection<IBond> bonds) {
@@ -1198,11 +1258,11 @@ public final class DepictionGenerator {
         return Font.SANS_SERIF;
     }
 
-  /**
-   * Utility class for storing coordinates and bond types and resetting them after use.
-   */
-  private static final class LayoutBackup {
-        private final Point2d[]      coords;
+    /**
+     * Utility class for storing coordinates and bond types and resetting them after use.
+     */
+    private static final class LayoutBackup {
+        private final Point2d[] coords;
         private final IBond.Stereo[] btypes;
         private final IAtomContainer mol;
 
