@@ -26,8 +26,10 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 /**
  * Determines the EState atom types.
@@ -62,7 +64,7 @@ public class EStateAtomTypeMatcher implements IAtomTypeMatcher {
 
         IAtomType atomType = null;
         try {
-            String fragment = "";
+            String fragment;
             int NumHAtoms = atom.getImplicitHydrogenCount() != null ?
                             atom.getImplicitHydrogenCount() : 0;
             int NumSingleBonds2 = NumHAtoms;
@@ -76,9 +78,9 @@ public class EStateAtomTypeMatcher implements IAtomTypeMatcher {
             List<IAtom> attachedAtoms = atomContainer.getConnectedAtomsList(atom);
 
             for (int j = 0; j <= attachedAtoms.size() - 1; j++) {
-                IAtom attached = (IAtom) attachedAtoms.get(j);
+                IAtom attached = attachedAtoms.get(j);
                 IBond b = atomContainer.getBond(atom, attached);
-                if ("H".equals(attached.getSymbol())) NumHAtoms++;
+                if (attached.getAtomicNumber() == IElement.H) NumHAtoms++;
 
                 if (atom.getFlag(CDKConstants.ISAROMATIC) && attached.getFlag(CDKConstants.ISAROMATIC)) {
 
@@ -142,7 +144,8 @@ public class EStateAtomTypeMatcher implements IAtomTypeMatcher {
             if (atom.getFlag(CDKConstants.ISAROMATIC)) atomType.setFlag(CDKConstants.ISAROMATIC, true);
 
         } catch (Exception e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(EStateAtomTypeMatcher.class)
+                              .warn("Unexpected Exception:", e);
         }
 
         return atomType;
