@@ -28,6 +28,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.NoSuchElementException;
 import java.util.Set;
 
 import org.openscience.cdk.exception.NoSuchAtomException;
@@ -99,7 +100,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      * Amount by which the bond and atom arrays grow when elements are added and
      * the arrays are not large enough for that.
      */
-    protected int growArraySize = 10;
+    protected final int growArraySize = 10;
 
     /**
      * Internal array of atoms.
@@ -150,7 +151,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         this.lonePairs = new ILonePair[this.lonePairCount];
         this.singleElectrons = new ISingleElectron[this.singleElectronCount];
 
-        stereoElements = new HashSet<IStereoElement>(atomCount / 2);
+        stereoElements = new HashSet<>(atomCount / 2);
 
         for (IStereoElement element : container.stereoElements()) {
             addStereoElement(element);
@@ -194,7 +195,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         bonds = new IBond[bondCount];
         lonePairs = new ILonePair[lpCount];
         singleElectrons = new ISingleElectron[seCount];
-        stereoElements = new HashSet<IStereoElement>(atomCount / 2);
+        stereoElements = new HashSet<>(atomCount / 2);
     }
 
     /**
@@ -210,7 +211,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public void setStereoElements(List<IStereoElement> elements) {
-        this.stereoElements = new HashSet<IStereoElement>();
+        this.stereoElements = new HashSet<>();
         this.stereoElements.addAll(elements);
     }
 
@@ -222,6 +223,71 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         return Collections.unmodifiableSet(stereoElements);
     }
 
+    private boolean isStale(IAtom atom) {
+        return indexOf(atom) < 0;
+    }
+
+    private boolean isStale(IBond bond) {
+        return indexOf(bond) < 0 ||
+                indexOf(bond.getBegin()) < 0 ||
+                indexOf(bond.getEnd()) < 0;
+    }
+
+    // helper for atom or bond
+    private boolean isStale(IChemObject cobj) {
+        if (cobj instanceof IAtom)
+            return isStale((IAtom)cobj);
+        else if (cobj instanceof IBond)
+            return isStale((IBond)cobj);
+        else return true;
+    }
+
+    // stereo is valid if all atoms/bonds are valid
+    private boolean isStale(IStereoElement<?,?> se) {
+        if (isStale(se.getFocus()))
+            return true;
+        for (IChemObject a : se.getCarriers())
+            if (isStale(a))
+                return true;
+        return false;
+    }
+
+    // Sgroup is valid if all atoms/bonds are valid
+    private boolean isStale(Sgroup sgroup) {
+        for (IAtom a : sgroup.getAtoms())
+            if (indexOf(a) < 0)
+                return true;
+        for (IBond b : sgroup.getBonds())
+            if (isStale(b))
+                return true;
+        return false;
+    }
+
+    private void validateStereoAndSgroups() {
+        // remove any Stereochemistry and Sgroups which now have "stale" atoms
+        if (!stereoElements.isEmpty()) {
+            List<IStereoElement<?, ?>> staleStereo = new ArrayList<>();
+            for (IStereoElement<?, ?> se : stereoElements) {
+                if (isStale(se))
+                    staleStereo.add(se);
+            }
+            stereoElements.removeAll(staleStereo);
+        }
+        List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups != null) {
+            List<Sgroup> staleSgroups = new ArrayList<>();
+            for (Sgroup sgroup : sgroups) {
+                if (isStale(sgroup))
+                    staleSgroups.add(sgroup);
+            }
+            if (!staleSgroups.isEmpty()) {
+                sgroups = new ArrayList<>(sgroups); // ensure mutable
+                sgroups.removeAll(staleSgroups);
+                setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
+            }
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -239,6 +305,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         if (newAtoms.length < this.atoms.length)
             Arrays.fill(atoms, newAtoms.length, this.atoms.length, null);
         this.atomCount = newAtoms.length;
+        validateStereoAndSgroups();
         notifyChanged();
     }
 
@@ -258,6 +325,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         if (newBonds.length < this.bonds.length)
             Arrays.fill(bonds, newBonds.length, this.bonds.length, null);
         this.bondCount = newBonds.length;
+        validateStereoAndSgroups();
     }
 
     /**
@@ -312,6 +380,17 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
             stereoElements.addAll(newStereo);
         }
 
+        // update Sgroups
+        List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups != null) {
+            for (Sgroup sgroup : sgroups) {
+                if (sgroup.getAtoms().contains(oldAtom)) {
+                    sgroup.removeAtom(oldAtom);
+                    sgroup.addAtom(atom);
+                }
+            }
+        }
+
         notifyChanged();
     }
 
@@ -360,13 +439,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public Iterable<IAtom> atoms() {
-        return new Iterable<IAtom>() {
-
-            @Override
-            public Iterator<IAtom> iterator() {
-                return new AtomIterator();
-            }
-        };
+        return AtomIterator::new;
     }
 
     /**
@@ -374,13 +447,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public Iterable<IBond> bonds() {
-        return new Iterable<IBond>() {
-
-            @Override
-            public Iterator<IBond> iterator() {
-                return new BondIterator();
-            }
-        };
+        return BondIterator::new;
     }
 
     /**
@@ -388,13 +455,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public Iterable<ILonePair> lonePairs() {
-        return new Iterable<ILonePair>() {
-
-            @Override
-            public Iterator<ILonePair> iterator() {
-                return new LonePairIterator();
-            }
-        };
+        return LonePairIterator::new;
     }
 
     /**
@@ -402,13 +463,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public Iterable<ISingleElectron> singleElectrons() {
-        return new Iterable<ISingleElectron>() {
-
-            @Override
-            public Iterator<ISingleElectron> iterator() {
-                return new SingleElectronIterator();
-            }
-        };
+        return SingleElectronIterator::new;
     }
 
     /**
@@ -416,13 +471,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public Iterable<IElectronContainer> electronContainers() {
-        return new Iterable<IElectronContainer>() {
-
-            @Override
-            public Iterator<IElectronContainer> iterator() {
-                return new ElectronContainerIterator();
-            }
-        };
+        return ElectronContainerIterator::new;
     }
 
     /**
@@ -438,7 +487,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public IAtom getLastAtom() {
-        return getAtomCount() > 0 ? (IAtom) atoms[getAtomCount() - 1] : null;
+        return getAtomCount() > 0 ? atoms[getAtomCount() - 1] : null;
     }
 
     /**
@@ -1098,11 +1147,29 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
                     --i;
                 }
             }
-            List<IStereoElement> atomElements = new ArrayList<IStereoElement>(3);
-            for (IStereoElement element : stereoElements) {
-                if (element.contains(atom)) atomElements.add(element);
+
+            // consider any stereochemistry involving this atom is now invalid
+            List<IStereoElement<?,?>> stereoToRemove = new ArrayList<>();
+            for (IStereoElement<?,?> element : stereoElements) {
+                if (element.contains(atom)) stereoToRemove.add(element);
             }
-            stereoElements.removeAll(atomElements);
+            stereoElements.removeAll(stereoToRemove);
+
+            // consider any sgroups involving this atom is now invalid
+            List<Sgroup> sgroups = getProperty(CDKConstants.CTAB_SGROUPS);
+            if (sgroups != null) {
+                List<Sgroup> sgrpToRemove = new ArrayList<>();
+                for (Sgroup sgroup : sgroups) {
+                    if (sgroup.getAtoms().contains(atom))
+                        sgrpToRemove.add(sgroup);
+                }
+                if (!sgrpToRemove.isEmpty()) {
+                    sgroups = new ArrayList<>(sgroups); // ensure mutable
+                    sgroups.removeAll(sgrpToRemove);
+                    setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
+                }
+            }
+
             removeAtomOnly(position);
         }
         notifyChanged();
@@ -1278,7 +1345,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
      */
     @Override
     public String toString() {
-        StringBuffer stringContent = new StringBuffer(64);
+        StringBuilder stringContent = new StringBuilder(64);
         stringContent.append("AtomContainer(");
         stringContent.append(this.hashCode());
         if (getAtomCount() > 0) {
@@ -1329,23 +1396,23 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
 
         // remove existing elements - we need to set the stereo elements list as list.clone() doesn't
         // work as expected and will also remove all elements from the original
-        clone.setStereoElements(new ArrayList<IStereoElement>(stereoElements.size()));
+        clone.setStereoElements(new ArrayList<>(stereoElements.size()));
         clone.removeAllElements();
 
         // create a mapping of the original atoms/bonds to the cloned atoms/bonds
         // we need this mapping to correctly clone bonds, single/paired electrons
         // and stereo elements
         // - the expected size stop the map be resized - method from Google Guava
-        Map<IAtom, IAtom> atomMap = new HashMap<IAtom, IAtom>(atomCount >= 3 ? atomCount + atomCount / 3
-                                                                             : atomCount + 1);
-        Map<IBond, IBond> bondMap = new HashMap<IBond, IBond>(bondCount >= 3 ? bondCount + bondCount / 3
-                                                                             : bondCount + 1);
+        Map<IAtom, IAtom> atomMap = new HashMap<>(atomCount >= 3 ? atomCount + atomCount / 3
+                : atomCount + 1);
+        Map<IBond, IBond> bondMap = new HashMap<>(bondCount >= 3 ? bondCount + bondCount / 3
+                : bondCount + 1);
 
         // clone atoms
         IAtom[] atoms = new IAtom[this.atomCount];
         for (int i = 0; i < atoms.length; i++) {
 
-            atoms[i] = (IAtom) this.atoms[i].clone();
+            atoms[i] = this.atoms[i].clone();
             atomMap.put(this.atoms[i], atoms[i]);
         }
         clone.setAtoms(atoms);
@@ -1355,7 +1422,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
         for (int i = 0; i < bonds.length; i++) {
 
             IBond   original = this.bonds[i];
-            IBond   bond     = (IBond) original.clone();
+            IBond   bond     = original.clone();
             int     n        = bond.getAtomCount();
             IAtom[] members  = new IAtom[n];
 
@@ -1523,6 +1590,8 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
 
         @Override
         public IAtom next() {
+            if (pointer >= atomCount)
+                throw new NoSuchElementException();
             return atoms[pointer++];
         }
 
@@ -1547,6 +1616,8 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
 
         @Override
         public IBond next() {
+            if (pointer >= bondCount)
+                throw new NoSuchElementException();
             return bonds[pointer++];
         }
 
@@ -1571,6 +1642,8 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
 
         @Override
         public ILonePair next() {
+            if (pointer >= lonePairCount)
+                throw new NoSuchElementException();
             return lonePairs[pointer++];
         }
 
@@ -1595,6 +1668,8 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
 
         @Override
         public ISingleElectron next() {
+            if (pointer >= singleElectronCount)
+                throw new NoSuchElementException();
             return singleElectrons[pointer++];
         }
 
@@ -1625,7 +1700,7 @@ public class AtomContainer extends ChemObject implements IAtomContainer, IChemOb
                 return lonePairs[(pointer++) - bondCount];
             else if (pointer < bondCount + lonePairCount + singleElectronCount)
                 return singleElectrons[(pointer++) - bondCount - lonePairCount];
-            return null;
+            throw new NoSuchElementException();
         }
 
         @Override
