@@ -27,6 +27,7 @@ import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 import java.io.Serializable;
 import java.util.Iterator;
+import java.util.NoSuchElementException;
 
 /**
  * Implements the concept of a covalent bond between two or more atoms. A bond is
@@ -69,12 +70,12 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
     /**
      * Number of atoms contained by this object.
      */
-    protected int             atomCount        = 0;
+    protected int             atomCount;
 
     /**
      * A list of atoms participating in this bond.
      */
-    protected IAtom[]         atoms            = null;
+    protected IAtom[]         atoms;
 
     /**
      * A descriptor the stereochemical orientation of this bond.
@@ -164,13 +165,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
      */
     @Override
     public Iterable<IAtom> atoms() {
-        return new Iterable<IAtom>() {
-
-            @Override
-            public Iterator<IAtom> iterator() {
-                return new AtomsIterator();
-            }
-        };
+        return AtomsIterator::new;
     }
 
     /**
@@ -203,6 +198,8 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
 
         @Override
         public IAtom next() {
+            if (pointer >= atomCount)
+                throw new NoSuchElementException();
             ++pointer;
             return atoms[pointer - 1];
         }
@@ -564,7 +561,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
             clone.atoms = new IAtom[atoms.length];
             for (int f = 0; f < atoms.length; f++) {
                 if (atoms[f] != null) {
-                    clone.atoms[f] = (IAtom) ((IAtom) atoms[f]).clone();
+                    clone.atoms[f] = atoms[f].clone();
                 }
             }
         }
@@ -597,7 +594,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
      */
     @Override
     public String toString() {
-        StringBuffer resultString = new StringBuffer(32);
+        StringBuilder resultString = new StringBuilder(32);
         resultString.append("Bond(").append(this.hashCode());
         if (getOrder() != null) {
             resultString.append(", #O:").append(getOrder());
