@@ -18,13 +18,12 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.test.interfaces.AbstractElementTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 import static org.hamcrest.CoreMatchers.is;
 
@@ -35,83 +34,77 @@ import static org.hamcrest.CoreMatchers.is;
  *
  * @see org.openscience.cdk.Element
  */
-public class ElementTest extends AbstractElementTest {
+class ElementTest extends AbstractElementTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new Element();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(Element::new);
     }
 
     // test constructors
 
     @Test
-    public void testElement() {
+    void testElement() {
         IElement e = new Element();
-        Assert.assertTrue(e instanceof IChemObject);
+        Assertions.assertTrue(e instanceof IChemObject);
     }
 
     @Test
-    public void testElement_IElement() {
+    void testElement_IElement() {
         IElement element = new Element();
         IElement e = new Element(element);
-        Assert.assertTrue(e instanceof IChemObject);
+        Assertions.assertTrue(e instanceof IChemObject);
     }
 
     @Test
-    public void testElement_String() {
+    void testElement_String() {
         IElement e = new Element("C");
-        Assert.assertEquals("C", e.getSymbol());
+        Assertions.assertEquals("C", e.getSymbol());
     }
 
     @Test
-    public void testElement_X() {
+    void testElement_X() {
         IElement e = new Element("X");
-        Assert.assertEquals("R", e.getSymbol());
+        Assertions.assertEquals("R", e.getSymbol());
         // and it should not throw exceptions
-        Assert.assertNotNull(e.getAtomicNumber());
+        Assertions.assertNotNull(e.getAtomicNumber());
         org.hamcrest.MatcherAssert.assertThat(e.getAtomicNumber(), is(0));
     }
 
     @Test
-    public void testElement_String_Integer() {
+    void testElement_String_Integer() {
         IElement e = new Element("H", 1);
-        Assert.assertEquals("H", e.getSymbol());
-        Assert.assertEquals(1, e.getAtomicNumber().intValue());
+        Assertions.assertEquals("H", e.getSymbol());
+        Assertions.assertEquals(1, e.getAtomicNumber().intValue());
     }
 
     @Test
-    public void compareSymbol() {
-        Element e1 = new Element(new String("H"), 1);
-        Element e2 = new Element(new String("H"), 1);
-        Assert.assertTrue(e1.compare(e2));
+    void compareSymbol() {
+        Element e1 = new Element("H", 1);
+        Element e2 = new Element("H", 1);
+        Assertions.assertTrue(e1.compare(e2));
     }
 
     @Test
-    public void compareAtomicNumber() {
-        Element e1 = new Element("H", new Integer(1));
-        Element e2 = new Element("H", new Integer(1));
-        Assert.assertTrue(e1.compare(e2));
+    void compareAtomicNumber() {
+        Element e1 = new Element("H", 1);
+        Element e2 = new Element("H", 1);
+        Assertions.assertTrue(e1.compare(e2));
     }
 
     @Test
-    public void compareDiffSymbol() {
-        Element e1 = new Element(new String("H"), 1);
-        Element e2 = new Element(new String("C"), 12);
-        Assert.assertFalse(e1.compare(e2));
+    void compareDiffSymbol() {
+        Element e1 = new Element("H", 1);
+        Element e2 = new Element("C", 12);
+        Assertions.assertFalse(e1.compare(e2));
     }
 
     @Test
-    public void compareDiffAtomicNumber() {
+    void compareDiffAtomicNumber() {
         Element e1 = new Element();
         Element e2 = new Element();
         e1.setAtomicNumber(1);
         e1.setAtomicNumber(2);
-        Assert.assertFalse(e1.compare(e2));
+        Assertions.assertFalse(e1.compare(e2));
     }
 }
