@@ -19,13 +19,11 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.openscience.cdk.interfaces.IChemObject;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IReactionScheme;
 import org.openscience.cdk.test.interfaces.AbstractReactionSchemeTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the MolecularFormulaSet class.
@@ -34,17 +32,11 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @see ReactionScheme
  */
-public class ReactionSchemeTest extends AbstractReactionSchemeTest {
+class ReactionSchemeTest extends AbstractReactionSchemeTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new ReactionScheme();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(ReactionScheme::new);
     }
 
     /**
@@ -53,9 +45,9 @@ public class ReactionSchemeTest extends AbstractReactionSchemeTest {
      *
      */
     @Test
-    public void testReactionScheme() {
+    void testReactionScheme() {
         IReactionScheme scheme = new ReactionScheme();
-        Assert.assertNotNull(scheme);
+        Assertions.assertNotNull(scheme);
     }
 
 }
