@@ -19,13 +19,11 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.openscience.cdk.interfaces.IChemObject;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.test.interfaces.AbstractReactionSetTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the ReactionSet class.
@@ -34,23 +32,17 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @see org.openscience.cdk.ReactionSet
  */
-public class ReactionSetTest extends AbstractReactionSetTest {
+class ReactionSetTest extends AbstractReactionSetTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new ReactionSet();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(ReactionSet::new);
     }
 
     @Test
-    public void testReactionSet() {
+    void testReactionSet() {
         IReactionSet reactionSet = new ReactionSet();
-        Assert.assertNotNull(reactionSet);
+        Assertions.assertNotNull(reactionSet);
     }
 
 }
