@@ -19,15 +19,13 @@
  */
 package org.openscience.cdk;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractRingTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
-import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IRing;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the Ring class.
@@ -36,51 +34,45 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @see org.openscience.cdk.Ring
  */
-public class RingTest extends AbstractRingTest {
+class RingTest extends AbstractRingTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new Ring();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(Ring::new);
     }
 
     @Test
-    public void testRing_int_String() {
+    void testRing_int_String() {
         IRing r = new Ring(5, "C");
-        Assert.assertEquals(5, r.getAtomCount());
-        Assert.assertEquals(5, r.getBondCount());
+        Assertions.assertEquals(5, r.getAtomCount());
+        Assertions.assertEquals(5, r.getBondCount());
     }
 
     @Test
-    public void testRing_int() {
+    void testRing_int() {
         IRing r = new Ring(5); // This does not create a ring!
-        Assert.assertEquals(0, r.getAtomCount());
-        Assert.assertEquals(0, r.getBondCount());
+        Assertions.assertEquals(0, r.getAtomCount());
+        Assertions.assertEquals(0, r.getBondCount());
     }
 
     @Test
-    public void testRing() {
+    void testRing() {
         IRing ring = new Ring();
-        Assert.assertNotNull(ring);
-        Assert.assertEquals(0, ring.getAtomCount());
-        Assert.assertEquals(0, ring.getBondCount());
+        Assertions.assertNotNull(ring);
+        Assertions.assertEquals(0, ring.getAtomCount());
+        Assertions.assertEquals(0, ring.getBondCount());
     }
 
     @Test
-    public void testRing_IAtomContainer() {
+    void testRing_IAtomContainer() {
         IAtomContainer container = new org.openscience.cdk.AtomContainer();
         container.addAtom(container.getBuilder().newInstance(IAtom.class, "C"));
         container.addAtom(container.getBuilder().newInstance(IAtom.class, "C"));
 
         IRing ring = new Ring(container);
-        Assert.assertNotNull(ring);
-        Assert.assertEquals(2, ring.getAtomCount());
-        Assert.assertEquals(0, ring.getBondCount());
+        Assertions.assertNotNull(ring);
+        Assertions.assertEquals(2, ring.getAtomCount());
+        Assertions.assertEquals(0, ring.getBondCount());
     }
 
 }
