@@ -18,27 +18,19 @@
  */
 package org.openscience.cdk;
 
-import org.junit.BeforeClass;
+import org.junit.jupiter.api.BeforeAll;
 import org.openscience.cdk.test.interfaces.AbstractSubstanceTest;
-import org.openscience.cdk.interfaces.IChemObject;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the {@link Substance} class.
  *
  * @cdk.module test-data
  */
-public class SubstanceTest extends AbstractSubstanceTest {
+class SubstanceTest extends AbstractSubstanceTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new Substance();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(Substance::new);
     }
 
 }
