@@ -18,9 +18,9 @@
  */
 package org.openscience.cdk.event;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
 
@@ -31,14 +31,14 @@ import org.openscience.cdk.test.CDKTestCase;
  *
  * @see org.openscience.cdk.event.ChemObjectChangeEvent
  */
-public class ChemObjectChangeEventTest extends CDKTestCase {
+class ChemObjectChangeEventTest extends CDKTestCase {
 
-    @BeforeClass
-    public static void setUp() {}
+    @BeforeAll
+    static void setUp() {}
 
     @Test
-    public void testChemObjectChangeEvent_Object() {
+    void testChemObjectChangeEvent_Object() {
         ChemObjectChangeEvent event = new ChemObjectChangeEvent(new Atom());
-        Assert.assertNotNull(event);
+        Assertions.assertNotNull(event);
     }
 }
