@@ -19,9 +19,9 @@
  */
 package org.openscience.cdk.debug;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractAtomTypeTest;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IChemObject;
@@ -33,10 +33,10 @@ import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
  *
  * @cdk.module test-datadebug
  */
-public class DebugAtomTypeTest extends AbstractAtomTypeTest {
+class DebugAtomTypeTest extends AbstractAtomTypeTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setTestObjectBuilder(new ITestObjectBuilder() {
 
             @Override
@@ -47,58 +47,58 @@ public class DebugAtomTypeTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testDebugAtomType_String() {
+    void testDebugAtomType_String() {
         IAtomType at = new DebugAtomType("C");
-        Assert.assertEquals("C", at.getSymbol());
+        Assertions.assertEquals("C", at.getSymbol());
     }
 
     @Test
-    public void testDebugAtomType_IElement() {
+    void testDebugAtomType_IElement() {
         IElement element = new DebugElement("C");
         IAtomType at = element.getBuilder().newInstance(IAtomType.class, element);
-        Assert.assertEquals("C", at.getSymbol());
+        Assertions.assertEquals("C", at.getSymbol());
     }
 
     @Test
-    public void testDebugAtomType_String_String() {
+    void testDebugAtomType_String_String() {
         IAtomType at = new DebugAtomType("C4", "C");
-        Assert.assertEquals("C", at.getSymbol());
-        Assert.assertEquals("C4", at.getAtomTypeName());
+        Assertions.assertEquals("C", at.getSymbol());
+        Assertions.assertEquals("C4", at.getAtomTypeName());
     }
 
     @Test
-    public void testCompare_AtomTypeName() {
+    void testCompare_AtomTypeName() {
         DebugAtomType at1 = new DebugAtomType("C");
         DebugAtomType at2 = new DebugAtomType("C");
-        at1.setAtomTypeName(new String("C4"));
-        at2.setAtomTypeName(new String("C4"));
-        Assert.assertTrue(at1.compare(at2));
+        at1.setAtomTypeName("C4");
+        at2.setAtomTypeName("C4");
+        Assertions.assertTrue(at1.compare(at2));
     }
 
     @Test
-    public void testCompare_DiffAtomTypeName() {
+    void testCompare_DiffAtomTypeName() {
         DebugAtomType at1 = new DebugAtomType("C");
         DebugAtomType at2 = new DebugAtomType("C");
-        at1.setAtomTypeName(new String("C4"));
-        at2.setAtomTypeName(new String("C3"));
-        Assert.assertFalse(at1.compare(at2));
+        at1.setAtomTypeName("C4");
+        at2.setAtomTypeName("C3");
+        Assertions.assertFalse(at1.compare(at2));
     }
 
     @Test
-    public void testCompare_BondOrderSum() {
+    void testCompare_BondOrderSum() {
         DebugAtomType at1 = new DebugAtomType("C");
         DebugAtomType at2 = new DebugAtomType("C");
         at1.setBondOrderSum(1.5);
         at2.setBondOrderSum(1.5);
-        Assert.assertTrue(at1.compare(at2));
+        Assertions.assertTrue(at1.compare(at2));
     }
 
     @Test
-    public void testCompare_DiffBondOrderSum() {
+    void testCompare_DiffBondOrderSum() {
         DebugAtomType at1 = new DebugAtomType("C");
         DebugAtomType at2 = new DebugAtomType("C");
         at1.setBondOrderSum(1.5);
         at2.setBondOrderSum(2.0);
-        Assert.assertFalse(at1.compare(at2));
+        Assertions.assertFalse(at1.compare(at2));
     }
 }
