@@ -19,45 +19,38 @@
  */
 package org.openscience.cdk.debug;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractBondTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObject;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the {@link DebugBond}.
  *
  * @cdk.module test-datadebug
  */
-public class DebugBondTest extends AbstractBondTest {
+class DebugBondTest extends AbstractBondTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new DebugBond();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(DebugBond::new);
     }
 
     @Test
-    public void testDebugBond() {
+    void testDebugBond() {
         IBond bond = new DebugBond();
-        Assert.assertEquals(0, bond.getAtomCount());
-        Assert.assertNull(bond.getBegin());
-        Assert.assertNull(bond.getEnd());
-        Assert.assertNull(bond.getOrder());
-        Assert.assertEquals(IBond.Stereo.NONE, bond.getStereo());
+        Assertions.assertEquals(0, bond.getAtomCount());
+        Assertions.assertNull(bond.getBegin());
+        Assertions.assertNull(bond.getEnd());
+        Assertions.assertNull(bond.getOrder());
+        Assertions.assertEquals(IBond.Stereo.NONE, bond.getStereo());
     }
 
     @Test
-    public void testDebugBond_arrayIAtom() {
+    void testDebugBond_arrayIAtom() {
         IChemObject object = newChemObject();
         IAtom atom1 = object.getBuilder().newInstance(IAtom.class, "C");
         IAtom atom2 = object.getBuilder().newInstance(IAtom.class, "O");
@@ -66,13 +59,13 @@ public class DebugBondTest extends AbstractBondTest {
         IAtom atom5 = object.getBuilder().newInstance(IAtom.class, "C");
 
         IBond bond1 = new DebugBond(new IAtom[]{atom1, atom2, atom3, atom4, atom5});
-        Assert.assertEquals(5, bond1.getAtomCount());
-        Assert.assertEquals(atom1, bond1.getBegin());
-        Assert.assertEquals(atom2, bond1.getEnd());
+        Assertions.assertEquals(5, bond1.getAtomCount());
+        Assertions.assertEquals(atom1, bond1.getBegin());
+        Assertions.assertEquals(atom2, bond1.getEnd());
     }
 
     @Test
-    public void testDebugBond_arrayIAtom_IBond_Order() {
+    void testDebugBond_arrayIAtom_IBond_Order() {
         IChemObject object = newChemObject();
         IAtom atom1 = object.getBuilder().newInstance(IAtom.class, "C");
         IAtom atom2 = object.getBuilder().newInstance(IAtom.class, "O");
@@ -81,51 +74,51 @@ public class DebugBondTest extends AbstractBondTest {
         IAtom atom5 = object.getBuilder().newInstance(IAtom.class, "C");
 
         IBond bond1 = new DebugBond(new IAtom[]{atom1, atom2, atom3, atom4, atom5}, IBond.Order.SINGLE);
-        Assert.assertEquals(5, bond1.getAtomCount());
-        Assert.assertEquals(atom1, bond1.getBegin());
-        Assert.assertEquals(atom2, bond1.getEnd());
-        Assert.assertEquals(IBond.Order.SINGLE, bond1.getOrder());
+        Assertions.assertEquals(5, bond1.getAtomCount());
+        Assertions.assertEquals(atom1, bond1.getBegin());
+        Assertions.assertEquals(atom2, bond1.getEnd());
+        Assertions.assertEquals(IBond.Order.SINGLE, bond1.getOrder());
     }
 
     @Test
-    public void testDebugBond_IAtom_IAtom() {
+    void testDebugBond_IAtom_IAtom() {
         IChemObject object = newChemObject();
         IAtom c = object.getBuilder().newInstance(IAtom.class, "C");
         IAtom o = object.getBuilder().newInstance(IAtom.class, "O");
         IBond bond = new DebugBond(c, o);
 
-        Assert.assertEquals(2, bond.getAtomCount());
-        Assert.assertEquals(c, bond.getBegin());
-        Assert.assertEquals(o, bond.getEnd());
-        Assert.assertEquals(IBond.Order.SINGLE, bond.getOrder());
-        Assert.assertEquals(IBond.Stereo.NONE, bond.getStereo());
+        Assertions.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(c, bond.getBegin());
+        Assertions.assertEquals(o, bond.getEnd());
+        Assertions.assertEquals(IBond.Order.SINGLE, bond.getOrder());
+        Assertions.assertEquals(IBond.Stereo.NONE, bond.getStereo());
     }
 
     @Test
-    public void testDebugBond_IAtom_IAtom_IBond_Order() {
+    void testDebugBond_IAtom_IAtom_IBond_Order() {
         IChemObject object = newChemObject();
         IAtom c = object.getBuilder().newInstance(IAtom.class, "C");
         IAtom o = object.getBuilder().newInstance(IAtom.class, "O");
         IBond bond = new DebugBond(c, o, IBond.Order.DOUBLE);
 
-        Assert.assertEquals(2, bond.getAtomCount());
-        Assert.assertEquals(c, bond.getBegin());
-        Assert.assertEquals(o, bond.getEnd());
-        Assert.assertTrue(bond.getOrder() == IBond.Order.DOUBLE);
-        Assert.assertEquals(IBond.Stereo.NONE, bond.getStereo());
+        Assertions.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(c, bond.getBegin());
+        Assertions.assertEquals(o, bond.getEnd());
+        Assertions.assertTrue(bond.getOrder() == IBond.Order.DOUBLE);
+        Assertions.assertEquals(IBond.Stereo.NONE, bond.getStereo());
     }
 
     @Test
-    public void testDebugBond_IAtom_IAtom_IBond_Order_IBond_Stereo() {
+    void testDebugBond_IAtom_IAtom_IBond_Order_IBond_Stereo() {
         IChemObject object = newChemObject();
         IAtom c = object.getBuilder().newInstance(IAtom.class, "C");
         IAtom o = object.getBuilder().newInstance(IAtom.class, "O");
         IBond bond = new DebugBond(c, o, IBond.Order.SINGLE, IBond.Stereo.UP);
 
-        Assert.assertEquals(2, bond.getAtomCount());
-        Assert.assertEquals(c, bond.getBegin());
-        Assert.assertEquals(o, bond.getEnd());
-        Assert.assertTrue(bond.getOrder() == IBond.Order.SINGLE);
-        Assert.assertEquals(IBond.Stereo.UP, bond.getStereo());
+        Assertions.assertEquals(2, bond.getAtomCount());
+        Assertions.assertEquals(c, bond.getBegin());
+        Assertions.assertEquals(o, bond.getEnd());
+        Assertions.assertTrue(bond.getOrder() == IBond.Order.SINGLE);
+        Assertions.assertEquals(IBond.Stereo.UP, bond.getStereo());
     }
 }
