@@ -35,6 +35,6 @@ public interface IReaderListener extends IChemObjectIOListener {
      *
      * @param event information about the event.
      */
-    public void frameRead(ReaderEvent event);
+    void frameRead(ReaderEvent event);
 
 }
