@@ -19,6 +19,7 @@
 package org.openscience.cdk.isomorphism.matchers;
 
 import java.util.Iterator;
+import java.util.NoSuchElementException;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -48,12 +49,12 @@ public class QueryBond extends QueryChemObject implements IQueryBond {
     /**
      * Number of atoms contained by this object.
      */
-    protected int               atomCount = 0;
+    protected int               atomCount;
 
     /**
      * A list of atoms participating in this query bond.
      */
-    protected IAtom[]           atoms     = null;
+    protected IAtom[]           atoms;
 
     /**
      * A descriptor the stereochemical orientation of this query bond.
@@ -197,13 +198,7 @@ public class QueryBond extends QueryChemObject implements IQueryBond {
      */
     @Override
     public Iterable<IAtom> atoms() {
-        return new Iterable<IAtom>() {
-
-            @Override
-            public Iterator<IAtom> iterator() {
-                return new AtomsIterator();
-            }
-        };
+        return AtomsIterator::new;
     }
 
     /**
@@ -236,6 +231,8 @@ public class QueryBond extends QueryChemObject implements IQueryBond {
 
         @Override
         public IAtom next() {
+            if (pointer >= atomCount)
+                throw new NoSuchElementException();
             ++pointer;
             return atoms[pointer - 1];
         }
@@ -518,7 +515,7 @@ public class QueryBond extends QueryChemObject implements IQueryBond {
             clone.atoms = new IAtom[atoms.length];
             for (int f = 0; f < atoms.length; f++) {
                 if (atoms[f] != null) {
-                    clone.atoms[f] = (IAtom) (atoms[f]).clone();
+                    clone.atoms[f] = (atoms[f]).clone();
                 }
             }
         }
@@ -532,7 +529,7 @@ public class QueryBond extends QueryChemObject implements IQueryBond {
      */
     @Override
     public String toString() {
-        StringBuffer resultString = new StringBuffer(32);
+        StringBuilder resultString = new StringBuilder(32);
         resultString.append("Bond(").append(this.hashCode());
         if (getOrder() != null) {
             resultString.append(", #O:").append(getOrder());
