@@ -202,35 +202,30 @@ public class RGroupList implements IRGroupList {
         StringTokenizer st = new StringTokenizer(occ, ",");
         while (st.hasMoreTokens()) {
             String cond = st.nextToken().trim().replaceAll(" ", "");
-            do {
-                //Number: "n"
-                if (match("^\\d+$", cond)) {
-                    if (Integer.valueOf(cond) < 0) // not allowed
-                        return false;
-                    break;
-                }
-                //Range: "n-m"
-                if (match("^\\d+-\\d+$", cond)) {
-                    int from = Integer.valueOf(cond.substring(0, cond.indexOf('-')));
-                    int to = Integer.valueOf(cond.substring(cond.indexOf('-') + 1, cond.length()));
-                    if (from < 0 || to < 0 || to < from) // not allowed
-                        return false;
-                    break;
-                }
-                //Smaller than: "<n"
-                if (match("^<\\d+$", cond)) {
-                    int n = Integer.valueOf(cond.substring(cond.indexOf('<') + 1, cond.length()));
-                    if (n == 0) // not allowed
-                        return false;
-                    break;
-                }
-                //Greater than: ">n"
-                if (match("^>\\d+$", cond)) {
-                    break;
-                }
-
+            //Number: "n"
+            if (match("^\\d+$", cond)) {
+                if (Integer.parseInt(cond) < 0) // not allowed
+                    return false;
+            }
+            //Range: "n-m"
+            else if (match("^\\d+-\\d+$", cond)) {
+                int from = Integer.parseInt(cond.substring(0, cond.indexOf('-')));
+                int to = Integer.parseInt(cond.substring(cond.indexOf('-') + 1));
+                if (from < 0 || to < 0 || to < from) // not allowed
+                    return false;
+            }
+            //Smaller than: "<n"
+            else if (match("^<\\d+$", cond)) {
+                int n = Integer.parseInt(cond.substring(cond.indexOf('<') + 1));
+                if (n == 0) // not allowed
+                    return false;
+            }
+            //Greater than: ">n"
+            else if (match("^>\\d+$", cond)) {
+                // no-op?
+            }
+            else
                 return false;
-            } while (1 == 0);
         }
 
         return true;
@@ -267,7 +262,7 @@ public class RGroupList implements IRGroupList {
     @Override
     public List<Integer> matchOccurence(int maxAttachments) {
 
-        List<Integer> validValues = new ArrayList<Integer>();
+        List<Integer> validValues = new ArrayList<>();
 
         for (int val = 0; val <= maxAttachments; val++) {
             boolean addVal = false;
@@ -276,23 +271,23 @@ public class RGroupList implements IRGroupList {
             while (st.hasMoreTokens() && !addVal) {
                 String cond = st.nextToken().trim().replaceAll(" ", "");
                 if (match("^\\d+$", cond)) { // n
-                    if (Integer.valueOf(cond) == val) addVal = true;
+                    if (Integer.parseInt(cond) == val) addVal = true;
                 }
                 if (match("^\\d+-\\d+$", cond)) { // n-m
-                    int from = Integer.valueOf(cond.substring(0, cond.indexOf('-')));
-                    int to = Integer.valueOf(cond.substring(cond.indexOf('-') + 1, cond.length()));
+                    int from = Integer.parseInt(cond.substring(0, cond.indexOf('-')));
+                    int to = Integer.parseInt(cond.substring(cond.indexOf('-') + 1, cond.length()));
                     if (val >= from && val <= to) {
                         addVal = true;
                     }
                 }
                 if (match("^>\\d+$", cond)) { // <n
-                    int n = Integer.valueOf(cond.substring(cond.indexOf('>') + 1, cond.length()));
+                    int n = Integer.parseInt(cond.substring(cond.indexOf('>') + 1, cond.length()));
                     if (val > n) {
                         addVal = true;
                     }
                 }
                 if (match("^<\\d+$", cond)) { // >n
-                    int n = Integer.valueOf(cond.substring(cond.indexOf('<') + 1, cond.length()));
+                    int n = Integer.parseInt(cond.substring(cond.indexOf('<') + 1, cond.length()));
                     if (val < n) {
                         addVal = true;
                     }
