@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.reaction;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.dict.Dictionary;
 import org.openscience.cdk.dict.DictionaryDatabase;
@@ -42,7 +42,6 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 
 import java.io.ByteArrayInputStream;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import static org.hamcrest.CoreMatchers.is;
@@ -59,7 +58,7 @@ public abstract class ReactionProcessTest extends CDKTestCase {
     private IReactionProcess   reaction;
     private Dictionary         dictionary;
     private String             entryString = "";
-    private IChemObjectBuilder builder     = SilentChemObjectBuilder.getInstance();
+    private final IChemObjectBuilder builder     = SilentChemObjectBuilder.getInstance();
 
     private static final SmilesGenerator smigen = new SmilesGenerator(SmiFlavor.Canonical |  SmiFlavor.CxRadical);
 
@@ -72,7 +71,7 @@ public abstract class ReactionProcessTest extends CDKTestCase {
         return smigen.create(AtomContainerManipulator.copyAndSuppressedHydrogens(mol));
     }
 
-    protected static String cansmi(IReaction rxn) throws CDKException {
+    static String cansmi(IReaction rxn) throws CDKException {
         IReaction copy = rxn.getBuilder().newInstance(IReaction.class);
         for (IAtomContainer mol : rxn.getReactants().atomContainers())
             copy.addReactant(AtomContainerManipulator.copyAndSuppressedHydrogens(mol));
@@ -101,10 +100,10 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @param reactionClass   The IReactionProcess class
      * @throws Exception
      */
-    public void setReaction(Class<?> reactionClass) throws Exception {
+    protected void setReaction(Class<?> reactionClass) throws Exception {
         if (dictionary == null) dictionary = openingDictionary();
 
-        Object object = (Object) reactionClass.newInstance();
+        Object object = reactionClass.newInstance();
         if (!(object instanceof IReactionProcess)) {
             throw new CDKException("The passed reaction class must be a IReactionProcess");
         } else if (reaction == null) {
@@ -141,8 +140,8 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * </pre>
      */
     @Test
-    public void testHasSetSuperDotDescriptor() {
-        Assert.assertNotNull("The extending class must set the super.descriptor in its setUp() method.", reaction);
+    void testHasSetSuperDotDescriptor() {
+        Assertions.assertNotNull(reaction, "The extending class must set the super.descriptor in its setUp() method.");
     }
 
     /**
@@ -151,12 +150,12 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetEntryFromReaction() throws Exception {
+    void testGetEntryFromReaction() throws Exception {
 
         entryString = reaction.getSpecification().getSpecificationReference();
         entryString = entryString.substring(entryString.indexOf("#") + 1, entryString.length());
 
-        Assert.assertNotSame("The Entry ID from  [" + reaction.getClass() + "] doesn't exist.", "nothing", entryString);
+        Assertions.assertNotSame("nothing", entryString, "The Entry ID from  [" + reaction.getClass() + "] doesn't exist.");
     }
 
     /**
@@ -165,10 +164,10 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetDictionaryEntry() throws Exception {
+    void testGetDictionaryEntry() throws Exception {
 
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
-        Assert.assertNotNull("The Entry [" + entryString + "] doesn't exist in OWL Dictionary.", entry);
+        Assertions.assertNotNull(entry, "The Entry [" + entryString + "] doesn't exist in OWL Dictionary.");
 
     }
 
@@ -178,11 +177,11 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetEntryDefinition() throws Exception {
+    void testGetEntryDefinition() throws Exception {
 
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
 
-        Assert.assertNotNull("The definition entry for [" + entryString + "] must not be null.", entry.getDefinition());
+        Assertions.assertNotNull(entry.getDefinition(), "The definition entry for [" + entryString + "] must not be null.");
 
     }
 
@@ -192,18 +191,16 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetParameterList() throws Exception {
+    void testGetParameterList() throws Exception {
         List<IParameterReact> paramObj = reaction.getParameterList();
 
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
         List<List<String>> paramDic = entry.getParameterClass();
 
-        Assert.assertNotNull("The parameters entry for [" + entryString + "]  must contain at least one parameter.",
-                paramObj);
-        Assert.assertNotNull("The parameters entry for [" + entryString + "]  must contain at least one parameter.",
-                paramDic);
-        Assert.assertSame("The parameters entry for [" + entryString
-                + "]  must contain the same lenght as the reaction object.", paramObj.size(), paramDic.size());
+        Assertions.assertNotNull(paramObj, "The parameters entry for [" + entryString + "]  must contain at least one parameter.");
+        Assertions.assertNotNull(paramDic, "The parameters entry for [" + entryString + "]  must contain at least one parameter.");
+        Assertions.assertSame(paramObj.size(), paramDic.size(), "The parameters entry for [" + entryString
+                + "]  must contain the same lenght as the reaction object.");
     }
 
     /**
@@ -211,23 +208,23 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetSpecification() {
+    void testGetSpecification() {
         ReactionSpecification spec = reaction.getSpecification();
-        Assert.assertNotNull("The descriptor specification returned must not be null.", spec);
+        Assertions.assertNotNull(spec, "The descriptor specification returned must not be null.");
 
-        Assert.assertNotNull("The specification identifier must not be null.", spec.getImplementationIdentifier());
-        Assert.assertNotSame("The specification identifier must not be empty.", 0, spec.getImplementationIdentifier()
-                .length());
+        Assertions.assertNotNull(spec.getImplementationIdentifier(), "The specification identifier must not be null.");
+        Assertions.assertNotSame(0, spec.getImplementationIdentifier()
+                                        .length(), "The specification identifier must not be empty.");
 
-        Assert.assertNotNull("The specification title must not be null.", spec.getImplementationTitle());
-        Assert.assertNotSame("The specification title must not be empty.", 0, spec.getImplementationTitle().length());
+        Assertions.assertNotNull(spec.getImplementationTitle(), "The specification title must not be null.");
+        Assertions.assertNotSame(0, spec.getImplementationTitle().length(), "The specification title must not be empty.");
 
-        Assert.assertNotNull("The specification vendor must not be null.", spec.getImplementationVendor());
-        Assert.assertNotSame("The specification vendor must not be empty.", 0, spec.getImplementationVendor().length());
+        Assertions.assertNotNull(spec.getImplementationVendor(), "The specification vendor must not be null.");
+        Assertions.assertNotSame(0, spec.getImplementationVendor().length(), "The specification vendor must not be empty.");
 
-        Assert.assertNotNull("The specification reference must not be null.", spec.getSpecificationReference());
-        Assert.assertNotSame("The specification reference must not be empty.", 0, spec.getSpecificationReference()
-                .length());
+        Assertions.assertNotNull(spec.getSpecificationReference(), "The specification reference must not be null.");
+        Assertions.assertNotSame(0, spec.getSpecificationReference()
+                                        .length(), "The specification reference must not be empty.");
     }
 
     /**
@@ -236,12 +233,11 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetEntryDescription() throws Exception {
+    void testGetEntryDescription() throws Exception {
 
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
 
-        Assert.assertNotNull("The description entry for [" + entryString + "] must not be null.",
-                entry.getDescription());
+        Assertions.assertNotNull(entry.getDescription(), "The description entry for [" + entryString + "] must not be null.");
     }
 
     /**
@@ -250,12 +246,12 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetEntryRepresentation() throws Exception {
+    void testGetEntryRepresentation() throws Exception {
 
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
 
-        Assert.assertNotSame("The representation entry for [" + entryString
-                + "]  must contain at least one representation.", 0, entry.getRepresentations().size());
+        Assertions.assertNotSame(0, entry.getRepresentations().size(), "The representation entry for [" + entryString
+                + "]  must contain at least one representation.");
     }
 
     /**
@@ -264,21 +260,21 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      *
      */
     @Test
-    public void testCentreActive() throws Exception {
+    void testCentreActive() throws Exception {
         IReactionProcess type = reaction;
 
         IParameterReact ipr = type.getParameterClass(SetReactionCenter.class);
-        Assert.assertNotNull(ipr);
-        Assert.assertFalse(ipr.isSetParameter());
+        Assertions.assertNotNull(ipr);
+        Assertions.assertFalse(ipr.isSetParameter());
 
-        List<IParameterReact> paramList = new ArrayList<IParameterReact>();
+        List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
         param.setParameter(Boolean.TRUE);
         paramList.add(param);
         type.setParameterList(paramList);
 
         IParameterReact ipr2 = type.getParameterClass(SetReactionCenter.class);
-        Assert.assertTrue(ipr2.isSetParameter());
+        Assertions.assertTrue(ipr2.isSetParameter());
     }
 
     /**
@@ -288,7 +284,7 @@ public abstract class ReactionProcessTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetExampleReaction() throws Exception {
+    void testGetExampleReaction() throws Exception {
         //		EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
         //    	List<String> xmlList = entry.getExampleReactions();
         //    	Assert.assertTrue("The representation entry for ["+entryString+"]  must contain at least one example of reaction.",
@@ -322,14 +318,13 @@ public abstract class ReactionProcessTest extends CDKTestCase {
     public void testInitiate_IAtomContainerSet_IAtomContainerSet() throws Exception {
         EntryReact entry = (EntryReact) dictionary.getEntry(entryString.toLowerCase());
         List<String> xmlList = entry.getExampleReactions();
-        Assert.assertTrue("The representation entry for [" + entryString
-                + "]  must contain at least one example of reaction.", xmlList.size() != 0);
-        Assert.assertTrue("The representation entry for [" + entryString
-                + "]  must contain at least one example of reaction.", xmlList.size() > 0);
-        for (Iterator<String> it = xmlList.iterator(); it.hasNext();) {
-            String xml = it.next();
+        Assertions.assertTrue(xmlList.size() != 0, "The representation entry for [" + entryString
+                + "]  must contain at least one example of reaction.");
+        Assertions.assertTrue(xmlList.size() > 0, "The representation entry for [" + entryString
+                + "]  must contain at least one example of reaction.");
+        for (String xml : xmlList) {
             CMLReader reader = new CMLReader(new ByteArrayInputStream(xml.getBytes()));
-            IChemFile chemFile = (IChemFile) reader.read(builder.newInstance(IChemFile.class));
+            IChemFile chemFile = reader.read(builder.newInstance(IChemFile.class));
             IReaction reactionDict = chemFile.getChemSequence(0).getChemModel(0).getReactionSet().getReaction(0);
 
             IAtomContainerSet reactants = reactionDict.getReactants();
@@ -339,12 +334,11 @@ public abstract class ReactionProcessTest extends CDKTestCase {
 
             IReactionSet reactions = reaction.initiate(reactants, agents);
 
-            Assert.assertTrue("The products for [" + entryString + "] reaction is at least one reaction expected.",
-                    reactions.getReactionCount() > 0);
+            Assertions.assertTrue(reactions.getReactionCount() > 0, "The products for [" + entryString + "] reaction is at least one reaction expected.");
 
-            Assert.assertSame("The products for [" + entryString + "] reaction is not the expected.", products
+            Assertions.assertSame(products
                     .getAtomContainer(0).getAtomCount(), reactions.getReaction(0).getProducts().getAtomContainer(0)
-                    .getAtomCount());
+                                                                  .getAtomCount(), "The products for [" + entryString + "] reaction is not the expected.");
 
         }
     }
