@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.reaction.type;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.atomtype.CDKAtomTypeMatcher;
@@ -29,12 +29,14 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IReactionSet;
 import org.openscience.cdk.reaction.IReactionProcess;
 import org.openscience.cdk.reaction.ReactionProcessTest;
 import org.openscience.cdk.reaction.type.parameters.IParameterReact;
 import org.openscience.cdk.reaction.type.parameters.SetReactionCenter;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
+import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.LonePairElectronChecker;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 import org.openscience.cdk.tools.manipulator.ReactionManipulator;
@@ -52,12 +54,12 @@ import java.util.List;
 public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
 
     private final LonePairElectronChecker lpcheck = new LonePairElectronChecker();
-    private IChemObjectBuilder            builder = SilentChemObjectBuilder.getInstance();
+    private final IChemObjectBuilder            builder = SilentChemObjectBuilder.getInstance();
 
     /**
      *  The JUnit setup method
      */
-    public ElectronImpactPDBReactionTest() throws Exception {
+    ElectronImpactPDBReactionTest() throws Exception {
         setReaction(ElectronImpactPDBReaction.class);
     }
 
@@ -65,9 +67,9 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *  The JUnit setup method
      */
     @Test
-    public void testElectronImpactPDBReaction() throws Exception {
+    void testElectronImpactPDBReaction() throws Exception {
         IReactionProcess type = new ElectronImpactPDBReaction();
-        Assert.assertNotNull(type);
+        Assertions.assertNotNull(type);
     }
 
     /**
@@ -97,12 +99,10 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         reactant.addBond(5, 6, IBond.Order.SINGLE);
         addExplicitHydrogens(reactant);
 
-        Iterator<IBond> bonds = reactant.bonds().iterator();
-        while (bonds.hasNext()) {
-            IBond bond = (IBond) bonds.next();
+        for (IBond bond : reactant.bonds()) {
             IAtom atom1 = bond.getBegin();
             IAtom atom2 = bond.getEnd();
-            if (bond.getOrder() == IBond.Order.DOUBLE && atom1.getSymbol().equals("C") && atom2.getSymbol().equals("C")) {
+            if (bond.getOrder() == IBond.Order.DOUBLE && atom1.getAtomicNumber() == IElement.C && atom2.getAtomicNumber() == IElement.C) {
                 bond.setFlag(CDKConstants.REACTIVE_CENTER, true);
                 atom1.setFlag(CDKConstants.REACTIVE_CENTER, true);
                 atom2.setFlag(CDKConstants.REACTIVE_CENTER, true);
@@ -117,27 +117,27 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         makeSureAtomTypesAreRecognized(reactant);
 
         IReactionProcess type = new ElectronImpactPDBReaction();
-        List<IParameterReact> paramList = new ArrayList<IParameterReact>();
+        List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
         param.setParameter(Boolean.TRUE);
         paramList.add(param);
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(2, setOfReactions.getReactionCount());
+        Assertions.assertEquals(2, setOfReactions.getReactionCount());
 
         IAtomContainer molecule = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
 
-        Assert.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
-        Assert.assertEquals(1, molecule.getSingleElectronCount());
+        Assertions.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
+        Assertions.assertEquals(1, molecule.getSingleElectronCount());
 
         molecule = setOfReactions.getReaction(1).getProducts().getAtomContainer(0);
-        Assert.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
-        Assert.assertEquals(1, molecule.getSingleElectronCount());
+        Assertions.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
+        Assertions.assertEquals(1, molecule.getSingleElectronCount());
 
-        Assert.assertEquals(17, setOfReactions.getReaction(0).getMappingCount());
+        Assertions.assertEquals(17, setOfReactions.getReaction(0).getMappingCount());
 
     }
 
@@ -149,7 +149,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *@return    Description of the Return Value
      */
     @Test
-    public void testAutomatic_Set_Active_Bond() throws Exception {
+    void testAutomatic_Set_Active_Bond() throws Exception {
         /* ionize all possible double bonds */
         IAtomContainer reactant = builder.newInstance(IAtomContainer.class);//miles("C=CC")
         reactant.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -169,15 +169,15 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         IReactionProcess type = new ElectronImpactPDBReaction();
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(2, setOfReactions.getReactionCount());
+        Assertions.assertEquals(2, setOfReactions.getReactionCount());
 
         IAtomContainer molecule = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
-        Assert.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
+        Assertions.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
 
         molecule = setOfReactions.getReaction(1).getProducts().getAtomContainer(0);
-        Assert.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
+        Assertions.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
 
     }
 
@@ -189,7 +189,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *@return    Description of the Return Value
      */
     @Test
-    public void testAutomatic_Set_Active_Bond2() throws Exception {
+    void testAutomatic_Set_Active_Bond2() throws Exception {
         /* ionize >C=C< , set the reactive center */
         IAtomContainer reactant = builder.newInstance(IAtomContainer.class);//Smiles("C=CCC(=O)CC")
         reactant.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -215,24 +215,24 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         makeSureAtomTypesAreRecognized(reactant);
 
         IReactionProcess type = new ElectronImpactPDBReaction();
-        List<IParameterReact> paramList = new ArrayList<IParameterReact>();
+        List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
         param.setParameter(Boolean.FALSE);
         paramList.add(param);
         type.setParameterList(paramList);
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(3, setOfReactions.getReactionCount());
+        Assertions.assertEquals(3, setOfReactions.getReactionCount());
 
         IAtomContainer molecule = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
-        Assert.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
+        Assertions.assertEquals(1, molecule.getAtom(0).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(1)));
 
         molecule = setOfReactions.getReaction(1).getProducts().getAtomContainer(0);
-        Assert.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
-        Assert.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
+        Assertions.assertEquals(1, molecule.getAtom(1).getFormalCharge().intValue());
+        Assertions.assertEquals(1, molecule.getConnectedSingleElectronsCount(molecule.getAtom(0)));
 
-        Assert.assertEquals(17, setOfReactions.getReaction(0).getMappingCount());
+        Assertions.assertEquals(17, setOfReactions.getReaction(0).getMappingCount());
 
     }
 
@@ -245,7 +245,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *
      */
     @Test
-    public void testCDKConstants_REACTIVE_CENTER() throws Exception {
+    void testCDKConstants_REACTIVE_CENTER() throws Exception {
         IReactionProcess type = new ElectronImpactPDBReaction();
         IAtomContainerSet setOfReactants = getExampleReactants();
         IAtomContainer molecule = setOfReactants.getAtomContainer(0);
@@ -255,7 +255,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         molecule.getAtom(1).setFlag(CDKConstants.REACTIVE_CENTER, true);
         molecule.getBond(0).setFlag(CDKConstants.REACTIVE_CENTER, true);
 
-        List<IParameterReact> paramList = new ArrayList<IParameterReact>();
+        List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
         param.setParameter(Boolean.TRUE);
         paramList.add(param);
@@ -266,16 +266,16 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
 
         IReactionSet setOfReactions = type.initiate(setOfReactants, null);
 
-        Assert.assertEquals(2, setOfReactions.getReactionCount());
-        Assert.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
+        Assertions.assertEquals(2, setOfReactions.getReactionCount());
+        Assertions.assertEquals(1, setOfReactions.getReaction(0).getProductCount());
 
         IAtomContainer reactant = setOfReactions.getReaction(0).getReactants().getAtomContainer(0);
-        Assert.assertTrue(molecule.getAtom(0).getFlag(CDKConstants.REACTIVE_CENTER));
-        Assert.assertTrue(reactant.getAtom(0).getFlag(CDKConstants.REACTIVE_CENTER));
-        Assert.assertTrue(molecule.getAtom(1).getFlag(CDKConstants.REACTIVE_CENTER));
-        Assert.assertTrue(reactant.getAtom(1).getFlag(CDKConstants.REACTIVE_CENTER));
-        Assert.assertTrue(molecule.getBond(0).getFlag(CDKConstants.REACTIVE_CENTER));
-        Assert.assertTrue(reactant.getBond(0).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(molecule.getAtom(0).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(reactant.getAtom(0).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(molecule.getAtom(1).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(reactant.getAtom(1).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(molecule.getBond(0).getFlag(CDKConstants.REACTIVE_CENTER));
+        Assertions.assertTrue(reactant.getBond(0).getFlag(CDKConstants.REACTIVE_CENTER));
     }
 
     /**
@@ -287,13 +287,13 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *
      */
     @Test
-    public void testMapping() throws Exception {
+    void testMapping() throws Exception {
         IReactionProcess type = new ElectronImpactPDBReaction();
         IAtomContainerSet setOfReactants = getExampleReactants();
         IAtomContainer molecule = setOfReactants.getAtomContainer(0);
 
         /* automatic search of the center active */
-        List<IParameterReact> paramList = new ArrayList<IParameterReact>();
+        List<IParameterReact> paramList = new ArrayList<>();
         IParameterReact param = new SetReactionCenter();
         param.setParameter(Boolean.FALSE);
         paramList.add(param);
@@ -304,13 +304,13 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
 
         IAtomContainer product = setOfReactions.getReaction(0).getProducts().getAtomContainer(0);
 
-        Assert.assertEquals(9, setOfReactions.getReaction(0).getMappingCount());
+        Assertions.assertEquals(9, setOfReactions.getReaction(0).getMappingCount());
         IAtom mappedProductA1 = (IAtom) ReactionManipulator.getMappedChemObject(setOfReactions.getReaction(0),
                 molecule.getAtom(0));
-        Assert.assertEquals(mappedProductA1, product.getAtom(0));
+        Assertions.assertEquals(mappedProductA1, product.getAtom(0));
         IAtom mappedProductA2 = (IAtom) ReactionManipulator.getMappedChemObject(setOfReactions.getReaction(0),
                 molecule.getAtom(1));
-        Assert.assertEquals(mappedProductA2, product.getAtom(1));
+        Assertions.assertEquals(mappedProductA2, product.getAtom(1));
     }
 
     /**
@@ -325,7 +325,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
         CDKAtomTypeMatcher matcher = CDKAtomTypeMatcher.getInstance(molecule.getBuilder());
         while (atoms.hasNext()) {
             IAtom nextAtom = atoms.next();
-            Assert.assertNotNull("Missing atom type for: " + nextAtom, matcher.findMatchingAtomType(molecule, nextAtom));
+            Assertions.assertNotNull(matcher.findMatchingAtomType(molecule, nextAtom), "Missing atom type for: " + nextAtom);
         }
     }
 
@@ -360,7 +360,8 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
             AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(molecule);
             lpcheck.saturate(molecule);
         } catch (CDKException e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(getClass())
+                              .error("Unexpected Error:", e);
         }
         setOfReactants.addAtomContainer(molecule);
 
@@ -373,7 +374,7 @@ public class ElectronImpactPDBReactionTest extends ReactionProcessTest {
      *
      * @return The IAtomContainerSet
      */
-    private IAtomContainerSet getExpectedProducts() {
+    IAtomContainerSet getExpectedProducts() {
         IAtomContainerSet setOfProducts = builder.newInstance(IAtomContainerSet.class);
 
         setOfProducts.addAtomContainer(null);
