@@ -21,6 +21,7 @@ package org.openscience.cdk.silent;
 
 import java.io.Serializable;
 import java.util.Iterator;
+import java.util.NoSuchElementException;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -72,7 +73,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
     /**
      * Number of atoms contained by this object.
      */
-    protected int             atomCount        = 0;
+    protected int             atomCount;
 
     /**
      * A list of atoms participating in this bond.
@@ -165,13 +166,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
      */
     @Override
     public Iterable<IAtom> atoms() {
-        return new Iterable<IAtom>() {
-
-            @Override
-            public Iterator<IAtom> iterator() {
-                return new AtomsIterator();
-            }
-        };
+        return AtomsIterator::new;
     }
 
     /**
@@ -204,6 +199,8 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
 
         @Override
         public IAtom next() {
+            if (pointer >= atomCount)
+                throw new NoSuchElementException();
             ++pointer;
             return atoms[pointer - 1];
         }
@@ -556,7 +553,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
             clone.atoms = new IAtom[atoms.length];
             for (int f = 0; f < atoms.length; f++) {
                 if (atoms[f] != null) {
-                    clone.atoms[f] = (IAtom) ((IAtom) atoms[f]).clone();
+                    clone.atoms[f] = atoms[f].clone();
                 }
             }
         }
@@ -589,7 +586,7 @@ public class Bond extends ElectronContainer implements IBond, Serializable, Clon
      */
     @Override
     public String toString() {
-        StringBuffer resultString = new StringBuffer(32);
+        StringBuilder resultString = new StringBuilder(32);
         resultString.append("Bond(").append(this.hashCode());
         if (getOrder() != null) {
             resultString.append(", #O:").append(getOrder());
