@@ -19,9 +19,9 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.interfaces.AbstractAdductFormulaTest;
 import org.openscience.cdk.interfaces.IAdductFormula;
 import org.openscience.cdk.interfaces.IMolecularFormula;
@@ -31,23 +31,23 @@ import org.openscience.cdk.interfaces.IMolecularFormula;
  *
  * @cdk.module test-silent
  */
-public class AdductFormulaTest extends AbstractAdductFormulaTest {
+class AdductFormulaTest extends AbstractAdductFormulaTest {
 
-    @BeforeClass
-    public static void setUp() {
+    @BeforeAll
+    static void setUp() {
         setBuilder(SilentChemObjectBuilder.getInstance());
     }
 
     @Test
-    public void testAdductFormula() {
+    void testAdductFormula() {
         IAdductFormula mfS = new AdductFormula();
-        Assert.assertNotNull(mfS);
+        Assertions.assertNotNull(mfS);
     }
 
     @Test
-    public void testAdductFormula_IMolecularFormula() {
+    void testAdductFormula_IMolecularFormula() {
         IAdductFormula mfS = new AdductFormula(getBuilder().newInstance(IMolecularFormula.class));
-        Assert.assertEquals(1, mfS.size());
+        Assertions.assertEquals(1, mfS.size());
     }
 
 }
