@@ -19,37 +19,29 @@
  */
 package org.openscience.cdk.silent;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.openscience.cdk.interfaces.IChemObject;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IElectronContainer;
 import org.openscience.cdk.test.interfaces.AbstractElectronContainerTest;
-import org.openscience.cdk.test.interfaces.ITestObjectBuilder;
 
 /**
  * Checks the functionality of the {@link ElectronContainer}.
  *
  * @cdk.module test-silent
  */
-public class ElectronContainerTest extends AbstractElectronContainerTest {
+class ElectronContainerTest extends AbstractElectronContainerTest {
 
-    @BeforeClass
-    public static void setUp() {
-        setTestObjectBuilder(new ITestObjectBuilder() {
-
-            @Override
-            public IChemObject newTestObject() {
-                return new ElectronContainer();
-            }
-        });
+    @BeforeAll
+    static void setUp() {
+        setTestObjectBuilder(ElectronContainer::new);
     }
 
     @Test
-    public void testElectronContainer() {
+    void testElectronContainer() {
         IElectronContainer ec = new ElectronContainer();
-        Assert.assertNotNull(ec);
-        Assert.assertEquals(0, ec.getElectronCount().intValue());
+        Assertions.assertNotNull(ec);
+        Assertions.assertEquals(0, ec.getElectronCount().intValue());
     }
 
     // Overwrite default methods: no notifications are expected!
