@@ -19,22 +19,25 @@
  */
 package org.openscience.cdk.graph;
 
-import java.util.*;
-
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObject;
-import org.openscience.cdk.interfaces.IDoubleBondStereochemistry;
+import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.ILonePair;
 import org.openscience.cdk.interfaces.ISingleElectron;
 import org.openscience.cdk.interfaces.IStereoElement;
-import org.openscience.cdk.interfaces.ITetrahedralChirality;
 import org.openscience.cdk.sgroup.Sgroup;
-import org.openscience.cdk.sgroup.SgroupKey;
-import org.openscience.cdk.stereo.ExtendedTetrahedral;
+import org.openscience.cdk.tools.manipulator.SgroupManipulator;
+
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 /**
  * Tool class for checking whether the (sub)structure in an
@@ -84,21 +87,105 @@ public class ConnectivityChecker {
      */
     public static IAtomContainerSet partitionIntoMolecules(IAtomContainer container) {
         ConnectedComponents cc = new ConnectedComponents(GraphUtil.toAdjList(container));
+        if (cc.nComponents() == 1) {
+            return singleton(container);
+        }
         return partitionIntoMolecules(container, cc.components());
     }
 
+    private static IAtomContainerSet singleton(IAtomContainer container) {
+        IChemObjectBuilder bldr = container.getBuilder();
+        IAtomContainerSet acSet = bldr.newInstance(IAtomContainerSet.class);
+        acSet.addAtomContainer(container);
+        return acSet;
+    }
+
+    private static IAtomContainerSet empty(IAtomContainer container) {
+        IChemObjectBuilder bldr = container.getBuilder();
+        return bldr.newInstance(IAtomContainerSet.class);
+    }
+
+    private static IAtomContainer getComponent(Map<IAtom, IAtomContainer> cmap,
+                                               IChemObject cobj) {
+        if (cobj instanceof IAtom)
+            return cmap.get(cobj);
+        else if (cobj instanceof IBond) {
+            IAtomContainer begMol = cmap.get(((IBond) cobj).getBegin());
+            IAtomContainer endMol = cmap.get(((IBond) cobj).getEnd());
+            return begMol == endMol ? begMol : null;
+        }
+        return null;
+    }
+
+    /**
+     * Given a component mapping atom -> molecule, provide the atom container
+     * to add the stereochemistry to. If the stereo is split across two
+     * molecules (components) null is returned.
+     *
+     * @param cmap component map
+     * @param se stereo element
+     * @return the molecule (or null if inconsistent)
+     */
+    private static IAtomContainer getComponent(Map<IAtom, IAtomContainer> cmap,
+                                               IStereoElement<?, ?> se) {
+        IAtomContainer mol = getComponent(cmap, se.getFocus());
+        for (IChemObject cobj : se.getCarriers()) {
+            IAtomContainer tmp = getComponent(cmap, cobj);
+            if (tmp != mol)
+                return null; // inconsistent
+        }
+        return mol;
+    }
+
+    private static IAtomContainer getComponent(Map<IAtom, IAtomContainer> cmap,
+                                               Sgroup sgroup) {
+        IAtomContainer mol = null;
+        for (IAtom atom : sgroup.getAtoms()) {
+            IAtomContainer tmp = cmap.get(atom);
+            if (mol == null)
+                mol = tmp;
+            else if (mol != tmp)
+                return null;
+        }
+        return mol;
+    }
+
+    private static void addSgroup(IAtomContainer component, Sgroup sgroup) {
+        List<Sgroup> sgroups = component.getProperty(CDKConstants.CTAB_SGROUPS);
+        if (sgroups == null) {
+            sgroups = new ArrayList<>();
+            component.setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
+        }
+        sgroups.add(sgroup);
+    }
+
+    /**
+     * Split a molecule based on the provided component array. Note this function
+     * can also be used to split a single molecule, breaking bonds and distributing
+     * stereochemistry as needed.
+     *
+     * @param container the container
+     * @param components the components
+     * @return the partitioned set
+     */
     public static IAtomContainerSet partitionIntoMolecules(IAtomContainer container, int[] components) {
 
+        int minComponentIndex = Integer.MAX_VALUE;
         int maxComponentIndex = 0;
-        for (int component : components)
-            if (component > maxComponentIndex)
-                maxComponentIndex = component;
+        for (int component : components) {
+            minComponentIndex = Math.min(component, minComponentIndex);
+            maxComponentIndex = Math.max(component, maxComponentIndex);
+        }
+
+        if (minComponentIndex == maxComponentIndex) {
+            if (maxComponentIndex == 0)
+                return empty(container);
+            else
+                return singleton(container);
+        }
 
         IAtomContainer[] containers = new IAtomContainer[maxComponentIndex + 1];
         Map<IAtom, IAtomContainer> componentsMap = new HashMap<>(2 * container.getAtomCount());
-        Map<IAtom, IAtom> componentAtomMap = new HashMap<>(2 * container.getAtomCount());
-        Map<IBond, IBond> componentBondMap = new HashMap<>(2 * container.getBondCount());
-
 
         for (int i = 1; i < containers.length; i++)
             containers[i] = container.getBuilder().newInstance(IAtomContainer.class);
@@ -110,8 +197,6 @@ public class ConnectivityChecker {
             IAtomContainer newContainer = containers[components[i]];
             componentsMap.put(origAtom, newContainer);
             newContainer.addAtom(origAtom);
-            //the atom should always be added so this should be safe
-            componentAtomMap.put(origAtom, newContainer.getAtom(newContainer.getAtomCount()-1));
         }
 
         for (IBond bond : container.bonds()) {
@@ -119,8 +204,6 @@ public class ConnectivityChecker {
             IAtomContainer endComp = componentsMap.get(bond.getEnd());
             if (begComp == endComp) {
                 begComp.addBond(bond);
-                //bond should always be added so this should be safe
-                componentBondMap.put(bond, begComp.getBond(begComp.getBondCount()-1));
             }
         }
 
@@ -130,97 +213,40 @@ public class ConnectivityChecker {
         for (ILonePair lonePair : container.lonePairs())
             componentsMap.get(lonePair.getAtom()).addLonePair(lonePair);
 
-        for (IStereoElement stereo : container.stereoElements()) {
-            IChemObject focus = stereo.getFocus();
-            if (focus instanceof IAtom) {
-                if (componentsMap.containsKey(focus))
-                    componentsMap.get(focus).addStereoElement(stereo);
-            } else if (focus instanceof IBond) {
-                if (componentsMap.containsKey(((IBond) focus).getBegin()))
-                    componentsMap.get(((IBond) focus).getBegin()).addStereoElement(stereo);
-            } else {
-                throw new IllegalStateException("New stereo element not using an atom/bond for focus?");
+        // split stereo chemistry, only keep if all atoms/bond in the stereo
+        // element are consistent and in the same container
+        for (IStereoElement<?,?>stereo : container.stereoElements()) {
+            IAtomContainer component = getComponent(componentsMap, stereo);
+            if (component != null)
+                component.addStereoElement(stereo);
+        }
+
+        // split Sgroups, only keep if all atoms/bond in the sgroup
+        // are consistent and in the same container
+        List<Sgroup> sgroups = SgroupManipulator.copy(container.getProperty(CDKConstants.CTAB_SGROUPS),
+                                                       new HashMap<>());
+        if (sgroups != null) {
+            Map<Sgroup,IAtomContainer> sgroupMap = new HashMap<>();
+            for (Sgroup sgroup : sgroups) {
+                IAtomContainer component = getComponent(componentsMap, sgroup);
+                if (component != null) {
+                    addSgroup(component, sgroup);
+                }
+            }
+            // remove any parents that were split
+            for (Sgroup sgroup : sgroups) {
+                Set<Sgroup> toremove = new HashSet<>();
+                for (Sgroup parent : sgroup.getParents()) {
+                    if (sgroupMap.get(parent) == null)
+                        toremove.add(parent);
+                }
+                sgroup.removeParents(toremove);
             }
         }
-        //add SGroups
-        List<Sgroup> sgroups = container.getProperty(CDKConstants.CTAB_SGROUPS);
 
-        if(sgroups !=null){
-            Map<Sgroup, Sgroup> old2NewSgroupMap = new HashMap<>();
-            List<Sgroup>[] newSgroups = new List[containers.length];
-            for(Sgroup sgroup : sgroups){
-                Iterator<IAtom> iter =sgroup.getAtoms().iterator();
-                if(!iter.hasNext()){
-                   continue;
-                }
-                int componentIndex = getComponentIndexFor(components, containers,iter.next());
-                boolean allMatch=componentIndex>=0;
-                while(allMatch && iter.hasNext()){
-                    //if component index for some atoms
-                    //don't match then the sgroup is split across components
-                    //so ignore it for now?
-                    allMatch = (componentIndex == getComponentIndexFor(components,containers, iter.next()));
-                }
-                if(allMatch && componentIndex >=0){
-                    Sgroup cpy = new Sgroup();
-                    List<Sgroup> newComponentSgroups = newSgroups[componentIndex];
-                    if(newComponentSgroups ==null){
-                        newComponentSgroups = newSgroups[componentIndex] = new ArrayList<>();
-                    }
-                    newComponentSgroups.add(cpy);
-                    old2NewSgroupMap.put(sgroup, cpy);
-                    for (IAtom atom : sgroup.getAtoms()) {
-                       cpy.addAtom(componentAtomMap.get(atom));
-
-                    }
-                    for (IBond bond : sgroup.getBonds()) {
-                        IBond newBond = componentBondMap.get(bond);
-                        if(newBond!=null) {
-                            cpy.addBond(newBond);
-                        }
-                    }
-
-                    for (SgroupKey key : sgroup.getAttributeKeys())
-                        cpy.putValue(key, sgroup.getValue(key));
-
-                }
-            }
-            //finally update parents
-            for(Sgroup sgroup : sgroups){
-                Sgroup newSgroup = old2NewSgroupMap.get(sgroup);
-                if(newSgroup !=null){
-                    for (Sgroup parent : sgroup.getParents()){
-                        Sgroup newParent = old2NewSgroupMap.get(parent);
-                        if(newParent !=null){
-                            newSgroup.addParent(newParent);
-                        }
-                    }
-                }
-            }
-            for(int i=1; i< containers.length; i++){
-                List<Sgroup> sg = newSgroups[i];
-                if(sg !=null){
-                    containers[i].setProperty(CDKConstants.CTAB_SGROUPS, sg);
-                }
-            }
-        }
+        // create our AtomContainerSet
         for (int i = 1; i < containers.length; i++)
             containerSet.addAtomContainer(containers[i]);
-
         return containerSet;
     }
-
-    private static int getComponentIndexFor(int[] components, IAtomContainer[] containers, IAtom atom) {
-        int aIndex = atom.getIndex();
-        if(aIndex >= 0) {
-            return components[aIndex];
-        }
-        //if index isn't known check each container
-        for (int i = 1; i < containers.length; i++){
-            if(containers[i].contains(atom)){
-                return i;
-            }
-        }
-        return -1;
-    }
 }
