@@ -36,6 +36,7 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
+import org.openscience.cdk.interfaces.IChemObject;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.interfaces.IDoubleBondStereochemistry;
 import org.openscience.cdk.interfaces.IElectronContainer;
@@ -54,6 +55,7 @@ import org.openscience.cdk.stereo.DoubleBondStereochemistry;
 import org.openscience.cdk.stereo.ExtendedCisTrans;
 import org.openscience.cdk.stereo.ExtendedTetrahedral;
 import org.openscience.cdk.stereo.TetrahedralChirality;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -69,6 +71,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
+import java.util.function.Predicate;
+import java.util.stream.Collectors;
 
 import static org.openscience.cdk.CDKConstants.SINGLE_OR_DOUBLE;
 import static org.openscience.cdk.interfaces.IDoubleBondStereochemistry.Conformation;
@@ -126,34 +130,126 @@ public class AtomContainerManipulator {
      * Extract a substructure from an atom container, in the form of a new
      * cloned atom container with only the atoms with indices in atomIndices and
      * bonds that connect these atoms.
-     *
      * Note that this may result in a disconnected atom container.
      *
      * @param atomContainer the source container to extract from
      * @param atomIndices the indices of the substructure
      * @return a cloned atom container with a substructure of the source
-     * @throws CloneNotSupportedException if the source container cannot be cloned
+     * @throws CloneNotSupportedException not thrown any longer, kept to retain compatability
+     * @deprecated use {@link #extractSubstructure(IAtomContainer, Collection)} instead
      */
+    @Deprecated
     public static IAtomContainer extractSubstructure(IAtomContainer atomContainer, int... atomIndices)
             throws CloneNotSupportedException {
-        IAtomContainer substructure = (IAtomContainer) atomContainer.clone();
-        int numberOfAtoms = substructure.getAtomCount();
-        IAtom[] atoms = new IAtom[numberOfAtoms];
-        for (int atomIndex = 0; atomIndex < numberOfAtoms; atomIndex++) {
-            atoms[atomIndex] = substructure.getAtom(atomIndex);
+        return extractSubstructure(atomContainer,
+                Arrays.stream(atomIndices).mapToObj(atomContainer::getAtom).collect(Collectors.toSet()));
+    }
+
+    /**
+     * Copy selected atoms/bonds from a 'source' molecule to the provided <code>dest</code>ination.
+     * For consistency the bond filter is only checked if both
+     * atoms of a bond pass the atom filter. i.e. you can't add a bond with
+     * atoms that would not be copied.
+     *
+     * @param dest the destination molecule
+     * @param source the source molecule
+     * @param atomFilter the atom filter indicates which atoms to copy
+     * @param bondFilter the bond filter indicates which bonds to copy
+     */
+    public static void copy(IAtomContainer dest,
+                            IAtomContainer source,
+                            Predicate<IAtom> atomFilter,
+                            Predicate<IBond> bondFilter) {
+        // holds entries of (reference to atom in source, reference to atom in dest)
+        Map<IChemObject, IChemObject> remap = new HashMap<>();
+
+        for (IAtom atom : source.atoms()) {
+            if (!atomFilter.test(atom))
+                continue;
+            dest.addAtom(atom);
+            // for AtomContainer2 we want the new "AtomRef" in the new container
+            remap.put(atom, dest.getAtom(dest.getAtomCount() - 1));
         }
 
-        Arrays.sort(atomIndices);
-        for (int index = 0; index < numberOfAtoms; index++) {
-            if (Arrays.binarySearch(atomIndices, index) < 0) {
-                IAtom atom = atoms[index];
-                substructure.removeAtom(atom);
+        for (IBond bond : source.bonds()) {
+            IAtom beg = (IAtom) remap.get(bond.getBegin());
+            IAtom end = (IAtom) remap.get(bond.getEnd());
+            if (beg != null && end != null && bondFilter.test(bond)) {
+                dest.addBond(dest.indexOf(beg), dest.indexOf(end),
+                             bond.getOrder(), bond.getStereo());
+                IBond destBond = dest.getBond(dest.getBondCount() - 1);
+                destBond.setIsInRing(bond.isInRing());
+                destBond.setIsAromatic(bond.isAromatic());
+                destBond.setProperties(bond.getProperties());
+                remap.put(bond, destBond);
             }
         }
 
-        return substructure;
+        for (ISingleElectron se : source.singleElectrons()) {
+            IAtom newAtom = (IAtom) remap.get(se.getAtom());
+            if (newAtom != null)
+                dest.addSingleElectron(dest.indexOf(newAtom));
+        }
+
+        for (ILonePair lp : source.lonePairs()) {
+            IAtom newAtom = (IAtom) remap.get(lp.getAtom());
+            if (newAtom != null)
+                dest.addLonePair(dest.indexOf(newAtom));
+        }
+
+        for (IStereoElement<?, ?> sourceStereo : source.stereoElements()) {
+            IStereoElement<?, ?> destStereo = sourceStereo.mapStrict(remap);
+            if (destStereo != null)
+                dest.addStereoElement(destStereo);
+        }
     }
 
+    /**
+     * Copy selected atoms from a 'source' molecule to the provided <code>dest</code>ination.
+     *
+     * @param dest the destination molecule
+     * @param source the source molecule
+     * @param atomFilter the atom filter indicates which atoms to copy
+     * @see #copy(org.openscience.cdk.interfaces.IAtomContainer, org.openscience.cdk.interfaces.IAtomContainer, java.util.function.Predicate, java.util.function.Predicate)
+     */
+    public static void copy(IAtomContainer dest,
+                            IAtomContainer source,
+                            Predicate<IAtom> atomFilter) {
+        copy(dest, source, atomFilter, b -> true);
+    }
+
+    /**
+     * Copy atoms in the collection from a 'source' molecule to the provided <code>dest</code>ination.
+     * For performance a {@link java.util.Set} of 'atoms' is preferred.
+     *
+     * @param dest the destination molecule
+     * @param source the source molecule
+     * @param atoms the atom collection indicates which atoms to copy
+     * @see #copy(org.openscience.cdk.interfaces.IAtomContainer, org.openscience.cdk.interfaces.IAtomContainer, java.util.function.Predicate, java.util.function.Predicate)
+     */
+    public static void copy(IAtomContainer dest,
+                            IAtomContainer source,
+                            Collection<IAtom> atoms) {
+        copy(dest, source, atoms::contains, b -> true);
+    }
+
+    /**
+     * Extract a substructure from a 'source' molecule to the provided <code>dest</code>ination based on the collection of atoms.
+     * For performance a {@link java.util.Set} of <code>atoms</code> is preferred.
+     *
+     * @param source the source molecule
+     * @param atoms the atom collection indicates which atoms to copy
+     * @return the extracted molecule
+     * @see #copy(org.openscience.cdk.interfaces.IAtomContainer, org.openscience.cdk.interfaces.IAtomContainer, java.util.function.Predicate, java.util.function.Predicate)
+     */
+    public static IAtomContainer extractSubstructure(IAtomContainer source,
+                                                     Collection<IAtom> atoms) {
+        IAtomContainer dest = source.getBuilder().newAtomContainer();
+        copy(dest, source, atoms::contains, b -> true);
+        return dest;
+    }
+
+
     /**
      * Returns an atom in an atomcontainer identified by id
      *
@@ -471,7 +567,8 @@ public class AtomContainerManipulator {
                     abundance *= hAbundance;
                 nImplH += atom.getImplicitHydrogenCount();
             }
-            return abundance / Math.pow(100, nImplH + atomContainer.getAtomCount());
+            int acount = atomContainer.getAtomCount();
+            return abundance / Math.pow(100, (double)nImplH + acount);
         } catch (IOException e) {
             throw new RuntimeException("Isotopes definitions could not be loaded", e);
         }
@@ -537,7 +634,7 @@ public class AtomContainerManipulator {
         int hydrogens = 0;
         for (IAtom atom : container.atoms()) {
 
-            if (Elements.HYDROGEN.getSymbol().equals(atom.getSymbol())) {
+            if (Elements.HYDROGEN.getAtomicNumber().equals(atom.getAtomicNumber())) {
                 hydrogens++;
             }
 
@@ -588,14 +685,14 @@ public class AtomContainerManipulator {
             throw new IllegalArgumentException("null container or atom provided");
         int hCount = 0;
         for (IAtom connected : atomContainer.getConnectedAtomsList(atom)) {
-            if (Elements.HYDROGEN.getSymbol().equals(connected.getSymbol())) {
+            if (Elements.HYDROGEN.getAtomicNumber().equals(connected.getAtomicNumber())) {
                 hCount++;
             }
         }
         return hCount;
     }
 
-    private static final void replaceAtom(IAtom[] atoms, IAtom org, IAtom rep) {
+    private static void replaceAtom(IAtom[] atoms, IAtom org, IAtom rep) {
         for (int i = 0; i < atoms.length; i++) {
             if (atoms[i].equals(org))
                 atoms[i] = rep;
@@ -610,14 +707,14 @@ public class AtomContainerManipulator {
      * @cdk.keyword hydrogens, adding
      */
     public static void convertImplicitToExplicitHydrogens(IAtomContainer atomContainer) {
-        List<IAtom> hydrogens = new ArrayList<IAtom>();
-        List<IBond> newBonds = new ArrayList<IBond>();
+        List<IAtom> hydrogens = new ArrayList<>();
+        List<IBond> newBonds = new ArrayList<>();
 
         // store a single explicit hydrogen of each original neighbor
         Map<IAtom, IAtom> hNeighbor = new HashMap<>(2*atomContainer.getAtomCount());
 
         for (IAtom atom : atomContainer.atoms()) {
-            if (!"H".equals(atom.getSymbol())) {
+            if (atom.getAtomicNumber() != IElement.H) {
                 Integer hCount = atom.getImplicitHydrogenCount();
                 if (hCount != null) {
                     for (int i = 0; i < hCount; i++) {
@@ -697,7 +794,7 @@ public class AtomContainerManipulator {
     }
 
     public static List<String> getAllIDs(IAtomContainer mol) {
-        List<String> idList = new ArrayList<String>();
+        List<String> idList = new ArrayList<>();
         if (mol != null) {
             if (mol.getID() != null) idList.add(mol.getID());
             for (IAtom atom : mol.atoms()) {
@@ -721,8 +818,8 @@ public class AtomContainerManipulator {
      */
     public static IAtomContainer removeNonChiralHydrogens(IAtomContainer org) {
 
-        Map<IAtom, IAtom> map = new HashMap<IAtom, IAtom>(); // maps original atoms to clones.
-        List<IAtom> remove = new ArrayList<IAtom>(); // lists removed Hs.
+        Map<IAtom, IAtom> map = new HashMap<>(); // maps original atoms to clones.
+        List<IAtom> remove = new ArrayList<>(); // lists removed Hs.
 
         // Clone atoms except those to be removed.
         IAtomContainer cpy = org.getBuilder().newInstance(IAtomContainer.class);
@@ -747,7 +844,7 @@ public class AtomContainerManipulator {
                             if (bondStereo != null && bondStereo != IBond.Stereo.NONE) addToRemove = false;
                             IAtom neighboursNeighbour = bond.getOther(neighbour);
                             // remove in any case if the hetero atom is connected to more than one hydrogen
-                            if ("H".equals(neighboursNeighbour.getSymbol()) && !neighboursNeighbour.equals(atom)) {
+                            if (neighboursNeighbour.getAtomicNumber() == IElement.H && !neighboursNeighbour.equals(atom)) {
                                 addToRemove = true;
                                 break;
                             }
@@ -768,7 +865,7 @@ public class AtomContainerManipulator {
             if (stereoElement instanceof ITetrahedralChirality) {
                 ITetrahedralChirality tetChirality = (ITetrahedralChirality) stereoElement;
                 for (IAtom atom : tetChirality.getLigands()) {
-                    if (atom.getSymbol().equals("H") && remove.contains(atom)) {
+                    if (atom.getAtomicNumber() == IElement.H && remove.contains(atom)) {
                         remove.remove(atom);
                         addClone(atom, cpy, map);
                     }
@@ -803,9 +900,10 @@ public class AtomContainerManipulator {
             if (!removedBond) {
                 IBond clone = null;
                 try {
-                    clone = (IBond) org.getBond(i).clone();
+                    clone = org.getBond(i).clone();
                 } catch (CloneNotSupportedException e) {
-                    e.printStackTrace();
+                    LoggingToolFactory.createLoggingTool(AtomContainerManipulator.class)
+                                      .warn("Unexpected Error:", e);
                 }
                 assert clone != null;
                 clone.setAtoms(new IAtom[]{map.get(bond.getBegin()), map.get(bond.getEnd())});
@@ -836,9 +934,10 @@ public class AtomContainerManipulator {
 
         IAtom clonedAtom = null;
         try {
-            clonedAtom = (IAtom) atom.clone();
+            clonedAtom = atom.clone();
         } catch (CloneNotSupportedException e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(AtomContainerManipulator.class)
+                              .warn("Unexpected Error:", e);
         }
         mol.addAtom(clonedAtom);
         map.put(atom, clonedAtom);
@@ -877,7 +976,7 @@ public class AtomContainerManipulator {
 
         boolean anyHydrogenPresent = false;
         for (IAtom atom : org.atoms()) {
-            if ("H".equals(atom.getSymbol())) {
+            if (atom.getAtomicNumber() == IElement.H) {
                 anyHydrogenPresent = true;
                 break;
             }
@@ -910,8 +1009,8 @@ public class AtomContainerManipulator {
         int nCpyAtoms = 0;
         int nCpyBonds = 0;
 
-        final Set<IAtom> hydrogens        = new HashSet<IAtom>(nOrgAtoms);
-        final Set<IBond> bondsToHydrogens = new HashSet<IBond>();
+        final Set<IAtom> hydrogens        = new HashSet<>(nOrgAtoms);
+        final Set<IBond> bondsToHydrogens = new HashSet<>();
         final IAtom[] cpyAtoms = new IAtom[nOrgAtoms];
 
         // filter the original container atoms for those that can/can't
@@ -949,7 +1048,7 @@ public class AtomContainerManipulator {
         if (nCpyBonds != cpyBonds.length)
             throw new IllegalArgumentException("number of removed bonds was less than the number of removed hydrogens");
 
-        List<IStereoElement> elements = new ArrayList<IStereoElement>();
+        List<IStereoElement> elements = new ArrayList<>();
 
         for (IStereoElement se : org.stereoElements()) {
             if (se instanceof ITetrahedralChirality) {
@@ -1112,7 +1211,7 @@ public class AtomContainerManipulator {
         // methods
 
         if (org.getSingleElectronCount() > 0) {
-            Set<ISingleElectron> remove = new HashSet<ISingleElectron>();
+            Set<ISingleElectron> remove = new HashSet<>();
             for (ISingleElectron se : org.singleElectrons()) {
                 if (hydrogens.contains(se.getAtom())) remove.add(se);
             }
@@ -1122,7 +1221,7 @@ public class AtomContainerManipulator {
         }
 
         if (org.getLonePairCount() > 0) {
-            Set<ILonePair> remove = new HashSet<ILonePair>();
+            Set<ILonePair> remove = new HashSet<>();
             for (ILonePair lp : org.lonePairs()) {
                 if (hydrogens.contains(lp.getAtom())) remove.add(lp);
             }
@@ -1142,6 +1241,7 @@ public class AtomContainerManipulator {
                 for (IBond bondToHydrogen : bondsToHydrogens)
                     sgroup.removeBond(bondToHydrogen);
             }
+            org.setProperty(CDKConstants.CTAB_SGROUPS, sgroups);
         }
 
         return org;
@@ -1173,7 +1273,7 @@ public class AtomContainerManipulator {
      */
     private static boolean suppressibleHydrogen(final IAtomContainer container, final IAtom atom) {
         // is the atom a hydrogen
-        if (!"H".equals(atom.getSymbol())) return false;
+        if (atom.getAtomicNumber() != IElement.H) return false;
         // is the hydrogen an ion?
         if (atom.getFormalCharge() != null && atom.getFormalCharge() != 0) return false;
         // is the hydrogen deuterium / tritium?
@@ -1182,7 +1282,7 @@ public class AtomContainerManipulator {
         if (atom.getImplicitHydrogenCount() != null && atom.getImplicitHydrogenCount() != 0) return false;
         // molecule hydrogen
         List<IAtom> neighbors = container.getConnectedAtomsList(atom);
-        if (neighbors.size() == 1 && ("H".equals(neighbors.get(0).getSymbol()) ||
+        if (neighbors.size() == 1 && (neighbors.get(0).getAtomicNumber() == IElement.H ||
                                       neighbors.get(0) instanceof IPseudoAtom)) return false;
         // what about bridging hydrogens?
         // hydrogens with atom-atom mapping?
@@ -1224,7 +1324,7 @@ public class AtomContainerManipulator {
         IAtom atom = container.getAtom(v);
 
         // is the atom a hydrogen
-        if (!"H".equals(atom.getSymbol())) return false;
+        if (atom.getAtomicNumber() != IElement.H) return false;
         // is the hydrogen an ion?
         if (atom.getFormalCharge() != null && atom.getFormalCharge() != 0) return false;
         // is the hydrogen deuterium / tritium?
@@ -1236,7 +1336,7 @@ public class AtomContainerManipulator {
 
         // okay the hydrogen has one neighbor, if that neighbor is a
         // hydrogen (i.e. molecular hydrogen) then we can not suppress it
-        if ("H".equals(container.getAtom(graph[v][0]).getSymbol()))
+        if (container.getAtom(graph[v][0]).getAtomicNumber() == IElement.H)
             return false;
         // can not nicely suppress hydrogens on pseudo atoms
         if (container.getAtom(graph[v][0]) instanceof IPseudoAtom)
@@ -1289,9 +1389,9 @@ public class AtomContainerManipulator {
      */
     @Deprecated
     private static IAtomContainer removeHydrogens(IAtomContainer ac, List<IAtom> preserve) {
-        Map<IAtom, IAtom> map = new HashMap<IAtom, IAtom>();
+        Map<IAtom, IAtom> map = new HashMap<>();
         // maps original atoms to clones.
-        List<IAtom> remove = new ArrayList<IAtom>();
+        List<IAtom> remove = new ArrayList<>();
         // lists removed Hs.
 
         // Clone atoms except those to be removed.
@@ -1303,13 +1403,13 @@ public class AtomContainerManipulator {
             if (!suppressibleHydrogen(ac, atom) || preserve.contains(atom)) {
                 IAtom a = null;
                 try {
-                    a = (IAtom) atom.clone();
+                    a = atom.clone();
+                    a.setImplicitHydrogenCount(0);
+                    mol.addAtom(a);
+                    map.put(atom, a);
                 } catch (CloneNotSupportedException e) {
-                    e.printStackTrace();
+                    throw new IllegalStateException("Could nod clone atom", e);
                 }
-                a.setImplicitHydrogenCount(0);
-                mol.addAtom(a);
-                map.put(atom, a);
             } else {
                 remove.add(atom);
                 // maintain list of removed H.
@@ -1337,12 +1437,12 @@ public class AtomContainerManipulator {
 
                 IBond clone = null;
                 try {
-                    clone = (IBond) ac.getBond(i).clone();
+                    clone = ac.getBond(i).clone();
+                    clone.setAtoms(new IAtom[]{map.get(atom0), map.get(atom1)});
+                    mol.addBond(clone);
                 } catch (CloneNotSupportedException e) {
-                    e.printStackTrace();
+                    throw new IllegalStateException("Could nod clone bond", e);
                 }
-                clone.setAtoms(new IAtom[]{map.get(atom0), map.get(atom1)});
-                mol.addBond(clone);
             }
         }
 
@@ -1502,10 +1602,12 @@ public class AtomContainerManipulator {
      * matcher finds a matching atom type, the <code>IAtom</code> will be configured
      * to have the same properties as the <code>IAtomType</code>. If no matching atom
      * type is found, no configuration is performed.
+     * <br>
      * <b>This method overwrites existing values.</b>
      *
-     * @param container
+     * @param container the container whose atom types are to be perceived
      * @throws CDKException
+     * @see AtomTypeManipulator#configure(IAtom, IAtomType)
      */
     public static void percieveAtomTypesAndConfigureAtoms(IAtomContainer container) throws CDKException {
         CDKAtomTypeMatcher matcher = CDKAtomTypeMatcher.getInstance(container.getBuilder());
@@ -1521,10 +1623,12 @@ public class AtomContainerManipulator {
      * matcher finds a matching atom type, the <code>IAtom</code> will be configured
      * to have the same properties as the <code>IAtomType</code>. If no matching atom
      * type is found, no configuration is performed.
-     * <b>This method overwrites existing values.</b>
+     * <br>
+     * <b>This method only sets <code>null</code> values.</b>
      *
-     * @param container
+     * @param container the container whose atom types are to be perceived
      * @throws CDKException
+     * @see AtomTypeManipulator#configureUnsetProperties(IAtom, IAtomType)
      */
     public static void percieveAtomTypesAndConfigureUnsetProperties(IAtomContainer container) throws CDKException {
         CDKAtomTypeMatcher matcher = CDKAtomTypeMatcher.getInstance(container.getBuilder());
@@ -1536,15 +1640,15 @@ public class AtomContainerManipulator {
 
     /**
      * This method will reset all atom configuration to UNSET.
-     *
+     * <br>
      * This method is the reverse of {@link #percieveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IAtomContainer)}
      * and after a call to this method all atoms will be "unconfigured".
-     *
+     * <br>
      * Note that it is not a complete reversal of {@link #percieveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IAtomContainer)}
      * since the atomic symbol of the atoms remains unchanged. Also, all the flags that were set
      * by the configuration method (such as IS_HYDROGENBOND_ACCEPTOR or ISAROMATIC) will be set to False.
      *
-     * @param container The molecule, whose atoms are to be unconfigured
+     * @param container The molecule whose atoms are to be unconfigured
      * @see #percieveAtomTypesAndConfigureAtoms(org.openscience.cdk.interfaces.IAtomContainer)
      */
     public static void clearAtomConfigurations(IAtomContainer container) {
@@ -1592,9 +1696,9 @@ public class AtomContainerManipulator {
      * @cdk.keyword    hydrogens, removal
      */
     public static List<IAtom> getHeavyAtoms(IAtomContainer container) {
-        List<IAtom> newAc = new ArrayList<IAtom>();
+        List<IAtom> newAc = new ArrayList<>();
         for (int f = 0; f < container.getAtomCount(); f++) {
-            if (!"H".equals(container.getAtom(f).getSymbol())) {
+            if (container.getAtom(f).getAtomicNumber() != IElement.H) {
                 newAc.add(container.getAtom(f));
             }
         }
@@ -1613,7 +1717,7 @@ public class AtomContainerManipulator {
      */
     public static IAtomContainer createAllCarbonAllSingleNonAromaticBondAtomContainer(IAtomContainer atomContainer)
             throws CloneNotSupportedException {
-        IAtomContainer query = (IAtomContainer) atomContainer.clone();
+        IAtomContainer query = atomContainer.clone();
         for (int i = 0; i < query.getBondCount(); i++) {
             query.getBond(i).setOrder(IBond.Order.SINGLE);
             query.getBond(i).setFlag(CDKConstants.ISAROMATIC, false);
