@@ -22,8 +22,8 @@ import java.io.InputStream;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IChemFile;
@@ -39,19 +39,19 @@ import org.openscience.cdk.tools.manipulator.ChemFileManipulator;
  *
  * @cdk.module test-core
  */
-public class CDKAtomTypeMatcherFilesTest extends AbstractCDKAtomTypeTest {
+class CDKAtomTypeMatcherFilesTest extends AbstractCDKAtomTypeTest {
 
-    private static Map<String, Integer> testedAtomTypes = new HashMap<String, Integer>();
+    private static final Map<String, Integer> testedAtomTypes = new HashMap<>();
 
     @Test
-    public void testFile3() throws Exception {
+    void testFile3() throws Exception {
         String filename = "3.cml";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CMLReader reader = new CMLReader(ins);
-        IChemFile chemFile = (IChemFile) reader.read(new ChemFile());
+        IChemFile chemFile = reader.read(new ChemFile());
 
         // test the resulting ChemFile content
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
 
         String[] expectedTypes = {"C.sp2", "N.sp2", "C.sp2", "N.sp3", "C.sp2", "N.sp2", "O.sp3", "C.sp2", "C.sp2",
@@ -63,14 +63,14 @@ public class CDKAtomTypeMatcherFilesTest extends AbstractCDKAtomTypeTest {
      * @cdk.bug 3141611
      */
     @Test
-    public void testBug3141611() throws Exception {
+    void testBug3141611() throws Exception {
         String filename = "error.sdf";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         MDLV2000Reader reader = new MDLV2000Reader(ins);
-        IChemFile chemFile = (IChemFile) reader.read(new ChemFile());
+        IChemFile chemFile = reader.read(new ChemFile());
 
         // test the resulting ChemFile content
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
 
         String[] expectedTypes = {"C.sp3", "C.sp2", "O.sp2", "C.sp3", "C.sp3", "C.sp3", "C.sp3", "P.ate", "O.sp2",
@@ -79,14 +79,14 @@ public class CDKAtomTypeMatcherFilesTest extends AbstractCDKAtomTypeTest {
     }
 
     @Test
-    public void testOla28() throws Exception {
+    void testOla28() throws Exception {
         String filename = "mol28.cml";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CMLReader reader = new CMLReader(ins);
-        IChemFile chemFile = (IChemFile) reader.read(new ChemFile());
+        IChemFile chemFile = reader.read(new ChemFile());
 
         // test the resulting ChemFile content
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
 
         String[] expectedTypes = {"C.sp2", "C.sp2", "C.sp2", "C.sp2", "F", "C.sp2", "C.sp2", "C.sp2", "O.sp2", "C.sp3",
@@ -96,32 +96,31 @@ public class CDKAtomTypeMatcherFilesTest extends AbstractCDKAtomTypeTest {
     }
 
     @Test
-    public void testSmilesFiles() throws Exception {
+    void testSmilesFiles() throws Exception {
         CDKAtomTypeMatcher atomTypeMatcher = CDKAtomTypeMatcher.getInstance(SilentChemObjectBuilder.getInstance());
 
         // Read the first file
         String filename = "smiles1.cml";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         CMLReader reader = new CMLReader(ins);
-        IChemFile chemFile = (IChemFile) reader.read(new ChemFile());
-        Assert.assertNotNull(chemFile);
+        IChemFile chemFile = reader.read(new ChemFile());
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol1 = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
 
         // Read the second file
         filename = "smiles2.cml";
         ins = this.getClass().getResourceAsStream(filename);
         reader = new CMLReader(ins);
-        chemFile = (IChemFile) reader.read(new ChemFile());
-        Assert.assertNotNull(chemFile);
+        chemFile = reader.read(new ChemFile());
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol2 = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
 
         IAtomType[] types1 = atomTypeMatcher.findMatchingAtomTypes(mol1);
         IAtomType[] types2 = atomTypeMatcher.findMatchingAtomTypes(mol2);
         for (int i = 0; i < mol1.getAtomCount(); i++) {
-            Assert.assertNotNull("Atom typing in mol1 failed for atom " + (i + 1), types1[i]);
-            Assert.assertNotNull("Atom typing in mol2 failed for atom " + (i + 1), types2[i]);
-            Assert.assertEquals("Atom type mismatch for the " + (i + 1) + " atom", types1[i].getAtomTypeName(),
-                    types2[i].getAtomTypeName());
+            Assertions.assertNotNull(types1[i], "Atom typing in mol1 failed for atom " + (i + 1));
+            Assertions.assertNotNull(types2[i], "Atom typing in mol2 failed for atom " + (i + 1));
+            Assertions.assertEquals(types1[i].getAtomTypeName(), types2[i].getAtomTypeName(), "Atom type mismatch for the " + (i + 1) + " atom");
         }
     }
 }
