@@ -22,7 +22,8 @@
  */
 package org.openscience.cdk.tools.manipulator;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IBond;
@@ -39,18 +40,16 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.CoreMatchers.sameInstance;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
 
-public class SgroupManipulatorTest {
+class SgroupManipulatorTest {
 
     @Test
-    public void copyNull() throws Exception {
-        assertNull(SgroupManipulator.copy(null, null));
+    void copyNull() throws Exception {
+        Assertions.assertNull(SgroupManipulator.copy(null, null));
     }
 
     @Test
-    public void copySgroups() throws Exception {
+    void copySgroups() throws Exception {
         List<Sgroup> sgroups = new ArrayList<>();
         IAtom a1 = Mockito.mock(IAtom.class);
         IAtom a2 = Mockito.mock(IAtom.class);
@@ -75,7 +74,7 @@ public class SgroupManipulatorTest {
 
 
     @Test
-    public void copySgroups2() throws Exception {
+    void copySgroups2() throws Exception {
         List<Sgroup>                 sgroups = new ArrayList<>();
         Map<IChemObject,IChemObject> replace = new HashMap<>();
 
@@ -109,9 +108,9 @@ public class SgroupManipulatorTest {
         assertThat(copiedSgroup.getSubscript(), is(sgroup.getSubscript()));
         assertThat(copiedSgroup.getAtoms(), is(not(sgroup.getAtoms())));
         assertThat(copiedSgroup.getBonds(), is(not(sgroup.getBonds())));
-        assertTrue(copiedSgroup.getAtoms().contains(a1copy));
-        assertTrue(copiedSgroup.getAtoms().contains(a2copy));
-        assertTrue(copiedSgroup.getBonds().contains(b1copy));
-        assertTrue(copiedSgroup.getBonds().contains(b2copy));
+        Assertions.assertTrue(copiedSgroup.getAtoms().contains(a1copy));
+        Assertions.assertTrue(copiedSgroup.getAtoms().contains(a2copy));
+        Assertions.assertTrue(copiedSgroup.getBonds().contains(b1copy));
+        Assertions.assertTrue(copiedSgroup.getBonds().contains(b2copy));
     }
 }
