@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.graph;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.test.CDKTestCase;
@@ -28,13 +28,13 @@ import org.openscience.cdk.interfaces.IBond;
 /**
  * @cdk.module test-standard
  */
-public class AtomContainerPermutorTest extends CDKTestCase {
+class AtomContainerPermutorTest extends CDKTestCase {
 
     @Test
-    public void testAtomPermutation() {
+    void testAtomPermutation() {
         AtomContainer ac = new org.openscience.cdk.AtomContainer();
         AtomContainer result;
-        String atoms = new String("");
+        String atoms;
         ac.addAtom(new Atom("C"));
         ac.addAtom(new Atom("N"));
         ac.addAtom(new Atom("P"));
@@ -56,14 +56,14 @@ public class AtomContainerPermutorTest extends CDKTestCase {
                 atoms += result.getAtom(f).getSymbol();
             }
         }
-        Assert.assertEquals(719, counter);
+        Assertions.assertEquals(719, counter);
     }
 
     @Test
-    public void testBondPermutation() {
+    void testBondPermutation() {
         AtomContainer ac = new org.openscience.cdk.AtomContainer();
         AtomContainer result;
-        String bonds = new String("");
+        String bonds;
         ac.addAtom(new Atom("C"));
         ac.addAtom(new Atom("N"));
         ac.addAtom(new Atom("P"));
@@ -86,7 +86,7 @@ public class AtomContainerPermutorTest extends CDKTestCase {
             }
             //logger.debug(bonds);
         }
-        Assert.assertEquals(119, counter);
+        Assertions.assertEquals(119, counter);
     }
 
 }
