@@ -19,23 +19,28 @@
  */
 package org.openscience.cdk.graph;
 
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.List;
 import java.util.Set;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.*;
+import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.exception.InvalidSmilesException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
+import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.io.HINReader;
 import org.openscience.cdk.io.ISimpleChemObjectReader;
 import org.openscience.cdk.io.MDLV2000Reader;
 import org.openscience.cdk.sgroup.Sgroup;
 import org.openscience.cdk.sgroup.SgroupType;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
+import org.openscience.cdk.smiles.SmiFlavor;
+import org.openscience.cdk.smiles.SmilesGenerator;
 import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.templates.TestMoleculeFactory;
 import org.openscience.cdk.test.CDKTestCase;
@@ -43,19 +48,17 @@ import org.openscience.cdk.tools.manipulator.ChemFileManipulator;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 
 /**
- *  Checks the functionality of the ConnectivityChecker
+ * Checks the functionality of the ConnectivityChecker
  *
+ * @author steinbeck
  * @cdk.module test-standard
- *
- * @author     steinbeck
- * @cdk.created    2001-07-24
+ * @cdk.created 2001-07-24
  */
-public class ConnectivityCheckerTest extends CDKTestCase {
+class ConnectivityCheckerTest extends CDKTestCase {
 
-    public ConnectivityCheckerTest() {
+    ConnectivityCheckerTest() {
         super();
     }
 
@@ -63,22 +66,22 @@ public class ConnectivityCheckerTest extends CDKTestCase {
      * This test tests the function of the partitionIntoMolecule() method.
      */
     @Test
-    public void testPartitionIntoMolecules_IAtomContainer() {
+    void testPartitionIntoMolecules_IAtomContainer() {
         //logger.debug(atomCon);
         AtomContainer atomCon = new org.openscience.cdk.AtomContainer();
         atomCon.add(TestMoleculeFactory.make4x3CondensedRings());
         atomCon.add(TestMoleculeFactory.makeAlphaPinene());
         atomCon.add(TestMoleculeFactory.makeSpiroRings());
         IAtomContainerSet moleculeSet = ConnectivityChecker.partitionIntoMolecules(atomCon);
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(3, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(3, moleculeSet.getAtomContainerCount());
     }
 
     /**
      * Test for SF bug #903551
      */
     @Test
-    public void testPartitionIntoMoleculesKeepsAtomIDs() {
+    void testPartitionIntoMoleculesKeepsAtomIDs() {
         AtomContainer atomCon = new org.openscience.cdk.AtomContainer();
         Atom atom1 = new Atom("C");
         atom1.setID("atom1");
@@ -87,13 +90,13 @@ public class ConnectivityCheckerTest extends CDKTestCase {
         atomCon.addAtom(atom1);
         atomCon.addAtom(atom2);
         IAtomContainerSet moleculeSet = ConnectivityChecker.partitionIntoMolecules(atomCon);
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(2, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(2, moleculeSet.getAtomContainerCount());
         org.openscience.cdk.interfaces.IAtom copy1 = moleculeSet.getAtomContainer(0).getAtom(0);
         org.openscience.cdk.interfaces.IAtom copy2 = moleculeSet.getAtomContainer(1).getAtom(0);
 
-        Assert.assertEquals(atom1.getID(), copy1.getID());
-        Assert.assertEquals(atom2.getID(), copy2.getID());
+        Assertions.assertEquals(atom1.getID(), copy1.getID());
+        Assertions.assertEquals(atom2.getID(), copy2.getID());
     }
 
     /**
@@ -101,19 +104,19 @@ public class ConnectivityCheckerTest extends CDKTestCase {
      * partitionIntoMolecules().
      */
     @Test
-    public void testPartitionIntoMolecules_IsConnected_Consistency() {
+    void testPartitionIntoMolecules_IsConnected_Consistency() {
         //logger.debug(atomCon);
         AtomContainer atomCon = new org.openscience.cdk.AtomContainer();
         atomCon.add(TestMoleculeFactory.make4x3CondensedRings());
         atomCon.add(TestMoleculeFactory.makeAlphaPinene());
         atomCon.add(TestMoleculeFactory.makeSpiroRings());
         IAtomContainerSet moleculeSet = ConnectivityChecker.partitionIntoMolecules(atomCon);
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(3, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(3, moleculeSet.getAtomContainerCount());
 
-        Assert.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(0)));
-        Assert.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(1)));
-        Assert.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(2)));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(0)));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(1)));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(2)));
     }
 
     /**
@@ -121,7 +124,7 @@ public class ConnectivityCheckerTest extends CDKTestCase {
      * method keeps LonePairs and SingleElectrons with its associated atoms.
      */
     @Test
-    public void testDontDeleteSingleElectrons() {
+    void testDontDeleteSingleElectrons() {
         AtomContainer atomCon = new org.openscience.cdk.AtomContainer();
         // make two molecules; one with an LonePair, the other with a SingleElectron
         IAtomContainer mol1 = new AtomContainer();
@@ -141,49 +144,49 @@ public class ConnectivityCheckerTest extends CDKTestCase {
 
         // now partition
         IAtomContainerSet moleculeSet = ConnectivityChecker.partitionIntoMolecules(atomCon);
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(2, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(2, moleculeSet.getAtomContainerCount());
 
-        Assert.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(0)));
-        Assert.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(1)));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(0)));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(moleculeSet.getAtomContainer(1)));
 
         // make sure
-        Assert.assertEquals(1, moleculeSet.getAtomContainer(0).getAtomCount());
-        Assert.assertEquals(1, moleculeSet.getAtomContainer(0).getElectronContainerCount());
-        Assert.assertEquals(1, moleculeSet.getAtomContainer(1).getAtomCount());
-        Assert.assertEquals(1, moleculeSet.getAtomContainer(1).getElectronContainerCount());
+        Assertions.assertEquals(1, moleculeSet.getAtomContainer(0).getAtomCount());
+        Assertions.assertEquals(1, moleculeSet.getAtomContainer(0).getElectronContainerCount());
+        Assertions.assertEquals(1, moleculeSet.getAtomContainer(1).getAtomCount());
+        Assertions.assertEquals(1, moleculeSet.getAtomContainer(1).getElectronContainerCount());
         // we don't know which partition contains the LP and which the electron
-        Assert.assertTrue(moleculeSet.getAtomContainer(0).getConnectedSingleElectronsCount(
+        Assertions.assertTrue(moleculeSet.getAtomContainer(0).getConnectedSingleElectronsCount(
                 moleculeSet.getAtomContainer(0).getAtom(0)) == 0
                 || moleculeSet.getAtomContainer(1).getConnectedSingleElectronsCount(
-                        moleculeSet.getAtomContainer(1).getAtom(0)) == 0);
-        Assert.assertTrue(moleculeSet.getAtomContainer(0).getConnectedLonePairsCount(
+                moleculeSet.getAtomContainer(1).getAtom(0)) == 0);
+        Assertions.assertTrue(moleculeSet.getAtomContainer(0).getConnectedLonePairsCount(
                 moleculeSet.getAtomContainer(0).getAtom(0)) == 0
                 || moleculeSet.getAtomContainer(1).getConnectedLonePairsCount(
-                        moleculeSet.getAtomContainer(1).getAtom(0)) == 0);
+                moleculeSet.getAtomContainer(1).getAtom(0)) == 0);
     }
 
     /**
      * This test tests the algorithm behind isConnected().
      */
     @Test
-    public void testIsConnected_IAtomContainer() {
+    void testIsConnected_IAtomContainer() {
         IAtomContainer spiro = TestMoleculeFactory.makeSpiroRings();
-        Assert.assertTrue(ConnectivityChecker.isConnected(spiro));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(spiro));
     }
 
     @Test
-    public void testIsConnectedArtemisinin1() throws InvalidSmilesException {
+    void testIsConnectedArtemisinin1() throws InvalidSmilesException {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer container = sp.parseSmiles("C1CN2CCN(CCCN(CCN(C1)Cc1ccccn1)CC2)C");
-        Assert.assertTrue(ConnectivityChecker.isConnected(container));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(container));
     }
 
     /**
      * @cdk.bug 2126904
      */
     @Test
-    public void testIsConnectedFromHINFile() throws Exception {
+    void testIsConnectedFromHINFile() throws Exception {
         String filename = "connectivity1.hin";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         ISimpleChemObjectReader reader = new HINReader(ins);
@@ -191,14 +194,14 @@ public class ConnectivityCheckerTest extends CDKTestCase {
         List<IAtomContainer> cList = ChemFileManipulator.getAllAtomContainers(content);
         IAtomContainer ac = cList.get(0);
 
-        Assert.assertTrue("Molecule appears not to be connected", ConnectivityChecker.isConnected(ac));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(ac), "Molecule appears not to be connected");
     }
 
     /**
-    * @cdk.bug 2126904
-    */
+     * @cdk.bug 2126904
+     */
     @Test
-    public void testIsConnectedFromSDFile() throws Exception {
+    void testIsConnectedFromSDFile() throws Exception {
         String filename = "mdeotest.sdf";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         ISimpleChemObjectReader reader = new MDLV2000Reader(ins);
@@ -206,51 +209,100 @@ public class ConnectivityCheckerTest extends CDKTestCase {
         List<IAtomContainer> cList = ChemFileManipulator.getAllAtomContainers(content);
         IAtomContainer ac = cList.get(0);
 
-        Assert.assertTrue("Molecule appears not to be connected", ConnectivityChecker.isConnected(ac));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(ac), "Molecule appears not to be connected");
     }
 
     @Test
-    public void testPartitionExtendedTetrahedral() throws Exception {
+    void testPartitionExtendedTetrahedral() throws Exception {
         SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         IAtomContainer container = smipar.parseSmiles("CC=[C@]=CC.C");
         IAtomContainerSet containerSet = ConnectivityChecker.partitionIntoMolecules(container);
         assertThat(containerSet.getAtomContainerCount(), is(2));
-        assertTrue(containerSet.getAtomContainer(0).stereoElements().iterator().hasNext());
+        Assertions.assertTrue(containerSet.getAtomContainer(0).stereoElements().iterator().hasNext());
     }
 
     /**
      * @cdk.bug 2784209
      */
     @Test
-    public void testNoAtomsIsConnected() {
+    void testNoAtomsIsConnected() {
         IAtomContainer container = new AtomContainer();
-        Assert.assertTrue("Molecule appears not to be connected", ConnectivityChecker.isConnected(container));
+        Assertions.assertTrue(ConnectivityChecker.isConnected(container), "Molecule appears not to be connected");
     }
 
     @Test
-    public void copySgroups() throws Exception {
+    void copySgroups() throws Exception {
         String filename = "sgroup-split.mol";
-        try(InputStream ins = this.getClass().getResourceAsStream(filename);
-            ISimpleChemObjectReader reader = new MDLV2000Reader(ins);
-        ){
+        try (InputStream ins = this.getClass().getResourceAsStream(filename);
+             ISimpleChemObjectReader reader = new MDLV2000Reader(ins)
+        ) {
             ChemFile content = (ChemFile) reader.read((ChemObject) new ChemFile());
             List<IAtomContainer> cList = ChemFileManipulator.getAllAtomContainers(content);
             IAtomContainer ac = cList.get(0);
             IAtomContainerSet containerSet = ConnectivityChecker.partitionIntoMolecules(ac);
-            Assert.assertEquals(2, containerSet.getAtomContainerCount());
+            Assertions.assertEquals(2, containerSet.getAtomContainerCount());
             IAtomContainer container1 = containerSet.getAtomContainer(0);
             IAtomContainer container2 = containerSet.getAtomContainer(1);
-            IAtomContainer h2o = container1.getAtomCount()<=3? container1 : container2;
-            Assert.assertNull( h2o.getProperty(CDKConstants.CTAB_SGROUPS));
-            IAtomContainer otherContainer = h2o == container1? container2: container1;
+            IAtomContainer h2o = container1.getAtomCount() <= 3 ? container1 : container2;
+            Assertions.assertNull(h2o.getProperty(CDKConstants.CTAB_SGROUPS));
+            IAtomContainer otherContainer = h2o == container1 ? container2 : container1;
             List<Sgroup> sgroups = otherContainer.getProperty(CDKConstants.CTAB_SGROUPS);
-            Assert.assertEquals(1, sgroups.size());
+            Assertions.assertEquals(1, sgroups.size());
             Sgroup sgroup = sgroups.get(0);
-            Assert.assertEquals(SgroupType.CtabStructureRepeatUnit, sgroup.getType());
+            Assertions.assertEquals(SgroupType.CtabStructureRepeatUnit, sgroup.getType());
             Set<IAtom> atoms = sgroup.getAtoms();
-            Assert.assertEquals(2, atoms.size());
+            Assertions.assertEquals(2, atoms.size());
 
         }
     }
 
+    @Test
+    void splitSgroups() throws IOException, CDKException {
+        IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
+        try (InputStream in = getClass().getResourceAsStream("sgroup-frags.mol");
+             MDLV2000Reader mdlr = new MDLV2000Reader(in)) {
+            IAtomContainer mol = mdlr.read(builder.newAtomContainer());
+            IAtomContainerSet acset = ConnectivityChecker.partitionIntoMolecules(mol);
+            Assertions.assertEquals(2, acset.getAtomContainerCount());
+            SmilesGenerator smigen = new SmilesGenerator(SmiFlavor.CxSmiles);
+            Assertions.assertEquals("CCOC |Sg:n:1,2:1:|", smigen.create(acset.getAtomContainer(0)));
+            Assertions.assertEquals("C(NC)C |Sg:n:0,1:1:|", smigen.create(acset.getAtomContainer(1)));
+        }
+    }
+
+    @Test
+    void splitSgroupsParent() throws IOException, CDKException {
+        IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
+        try (InputStream in = getClass().getResourceAsStream("sgroup-mix.mol");
+             MDLV2000Reader mdlr = new MDLV2000Reader(in)) {
+            IAtomContainer mol = mdlr.read(builder.newAtomContainer());
+            IAtomContainerSet acset = ConnectivityChecker.partitionIntoMolecules(mol);
+            Assertions.assertEquals(2, acset.getAtomContainerCount());
+            SmilesGenerator smigen = new SmilesGenerator(SmiFlavor.CxSmiles);
+            IAtomContainer part1 = acset.getAtomContainer(0);
+            IAtomContainer part2 = acset.getAtomContainer(1);
+            Assertions.assertEquals("C1CCCCC1 |Sg:c:0,1,2,3,4,5::|", smigen.create(part1));
+            Assertions.assertEquals("CO |Sg:c:0,1::|", smigen.create(part2));
+            List<Sgroup> sgroups1 = part1.getProperty(CDKConstants.CTAB_SGROUPS);
+            List<Sgroup> sgroups2 = part2.getProperty(CDKConstants.CTAB_SGROUPS);
+            Assertions.assertEquals(1, sgroups1.size());
+            Assertions.assertEquals(0, sgroups1.get(0).getParents().size());
+            Assertions.assertEquals(1, sgroups2.size());
+            Assertions.assertEquals(0, sgroups2.get(0).getParents().size());
+            List<Sgroup> orgSgroups = mol.getProperty(CDKConstants.CTAB_SGROUPS);
+            assertThat(orgSgroups.size(), is(3));
+            assertNonEmptySgrpParent(orgSgroups);
+        }
+    }
+
+    // check at least one of the sgroups has a non-empty parent
+    private void assertNonEmptySgrpParent(List<Sgroup> orgSgroups) {
+        boolean found = false;
+        for (Sgroup orgSgroup : orgSgroups) {
+            if (!orgSgroup.getParents().isEmpty())
+                found = true;
+        }
+        Assertions.assertTrue(found);
+    }
+
 }
