@@ -18,28 +18,28 @@
  */
 package org.openscience.cdk.graph.rebond;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class BsptTest extends CDKTestCase {
+class BsptTest extends CDKTestCase {
 
-    public BsptTest() {
+    BsptTest() {
         super();
     }
 
     @Test
-    public void testToString() {
+    void testToString() {
         Bspt bspt = new Bspt(3);
-        Assert.assertNotNull(bspt.toString());
+        Assertions.assertNotNull(bspt.toString());
     }
 
     @Test
-    public void testBspt() {
+    void testBspt() {
         Bspt bspt = new Bspt(3);
-        Assert.assertNotNull(bspt);
+        Assertions.assertNotNull(bspt);
     }
 }
