@@ -18,22 +18,22 @@
  */
 package org.openscience.cdk.math;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class FortranFormatTest extends CDKTestCase {
+class FortranFormatTest extends CDKTestCase {
 
-    public FortranFormatTest() {
+    FortranFormatTest() {
         super();
     }
 
     @Test
-    public void testAtof_String() {
-        Assert.assertEquals(1.5, FortranFormat.atof("1.5"), 0.0001);
+    void testAtof_String() {
+        Assertions.assertEquals(1.5, FortranFormat.atof("1.5"), 0.0001);
 
         // FIXME: need to add something here with a 'd'
     }
