@@ -18,80 +18,80 @@
  */
 package org.openscience.cdk.qsar.result;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 
 /**
  * @cdk.module test-standard
  */
-public class DoubleArrayResultTest extends CDKTestCase {
+class DoubleArrayResultTest extends CDKTestCase {
 
-    public DoubleArrayResultTest() {
+    DoubleArrayResultTest() {
         super();
     }
 
     @Test
-    public void testDoubleArrayResult_int() {
+    void testDoubleArrayResult_int() {
         DoubleArrayResult result = new DoubleArrayResult(5);
-        Assert.assertNotNull(result);
-        Assert.assertEquals(5, result.length());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals(5, result.length());
     }
 
     @Test
-    public void testDoubleArrayResult() {
+    void testDoubleArrayResult() {
         DoubleArrayResult result = new DoubleArrayResult();
-        Assert.assertNotNull(result);
-        Assert.assertEquals(0, result.length());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals(0, result.length());
     }
 
     @Test
-    public void testSize() {
+    void testSize() {
         DoubleArrayResult result = new DoubleArrayResult();
-        Assert.assertNotNull(result);
-        Assert.assertEquals(0, result.length());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals(0, result.length());
         result.add(5);
-        Assert.assertEquals(1, result.length());
+        Assertions.assertEquals(1, result.length());
     }
 
     @Test
-    public void testAdd_double() {
+    void testAdd_double() {
         DoubleArrayResult result = new DoubleArrayResult();
-        Assert.assertNotNull(result);
-        Assert.assertEquals("", result.toString());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals("", result.toString());
         result.add(5);
         result.add(2);
         result.add(-3);
-        Assert.assertEquals(3, result.length());
+        Assertions.assertEquals(3, result.length());
     }
 
     @Test
-    public void testToString() {
+    void testToString() {
         DoubleArrayResult result = new DoubleArrayResult();
-        Assert.assertNotNull(result);
-        Assert.assertEquals("", result.toString());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals("", result.toString());
         result.add(5);
-        Assert.assertEquals("5.0", result.toString());
+        Assertions.assertEquals("5.0", result.toString());
         result.add(2);
-        Assert.assertEquals("5.0,2.0", result.toString());
+        Assertions.assertEquals("5.0,2.0", result.toString());
         result.add(-3);
-        Assert.assertEquals("5.0,2.0,-3.0", result.toString());
+        Assertions.assertEquals("5.0,2.0,-3.0", result.toString());
     }
 
     @Test
-    public void testGet_int() {
+    void testGet_int() {
         DoubleArrayResult result = new DoubleArrayResult();
-        Assert.assertNotNull(result);
-        Assert.assertEquals("", result.toString());
+        Assertions.assertNotNull(result);
+        Assertions.assertEquals("", result.toString());
         result.add(5);
-        Assert.assertEquals(5, result.get(0), 0.000001);
+        Assertions.assertEquals(5, result.get(0), 0.000001);
         result.add(2);
-        Assert.assertEquals(5, result.get(0), 0.000001);
-        Assert.assertEquals(2, result.get(1), 0.000001);
+        Assertions.assertEquals(5, result.get(0), 0.000001);
+        Assertions.assertEquals(2, result.get(1), 0.000001);
         result.add(-1);
-        Assert.assertEquals(5, result.get(0), 0.000001);
-        Assert.assertEquals(2, result.get(1), 0.000001);
-        Assert.assertEquals(-1, result.get(2), 0.000001);
+        Assertions.assertEquals(5, result.get(0), 0.000001);
+        Assertions.assertEquals(2, result.get(1), 0.000001);
+        Assertions.assertEquals(-1, result.get(2), 0.000001);
     }
 
 }
