@@ -20,8 +20,8 @@ package org.openscience.cdk.tools;
 
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.AtomContainerSet;
@@ -35,14 +35,14 @@ import org.openscience.cdk.tools.manipulator.MoleculeSetManipulator;
 /**
  * @cdk.module test-standard
  */
-public class IDCreatorTest extends CDKTestCase {
+class IDCreatorTest extends CDKTestCase {
 
-    public IDCreatorTest() {
+    IDCreatorTest() {
         super();
     }
 
     @Test
-    public void testCreateIDs_IChemObject() {
+    void testCreateIDs_IChemObject() {
         IAtomContainer mol = new AtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
@@ -52,14 +52,14 @@ public class IDCreatorTest extends CDKTestCase {
         mol.addBond(bond);
 
         IDCreator.createIDs(mol);
-        Assert.assertEquals("a1", atom1.getID());
-        Assert.assertEquals("b1", bond.getID());
+        Assertions.assertEquals("a1", atom1.getID());
+        Assertions.assertEquals("b1", bond.getID());
         List<String> ids = AtomContainerManipulator.getAllIDs(mol);
-        Assert.assertEquals(4, ids.size());
+        Assertions.assertEquals(4, ids.size());
     }
 
     @Test
-    public void testKeepingIDs() {
+    void testKeepingIDs() {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("C");
         atom.setID("atom1");
@@ -67,14 +67,14 @@ public class IDCreatorTest extends CDKTestCase {
 
         IDCreator.createIDs(mol);
 
-        Assert.assertEquals("atom1", atom.getID());
-        Assert.assertNotNull(mol.getID());
+        Assertions.assertEquals("atom1", atom.getID());
+        Assertions.assertNotNull(mol.getID());
         List<String> ids = AtomContainerManipulator.getAllIDs(mol);
-        Assert.assertEquals(2, ids.size());
+        Assertions.assertEquals(2, ids.size());
     }
 
     @Test
-    public void testNoDuplicateCreation() {
+    void testNoDuplicateCreation() {
         IAtomContainer mol = new AtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
@@ -83,16 +83,16 @@ public class IDCreatorTest extends CDKTestCase {
         mol.addAtom(atom1);
 
         IDCreator.createIDs(mol);
-        Assert.assertEquals("a2", atom2.getID());
+        Assertions.assertEquals("a2", atom2.getID());
         List<String> ids = AtomContainerManipulator.getAllIDs(mol);
-        Assert.assertEquals(3, ids.size());
+        Assertions.assertEquals(3, ids.size());
     }
 
     /**
      * @cdk.bug 1455341
      */
     @Test
-    public void testCallingTwice() {
+    void testCallingTwice() {
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer mol = new AtomContainer();
         Atom atom0 = new Atom("C");
@@ -104,7 +104,7 @@ public class IDCreatorTest extends CDKTestCase {
 
         IDCreator.createIDs(molSet);
         List<String> ids = MoleculeSetManipulator.getAllIDs(molSet);
-        Assert.assertEquals(4, ids.size());
+        Assertions.assertEquals(4, ids.size());
 
         mol = new AtomContainer();
         Atom atom1 = new Atom("C");
@@ -116,7 +116,7 @@ public class IDCreatorTest extends CDKTestCase {
 
         IDCreator.createIDs(molSet);
         ids = MoleculeSetManipulator.getAllIDs(molSet);
-        Assert.assertEquals(7, ids.size());
+        Assertions.assertEquals(7, ids.size());
 
         mol = new AtomContainer();
         atom1 = new Atom("C");
@@ -127,12 +127,12 @@ public class IDCreatorTest extends CDKTestCase {
 
         atom0.setID("atomX");
         ids = MoleculeSetManipulator.getAllIDs(molSet);
-        Assert.assertFalse(ids.contains("a1"));
+        Assertions.assertFalse(ids.contains("a1"));
 
         IDCreator.createIDs(molSet);
         List<String> idsAfter = MoleculeSetManipulator.getAllIDs(molSet);
-        Assert.assertTrue(idsAfter.contains("a1"));
-        Assert.assertEquals(10, idsAfter.size());
+        Assertions.assertTrue(idsAfter.contains("a1"));
+        Assertions.assertEquals(10, idsAfter.size());
     }
 
 }
