@@ -18,9 +18,9 @@
  */
 package org.openscience.cdk.tools;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomType;
 import org.openscience.cdk.Bond;
@@ -33,6 +33,7 @@ import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IBond.Order;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.silent.AtomContainer;
 import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.SmilesParser;
@@ -47,15 +48,15 @@ import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
  * @cdk.created 2012-04-18
  * @cdk.module  test-valencycheck
  */
-public class ATASaturationCheckerTest extends CDKTestCase {
+class ATASaturationCheckerTest extends CDKTestCase {
 
-    SaturationChecker                      satcheck   = null;
+    private SaturationChecker                      satcheck   = null;
     boolean                                standAlone = false;
-    private static SmilesParser            sp         = new SmilesParser(SilentChemObjectBuilder.getInstance());
-    private AtomTypeAwareSaturationChecker atasc      = new AtomTypeAwareSaturationChecker();
+    private static final SmilesParser            sp         = new SmilesParser(SilentChemObjectBuilder.getInstance());
+    private final AtomTypeAwareSaturationChecker atasc      = new AtomTypeAwareSaturationChecker();
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         satcheck = new SaturationChecker();
     }
 
@@ -65,7 +66,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testASimpleCarbonRing() throws Exception {
+    void testASimpleCarbonRing() throws Exception {
         // First we create a simple carbon ring to play with...
         IAtomContainer mol = new AtomContainer();
         IAtomType carbon = new AtomType(Elements.CARBON);
@@ -128,14 +129,14 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         // ...then we send it to the method we want to test...
         atasc.decideBondOrder(mol, false);
 
-        Assert.assertEquals(IBond.Order.DOUBLE, b0.getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, b1.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b2.getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, b3.getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, b4.getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, b5.getOrder());
+        Assertions.assertEquals(Order.DOUBLE, b0.getOrder());
+        Assertions.assertEquals(Order.SINGLE, b1.getOrder());
+        Assertions.assertEquals(Order.DOUBLE, b2.getOrder());
+        Assertions.assertEquals(Order.SINGLE, b3.getOrder());
+        Assertions.assertEquals(Order.DOUBLE, b4.getOrder());
+        Assertions.assertEquals(Order.SINGLE, b5.getOrder());
 
-        Assert.assertTrue(satcheck.isSaturated(a0, mol));
+        Assertions.assertTrue(satcheck.isSaturated(a0, mol));
 
     }
 
@@ -145,47 +146,47 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testQuinone() throws Exception {
+    void testQuinone() throws Exception {
         IAtomContainer mol = sp.parseSmiles("O=c1ccc(=O)cc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
 
-        Assert.assertTrue(mol.getAtom(1).getHybridization() == IAtomType.Hybridization.SP2);
+        Assertions.assertSame(IAtomType.Hybridization.SP2, mol.getAtom(1).getHybridization());
 
-        Assert.assertTrue(mol.getBond(0).getEnd().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(0).getBegin().getSymbol().equals("O"));
-        Assert.assertEquals(mol.getBond(0).getOrder(), IBond.Order.DOUBLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(0).getEnd().getAtomicNumber());
+        Assertions.assertEquals(IElement.O, (int) mol.getBond(0).getBegin().getAtomicNumber());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(0).getOrder());
 
-        Assert.assertTrue(mol.getBond(1).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(1).getEnd().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(1).getOrder(), IBond.Order.SINGLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(1).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(1).getEnd().getAtomicNumber());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(1).getOrder());
 
-        Assert.assertTrue(mol.getBond(2).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(2).getEnd().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(2).getOrder(), IBond.Order.DOUBLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(2).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(2).getEnd().getAtomicNumber());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(2).getOrder());
 
-        Assert.assertTrue(mol.getBond(3).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(3).getEnd().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(3).getOrder(), IBond.Order.SINGLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(3).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(3).getEnd().getAtomicNumber());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(3).getOrder());
 
-        Assert.assertTrue(mol.getBond(4).getEnd().getSymbol().equals("O"));
-        Assert.assertTrue(mol.getBond(4).getBegin().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(4).getOrder(), IBond.Order.DOUBLE);
+        Assertions.assertEquals(IElement.O, (int) mol.getBond(4).getEnd().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(4).getBegin().getAtomicNumber());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(4).getOrder());
 
-        Assert.assertTrue(mol.getBond(5).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(5).getEnd().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(5).getOrder() == IBond.Order.SINGLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(5).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(5).getEnd().getAtomicNumber());
+        Assertions.assertSame(Order.SINGLE, mol.getBond(5).getOrder());
 
-        Assert.assertTrue(mol.getBond(6).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(6).getEnd().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(6).getOrder(), IBond.Order.DOUBLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(6).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(6).getEnd().getAtomicNumber());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(6).getOrder());
 
-        Assert.assertTrue(mol.getBond(7).getBegin().getSymbol().equals("C"));
-        Assert.assertTrue(mol.getBond(7).getEnd().getSymbol().equals("C"));
-        Assert.assertEquals(mol.getBond(7).getOrder(), IBond.Order.SINGLE);
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(7).getBegin().getAtomicNumber());
+        Assertions.assertEquals(IElement.C, (int) mol.getBond(7).getEnd().getAtomicNumber());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(7).getOrder());
 
-        Assert.assertEquals(mol.getBond(0).getEnd(), mol.getBond(7).getBegin());
+        Assertions.assertEquals(mol.getBond(0).getEnd(), mol.getBond(7).getBegin());
     }
 
     /**
@@ -194,19 +195,19 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws CDKException
      */
     @Test
-    public void testASimpleCarbonRing2() throws CDKException {
+    void testASimpleCarbonRing2() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1ccccc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
 
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
-        Assert.assertEquals(mol.getBond(0).getOrder(), IBond.Order.DOUBLE);
-        Assert.assertEquals(mol.getBond(1).getOrder(), IBond.Order.SINGLE);
-        Assert.assertEquals(mol.getBond(2).getOrder(), IBond.Order.DOUBLE);
-        Assert.assertEquals(mol.getBond(3).getOrder(), IBond.Order.SINGLE);
-        Assert.assertEquals(mol.getBond(4).getOrder(), IBond.Order.DOUBLE);
-        Assert.assertEquals(mol.getBond(5).getOrder(), IBond.Order.SINGLE);
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(mol.getBond(0).getOrder(), Order.DOUBLE);
+        Assertions.assertEquals(mol.getBond(1).getOrder(), Order.SINGLE);
+        Assertions.assertEquals(mol.getBond(2).getOrder(), Order.DOUBLE);
+        Assertions.assertEquals(mol.getBond(3).getOrder(), Order.SINGLE);
+        Assertions.assertEquals(mol.getBond(4).getOrder(), Order.DOUBLE);
+        Assertions.assertEquals(mol.getBond(5).getOrder(), Order.SINGLE);
     }
 
     /**
@@ -215,7 +216,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testALargeRingSystem() throws Exception {
+    void testALargeRingSystem() throws Exception {
         // Should have 13 double bonds.
         String smiles = "O=C1Oc6ccccc6(C(O)C1C5c2ccccc2CC(c3ccc(cc3)c4ccccc4)C5)";
         IAtomContainer mol = sp.parseSmiles(smiles);
@@ -226,7 +227,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(13, doubleBondCount);
+        Assertions.assertEquals(13, doubleBondCount);
     }
 
     /**
@@ -235,7 +236,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testLargeRingSystem1() throws Exception {
+    void testLargeRingSystem1() throws Exception {
         // Should have 6 double bonds
         String smiles = "c1ccc2c(c1)CC4NCCc3cccc2c34";
         IAtomContainer mol = sp.parseSmiles(smiles);
@@ -245,11 +246,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(6, doubleBondCount);
+        Assertions.assertEquals(6, doubleBondCount);
     }
 
     @Test
-    public void testLargeRingSystem2() throws Exception {
+    void testLargeRingSystem2() throws Exception {
         // Should have 8 double bonds
         String smiles = "Oc1ccc(cc1)c1coc2c(c1=O)c(O)cc(c2)O";
         IAtomContainer mol = sp.parseSmiles(smiles);
@@ -259,11 +260,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(8, doubleBondCount);
+        Assertions.assertEquals(8, doubleBondCount);
     }
 
     @Test
-    public void testADoubleRingWithANitrogenAtom() throws Exception {
+    void testADoubleRingWithANitrogenAtom() throws Exception {
         /*
          * Should have 4 double bonds and all three bonds to/from the nitrogen
          * should be single
@@ -281,12 +282,12 @@ public class ATASaturationCheckerTest extends CDKTestCase {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
             if (bond.contains(nitrogen)) if (bond.getOrder().equals(Order.SINGLE)) singleBondCount++;
         }
-        Assert.assertEquals(4, doubleBondCount);
-        Assert.assertEquals(3, singleBondCount);
+        Assertions.assertEquals(4, doubleBondCount);
+        Assertions.assertEquals(3, singleBondCount);
     }
 
     @Test
-    public void testLargeRingSystem3() throws Exception {
+    void testLargeRingSystem3() throws Exception {
         // Should have 17 double bonds
         String smiles = "O=C5C=C(O)C(N=Nc1ccc(cc1)Nc2ccccc2)=CC5(=NNc3ccc(cc3)Nc4ccccc4)";
         IAtomContainer mol = sp.parseSmiles(smiles);
@@ -296,11 +297,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(17, doubleBondCount);
+        Assertions.assertEquals(17, doubleBondCount);
     }
 
     @Test
-    public void testLargeRingSystem4() throws Exception {
+    void testLargeRingSystem4() throws Exception {
         // Should have 18 double bonds
         String smiles = "c1ccc(cc1)[Sn](c2ccccc2)(c3ccccc3)S[Sn](c4ccccc4)(c5ccccc5)c6ccccc6";
         IAtomContainer mol = sp.parseSmiles(smiles);
@@ -310,11 +311,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(18, doubleBondCount);
+        Assertions.assertEquals(18, doubleBondCount);
     }
 
     @Test
-    public void testLargeRingSystem5() throws Exception {
+    void testLargeRingSystem5() throws Exception {
         // Should have 24 double bonds
         String smiles = "O=C1c2ccccc2C(=O)c3c1ccc4c3[nH]c5c6C(=O)c7ccccc7C(=O)c6c8[nH]c9c%10C(=O)c%11ccccc%11C(=O)c%10ccc9c8c45";
 
@@ -325,7 +326,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder().equals(Order.DOUBLE)) doubleBondCount++;
         }
-        Assert.assertEquals(24, doubleBondCount);
+        Assertions.assertEquals(24, doubleBondCount);
     }
 
     /**
@@ -334,7 +335,7 @@ public class ATASaturationCheckerTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testLargeBioclipseUseCase() throws Exception {
+    void testLargeBioclipseUseCase() throws Exception {
         // Should have 14 double bonds
         String smiles = "COc1ccc2[C@@H]3[C@H](COc2c1)C(C)(C)OC4=C3C(=O)C(=O)C5=C4OC(C)(C)[C@@H]6COc7cc(OC)ccc7[C@H]56";
         IAtomContainer molecule = sp.parseSmiles(smiles);
@@ -346,98 +347,98 @@ public class ATASaturationCheckerTest extends CDKTestCase {
             IBond bond = molecule.getBond(i);
             if (bond.getOrder() == Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(10, doubleBondCount);
+        Assertions.assertEquals(10, doubleBondCount);
     }
 
     @Test
-    public void testCyclobutadiene() throws CDKException {
+    void testCyclobutadiene() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1ccc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(0).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(1).getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(2).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(3).getOrder());
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(0).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(1).getOrder());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(2).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(3).getOrder());
     }
 
     @Test
-    public void testPyrrole() throws CDKException {
+    void testPyrrole() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1c[nH]cc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(0).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(1).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(2).getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(3).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(4).getOrder());
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(0).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(1).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(2).getOrder());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(3).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(4).getOrder());
     }
 
     @Test
-    public void testFurane() throws CDKException {
+    void testFurane() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1cocc1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(0).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(1).getOrder());
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(0).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(1).getOrder());
         //bond to oxygen
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(2).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(2).getOrder());
         //bond to oxygen
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(3).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(4).getOrder());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(3).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(4).getOrder());
     }
 
     @Test
-    public void testAnOtherDoubleRing() throws CDKException {
+    void testAnOtherDoubleRing() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1cccc2cccc2c1");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
 
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
         int doubleBondCount = 0;
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(5, doubleBondCount);
+        Assertions.assertEquals(5, doubleBondCount);
     }
 
     @Test
-    public void testAnOtherRingSystem() throws CDKException {
+    void testAnOtherRingSystem() throws CDKException {
         // Should have 7 double bonds
         //    	IAtomContainer mol = sp.parseSmiles("O=c2c1ccccc1c3ccccc23");
         // Should have 6 double bonds
         IAtomContainer mol = sp.parseSmiles("o2c1ccccc1c3c2cccc3");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
         int doubleBondCount = 0;
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(6, doubleBondCount);
+        Assertions.assertEquals(6, doubleBondCount);
     }
 
     @Test
-    public void testAnOtherRingSystem2() throws CDKException {
+    void testAnOtherRingSystem2() throws CDKException {
         // Should have 7 double bonds
         IAtomContainer mol = sp.parseSmiles("O=c2c1ccccc1c3ccccc23");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         atasc.decideBondOrder(mol, true);
-        Assert.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
+        Assertions.assertEquals(mol.getAtom(1).getHybridization(), IAtomType.Hybridization.SP2);
         int doubleBondCount = 0;
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(7, doubleBondCount);
+        Assertions.assertEquals(7, doubleBondCount);
     }
 
     @Test
-    public void testAzulene() throws CDKException {
+    void testAzulene() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c12c(ccccc2)ccc1");
         atasc.decideBondOrder(mol, true);
 
@@ -445,13 +446,13 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(5, doubleBondCount);
+        Assertions.assertEquals(5, doubleBondCount);
 
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(0).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(0).getOrder());
     }
 
     @Test
-    public void mailCase1a() throws CDKException {
+    void mailCase1a() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("o1cccc1");
         atasc.decideBondOrder(mol, true);
 
@@ -459,11 +460,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(2, doubleBondCount);
+        Assertions.assertEquals(2, doubleBondCount);
     }
 
     @Test
-    public void mailCase1b() throws CDKException {
+    void mailCase1b() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("O1cccc1");
         atasc.decideBondOrder(mol, true);
 
@@ -471,11 +472,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(2, doubleBondCount);
+        Assertions.assertEquals(2, doubleBondCount);
     }
 
     @Test
-    public void mailCase3b() throws CDKException {
+    void mailCase3b() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1ccccc1Oc1cOcc1");
         atasc.decideBondOrder(mol, true);
 
@@ -483,11 +484,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(5, doubleBondCount);
+        Assertions.assertEquals(5, doubleBondCount);
     }
 
     @Test
-    public void mailCase4() throws CDKException {
+    void mailCase4() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("o2c1ccccc1c3c2cccc3");
         atasc.decideBondOrder(mol, true);
 
@@ -495,11 +496,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(6, doubleBondCount);
+        Assertions.assertEquals(6, doubleBondCount);
     }
 
     @Test
-    public void mailCase5a() throws CDKException {
+    void mailCase5a() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c5cc2ccc1ccccc1c2c6c4c3ccccc3ccc4ccc56");
         atasc.decideBondOrder(mol, true);
 
@@ -507,11 +508,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(13, doubleBondCount);
+        Assertions.assertEquals(13, doubleBondCount);
     }
 
     @Test
-    public void mailCase5b() throws CDKException {
+    void mailCase5b() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1cc2ccc3ccc4ccc5ccc6ccc1c7c2c3c4c5c67");
 
         atasc.decideBondOrder(mol, true);
@@ -521,11 +522,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
 
-        Assert.assertEquals(12, doubleBondCount);
+        Assertions.assertEquals(12, doubleBondCount);
     }
 
     @Test
-    public void mailCase6() throws CDKException {
+    void mailCase6() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("c1ccc2c(c1)cc-3c4c2cccc4-c5c3cccc5");
         atasc.decideBondOrder(mol, true);
 
@@ -533,11 +534,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(10, doubleBondCount);
+        Assertions.assertEquals(10, doubleBondCount);
     }
 
     @Test
-    public void testNPolycyclicCompounds() throws CDKException {
+    void testNPolycyclicCompounds() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("n12cncc1cccc2");
         atasc.decideBondOrder(mol, true);
 
@@ -545,11 +546,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(4, doubleBondCount);
+        Assertions.assertEquals(4, doubleBondCount);
     }
 
     @Test
-    public void testIndoles2() throws CDKException {
+    void testIndoles2() throws CDKException {
         IAtomContainer mol = sp
                 .parseSmiles("Cl.Cl.Oc1ccc2CC3[C@](Cc4c(-c5ccccc5)c(C)[nH0](Cc5ccccc5)c4[C@@H]([C@](CCN3CC3CC3)(c2c1O1)2)1)2(O)");
         atasc.decideBondOrder(mol, true);
@@ -558,11 +559,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(11, doubleBondCount);
+        Assertions.assertEquals(11, doubleBondCount);
     }
 
     @Test
-    public void someOtherWieredDoubleRing() throws CDKException {
+    void someOtherWieredDoubleRing() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("CCc2c3ccccc3[nH]c2");
         atasc.decideBondOrder(mol, true);
 
@@ -570,11 +571,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds())
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
 
-        Assert.assertEquals(4, doubleBondCount);
+        Assertions.assertEquals(4, doubleBondCount);
     }
 
     @Test
-    public void testButadieneSmile() throws Exception {
+    void testButadieneSmile() throws Exception {
         IAtomContainer mol = sp.parseSmiles("cccc");
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
         /*
@@ -590,11 +591,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(2, doubleBondCount);
+        Assertions.assertEquals(2, doubleBondCount);
     }
 
     @Test
-    public void testButadiene() throws Exception {
+    void testButadiene() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtomType carbon = new AtomType(Elements.CARBON);
 
@@ -636,13 +637,13 @@ public class ATASaturationCheckerTest extends CDKTestCase {
 
         atasc.decideBondOrder(mol, true);
 
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(0).getOrder());
-        Assert.assertEquals(IBond.Order.SINGLE, mol.getBond(1).getOrder());
-        Assert.assertEquals(IBond.Order.DOUBLE, mol.getBond(2).getOrder());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(0).getOrder());
+        Assertions.assertEquals(Order.SINGLE, mol.getBond(1).getOrder());
+        Assertions.assertEquals(Order.DOUBLE, mol.getBond(2).getOrder());
     }
 
     @Test
-    public void testMolFromSdf() throws CDKException {
+    void testMolFromSdf() throws CDKException {
         IAtomContainer mol = sp.parseSmiles("OC(COc1ccccc1CC=C)CNC(C)C");
         atasc.decideBondOrder(mol, true);
 
@@ -650,11 +651,11 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         for (IBond bond : mol.bonds()) {
             if (bond.getOrder() == IBond.Order.DOUBLE) doubleBondCount++;
         }
-        Assert.assertEquals(4, doubleBondCount);
+        Assertions.assertEquals(4, doubleBondCount);
     }
 
     @Test
-    public void testOnlyOneAtom() throws CDKException {
+    void testOnlyOneAtom() throws CDKException {
         /*
          * If all bonds in the molecule are implicit, then it was noticed that
          * the SatChecker failed
@@ -664,19 +665,19 @@ public class ATASaturationCheckerTest extends CDKTestCase {
         int preBondCount = mol.getBondCount();
         atasc.decideBondOrder(mol);
 
-        Assert.assertEquals(preBondCount, mol.getBondCount());
+        Assertions.assertEquals(preBondCount, mol.getBondCount());
     }
 
     @Test
-    public void testBug3394() {
+    void testBug3394() {
         IAtomContainer mol;
         try {
             mol = sp.parseSmiles("OCC1OC(O)C(O)C(Op2(OC3C(O)C(O)OC(CO)C3O)np(OC4C(O)C(O)OC(CO)C4O)(OC5C(O)C(O)OC(CO)C5O)np(OC6C(O)C(O)OC(CO)C6O)(OC7C(O)C(O)OC(CO)C7O)n2)C1O");
             atasc.decideBondOrder(mol);
         } catch (InvalidSmilesException e) {
-            Assert.fail("SMILES failed");
+            Assertions.fail("SMILES failed");
         } catch (CDKException e) {
-            Assert.fail("ATASatChecer failed");
+            Assertions.fail("ATASatChecer failed");
         }
 
     }
