@@ -27,7 +27,6 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.BitSet;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
@@ -94,8 +93,8 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
     /**
      * The default length of created fingerprints.
      */
-    private int                 fingerprintLength;
-    private static ILoggingTool logger           = LoggingToolFactory
+    private final int                 fingerprintLength;
+    private static final ILoggingTool logger           = LoggingToolFactory
                                                          .createLoggingTool(ShortestPathFingerprinter.class);
 
     /**
@@ -128,7 +127,7 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
 
         IAtomContainer atomContainer = null;
         try {
-            atomContainer = (IAtomContainer) ac.clone();
+            atomContainer = ac.clone();
         } catch (CloneNotSupportedException ex) {
             logger.error("Failed to clone the molecule:", ex);
         }
@@ -187,7 +186,7 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
 
         ShortestPathWalker walker = new ShortestPathWalker(container);
         // convert paths to hashes
-        List<Integer> paths = new ArrayList<Integer>();
+        List<Integer> paths = new ArrayList<>();
         int patternIndex = 0;
 
         for (String s : walker.paths()) {
@@ -201,8 +200,7 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
          */
         IRingSet sssr = Cycles.essential(container).toRingSet();
         RingSetManipulator.sort(sssr);
-        for (Iterator<IAtomContainer> it = sssr.atomContainers().iterator(); it.hasNext();) {
-            IAtomContainer ring = it.next();
+        for (IAtomContainer ring : sssr.atomContainers()) {
             int toHashCode = String.valueOf(ring.getAtomCount()).hashCode();
             paths.add(patternIndex, toHashCode);
             patternIndex++;
@@ -210,9 +208,8 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
         /*
          * Check for the charges
          */
-        List<String> l = new ArrayList<String>();
-        for (Iterator<IAtom> it = container.atoms().iterator(); it.hasNext();) {
-            IAtom atom = it.next();
+        List<String> l = new ArrayList<>();
+        for (IAtom atom : container.atoms()) {
             int charge = atom.getFormalCharge() == null ? 0 : atom.getFormalCharge();
             if (charge != 0) {
                 l.add(atom.getSymbol().concat(String.valueOf(charge)));
@@ -223,12 +220,11 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
         paths.add(patternIndex, toHashCode);
         patternIndex++;
 
-        l = new ArrayList<String>();
+        l = new ArrayList<>();
         /*
          * atom stereo parity
          */
-        for (Iterator<IAtom> it = container.atoms().iterator(); it.hasNext();) {
-            IAtom atom = it.next();
+        for (IAtom atom : container.atoms()) {
             int st = atom.getStereoParity() == null ? 0 : atom.getStereoParity();
             if (st != 0) {
                 l.add(atom.getSymbol().concat(String.valueOf(st)));
@@ -241,13 +237,13 @@ public class ShortestPathFingerprinter extends AbstractFingerprinter implements
 
         if (container.getSingleElectronCount() > 0) {
             StringBuilder radicalInformation = new StringBuilder();
-            radicalInformation.append("RAD: ").append(String.valueOf(container.getSingleElectronCount()));
+            radicalInformation.append("RAD: ").append(container.getSingleElectronCount());
             paths.add(patternIndex, radicalInformation.toString().hashCode());
             patternIndex++;
         }
         if (container.getLonePairCount() > 0) {
             StringBuilder lpInformation = new StringBuilder();
-            lpInformation.append("LP: ").append(String.valueOf(container.getLonePairCount()));
+            lpInformation.append("LP: ").append(container.getLonePairCount());
             paths.add(patternIndex, lpInformation.toString().hashCode());
             patternIndex++;
         }
