@@ -30,7 +30,6 @@ package org.openscience.cdk.fingerprint;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertNotNull;
 
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
@@ -45,10 +44,10 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 
 import org.hamcrest.CoreMatchers;
+import org.junit.jupiter.api.Assertions;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.CDK;
 import org.openscience.cdk.test.CDKTestCase;
-import org.openscience.cdk.test.SlowTest;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.exception.InvalidSmilesException;
 import org.openscience.cdk.interfaces.IAtom;
@@ -63,8 +62,8 @@ import org.openscience.cdk.smiles.SmilesParser;
 import org.openscience.cdk.tools.ILoggingTool;
 import org.openscience.cdk.tools.LoggingToolFactory;
 
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
@@ -72,9 +71,9 @@ import javax.vecmath.Point3d;
 /**
  * @cdk.module test-standard
  */
-public class CircularFingerprinterTest extends CDKTestCase {
+class CircularFingerprinterTest extends CDKTestCase {
 
-    private static ILoggingTool   logger     = LoggingToolFactory.createLoggingTool(CircularFingerprinterTest.class);
+    private static final ILoggingTool   logger     = LoggingToolFactory.createLoggingTool(CircularFingerprinterTest.class);
 
     private static IAtomContainer trivialMol = null;
     static {
@@ -86,8 +85,8 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    @Category(SlowTest.class)
-    public void testFingerprints() throws Exception {
+    @Tag("SlowTest")
+    void testFingerprints() throws Exception {
         logger.info("CircularFingerprinter test: loading source materials");
 
         String fnzip = "data/cdd/circular_validation.zip";
@@ -99,7 +98,8 @@ public class CircularFingerprinterTest extends CDKTestCase {
         logger.info("CircularFingerprinter test: completed without any problems");
     }
 
-    @Test public void testUseStereoElements() throws CDKException {
+    @Test
+    void testUseStereoElements() throws CDKException {
         final String smiles1  = "CC[C@@H](C)O";
         final String smiles2  = "CC[C@H](O)C";
         final String molfile = "\n"
@@ -138,7 +138,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    public void testGetBitFingerprint() throws Exception {
+    void testGetBitFingerprint() throws Exception {
         assert (trivialMol != null);
         CircularFingerprinter circ = new CircularFingerprinter();
         IBitFingerprint result = circ.getBitFingerprint(trivialMol);
@@ -151,7 +151,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    public void testGetCountFingerprint() throws Exception {
+    void testGetCountFingerprint() throws Exception {
         assert (trivialMol != null);
         CircularFingerprinter circ = new CircularFingerprinter();
         ICountFingerprint result = circ.getCountFingerprint(trivialMol);
@@ -182,7 +182,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    public void testGetRawFingerprint() throws Exception {
+    void testGetRawFingerprint() throws Exception {
         // currently no-op
     }
 
@@ -190,7 +190,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
         ZipInputStream zip = new ZipInputStream(in);
 
         // stream the contents form the zipfile: these are all short
-        HashMap<String, byte[]> content = new HashMap<String, byte[]>();
+        HashMap<String, byte[]> content = new HashMap<>();
         while (true) {
             ZipEntry ze = zip.getNextEntry();
             if (ze == null) break;
@@ -232,7 +232,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     private CircularFingerprinter.FP[] parseValidation(byte[] raw) throws Exception {
         InputStream in = new ByteArrayInputStream(raw);
         BufferedReader rdr = new BufferedReader(new InputStreamReader(in));
-        ArrayList<CircularFingerprinter.FP> list = new ArrayList<CircularFingerprinter.FP>();
+        ArrayList<CircularFingerprinter.FP> list = new ArrayList<>();
 
         while (true) {
             String line = rdr.readLine();
@@ -270,8 +270,8 @@ public class CircularFingerprinterTest extends CDKTestCase {
         boolean same = obtained.length == validate.length;
         for (int i = 0; i < obtained.length && same; i++) {
             boolean hit = false;
-            for (int j = 0; j < validate.length; j++)
-                if (equalFingerprints(obtained[i], validate[j])) {
+            for (CircularFingerprinter.FP fp : validate)
+                if (equalFingerprints(obtained[i], fp)) {
                     hit = true;
                     break;
                 }
@@ -279,8 +279,8 @@ public class CircularFingerprinterTest extends CDKTestCase {
         }
         for (int i = 0; i < validate.length && same; i++) {
             boolean hit = false;
-            for (int j = 0; j < obtained.length; j++)
-                if (equalFingerprints(validate[i], obtained[j])) {
+            for (CircularFingerprinter.FP fp : obtained)
+                if (equalFingerprints(validate[i], fp)) {
                     hit = true;
                     break;
                 }
@@ -319,7 +319,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    public void protonsDontCauseNPE() throws Exception {
+    void protonsDontCauseNPE() throws Exception {
         IAtomContainer proton = new AtomContainer(1, 0, 0, 0);
         proton.addAtom(atom("H", +1, 0));
         CircularFingerprinter circ = new CircularFingerprinter(CircularFingerprinter.CLASS_FCFP2);
@@ -327,7 +327,7 @@ public class CircularFingerprinterTest extends CDKTestCase {
     }
 
     @Test
-    public void iminesDetectionDoesntCauseNPE() throws Exception {
+    void iminesDetectionDoesntCauseNPE() throws Exception {
         IAtomContainer pyrazole = new AtomContainer(6, 6, 0, 0);
         pyrazole.addAtom(atom("H", 0, 0));
         pyrazole.addAtom(atom("N", 0, 0));
@@ -342,14 +342,14 @@ public class CircularFingerprinterTest extends CDKTestCase {
         pyrazole.addBond(4, 5, IBond.Order.DOUBLE);
         pyrazole.addBond(1, 5, IBond.Order.SINGLE);
         CircularFingerprinter circ = new CircularFingerprinter(CircularFingerprinter.CLASS_FCFP2);
-        assertNotNull(circ.getBitFingerprint(pyrazole));
+        Assertions.assertNotNull(circ.getBitFingerprint(pyrazole));
     }
 
     /**
      * @cdk.bug 1357
      */
     @Test
-    public void partialCoordinatesDontCauseNPE() throws Exception {
+    void partialCoordinatesDontCauseNPE() throws Exception {
         IAtomContainer m = new AtomContainer();
         m.addAtom(atom("C", 3, 0.000, 0.000));
         m.addAtom(atom("C", 0, 1.299, -0.750));
@@ -363,11 +363,11 @@ public class CircularFingerprinterTest extends CDKTestCase {
         m.addBond(1, 4, IBond.Order.SINGLE);
         m.addBond(4, 5, IBond.Order.SINGLE);
         CircularFingerprinter circ = new CircularFingerprinter(CircularFingerprinter.CLASS_ECFP6);
-        assertNotNull(circ.getBitFingerprint(m));
+        Assertions.assertNotNull(circ.getBitFingerprint(m));
     }
 
 	@Test
-	public void testNonZZeroPlaner() throws Exception {
+    void testNonZZeroPlaner() throws Exception {
 	    IAtomContainer mol = new AtomContainer();
 	    Atom[] atoms = new Atom[] {
 	        new Atom("C"),
@@ -388,11 +388,11 @@ public class CircularFingerprinterTest extends CDKTestCase {
 	    CircularFingerprinter circ = new CircularFingerprinter(CircularFingerprinter.CLASS_ECFP6);
 	    circ.setPerceiveStereo(true);
 	    IBitFingerprint fp0 = circ.getBitFingerprint(mol);
-	    
-	    for (int i = 0; i < atoms.length; i++) {
-	        Point3d p = atoms[i].getPoint3d();
-	        atoms[i].setPoint3d(new Point3d(p.x, p.y, p.z + 20));
-	    }
+
+        for (Atom atom : atoms) {
+            Point3d p = atom.getPoint3d();
+            atom.setPoint3d(new Point3d(p.x, p.y, p.z + 20));
+        }
 	
 	    IBitFingerprint fp1 = circ.getBitFingerprint(mol);
 	    
@@ -413,7 +413,8 @@ public class CircularFingerprinterTest extends CDKTestCase {
         return a;
     }
 
-    @Test public void testVersion() {
+    @Test
+    void testVersion() {
         CircularFingerprinter fpr = new CircularFingerprinter(CircularFingerprinter.CLASS_ECFP4);
         String expected = "CDK-CircularFingerprinter/" + CDK.getVersion() +
                           " classType=ECFP4 perceiveStereochemistry=false";
