@@ -23,19 +23,23 @@
 package org.openscience.cdk.fingerprint;
 
 import java.io.InputStream;
-import java.math.BigInteger;
+import java.util.ArrayList;
 import java.util.BitSet;
+import java.util.Comparator;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Random;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.CDK;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.Reaction;
-import org.openscience.cdk.test.SlowTest;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.graph.AtomContainerAtomPermutor;
 import org.openscience.cdk.graph.AtomContainerBondPermutor;
@@ -53,17 +57,15 @@ import org.openscience.cdk.tools.ILoggingTool;
 import org.openscience.cdk.tools.LoggingToolFactory;
 import org.openscience.cdk.tools.manipulator.ChemFileManipulator;
 
-import static org.junit.Assert.assertFalse;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 
 /**
  * @cdk.module test-standard
  */
-public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
+class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
 
     boolean                     standAlone = false;
-    private static ILoggingTool logger     = LoggingToolFactory.createLoggingTool(FingerprinterTest.class);
+    private static final ILoggingTool logger     = LoggingToolFactory.createLoggingTool(FingerprinterTest.class);
 
     @Override
     public IFingerprinter getBitFingerprinter() {
@@ -71,131 +73,128 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
     }
 
     @Test
-    public void testRegression() throws Exception {
+    void testRegression() throws Exception {
         IAtomContainer mol1 = TestMoleculeFactory.makeIndole();
         IAtomContainer mol2 = TestMoleculeFactory.makePyrrole();
         Fingerprinter fingerprinter = new Fingerprinter(1024, 8);
         IBitFingerprint bs1 = fingerprinter.getBitFingerprint(mol1);
-        Assert.assertEquals(
-                "Seems the fingerprint code has changed. This will cause a number of other tests to fail too!", 33,
-                bs1.cardinality());
+        Assertions.assertEquals(33, bs1.cardinality(), "Seems the fingerprint code has changed. This will cause a number of other tests to fail too!");
         IBitFingerprint bs2 = fingerprinter.getBitFingerprint(mol2);
-        Assert.assertEquals(
-                "Seems the fingerprint code has changed. This will cause a number of other tests to fail too!", 13,
-                bs2.cardinality());
+        Assertions.assertEquals(13, bs2.cardinality(), "Seems the fingerprint code has changed. This will cause a number of other tests to fail too!");
     }
 
     @Test
-    public void testGetSize() throws java.lang.Exception {
+    void testGetSize() throws java.lang.Exception {
         IFingerprinter fingerprinter = new Fingerprinter(512);
-        Assert.assertNotNull(fingerprinter);
-        Assert.assertEquals(512, fingerprinter.getSize());
+        Assertions.assertNotNull(fingerprinter);
+        Assertions.assertEquals(512, fingerprinter.getSize());
     }
 
     @Test
-    public void testGetSearchDepth() throws java.lang.Exception {
+    void testGetSearchDepth() throws java.lang.Exception {
         Fingerprinter fingerprinter = new Fingerprinter(512, 3);
-        Assert.assertNotNull(fingerprinter);
-        Assert.assertEquals(3, fingerprinter.getSearchDepth());
+        Assertions.assertNotNull(fingerprinter);
+        Assertions.assertEquals(3, fingerprinter.getSearchDepth());
     }
 
     @Test
-    public void testgetBitFingerprint_IAtomContainer() throws java.lang.Exception {
+    void testgetBitFingerprint_IAtomContainer() throws java.lang.Exception {
         Fingerprinter fingerprinter = new Fingerprinter();
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         IBitFingerprint bs = fingerprinter.getBitFingerprint(mol);
-        Assert.assertNotNull(bs);
-        Assert.assertEquals(fingerprinter.getSize(), bs.size());
+        Assertions.assertNotNull(bs);
+        Assertions.assertEquals(fingerprinter.getSize(), bs.size());
     }
 
     @Test
-    public void testFingerprinter() throws java.lang.Exception {
+    void testFingerprinter() throws java.lang.Exception {
         Fingerprinter fingerprinter = new Fingerprinter();
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
     }
 
     @Test
-    public void testFingerprinter_int() throws java.lang.Exception {
+    void testFingerprinter_int() throws java.lang.Exception {
         Fingerprinter fingerprinter = new Fingerprinter(512);
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
     }
 
     @Test
-    public void testFingerprinter_int_int() throws java.lang.Exception {
+    void testFingerprinter_int_int() throws java.lang.Exception {
         Fingerprinter fingerprinter = new Fingerprinter(1024, 7);
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
 
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         BitSet bs1 = fingerprinter.getBitFingerprint(frag1).asBitSet();
-        assertTrue(FingerprinterTool.isSubset(bs, bs1));
+        Assertions.assertTrue(FingerprinterTool.isSubset(bs, bs1));
     }
 
     @Test
-    public void testFingerprinterBitSetSize() throws Exception {
+    void testFingerprinterBitSetSize() throws Exception {
         Fingerprinter fingerprinter = new Fingerprinter(1024, 7);
-        Assert.assertNotNull(fingerprinter);
+        Assertions.assertNotNull(fingerprinter);
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         BitSet bs = fingerprinter.getBitFingerprint(mol).asBitSet();
-        Assert.assertEquals(994, bs.length()); // highest set bit
-        Assert.assertEquals(1024, bs.size()); // actual bit set size
+        Assertions.assertEquals(994, bs.length()); // highest set bit
+        Assertions.assertEquals(1024, bs.size()); // actual bit set size
     }
 
     /**
      * @cdk.bug 1851202
      */
     @Test
-    public void testBug1851202() throws Exception {
+    void testBug1851202() throws Exception {
         String filename1 = "0002.stg01.rxn";
         logger.info("Testing: " + filename1);
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLRXNV2000Reader reader = new MDLRXNV2000Reader(ins1, Mode.STRICT);
-        IReaction reaction = (IReaction) reader.read(new Reaction());
-        Assert.assertNotNull(reaction);
+        IReaction reaction = reader.read(new Reaction());
+        Assertions.assertNotNull(reaction);
 
         IAtomContainer reactant = reaction.getReactants().getAtomContainer(0);
         IAtomContainer product = reaction.getProducts().getAtomContainer(0);
 
         Fingerprinter fingerprinter = new Fingerprinter(64 * 26, 8);
-        Assert.assertNotNull(fingerprinter.getBitFingerprint(reactant));
-        Assert.assertNotNull(fingerprinter.getBitFingerprint(product));
+        Assertions.assertNotNull(fingerprinter.getBitFingerprint(reactant));
+        Assertions.assertNotNull(fingerprinter.getBitFingerprint(product));
     }
 
-    @Test(expected = CDKException.class)
-    @Category(SlowTest.class)
-    public void testbug2917084() throws Exception {
+    @Tag("SlowTest")
+    @Test
+    void testbug2917084() throws Exception {
         String filename1 = "boronBuckyBall.mol";
         logger.info("Testing: " + filename1);
         InputStream ins1 = this.getClass().getResourceAsStream(filename1);
         MDLV2000Reader reader = new MDLV2000Reader(ins1, Mode.STRICT);
         IChemFile chemFile = reader.read(new ChemFile());
-        Assert.assertNotNull(chemFile);
+        Assertions.assertNotNull(chemFile);
         IAtomContainer mol = ChemFileManipulator.getAllAtomContainers(chemFile).get(0);
-
         Fingerprinter fingerprinter = new Fingerprinter(1024, 8);
-        Assert.assertNotNull(fingerprinter.getBitFingerprint(mol));
+        Assertions.assertThrows(CDKException.class, () -> {
+            fingerprinter.getBitFingerprint(mol);
+        });
     }
 
     /**
-     * @cdk.bug 2819557
      * @throws org.openscience.cdk.exception.CDKException
+     * @cdk.bug 2819557
      */
     @Test
-    public void testBug2819557() throws CDKException {
+    void testBug2819557() throws CDKException {
         IAtomContainer butane = makeButane();
         IAtomContainer propylAmine = makePropylAmine();
 
@@ -203,11 +202,11 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         BitSet b1 = fp.getBitFingerprint(butane).asBitSet();
         BitSet b2 = fp.getBitFingerprint(propylAmine).asBitSet();
 
-        Assert.assertFalse("butane should not be a substructure of propylamine", FingerprinterTool.isSubset(b2, b1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(b2, b1), "butane should not be a substructure of propylamine");
     }
 
     @Test
-    public void testBondPermutation() throws CDKException {
+    void testBondPermutation() throws CDKException {
         IAtomContainer pamine = makePropylAmine();
         Fingerprinter fp = new Fingerprinter();
         IBitFingerprint bs1 = fp.getBitFingerprint(pamine);
@@ -216,12 +215,12 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         while (acp.hasNext()) {
             IAtomContainer container = acp.next();
             IBitFingerprint bs2 = fp.getBitFingerprint(container);
-            assertTrue(bs1.equals(bs2));
+            Assertions.assertTrue(bs1.equals(bs2));
         }
     }
 
     @Test
-    public void testAtomPermutation() throws CDKException {
+    void testAtomPermutation() throws CDKException {
         IAtomContainer pamine = makePropylAmine();
         Fingerprinter fp = new Fingerprinter();
         IBitFingerprint bs1 = fp.getBitFingerprint(pamine);
@@ -230,12 +229,12 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         while (acp.hasNext()) {
             IAtomContainer container = acp.next();
             IBitFingerprint bs2 = fp.getBitFingerprint(container);
-            assertTrue(bs1.equals(bs2));
+            Assertions.assertTrue(bs1.equals(bs2));
         }
     }
 
     @Test
-    public void testBondPermutation2() throws CDKException {
+    void testBondPermutation2() throws CDKException {
         IAtomContainer pamine = TestMoleculeFactory.makeCyclopentane();
         Fingerprinter fp = new Fingerprinter();
         IBitFingerprint bs1 = fp.getBitFingerprint(pamine);
@@ -244,12 +243,12 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         while (acp.hasNext()) {
             IAtomContainer container = acp.next();
             IBitFingerprint bs2 = fp.getBitFingerprint(container);
-            assertTrue(bs1.equals(bs2));
+            Assertions.assertTrue(bs1.equals(bs2));
         }
     }
 
     @Test
-    public void testAtomPermutation2() throws CDKException {
+    void testAtomPermutation2() throws CDKException {
         IAtomContainer pamine = TestMoleculeFactory.makeCyclopentane();
         Fingerprinter fp = new Fingerprinter();
         IBitFingerprint bs1 = fp.getBitFingerprint(pamine);
@@ -258,11 +257,11 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         while (acp.hasNext()) {
             IAtomContainer container = acp.next();
             IBitFingerprint bs2 = fp.getBitFingerprint(container);
-            assertTrue(bs1.equals(bs2));
+            Assertions.assertTrue(bs1.equals(bs2));
         }
     }
 
-    public static IAtomContainer makeFragment1() {
+    static IAtomContainer makeFragment1() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -281,7 +280,7 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static IAtomContainer makeFragment4() {
+    static IAtomContainer makeFragment4() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -290,7 +289,7 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static IAtomContainer makeFragment2() {
+    static IAtomContainer makeFragment2() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -310,7 +309,7 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static IAtomContainer makeFragment3() {
+    static IAtomContainer makeFragment3() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -329,7 +328,7 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static IAtomContainer makeButane() {
+    static IAtomContainer makeButane() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -343,7 +342,7 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static IAtomContainer makePropylAmine() {
+    static IAtomContainer makePropylAmine() {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         mol.addAtom(new Atom("C")); // 0
         mol.addAtom(new Atom("C")); // 1
@@ -357,24 +356,8 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         return mol;
     }
 
-    public static void main(String[] args) throws Exception {
-        BigInteger bi = new BigInteger("0");
-        bi = bi.add(BigInteger.valueOf((long) Math.pow(2, 63)));
-        System.err.println(bi.toString());
-        bi = bi.add(BigInteger.valueOf((long) Math.pow(2, 0)));
-        System.err.println(bi.toString());
-        FingerprinterTest fpt = new FingerprinterTest();
-        fpt.standAlone = true;
-        //fpt.testFingerprinter();
-        //fpt.testFingerprinterArguments();
-        //fpt.testBug706786();
-        //fpt.testBug771485();
-        //fpt.testBug853254();
-        //fpt.testBug931608();
-        fpt.testBug934819();
-    }
-
-    @Test public void pseudoAtomFingerprint() throws CDKException {
+    @Test
+    void pseudoAtomFingerprint() throws CDKException {
         final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         final String query  = "*1CCCC1";
         final String indole = "N1CCCC1";
@@ -383,16 +366,17 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         Fingerprinter fpr = new Fingerprinter();
         BitSet fp1 = fpr.getFingerprint(queryMol);
         BitSet fp2 = fpr.getFingerprint(indoleMol);
-        assertTrue(FingerprinterTool.isSubset(fp2, fp1));
-        assertFalse(FingerprinterTool.isSubset(fp1, fp2));
+        Assertions.assertTrue(FingerprinterTool.isSubset(fp2, fp1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp1, fp2));
         fpr.setHashPseudoAtoms(true);
         BitSet fp3 = fpr.getFingerprint(queryMol);
         BitSet fp4 = fpr.getFingerprint(indoleMol);
-        assertFalse(FingerprinterTool.isSubset(fp4, fp3));
-        assertFalse(FingerprinterTool.isSubset(fp3, fp4));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp4, fp3));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp3, fp4));
     }
 
-    @Test public void pseudoAtomFingerprintArom() throws CDKException {
+    @Test
+    void pseudoAtomFingerprintArom() throws CDKException {
         final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         final String query  = "*1cnccc1";
         final String indole = "n1cnccc1";
@@ -401,16 +385,17 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         Fingerprinter fpr = new Fingerprinter();
         BitSet fp1 = fpr.getFingerprint(queryMol);
         BitSet fp2 = fpr.getFingerprint(indoleMol);
-        assertTrue(FingerprinterTool.isSubset(fp2, fp1));
-        assertFalse(FingerprinterTool.isSubset(fp1, fp2));
+        Assertions.assertTrue(FingerprinterTool.isSubset(fp2, fp1));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp1, fp2));
         fpr.setHashPseudoAtoms(true);
         BitSet fp3 = fpr.getFingerprint(queryMol);
         BitSet fp4 = fpr.getFingerprint(indoleMol);
-        assertFalse(FingerprinterTool.isSubset(fp4, fp3));
-        assertFalse(FingerprinterTool.isSubset(fp3, fp4));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp4, fp3));
+        Assertions.assertFalse(FingerprinterTool.isSubset(fp3, fp4));
     }
 
-    @Test public void testVersion() {
+    @Test
+    void testVersion() {
         Fingerprinter fpr = new Fingerprinter(1024, 7);
         fpr.setPathLimit(2000);
         fpr.setHashPseudoAtoms(true);
@@ -418,4 +403,238 @@ public class FingerprinterTest extends AbstractFixedLengthFingerprinterTest {
         assertThat(fpr.getVersionDescription(),
                    CoreMatchers.is(expected));
     }
+
+    // manually review once generated
+    static void makeTest(Map<String,Integer> map) {
+        List<Map.Entry<String, Integer>> entries = new ArrayList<>(map.entrySet());
+        entries.sort(Comparator.comparingInt(o -> o.getKey().length()));
+        System.err.println("Map<String,Integer> expected = new HashMap<>();");
+        for (Map.Entry<String,Integer> e : entries) {
+            System.err.println("expected.put(\"" + e.getKey() + "\", " + e.getValue() + ");");
+        }
+        System.err.println("Assert.assertEquals(expected, actual);");
+    }
+
+    @Test
+    void rawFpTestLinear() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7);
+        fpr.setPathLimit(2000);
+        final String smi  = "CCC=O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 3);
+        expected.put("O", 1);
+        expected.put("O=C", 1);
+        expected.put("C-C", 2);
+        expected.put("C-C-C", 1);
+        expected.put("O=C-C", 1);
+        expected.put("O=C-C-C", 1);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test
+    void rawFpTestBranching() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7);
+        fpr.setPathLimit(2000);
+        final String smi  = "CCC(O)=O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 3);
+        expected.put("O", 2);
+        expected.put("O=C", 1);
+        expected.put("O-C", 1);
+        expected.put("C-C", 2);
+        expected.put("O=C-O", 1);
+        expected.put("O-C-C", 1);
+        expected.put("C-C-C", 1);
+        expected.put("O=C-C", 1);
+        expected.put("O=C-C-C", 1);
+        expected.put("O-C-C-C", 1);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test
+    void rawFpTestBranching2() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7);
+        fpr.setPathLimit(2000);
+        final String smi  = "C(Cl)CC(O)=O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 3);
+        expected.put("O", 2);
+        expected.put("X", 1);
+        expected.put("O-C", 1);
+        expected.put("X-C", 1);
+        expected.put("O=C", 1);
+        expected.put("C-C", 2);
+        expected.put("O=C-O", 1);
+        expected.put("X-C-C", 1);
+        expected.put("C-C-C", 1);
+        expected.put("O-C-C", 1);
+        expected.put("O=C-C", 1);
+        expected.put("O=C-C-C", 1);
+        expected.put("O-C-C-C", 1);
+        expected.put("X-C-C-C", 1);
+        expected.put("X-C-C-C=O", 1);
+        expected.put("X-C-C-C-O", 1);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test
+    void rawFpTestRings() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7);
+        fpr.setPathLimit(2000);
+        final String smi  = "c1cc(Cl)c(C)cc1";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 7);
+        expected.put("X", 1);
+        expected.put("C:C", 6);
+        expected.put("X-C", 1);
+        expected.put("C-C", 1);
+        expected.put("C:C-C", 2);
+        expected.put("X-C:C", 2);
+        expected.put("C:C:C", 6);
+        expected.put("C:C:C-C", 2);
+        expected.put("X-C:C-C", 1);
+        expected.put("C:C:C:C", 6);
+        expected.put("X-C:C:C", 2);
+        expected.put("C:C:C:C-C", 2);
+        expected.put("X-C:C:C:C", 2);
+        expected.put("C:C:C:C:C", 6);
+        expected.put("C:C:C:C:C:C", 6);
+        expected.put("X-C:C:C:C:C", 2);
+        expected.put("C:C:C:C:C-C", 2);
+        expected.put("X-C:C:C:C:C:C", 2);
+        expected.put("C:C:C:C:C:C-C", 2);
+        expected.put("X-C:C:C:C:C:C-C", 1);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test
+    void rawFpTestDepth() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7); // 7 bonds
+        fpr.setPathLimit(2000);
+        final String smi  = "CCCCCCCCCC";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 10);
+        expected.put("C-C", 9);
+        expected.put("C-C-C", 8);
+        expected.put("C-C-C-C", 7);
+        expected.put("C-C-C-C-C", 6);
+        expected.put("C-C-C-C-C-C", 5);
+        expected.put("C-C-C-C-C-C-C", 4);
+        expected.put("C-C-C-C-C-C-C-C", 3);
+        Assertions.assertEquals(8, actual.size());
+        Assertions.assertEquals(expected, actual);
+    }
+
+    @Test public void testGetRawFingerprint() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7); // 7 bonds
+        fpr.setPathLimit(2000);
+        final String smi  = "CC(=O)OC1=CC=CC=C1C(=O)O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        Map<String,Integer> actual = fpr.getRawFingerprint(mol);
+        Map<String,Integer> expected = new HashMap<>();
+        expected.put("C", 9);
+        expected.put("O", 4);
+        expected.put("O=C", 2);
+        expected.put("C-C", 2);
+        expected.put("O-C", 3);
+        expected.put("C:C", 6);
+        expected.put("O-C:C", 2);
+        expected.put("O=C-O", 2);
+        expected.put("C:C-C", 2);
+        expected.put("O-C-C", 2);
+        expected.put("C:C:C", 6);
+        expected.put("O=C-C", 2);
+        expected.put("C-O-C", 1);
+        expected.put("C:C:C-C", 2);
+        expected.put("C:C:C:C", 6);
+        expected.put("O-C:C-C", 1);
+        expected.put("O-C:C:C", 2);
+        expected.put("C:C-O-C", 2);
+        expected.put("O=C-O-C", 1);
+        expected.put("C-O-C-C", 1);
+        expected.put("O=C-C:C", 2);
+        expected.put("O-C-C:C", 2);
+        expected.put("O-C-C:C:C", 2);
+        expected.put("C:C:C:C:C", 6);
+        expected.put("O-C:C:C:C", 2);
+        expected.put("C:C-O-C-C", 2);
+        expected.put("C:C:C:C-C", 2);
+        expected.put("O=C-C:C:C", 2);
+        expected.put("C:C:C-O-C", 2);
+        expected.put("C-O-C:C-C", 1);
+        expected.put("O=C-C:C-O", 1);
+        expected.put("O-C:C-C-O", 1);
+        expected.put("O=C-O-C:C", 2);
+        expected.put("C:C:C:C:C:C", 6);
+        expected.put("O-C:C:C:C:C", 2);
+        expected.put("O=C-C:C:C:C", 2);
+        expected.put("O-C-C:C:C:C", 2);
+        expected.put("C:C:C:C:C-C", 2);
+        expected.put("O=C-C:C-O-C", 1);
+        expected.put("O-C-C:C-O-C", 1);
+        expected.put("O=C-O-C:C:C", 2);
+        expected.put("C-C:C-O-C-C", 1);
+        expected.put("O=C-O-C:C-C", 1);
+        expected.put("C:C:C-O-C-C", 2);
+        expected.put("C:C:C:C-O-C", 2);
+        expected.put("O=C-C:C-O-C-C", 1);
+        expected.put("O=C-O-C:C-C-O", 1);
+        expected.put("O=C-O-C:C-C=O", 1);
+        expected.put("O-C-C:C-O-C-C", 1);
+        expected.put("C:C:C:C:C-O-C", 2);
+        expected.put("O=C-C:C:C:C:C", 2);
+        expected.put("C:C:C:C-O-C-C", 2);
+        expected.put("O-C-C:C:C:C:C", 2);
+        expected.put("O=C-O-C:C:C:C", 2);
+        expected.put("C:C:C:C:C:C-C", 2);
+        expected.put("O-C:C:C:C:C:C", 2);
+        expected.put("O-C:C:C:C:C:C-C", 1);
+        expected.put("O-C-C:C:C:C:C:C", 2);
+        expected.put("C:C:C:C:C-O-C-C", 2);
+        expected.put("C:C:C:C:C:C-O-C", 2);
+        expected.put("O=C-O-C:C:C:C:C", 2);
+        expected.put("O=C-C:C:C:C:C:C", 2);
+        Assertions.assertEquals(expected, actual);
+    }
+
+    private BitSet foldFp(ICountFingerprint fp, int size) {
+        BitSet bs = new BitSet();
+        Random rand = new Random();
+        for (int i = 0; i < fp.numOfPopulatedbins(); i++) {
+            int hash = fp.getHash(i);
+            rand.setSeed(hash);
+            int hashFolded = rand.nextInt(1024);
+            bs.set(hashFolded);
+        }
+        return bs;
+    }
+
+    @Test public void testGetCountFingerprint() throws CDKException {
+        final SmilesParser smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
+        Fingerprinter fpr = new Fingerprinter(1024, 7); // 7 bonds
+        fpr.setPathLimit(2000);
+        final String smi  = "CC(=O)OC1=CC=CC=C1C(=O)O";
+        IAtomContainer mol  = smipar.parseSmiles(smi);
+        ICountFingerprint cntFp = fpr.getCountFingerprint(mol);
+        IBitFingerprint expBitset = fpr.getBitFingerprint(mol);
+        Assertions.assertEquals(62, cntFp.numOfPopulatedbins());
+        BitSet actBitset = foldFp(cntFp, 1024);
+        Assertions.assertEquals(expBitset.asBitSet(), actBitset);
+    }
 }
