@@ -21,7 +21,6 @@
 package org.openscience.cdk.qsar.descriptors.atomic;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import javax.vecmath.Point3d;
@@ -165,7 +164,7 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
 
         IAtomContainer varAtomContainer;
         try {
-            varAtomContainer = (IAtomContainer) atomContainer.clone();
+            varAtomContainer = atomContainer.clone();
         } catch (CloneNotSupportedException e) {
             return getDummyDescriptorValue(e);
         }
@@ -214,9 +213,7 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
         IRingSet ringsWithThisBond;
         // SET ISINRING FLAGS FOR BONDS
 
-        Iterator<IBond> bondsInContainer = varAtomContainer.bonds().iterator();
-        while (bondsInContainer.hasNext()) {
-            IBond bond = bondsInContainer.next();
+        for (IBond bond : varAtomContainer.bonds()) {
             ringsWithThisBond = varRingSet.getRings(bond);
             if (ringsWithThisBond.getAtomContainerCount() > 0) {
                 bond.setFlag(CDKConstants.ISINRING, true);
@@ -240,18 +237,18 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
 
         // 2', 3', 4', 5', 6', and 7' atoms up to the target are detected:
         List<IAtom> atomsInSecondSphere = mol.getConnectedAtomsList(neighbour0);
-        List<IAtom> atomsInThirdSphere = null;
-        List<IAtom> atomsInFourthSphere = null;
-        List<IAtom> atomsInFifthSphere = null;
-        List<IAtom> atomsInSixthSphere = null;
-        List<IAtom> atomsInSeventhSphere = null;
+        List<IAtom> atomsInThirdSphere;
+        List<IAtom> atomsInFourthSphere;
+        List<IAtom> atomsInFifthSphere;
+        List<IAtom> atomsInSixthSphere;
+        List<IAtom> atomsInSeventhSphere;
 
         // SOME LISTS ARE CREATED FOR STORING OF INTERESTING ATOMS AND BONDS DURING DETECTION
-        ArrayList<Integer> singles = new ArrayList<Integer>(); // list of any bond not rotatable
-        ArrayList<Integer> doubles = new ArrayList<Integer>(); // list with only double bonds
-        ArrayList<Integer> atoms = new ArrayList<Integer>(); // list with all the atoms in spheres
+        ArrayList<Integer> singles = new ArrayList<>(); // list of any bond not rotatable
+        ArrayList<Integer> doubles = new ArrayList<>(); // list with only double bonds
+        ArrayList<Integer> atoms = new ArrayList<>(); // list with all the atoms in spheres
         //atoms.add( Integer.valueOf( mol.indexOf(neighboors[0]) ) );
-        ArrayList<Integer> bondsInCycloex = new ArrayList<Integer>(); // list for bonds in cycloexane-like rings
+        ArrayList<Integer> bondsInCycloex = new ArrayList<>(); // list for bonds in cycloexane-like rings
 
         // 2', 3', 4', 5', 6', and 7' bonds up to the target are detected:
         IBond secondBond; // (remember that first bond is proton bond)
@@ -384,7 +381,7 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
         //Variables
         double[] values; // for storage of results of other methods
         double sum;
-        double smooth = -20;
+        double smooth;
         double partial;
         int position;
         double limitInf;
@@ -409,14 +406,14 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
             partial = 0;
             IBond theDoubleBond;
             smooth = -1.15;
-            int goodPosition = 0;
+            int goodPosition;
             IBond goodBond;
             for (int c = 0; c < gdr_desc_length; c++) {
             	double ghd = limitInf + (limitSup - limitInf) * ((double)c / gdr_desc_length);
                 sum = 0;
-                for (int dou = 0; dou < doubles.size(); dou++) {
+                for (Integer aDouble : doubles) {
                     partial = 0;
-                    position = doubles.get(dou);
+                    position = aDouble;
                     theDoubleBond = mol.getBond(position);
                     goodPosition = getNearestBondtoAGivenAtom(mol, atom, theDoubleBond);
                     goodBond = mol.getBond(goodPosition);
@@ -514,19 +511,19 @@ public class RDFProtonDescriptor_GDR extends AbstractAtomicDescriptor implements
     private void checkAndStore(int bondToStore, IBond.Order bondOrder, ArrayList<Integer> singleVec,
             ArrayList<Integer> doubleVec, ArrayList<Integer> cycloexVec, int a1, ArrayList<Integer> atomVec,
             int sphere, boolean isBondInCycloex) {
-        if (!atomVec.contains(Integer.valueOf(a1))) {
+        if (!atomVec.contains(a1)) {
             if (sphere < 6) atomVec.add(a1);
         }
-        if (!cycloexVec.contains(Integer.valueOf(bondToStore))) {
+        if (!cycloexVec.contains(bondToStore)) {
             if (isBondInCycloex) {
                 cycloexVec.add(bondToStore);
             }
         }
         if (bondOrder == IBond.Order.DOUBLE) {
-            if (!doubleVec.contains(Integer.valueOf(bondToStore))) doubleVec.add(bondToStore);
+            if (!doubleVec.contains(bondToStore)) doubleVec.add(bondToStore);
         }
         if (bondOrder == IBond.Order.SINGLE) {
-            if (!singleVec.contains(Integer.valueOf(bondToStore))) singleVec.add(bondToStore);
+            if (!singleVec.contains(bondToStore)) singleVec.add(bondToStore);
         }
     }
 
