@@ -20,7 +20,6 @@
 package org.openscience.cdk.qsar.descriptors.atomic;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import javax.vecmath.Point3d;
@@ -161,7 +160,7 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
     public DescriptorValue calculate(IAtom atom, IAtomContainer atomContainer, IRingSet precalculatedringset) {
         IAtomContainer varAtomContainer;
         try {
-            varAtomContainer = (IAtomContainer) atomContainer.clone();
+            varAtomContainer = atomContainer.clone();
         } catch (CloneNotSupportedException e) {
             return getDummyDescriptorValue(e);
         }
@@ -209,9 +208,7 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
         IRing ring;
         IRingSet ringsWithThisBond;
         // SET ISINRING FLAGS FOR BONDS
-        Iterator<IBond> bondsInContainer = varAtomContainer.bonds().iterator();
-        while (bondsInContainer.hasNext()) {
-            IBond bond = bondsInContainer.next();
+        for (IBond bond : varAtomContainer.bonds()) {
             ringsWithThisBond = varRingSet.getRings(bond);
             if (ringsWithThisBond.getAtomContainerCount() > 0) {
                 bond.setFlag(CDKConstants.ISINRING, true);
@@ -243,11 +240,11 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
         List<IAtom> atomsInSeventhSphere;
 
         // SOME LISTS ARE CREATED FOR STORING OF INTERESTING ATOMS AND BONDS DURING DETECTION
-        ArrayList<Integer> singles = new ArrayList<Integer>(); // list of any bond not rotatable
-        ArrayList<Integer> doubles = new ArrayList<Integer>(); // list with only double bonds
-        ArrayList<Integer> atoms = new ArrayList<Integer>(); // list with all the atoms in spheres
+        ArrayList<Integer> singles = new ArrayList<>(); // list of any bond not rotatable
+        ArrayList<Integer> doubles = new ArrayList<>(); // list with only double bonds
+        ArrayList<Integer> atoms = new ArrayList<>(); // list with all the atoms in spheres
         //atoms.add( Integer.valueOf( mol.indexOf(neighboors[0]) ) );
-        ArrayList<Integer> bondsInCycloex = new ArrayList<Integer>(); // list for bonds in cycloexane-like rings
+        ArrayList<Integer> bondsInCycloex = new ArrayList<>(); // list for bonds in cycloexane-like rings
 
         // 2', 3', 4', 5', 6', and 7' bonds up to the target are detected:
         IBond secondBond; // (remember that first bond is proton bond)
@@ -380,7 +377,7 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
         //Variables
         double[] values; // for storage of results of other methods
         double sum;
-        double smooth = -20;
+        double smooth;
         double partial;
         int position;
         double limitInf;
@@ -394,7 +391,7 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
         Vector3d bA = new Vector3d();
         Vector3d bB = new Vector3d();
         Point3d middlePoint = new Point3d();
-        double angle = 0;
+        double angle;
 
         if (singles.size() > 0) {
             double dist0;
@@ -402,17 +399,17 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
             IAtom singleBondAtom0;
             IAtom singleBondAtom1;
             position = 0;
-            IBond theSingleBond = null;
+            IBond theSingleBond;
             limitInf = 0;
             limitSup = Math.PI / 2;
             smooth = -1.15;
             for (int c = 0; c < gsr_desc_length; c++) {
             	double ghs = limitSup * ((double)c / gsr_desc_length);
                 sum = 0;
-                for (int sing = 0; sing < singles.size(); sing++) {
+                for (Integer single : singles) {
                     angle = 0;
                     partial = 0;
-                    Integer thisSingleBond = singles.get(sing);
+                    Integer thisSingleBond = single;
                     position = thisSingleBond;
                     theSingleBond = mol.getBond(position);
                     middlePoint = theSingleBond.get3DCenter();
@@ -485,8 +482,7 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
         List<IAtom> neighToCarbon = mol.getConnectedAtomsList(carbonAtom);
         IBond tmpBond;
         int counter = 0;
-        for (int nei = 0; nei < neighToCarbon.size(); nei++) {
-            IAtom neighbour = neighToCarbon.get(nei);
+        for (IAtom neighbour : neighToCarbon) {
             if (neighbour.getAtomicNumber() == IElement.O) {
                 tmpBond = mol.getBond(neighbour, carbonAtom);
                 if (tmpBond.getOrder() == IBond.Order.DOUBLE) counter += 1;
@@ -512,19 +508,19 @@ public class RDFProtonDescriptor_GSR extends AbstractAtomicDescriptor implements
     private void checkAndStore(int bondToStore, IBond.Order bondOrder, ArrayList<Integer> singleVec,
             ArrayList<Integer> doubleVec, ArrayList<Integer> cycloexVec, int a1, ArrayList<Integer> atomVec,
             int sphere, boolean isBondInCycloex) {
-        if (!atomVec.contains(Integer.valueOf(a1))) {
+        if (!atomVec.contains(a1)) {
             if (sphere < 6) atomVec.add(a1);
         }
-        if (!cycloexVec.contains(Integer.valueOf(bondToStore))) {
+        if (!cycloexVec.contains(bondToStore)) {
             if (isBondInCycloex) {
                 cycloexVec.add(bondToStore);
             }
         }
         if (bondOrder == IBond.Order.DOUBLE) {
-            if (!doubleVec.contains(Integer.valueOf(bondToStore))) doubleVec.add(bondToStore);
+            if (!doubleVec.contains(bondToStore)) doubleVec.add(bondToStore);
         }
         if (bondOrder == IBond.Order.SINGLE) {
-            if (!singleVec.contains(Integer.valueOf(bondToStore))) singleVec.add(bondToStore);
+            if (!singleVec.contains(bondToStore)) singleVec.add(bondToStore);
         }
     }
 
