@@ -2,9 +2,9 @@ package org.openscience.cdk.qsar.descriptors.atomic;
 
 import java.io.InputStream;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.ChemFile;
@@ -24,17 +24,17 @@ import org.openscience.cdk.qsar.result.IDescriptorResult;
 /**
  * @cdk.module test-qsaratomic
  */
-public class RDFProtonDescriptor_GHR_topolTest extends AtomicDescriptorTest {
+class RDFProtonDescriptor_GHR_topolTest extends AtomicDescriptorTest {
 
-    public RDFProtonDescriptor_GHR_topolTest() {}
+    RDFProtonDescriptor_GHR_topolTest() {}
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    void setUp() throws Exception {
         setDescriptor(RDFProtonDescriptor_GHR_topol.class);
     }
 
     @Test
-    public void testExample1() throws Exception {
+    void testExample1() throws Exception {
         //firstly read file to molecule
         String filename = "hydroxyamino.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -53,25 +53,25 @@ public class RDFProtonDescriptor_GHR_topolTest extends AtomicDescriptorTest {
                 DescriptorValue dv = descriptor.calculate(mol.getAtom(i), mol);
                 IDescriptorResult result = dv.getValue();
                 //				System.out.println("array: " + result.toString());
-                Assert.assertNotNull(result);
-                Assert.assertEquals(dv.getNames().length, result.length());
+                Assertions.assertNotNull(result);
+                Assertions.assertEquals(dv.getNames().length, result.length());
             }
 
         }
     }
 
     @Test
-    public void testReturnsNaNForNonHydrogen() throws Exception {
+    void testReturnsNaNForNonHydrogen() throws Exception {
         IAtomContainer mol = new AtomContainer();
         IAtom atom = new Atom("O");
         mol.addAtom(atom);
         DescriptorValue dv = descriptor.calculate(atom, mol);
         IDescriptorResult result = dv.getValue();
-        Assert.assertNotNull(result);
-        Assert.assertTrue(result instanceof DoubleArrayResult);
+        Assertions.assertNotNull(result);
+        Assertions.assertTrue(result instanceof DoubleArrayResult);
         DoubleArrayResult dResult = (DoubleArrayResult) result;
         for (int i = 0; i < result.length(); i++) {
-            Assert.assertEquals(Double.NaN, dResult.get(i), 0.000001);
+            Assertions.assertEquals(Double.NaN, dResult.get(i), 0.000001);
         }
     }
 
