@@ -25,9 +25,9 @@
 package org.openscience.cdk.io.cml;
 
 import nu.xom.Element;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IChemFile;
@@ -36,7 +36,6 @@ import org.openscience.cdk.interfaces.IChemSequence;
 import org.openscience.cdk.io.CMLReader;
 import org.openscience.cdk.io.CMLWriter;
 import org.openscience.cdk.libio.cml.Convertor;
-import org.openscience.cdk.libio.cml.QSARCustomizer;
 import org.openscience.cdk.qsar.DescriptorSpecification;
 import org.openscience.cdk.qsar.DescriptorValue;
 import org.openscience.cdk.qsar.IMolecularDescriptor;
@@ -52,82 +51,83 @@ import java.io.StringWriter;
  * @author John Mayfield
  * @cdk.module test-qsarcml
  */
-public class QSARCMLRoundTripTest {
+class QSARCMLRoundTripTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(QSARCMLRoundTripTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(QSARCMLRoundTripTest.class);
 
     private static Convertor    convertor;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         convertor = new Convertor(false, "");
-        convertor.registerCustomizer(new QSARCustomizer());
+        // not needed QSARCustomizer is on by default
+        // convertor.registerCustomizer(new QSARCustomizer());
     }
 
     // See also CMLRoundTripTool
-    public static IAtomContainer roundTripMolecule(Convertor convertor, IAtomContainer mol) throws Exception {
-        String cmlString = "<!-- failed -->";
+    static IAtomContainer roundTripMolecule(Convertor convertor, IAtomContainer mol) throws Exception {
+        String cmlString;
         Element cmlDOM = convertor.cdkAtomContainerToCMLMolecule(mol);
         cmlString = cmlDOM.toXML();
 
-        IAtomContainer roundTrippedMol = null;
+        IAtomContainer roundTrippedMol;
         logger.debug("CML string: ", cmlString);
         CMLReader reader = new CMLReader(new ByteArrayInputStream(cmlString.getBytes()));
 
-        IChemFile file = (IChemFile) reader.read(new org.openscience.cdk.ChemFile());
+        IChemFile file = reader.read(new org.openscience.cdk.ChemFile());
         reader.close();
-        Assert.assertNotNull(file);
-        Assert.assertEquals(1, file.getChemSequenceCount());
+        Assertions.assertNotNull(file);
+        Assertions.assertEquals(1, file.getChemSequenceCount());
         IChemSequence sequence = file.getChemSequence(0);
-        Assert.assertNotNull(sequence);
-        Assert.assertEquals(1, sequence.getChemModelCount());
+        Assertions.assertNotNull(sequence);
+        Assertions.assertEquals(1, sequence.getChemModelCount());
         IChemModel chemModel = sequence.getChemModel(0);
-        Assert.assertNotNull(chemModel);
+        Assertions.assertNotNull(chemModel);
         IAtomContainerSet moleculeSet = chemModel.getMoleculeSet();
-        Assert.assertNotNull(moleculeSet);
-        Assert.assertEquals(1, moleculeSet.getAtomContainerCount());
+        Assertions.assertNotNull(moleculeSet);
+        Assertions.assertEquals(1, moleculeSet.getAtomContainerCount());
         roundTrippedMol = moleculeSet.getAtomContainer(0);
-        Assert.assertNotNull(roundTrippedMol);
+        Assertions.assertNotNull(roundTrippedMol);
 
         return roundTrippedMol;
     }
 
     @Test
-    public void testDescriptorValue_QSAR() throws Exception {
+    void testDescriptorValue_QSAR() throws Exception {
         IAtomContainer molecule = TestMoleculeFactory.makeBenzene();
         IMolecularDescriptor descriptor = new WeightDescriptor();
 
-        DescriptorValue originalValue = null;
+        DescriptorValue originalValue;
         originalValue = descriptor.calculate(molecule);
         molecule.setProperty(originalValue.getSpecification(), originalValue);
         IAtomContainer roundTrippedMol = roundTripMolecule(convertor, molecule);
 
-        Assert.assertEquals(1, roundTrippedMol.getProperties().size());
+        Assertions.assertEquals(1, roundTrippedMol.getProperties().size());
         Object object = roundTrippedMol.getProperties().keySet().toArray()[0];
-        Assert.assertTrue(object instanceof DescriptorSpecification);
+        Assertions.assertTrue(object instanceof DescriptorSpecification);
         DescriptorSpecification spec = (DescriptorSpecification) object;
-        Assert.assertEquals(descriptor.getSpecification().getSpecificationReference(), spec.getSpecificationReference());
-        Assert.assertEquals(descriptor.getSpecification().getImplementationIdentifier(),
-                spec.getImplementationIdentifier());
-        Assert.assertEquals(descriptor.getSpecification().getImplementationTitle(), spec.getImplementationTitle());
-        Assert.assertEquals(descriptor.getSpecification().getImplementationVendor(), spec.getImplementationVendor());
+        Assertions.assertEquals(descriptor.getSpecification().getSpecificationReference(), spec.getSpecificationReference());
+        Assertions.assertEquals(descriptor.getSpecification().getImplementationIdentifier(), spec.getImplementationIdentifier());
+        Assertions.assertEquals(descriptor.getSpecification().getImplementationTitle(), spec.getImplementationTitle());
+        Assertions.assertEquals(descriptor.getSpecification().getImplementationVendor(), spec.getImplementationVendor());
 
         Object value = roundTrippedMol.getProperty(spec);
-        Assert.assertNotNull(value);
-        Assert.assertTrue(value instanceof DescriptorValue);
+        Assertions.assertNotNull(value);
+        Assertions.assertTrue(value instanceof DescriptorValue);
         DescriptorValue descriptorResult = (DescriptorValue) value;
-        Assert.assertEquals(originalValue.getClass().getName(), descriptorResult.getClass().getName());
-        Assert.assertEquals(originalValue.getValue().toString(), descriptorResult.getValue().toString());
+        Assertions.assertEquals(originalValue.getClass().getName(), descriptorResult.getClass().getName());
+        Assertions.assertEquals(originalValue.getValue().toString(), descriptorResult.getValue().toString());
     }
 
     @Test
-    public void testQSARCustomization() throws Exception {
+    void testQSARCustomization() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainer molecule = TestMoleculeFactory.makeBenzene();
         IMolecularDescriptor descriptor = new WeightDescriptor();
 
         CMLWriter cmlWriter = new CMLWriter(writer);
-        cmlWriter.registerCustomizer(new QSARCustomizer());
+        // not needed QSARCustomizer is on by default
+        // convertor.registerCustomizer(new QSARCustomizer());
         DescriptorValue value = descriptor.calculate(molecule);
         molecule.setProperty(value.getSpecification(), value);
 
@@ -136,8 +136,8 @@ public class QSARCMLRoundTripTest {
         logger.debug("****************************** testQSARCustomization()");
         logger.debug(cmlContent);
         logger.debug("******************************");
-        Assert.assertTrue(cmlContent.indexOf("<property") != -1 && cmlContent.indexOf("xmlns:qsar") != -1);
-        Assert.assertTrue(cmlContent.indexOf("#weight\"") != -1);
+        Assertions.assertTrue(cmlContent.contains("<property") && cmlContent.contains("xmlns:qsar"));
+        Assertions.assertTrue(cmlContent.contains("#weight\""));
     }
 
 }
