@@ -46,6 +46,8 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 import Jama.EigenvalueDecomposition;
 import Jama.Matrix;
 
+import java.util.Arrays;
+
 /**
  * Eigenvalue based descriptor noted for its utility in chemical diversity.
  * Described by Pearlman et al. {@cdk.cite PEA99}.
@@ -119,7 +121,7 @@ import Jama.Matrix;
  */
 public class BCUTDescriptor extends AbstractMolecularDescriptor implements IMolecularDescriptor {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(BCUTDescriptor.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(BCUTDescriptor.class);
 
     // the number of negative & positive eigenvalues
     // to return for each class of BCUT descriptor
@@ -182,7 +184,7 @@ public class BCUTDescriptor extends AbstractMolecularDescriptor implements IMole
      */
     @Override
     public Object[] getParameters() {
-        Object params[] = new Object[3];
+        Object[] params = new Object[3];
         params[0] = this.nhigh;
         params[1] = this.nlow;
         params[2] = this.checkAromaticity;
@@ -255,36 +257,26 @@ public class BCUTDescriptor extends AbstractMolecularDescriptor implements IMole
 
             int natom = local.getAtomCount();
             double[][] matrix = new double[natom][natom];
-            for (int i = 0; i < natom; i++) {
-                for (int j = 0; j < natom; j++) {
-                    matrix[i][j] = 0.0;
-                }
-            }
+            for (int i = 0; i < natom; i++)
+                Arrays.fill(matrix[i], 0.001);
 
             /* set the off diagonal entries */
-            for (int i = 0; i < natom - 1; i++) {
-                for (int j = i + 1; j < natom; j++) {
-                    for (int k = 0; k < local.getBondCount(); k++) {
-                        IBond bond = local.getBond(k);
-                        if (bond.contains(local.getAtom(i)) && bond.contains(local.getAtom(j))) {
-                            if (bond.getFlag(CDKConstants.ISAROMATIC))
-                                matrix[i][j] = 0.15;
-                            else if (bond.getOrder() == Order.SINGLE)
-                                matrix[i][j] = 0.1;
-                            else if (bond.getOrder() == Order.DOUBLE)
-                                matrix[i][j] = 0.2;
-                            else if (bond.getOrder() == Order.TRIPLE) matrix[i][j] = 0.3;
-
-                            if (local.getConnectedBondsCount(i) == 1 || local.getConnectedBondsCount(j) == 1) {
-                                matrix[i][j] += 0.01;
-                            }
-                            matrix[j][i] = matrix[i][j];
-                        } else {
-                            matrix[i][j] = 0.001;
-                            matrix[j][i] = 0.001;
-                        }
-                    }
+            for (IBond bond : local.bonds()) {
+                int i = local.indexOf(bond.getBegin());
+                int j = local.indexOf(bond.getEnd());
+                if (bond.getFlag(CDKConstants.ISAROMATIC))
+                    matrix[i][j] = 0.15;
+                else if (bond.getOrder() == Order.SINGLE)
+                    matrix[i][j] = 0.1;
+                else if (bond.getOrder() == Order.DOUBLE)
+                    matrix[i][j] = 0.2;
+                else if (bond.getOrder() == Order.TRIPLE) matrix[i][j] = 0.3;
+                // is terminal?
+                if (local.getConnectedBondsCount(i) == 1 ||
+                    local.getConnectedBondsCount(j) == 1) {
+                    matrix[i][j] += 0.01;
                 }
+                matrix[j][i] = matrix[i][j];
             }
 
             /* set the diagonal entries */
