@@ -24,8 +24,8 @@ package org.openscience.cdk.renderer.color;
 
 import java.awt.Color;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.PseudoAtom;
@@ -34,22 +34,22 @@ import org.openscience.cdk.interfaces.IAtom;
 /**
  * @cdk.module test-render
  */
-public class CPKAtomColorsTest extends CDKTestCase {
+class CPKAtomColorsTest extends CDKTestCase {
 
     @Test
-    public void testGetAtomColor() {
+    void testGetAtomColor() {
         CPKAtomColors colors = new CPKAtomColors();
-        Assert.assertNotNull(colors);
-        Assert.assertEquals(Color.WHITE, colors.getAtomColor(new Atom("H")));
-        Assert.assertEquals(new Color(0xFFC0CB), colors.getAtomColor(new Atom("He")));
+        Assertions.assertNotNull(colors);
+        Assertions.assertEquals(Color.WHITE, colors.getAtomColor(new Atom("H")));
+        Assertions.assertEquals(new Color(0xFFC0CB), colors.getAtomColor(new Atom("He")));
     }
 
     @Test
-    public void testGetDefaultAtomColor() {
+    void testGetDefaultAtomColor() {
         CPKAtomColors colors = new CPKAtomColors();
 
-        Assert.assertNotNull(colors);
+        Assertions.assertNotNull(colors);
         IAtom imaginary = new PseudoAtom("Ix");
-        Assert.assertEquals(Color.ORANGE, colors.getAtomColor(imaginary, Color.ORANGE));
+        Assertions.assertEquals(Color.ORANGE, colors.getAtomColor(imaginary, Color.ORANGE));
     }
 }
