@@ -23,15 +23,15 @@ package org.openscience.cdk.renderer.elements;
 
 import java.awt.Color;
 
-import org.junit.BeforeClass;
+import org.junit.jupiter.api.BeforeAll;
 
 /**
  * @cdk.module test-renderbasic
  */
-public class LineElementTest extends AbstractElementTest {
+class LineElementTest extends AbstractElementTest {
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         IRenderingElement element = new LineElement(0, 0, 1, 1, 1.0, Color.orange);
         setRenderingElement(element);
     }
