@@ -44,8 +44,8 @@ import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemModel;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IReaction;
-import org.openscience.cdk.interfaces.IRing;
 import org.openscience.cdk.interfaces.IRingSet;
 import org.openscience.cdk.tools.ILoggingTool;
 import org.openscience.cdk.tools.LoggingToolFactory;
@@ -72,7 +72,7 @@ import org.openscience.cdk.tools.manipulator.ChemModelManipulator;
 @Deprecated
 public class GeometryTools {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(GeometryTools.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(GeometryTools.class);
 
     /**
      * Provides the coverage of coordinates for this molecule.
@@ -80,7 +80,7 @@ public class GeometryTools {
      * @see GeometryTools#get2DCoordinateCoverage(org.openscience.cdk.interfaces.IAtomContainer)
      * @see GeometryTools#get3DCoordinateCoverage(org.openscience.cdk.interfaces.IAtomContainer)
      */
-    public static enum CoordinateCoverage {
+    public enum CoordinateCoverage {
 
         /**
          * All atoms have coordinates.
@@ -97,7 +97,7 @@ public class GeometryTools {
          */
         NONE
 
-    };
+    }
 
     /**
      *  Adds an automatically calculated offset to the coordinates of all atoms
@@ -111,9 +111,7 @@ public class GeometryTools {
     public static void translateAllPositive(IAtomContainer atomCon) {
         double minX = Double.MAX_VALUE;
         double minY = Double.MAX_VALUE;
-        Iterator<IAtom> atoms = atomCon.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = (IAtom) atoms.next();
+        for (IAtom atom : atomCon.atoms()) {
             if (atom.getPoint2d() != null) {
                 if (atom.getPoint2d().x < minX) {
                     minX = atom.getPoint2d().x;
@@ -370,10 +368,10 @@ public class GeometryTools {
      */
     public static void translate2DCentreOfMassTo(IAtomContainer atomCon, Point2d p) {
         Point2d com = get2DCentreOfMass(atomCon);
+        if (com == null)
+            throw new IllegalArgumentException("Null centre of mass, due to unset exact mass?");
         Vector2d translation = new Vector2d(p.x - com.x, p.y - com.y);
-        Iterator<IAtom> atoms = atomCon.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = (IAtom) atoms.next();
+        for (IAtom atom : atomCon.atoms()) {
             if (atom.getPoint2d() != null) {
                 atom.getPoint2d().add(translation);
             }
@@ -398,6 +396,8 @@ public class GeometryTools {
                 length++;
             }
         }
+        if (length == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / (double) length, ysum / (double) length);
     }
 
@@ -414,13 +414,15 @@ public class GeometryTools {
         double ysum = 0;
         int length = 0;
         while (atoms.hasNext()) {
-            atom = (IAtom) atoms.next();
+            atom = atoms.next();
             if (atom.getPoint2d() != null) {
                 xsum += atom.getPoint2d().x;
                 ysum += atom.getPoint2d().y;
             }
             ++length;
         }
+        if (length == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / (double) length, ysum / (double) length);
     }
 
@@ -435,7 +437,7 @@ public class GeometryTools {
         double centerX = 0;
         double centerY = 0;
         for (int i = 0; i < ringSet.getAtomContainerCount(); i++) {
-            Point2d centerPoint = get2DCenter((IRing) ringSet.getAtomContainer(i));
+            Point2d centerPoint = get2DCenter(ringSet.getAtomContainer(i));
             centerX += centerPoint.x;
             centerY += centerPoint.y;
         }
@@ -458,16 +460,15 @@ public class GeometryTools {
 
         double totalmass = 0.0;
 
-        Iterator<IAtom> atoms = ac.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom a = (IAtom) atoms.next();
+        for (IAtom a : ac.atoms()) {
             Double mass = a.getExactMass();
             if (mass == null) return null;
             totalmass += mass;
             xsum += mass * a.getPoint2d().x;
             ysum += mass * a.getPoint2d().y;
         }
-
+        if (totalmass == 0)
+            return new Point2d(0,0);
         return new Point2d(xsum / totalmass, ysum / totalmass);
     }
 
@@ -482,15 +483,15 @@ public class GeometryTools {
         double centerX = 0;
         double centerY = 0;
         double counter = 0;
-        Iterator<IAtom> atoms = container.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = (IAtom) atoms.next();
+        for (IAtom atom : container.atoms()) {
             if (atom.getPoint2d() != null) {
                 centerX += atom.getPoint2d().x;
                 centerY += atom.getPoint2d().y;
                 counter++;
             }
         }
+        if (counter == 0)
+            return new Point2d(0,0);
         return new Point2d(centerX / (counter), centerY / (counter));
     }
 
@@ -506,9 +507,7 @@ public class GeometryTools {
     public static void translate2DCenterTo(IAtomContainer container, Point2d p) {
         Point2d com = get2DCenter(container);
         Vector2d translation = new Vector2d(p.x - com.x, p.y - com.y);
-        Iterator<IAtom> atoms = container.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = (IAtom) atoms.next();
+        for (IAtom atom : container.atoms()) {
             if (atom.getPoint2d() != null) {
                 atom.getPoint2d().add(translation);
             }
@@ -532,9 +531,7 @@ public class GeometryTools {
 
         double totalmass = 0.0;
 
-        Iterator<IAtom> atoms = ac.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom a = (IAtom) atoms.next();
+        for (IAtom a : ac.atoms()) {
             Double mass = a.getExactMass();
             // some sanity checking
             if (a.getPoint3d() == null) return null;
@@ -545,7 +542,8 @@ public class GeometryTools {
             ysum += mass * a.getPoint3d().y;
             zsum += mass * a.getPoint3d().z;
         }
-
+        if (totalmass == 0)
+            return new Point3d(0,0,0);
         return new Point3d(xsum / totalmass, ysum / totalmass, zsum / totalmass);
     }
 
@@ -561,9 +559,7 @@ public class GeometryTools {
         double centerY = 0;
         double centerZ = 0;
         double counter = 0;
-        Iterator<IAtom> atoms = ac.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = (IAtom) atoms.next();
+        for (IAtom atom : ac.atoms()) {
             if (atom.getPoint3d() != null) {
                 centerX += atom.getPoint3d().x;
                 centerY += atom.getPoint3d().y;
@@ -571,6 +567,8 @@ public class GeometryTools {
                 counter++;
             }
         }
+        if (counter == 0)
+            return new Point3d(0,0,0);
         return new Point3d(centerX / (counter), centerY / (counter), centerZ / (counter));
     }
 
@@ -632,7 +630,7 @@ public class GeometryTools {
         if ((coords[2] - coords[0]) == 0) {
             angle = Math.PI / 2;
         } else {
-            angle = Math.atan(((double) coords[3] - (double) coords[1]) / ((double) coords[2] - (double) coords[0]));
+            angle = Math.atan((coords[3] - coords[1]) / (coords[2] - coords[0]));
         }
         double begin1X = (Math.cos(angle + Math.PI / 2) * dist + coords[0]);
         double begin1Y = (Math.sin(angle + Math.PI / 2) * dist + coords[1]);
@@ -802,9 +800,7 @@ public class GeometryTools {
 
         double smallestMouseDistance = -1;
         double mouseDistance;
-        Iterator<IBond> bonds = atomCon.bonds().iterator();
-        while (bonds.hasNext()) {
-            IBond currentBond = (IBond) bonds.next();
+        for (IBond currentBond : atomCon.bonds()) {
             bondCenter = get2DCenter(currentBond.atoms());
             mouseDistance = Math.sqrt(Math.pow(bondCenter.x - xPosition, 2) + Math.pow(bondCenter.y - yPosition, 2));
             if (mouseDistance < smallestMouseDistance || smallestMouseDistance == -1) {
@@ -831,9 +827,7 @@ public class GeometryTools {
 
         double smallestMouseDistance = -1;
         double mouseDistance;
-        Iterator<IBond> bonds = atomCon.bonds().iterator();
-        while (bonds.hasNext()) {
-            IBond currentBond = (IBond) bonds.next();
+        for (IBond currentBond : atomCon.bonds()) {
             bondCenter = get2DCenter(currentBond.atoms());
             mouseDistance = Math.sqrt(Math.pow(bondCenter.x - xPosition, 2) + Math.pow(bondCenter.y - yPosition, 2));
             if (mouseDistance < smallestMouseDistance || smallestMouseDistance == -1) {
@@ -915,6 +909,8 @@ public class GeometryTools {
                 bondLengthSum += getLength2D(bond);
             }
         }
+        if (bondCounter == 0)
+            return 0;
         return bondLengthSum / bondCounter;
     }
 
@@ -1179,6 +1175,8 @@ public class GeometryTools {
                         + Math.pow(atom1.getPoint2d().y - atom2.getPoint2d().y, 2));
             }
         }
+        if (counter == 0)
+            return 1.0;
         bondlength = bondlength / counter;
         ratio = desiredBondLength / bondlength;
         return ratio;
@@ -1251,7 +1249,7 @@ public class GeometryTools {
         if (originalPoint == null) {
             throw new CDKException("No point3d, but findClosestInSpace is working on point3ds");
         }
-        Map<Double, IAtom> atomsByDistance = new TreeMap<Double, IAtom>();
+        Map<Double, IAtom> atomsByDistance = new TreeMap<>();
         for (IAtom atom : container.atoms()) {
             if (!atom.equals(startAtom)) {
                 if (atom.getPoint3d() == null) {
@@ -1264,7 +1262,7 @@ public class GeometryTools {
         // FIXME: should there not be some sort here??
         Set<Double> keySet = atomsByDistance.keySet();
         Iterator<Double> keyIter = keySet.iterator();
-        List<IAtom> returnValue = new ArrayList<IAtom>();
+        List<IAtom> returnValue = new ArrayList<>();
         int i = 0;
         while (keyIter.hasNext() && i < max) {
             returnValue.add(atomsByDistance.get(keyIter.next()));
@@ -1344,12 +1342,12 @@ public class GeometryTools {
         if (firstAC.getAtomCount() < secondAC.getAtomCount()) {
             IAtomContainer tmp;
             try {
-                tmp = (IAtomContainer) firstAC.clone();
-                firstAC = (IAtomContainer) secondAC.clone();
-                secondAC = (IAtomContainer) tmp.clone();
+                tmp = firstAC.clone();
+                firstAC = secondAC.clone();
+                secondAC = tmp.clone();
             } catch (CloneNotSupportedException e) {
-                // TODO Auto-generated catch block
-                e.printStackTrace();
+                LoggingToolFactory.createLoggingTool(GeometryTools.class)
+                                  .warn("Unexpected Error:", e);
             }
         }
     }
@@ -1358,14 +1356,10 @@ public class GeometryTools {
             int posSecondAtom) {
         IAtom firstAtom = firstAC.getAtom(posFirstAtom);
         IAtom secondAtom = secondAC.getAtom(posSecondAtom);
-        if (firstAtom.getSymbol().equals(secondAtom.getSymbol())
-            && firstAC.getConnectedAtomsList(firstAtom).size() == secondAC.getConnectedAtomsList(secondAtom).size()
-            && Objects.equals(firstAtom.getBondOrderSum(), secondAtom.getBondOrderSum())
-            && firstAtom.getMaxBondOrder() == secondAtom.getMaxBondOrder()) {
-            return true;
-        } else {
-            return false;
-        }
+        return firstAtom.getAtomicNumber().equals(secondAtom.getAtomicNumber())
+                && firstAC.getConnectedAtomsList(firstAtom).size() == secondAC.getConnectedAtomsList(secondAtom).size()
+                && Objects.equals(firstAtom.getBondOrderSum(), secondAtom.getBondOrderSum())
+                && firstAtom.getMaxBondOrder() == secondAtom.getMaxBondOrder();
     }
 
     private static IAtomContainer setVisitedFlagsToFalse(IAtomContainer atomContainer) {
@@ -1394,8 +1388,8 @@ public class GeometryTools {
         List<IAtom> connectedAtoms;
         double sum = 0;
         double n = 0;
-        double distance1 = 0;
-        double distance2 = 0;
+        double distance1;
+        double distance2;
         setVisitedFlagsToFalse(firstAtomContainer);
         setVisitedFlagsToFalse(secondAtomContainer);
         while (firstAtoms.hasNext()) {
@@ -1404,19 +1398,19 @@ public class GeometryTools {
             centerAtomSecondMolecule = secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer
                     .indexOf(centerAtomFirstMolecule)));
             connectedAtoms = firstAtomContainer.getConnectedAtomsList(centerAtomFirstMolecule);
-            for (int i = 0; i < connectedAtoms.size(); i++) {
-                IAtom conAtom = (IAtom) connectedAtoms.get(i);
+            for (IAtom connectedAtom : connectedAtoms) {
+                IAtom conAtom = connectedAtom;
                 //this step is built to know if the program has already calculate a bond length (so as not to have duplicate values)
                 if (!conAtom.getFlag(CDKConstants.VISITED)) {
                     if (Coords3d) {
-                        distance1 = ((Point3d) centerAtomFirstMolecule.getPoint3d()).distance(conAtom.getPoint3d());
-                        distance2 = ((Point3d) centerAtomSecondMolecule.getPoint3d()).distance(secondAtomContainer
+                        distance1 = centerAtomFirstMolecule.getPoint3d().distance(conAtom.getPoint3d());
+                        distance2 = centerAtomSecondMolecule.getPoint3d().distance(secondAtomContainer
                                 .getAtom(mappedAtoms.get(firstAtomContainer.indexOf(conAtom))).getPoint3d());
                         sum = sum + Math.pow((distance1 - distance2), 2);
                         n++;
                     } else {
-                        distance1 = ((Point2d) centerAtomFirstMolecule.getPoint2d()).distance(conAtom.getPoint2d());
-                        distance2 = ((Point2d) centerAtomSecondMolecule.getPoint2d()).distance(secondAtomContainer
+                        distance1 = centerAtomFirstMolecule.getPoint2d().distance(conAtom.getPoint2d());
+                        distance2 = centerAtomSecondMolecule.getPoint2d().distance(secondAtomContainer
                                 .getAtom((mappedAtoms.get(firstAtomContainer.indexOf(conAtom)))).getPoint2d());
                         sum = sum + Math.pow((distance1 - distance2), 2);
                         n++;
@@ -1426,6 +1420,8 @@ public class GeometryTools {
         }
         setVisitedFlagsToFalse(firstAtomContainer);
         setVisitedFlagsToFalse(secondAtomContainer);
+        if (n == 0)
+            return 0;
         return Math.sqrt(sum / n);
     }
 
@@ -1459,16 +1455,16 @@ public class GeometryTools {
             if (connectedAtoms.size() > 1) {
                 //logger.debug("If "+centerAtomfirstAC.getSymbol()+" is the center atom :");
                 for (int i = 0; i < connectedAtoms.size() - 1; i++) {
-                    firstAtomfirstAC = (IAtom) connectedAtoms.get(i);
+                    firstAtomfirstAC = connectedAtoms.get(i);
                     for (int j = i + 1; j < connectedAtoms.size(); j++) {
                         angleFirstMolecule = getAngle(centerAtomfirstAC, firstAtomfirstAC,
-                                (IAtom) connectedAtoms.get(j));
+                                connectedAtoms.get(j));
                         centerAtomsecondAC = secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer
                                 .indexOf(centerAtomfirstAC)));
                         firstAtomsecondAC = secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer
                                 .indexOf(firstAtomfirstAC)));
                         secondAtomsecondAC = secondAtomContainer.getAtom(mappedAtoms.get(firstAtomContainer
-                                .indexOf((IAtom) connectedAtoms.get(j))));
+                                .indexOf(connectedAtoms.get(j))));
                         angleSecondMolecule = getAngle(centerAtomsecondAC, firstAtomsecondAC, secondAtomsecondAC);
                         sum = sum + Math.pow(angleFirstMolecule - angleSecondMolecule, 2);
                         n++;
@@ -1477,6 +1473,8 @@ public class GeometryTools {
                 }
             }//if
         }
+        if (n == 0)
+            return 0;
         return Math.sqrt(sum / n);
     }
 
@@ -1518,7 +1516,7 @@ public class GeometryTools {
             Map<Integer, Integer> mappedAtoms, boolean Coords3d) throws CDKException {
         //logger.debug("**** GT getAllAtomRMSD ****");
         double sum = 0;
-        double RMSD;
+        double rmsd;
         Iterator<Integer> firstAtoms = mappedAtoms.keySet().iterator();
         int firstAtomNumber;
         int secondAtomNumber;
@@ -1545,8 +1543,10 @@ public class GeometryTools {
                 throw new CDKException(ex.getMessage(), ex);
             }
         }
-        RMSD = Math.sqrt(sum / n);
-        return RMSD;
+        if (n == 0)
+            return 0;
+        rmsd = Math.sqrt(sum / n);
+        return rmsd;
     }
 
     /**
@@ -1564,43 +1564,43 @@ public class GeometryTools {
             Map<Integer, Integer> mappedAtoms, boolean hetAtomOnly, boolean Coords3d) {
         //logger.debug("**** GT getAllAtomRMSD ****");
         double sum = 0;
-        double RMSD = 0;
+        double rmsd;
         Iterator<Integer> firstAtoms = mappedAtoms.keySet().iterator();
-        int firstAtomNumber = 0;
-        int secondAtomNumber = 0;
+        int firstAtomNumber;
+        int secondAtomNumber;
         int n = 0;
         while (firstAtoms.hasNext()) {
             firstAtomNumber = firstAtoms.next();
             secondAtomNumber = mappedAtoms.get(firstAtomNumber);
             IAtom firstAtom = firstAtomContainer.getAtom(firstAtomNumber);
             if (hetAtomOnly) {
-                if (!firstAtom.getSymbol().equals("H") && !firstAtom.getSymbol().equals("C")) {
+                if (firstAtom.getAtomicNumber() != IElement.H && firstAtom.getAtomicNumber() != IElement.C) {
                     if (Coords3d) {
                         sum = sum
                                 + Math.pow(
-                                        ((Point3d) firstAtom.getPoint3d()).distance(secondAtomContainer.getAtom(
+                                        firstAtom.getPoint3d().distance(secondAtomContainer.getAtom(
                                                 secondAtomNumber).getPoint3d()), 2);
                         n++;
                     } else {
                         sum = sum
                                 + Math.pow(
-                                        ((Point2d) firstAtom.getPoint2d()).distance(secondAtomContainer.getAtom(
+                                        firstAtom.getPoint2d().distance(secondAtomContainer.getAtom(
                                                 secondAtomNumber).getPoint2d()), 2);
                         n++;
                     }
                 }
             } else {
-                if (!firstAtom.getSymbol().equals("H")) {
+                if (firstAtom.getAtomicNumber() != IElement.H) {
                     if (Coords3d) {
                         sum = sum
                                 + Math.pow(
-                                        ((Point3d) firstAtom.getPoint3d()).distance(secondAtomContainer.getAtom(
+                                        firstAtom.getPoint3d().distance(secondAtomContainer.getAtom(
                                                 secondAtomNumber).getPoint3d()), 2);
                         n++;
                     } else {
                         sum = sum
                                 + Math.pow(
-                                        ((Point2d) firstAtom.getPoint2d()).distance(secondAtomContainer.getAtom(
+                                        firstAtom.getPoint2d().distance(secondAtomContainer.getAtom(
                                                 secondAtomNumber).getPoint2d()), 2);
                         n++;
                     }
@@ -1608,8 +1608,10 @@ public class GeometryTools {
             }
 
         }
-        RMSD = Math.sqrt(sum / n);
-        return RMSD;
+        if (n == 0)
+            return 0;
+        rmsd = Math.sqrt(sum / n);
+        return rmsd;
     }
 
     /**
@@ -1631,6 +1633,8 @@ public class GeometryTools {
                 bondLengthSum += atom1.getPoint3d().distance(atom2.getPoint3d());
             }
         }
+        if (bondCounter == 0)
+            return 0;
         return bondLengthSum / bondCounter;
     }
 
@@ -1676,6 +1680,8 @@ public class GeometryTools {
             containercount++;
             bondlenghtsum += getBondLengthAverage(container);
         }
+        if (containercount == 0)
+            return 0;
         return bondlenghtsum / containercount;
     }
 
@@ -1687,9 +1693,8 @@ public class GeometryTools {
      */
     public static boolean has3DCoordinates(IChemModel chemModel) {
         List<IAtomContainer> acs = ChemModelManipulator.getAllAtomContainers(chemModel);
-        Iterator<IAtomContainer> it = acs.iterator();
-        while (it.hasNext()) {
-            if (!has3DCoordinates(it.next())) {
+        for (IAtomContainer ac : acs) {
+            if (!has3DCoordinates(ac)) {
                 return false;
             }
         }
