@@ -38,7 +38,6 @@ import org.openscience.cdk.tools.CDKHydrogenAdder;
 import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 import org.openscience.cdk.tools.manipulator.AtomTypeManipulator;
 
-import java.util.Iterator;
 import java.util.List;
 
 /**
@@ -56,7 +55,7 @@ import java.util.List;
 public class MoleculeBuilder {
 
     /** The molecule which is worked upon throughout the class and returned at the end */
-    private IAtomContainer currentMolecule = null;
+    private IAtomContainer currentMolecule;
     private IAtom          endOfChain;
 
     public MoleculeBuilder(IChemObjectBuilder builder) {
@@ -105,13 +104,8 @@ public class MoleculeBuilder {
      * @see #addFunGroup
      */
     private void buildFunGroups(List<AttachedGroup> attachedGroups) {
-        Iterator<AttachedGroup> groupsIterator = attachedGroups.iterator();
-        while (groupsIterator.hasNext()) {
-            AttachedGroup attachedGroup = groupsIterator.next();
-
-            Iterator<Token> locationsIterator = attachedGroup.getLocations().iterator();
-            while (locationsIterator.hasNext()) {
-                Token locationToken = locationsIterator.next();
+        for (AttachedGroup attachedGroup : attachedGroups) {
+            for (Token locationToken : attachedGroup.getLocations()) {
                 addFunGroup(attachedGroup.getName(), Integer.parseInt(locationToken.image) - 1);
             }
         }
@@ -392,14 +386,8 @@ public class MoleculeBuilder {
      * @param attachedSubstituents A vector of AttachedGroup's representing substituents.
      */
     private void addHeads(List<AttachedGroup> attachedSubstituents) {
-        Iterator<AttachedGroup> substituentsIterator = attachedSubstituents.iterator();
-        while (substituentsIterator.hasNext()) {
-            AttachedGroup attachedSubstituent = substituentsIterator.next();
-
-            Iterator<Token> locationsIterator = attachedSubstituent.getLocations().iterator();
-            while (locationsIterator.hasNext()) {
-                Token locationToken = locationsIterator.next();
-
+        for (AttachedGroup attachedSubstituent : attachedSubstituents) {
+            for (Token locationToken : attachedSubstituent.getLocations()) {
                 int joinLocation = Integer.parseInt(locationToken.image) - 1;
                 IAtom connectingAtom;
 
@@ -450,9 +438,7 @@ public class MoleculeBuilder {
 
         //Add the hydrogens to create a balanced molecule
         CDKAtomTypeMatcher matcher = CDKAtomTypeMatcher.getInstance(currentMolecule.getBuilder());
-        Iterator<IAtom> atoms = currentMolecule.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = atoms.next();
+        for (IAtom atom : currentMolecule.atoms()) {
             IAtomType type = matcher.findMatchingAtomType(currentMolecule, atom);
             AtomTypeManipulator.configure(atom, type);
         }
