@@ -38,6 +38,7 @@ import org.openscience.cdk.smsd.algorithm.matchers.DefaultBondMatcher;
 import org.openscience.cdk.smsd.algorithm.matchers.DefaultMCSPlusAtomMatcher;
 import org.openscience.cdk.smsd.algorithm.matchers.DefaultMatcher;
 import org.openscience.cdk.smsd.helper.BinaryTree;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 /**
  * Class to perform check/methods for McGregor class.
@@ -99,7 +100,8 @@ public class McGregorChecks {
                             return true;
                         }
                     } catch (Exception e) {
-                        e.printStackTrace();
+                        LoggingToolFactory.createLoggingTool(McGregorChecks.class)
+                                          .warn("Unexpected Error:", e);
                     }
                 }
             }
@@ -152,14 +154,14 @@ public class McGregorChecks {
     protected static int searchCorrespondingAtom(int mappedAtomsSize, int atomFromOtherMolecule, int molecule,
             List<Integer> mappedAtomsOrg) {
 
-        List<Integer> mappedAtoms = new ArrayList<Integer>(mappedAtomsOrg);
+        List<Integer> mappedAtoms = new ArrayList<>(mappedAtomsOrg);
 
         int correspondingAtom = 0;
         for (int a = 0; a < mappedAtomsSize; a++) {
-            if ((molecule == 1) && (mappedAtoms.get(a * 2 + 0).intValue() == atomFromOtherMolecule)) {
+            if ((molecule == 1) && (mappedAtoms.get(a * 2 + 0) == atomFromOtherMolecule)) {
                 correspondingAtom = mappedAtoms.get(a * 2 + 1);
             }
-            if ((molecule == 2) && (mappedAtoms.get(a * 2 + 1).intValue() == atomFromOtherMolecule)) {
+            if ((molecule == 2) && (mappedAtoms.get(a * 2 + 1) == atomFromOtherMolecule)) {
                 correspondingAtom = mappedAtoms.get(a * 2 + 0);
             }
         }
@@ -213,7 +215,7 @@ public class McGregorChecks {
     protected static List<Integer> removeRecurringMappings(List<Integer> atomMapping) {
 
         boolean exist = true;
-        List<Integer> tempMap = new ArrayList<Integer>();
+        List<Integer> tempMap = new ArrayList<>();
         int tempCounter = 0;
         int atomMappingSize = atomMapping.size();
         for (int x = 0; x < atomMappingSize; x += 2) {
@@ -290,7 +292,7 @@ public class McGregorChecks {
      * @return
      */
     protected static List<String> generateCSetCopy(int bondNumber, List<String> cSet) {
-        List<String> cTabCopy = new ArrayList<String>();
+        List<String> cTabCopy = new ArrayList<>();
         for (int a = 0; a < bondNumber; a++) {
             cTabCopy.add(cSet.get(a * 4 + 0));
             cTabCopy.add(cSet.get(a * 4 + 1));
@@ -307,7 +309,7 @@ public class McGregorChecks {
      * @throws IOException
      */
     protected static List<String> generateCTabCopy(IAtomContainer atomContainer) throws IOException {
-        List<String> cTabCopy = new ArrayList<String>();
+        List<String> cTabCopy = new ArrayList<>();
         for (int a = 0; a < atomContainer.getBondCount(); a++) {
             String atomI = atomContainer.getBond(a).getBegin().getSymbol();
             String atomJ = atomContainer.getBond(a).getEnd().getSymbol();
@@ -595,7 +597,8 @@ public class McGregorChecks {
                             return true;
                         }
                     } catch (Exception e) {
-                        e.printStackTrace();
+                        LoggingToolFactory.createLoggingTool(McGregorChecks.class)
+                                          .warn("Unexpected Error:", e);
                     }
                 }
             }
@@ -605,7 +608,7 @@ public class McGregorChecks {
     }
 
     static List<Integer> markUnMappedAtoms(boolean flag, IAtomContainer container, Map<Integer, Integer> presentMapping) {
-        List<Integer> unmappedMolAtoms = new ArrayList<Integer>();
+        List<Integer> unmappedMolAtoms = new ArrayList<>();
 
         int unmappedNum = 0;
         boolean atomIsUnmapped = true;
@@ -627,7 +630,7 @@ public class McGregorChecks {
 
     static List<Integer> markUnMappedAtoms(boolean flag, IAtomContainer container, List<Integer> mappedAtoms,
             int cliqueSize) {
-        List<Integer> unmappedMolAtoms = new ArrayList<Integer>();
+        List<Integer> unmappedMolAtoms = new ArrayList<>();
         int unmappedNum = 0;
         boolean atomIsUnmapped = true;
         for (int a = 0; a < container.getAtomCount(); a++) {
