@@ -26,8 +26,8 @@ import java.util.Map;
 import javax.vecmath.Point2d;
 import javax.vecmath.Point3d;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.Bond;
@@ -62,10 +62,10 @@ import static org.hamcrest.MatcherAssert.assertThat;
  *
  * @see org.openscience.cdk.geometry.GeometryTools
  */
-public class GeometryToolsTest extends CDKTestCase {
+class GeometryToolsTest extends CDKTestCase {
 
     @Test
-    public void testHas2DCoordinates_IAtomContainer() {
+    void testHas2DCoordinates_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -73,7 +73,7 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertTrue(GeometryTools.has2DCoordinates(container));
+        Assertions.assertTrue(GeometryTools.has2DCoordinates(container));
 
         atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 1));
@@ -82,51 +82,50 @@ public class GeometryToolsTest extends CDKTestCase {
         container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertFalse(GeometryTools.has2DCoordinates(container));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates(container));
     }
 
     @Test
-    public void testHas2DCoordinates_EmptyAtomContainer() {
+    void testHas2DCoordinates_EmptyAtomContainer() {
         IAtomContainer container = new AtomContainer();
-        Assert.assertFalse(GeometryTools.has2DCoordinates(container));
-        Assert.assertFalse(GeometryTools.has2DCoordinates((IAtomContainer) null));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates(container));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates((IAtomContainer) null));
     }
 
     @Test
-    public void testHas2DCoordinates_Partial() {
+    void testHas2DCoordinates_Partial() {
         IAtomContainer container = new AtomContainer();
         Atom atom1 = new Atom("C");
         Atom atom2 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         container.addAtom(atom1);
-        Assert.assertTrue(GeometryTools.has2DCoordinates(container));
+        Assertions.assertTrue(GeometryTools.has2DCoordinates(container));
         container.addAtom(atom2);
-        Assert.assertFalse(GeometryTools.has2DCoordinates(container));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates(container));
     }
 
     /**
      * @cdk.bug 2936440
      */
     @Test
-    public void testHas2DCoordinates_With000() throws CDKException {
+    void testHas2DCoordinates_With000() throws CDKException {
         String filenameMol = "with000coordinate.mol";
         InputStream ins = this.getClass().getResourceAsStream(filenameMol);
-        IAtomContainer molOne = null;
+        IAtomContainer molOne;
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
-        molOne = (IAtomContainer) reader.read(new AtomContainer());
-        Assert.assertTrue(GeometryTools.has2DCoordinates(molOne));
+        molOne = reader.read(new AtomContainer());
+        Assertions.assertTrue(GeometryTools.has2DCoordinates(molOne));
     }
 
     @Test
-    public void get2DCoordinateCoverage_EmptyAtomContainer() {
+    void get2DCoordinateCoverage_EmptyAtomContainer() {
         IAtomContainer container = new AtomContainer();
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(container));
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE,
-                GeometryTools.get2DCoordinateCoverage((IAtomContainer) null));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(null));
     }
 
     @Test
-    public void get2DCoordinateCoverage_Partial() {
+    void get2DCoordinateCoverage_Partial() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -141,12 +140,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.PARTIAL, GeometryTools.get2DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.PARTIAL, GeometryTools.get2DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void get2DCoordinateCoverage_Full() {
+    void get2DCoordinateCoverage_Full() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -162,12 +161,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.FULL, GeometryTools.get2DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.FULL, GeometryTools.get2DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void get2DCoordinateCoverage_None_3D() {
+    void get2DCoordinateCoverage_None_3D() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -183,39 +182,39 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get2DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void testTranslateAllPositive_IAtomContainer() {
+    void testTranslateAllPositive_IAtomContainer() {
         IAtomContainer container = new AtomContainer();
         IAtom atom = new Atom(Elements.CARBON);
         atom.setPoint2d(new Point2d(-3, -2));
         container.addAtom(atom);
         GeometryTools.translateAllPositive(container);
-        Assert.assertTrue(0 <= atom.getPoint2d().x);
-        Assert.assertTrue(0 <= atom.getPoint2d().y);
+        Assertions.assertTrue(0 <= atom.getPoint2d().x);
+        Assertions.assertTrue(0 <= atom.getPoint2d().y);
     }
 
     @Test
-    public void testGetLength2D_IBond() {
+    void testGetLength2D_IBond() {
         Atom o = new Atom("O", new Point2d(0.0, 0.0));
         Atom c = new Atom("C", new Point2d(1.0, 0.0));
         Bond bond = new Bond(c, o);
 
-        Assert.assertEquals(1.0, GeometryTools.getLength2D(bond), 0.001);
+        Assertions.assertEquals(1.0, GeometryTools.getLength2D(bond), 0.001);
     }
 
     @Test
-    public void testMapAtomsOfAlignedStructures() throws Exception {
+    void testMapAtomsOfAlignedStructures() throws Exception {
         String filenameMolOne = "murckoTest6_3d_2.mol";
         String filenameMolTwo = "murckoTest6_3d.mol";
         //String filenameMolTwo = "data/mdl/murckoTest6_3d_2.mol";
         InputStream ins = this.getClass().getResourceAsStream(filenameMolOne);
         IAtomContainer molOne;
         IAtomContainer molTwo;
-        Map<Integer, Integer> mappedAtoms = new HashMap<Integer, Integer>();
+        Map<Integer, Integer> mappedAtoms = new HashMap<>();
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
         molOne = reader.read(new AtomContainer());
 
@@ -229,21 +228,21 @@ public class GeometryToolsTest extends CDKTestCase {
         double AngleRMSD = GeometryTools.getAngleRMSD(molOne, molTwo, mappedAtoms);
         //logger.debug("The Angle RMSD between the first and the second structure is :"+AngleRMSD);
         //logger.debug("***** ALL ATOMS RMSD *****");
-        Assert.assertEquals(0.2, AngleRMSD, 0.1);
+        Assertions.assertEquals(0.2, AngleRMSD, 0.1);
         double AllRMSD = GeometryTools.getAllAtomRMSD(molOne, molTwo, mappedAtoms, true);
         //logger.debug("The RMSD between the first and the second structure is :"+AllRMSD);
-        Assert.assertEquals(0.242, AllRMSD, 0.001);
+        Assertions.assertEquals(0.242, AllRMSD, 0.001);
         //logger.debug("***** BOND LENGTH RMSD *****");
         double BondLengthRMSD = GeometryTools.getBondLengthRMSD(molOne, molTwo, mappedAtoms, true);
         //logger.debug("The Bond length RMSD between the first and the second structure is :"+BondLengthRMSD);
-        Assert.assertEquals(0.2, BondLengthRMSD, 0.1);
+        Assertions.assertEquals(0.2, BondLengthRMSD, 0.1);
     }
 
     /*
      * @cdk.bug 1649007
      */
     @Test
-    public void testRotate_IAtomContainer_Point2d_double() {
+    void testRotate_IAtomContainer_Point2d_double() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -252,18 +251,18 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         GeometryTools.rotate(ac, new Point2d(0, 0), Math.PI / 2);
-        Assert.assertEquals(atom1.getPoint2d().x, -1, .2);
-        Assert.assertEquals(atom1.getPoint2d().y, 1, .2);
-        Assert.assertEquals(atom2.getPoint2d().x, 0, .2);
-        Assert.assertEquals(atom2.getPoint2d().y, 1, .2);
+        Assertions.assertEquals(atom1.getPoint2d().x, -1, .2);
+        Assertions.assertEquals(atom1.getPoint2d().y, 1, .2);
+        Assertions.assertEquals(atom2.getPoint2d().x, 0, .2);
+        Assertions.assertEquals(atom2.getPoint2d().y, 1, .2);
         atom2.setPoint2d(new Point2d(0, 0));
         GeometryTools.rotate(ac, new Point2d(0, 0), Math.PI);
-        Assert.assertFalse(Double.isNaN(atom2.getPoint2d().x));
-        Assert.assertFalse(Double.isNaN(atom2.getPoint2d().y));
+        Assertions.assertFalse(Double.isNaN(atom2.getPoint2d().x));
+        Assertions.assertFalse(Double.isNaN(atom2.getPoint2d().y));
     }
 
     @Test
-    public void testGetMinMax_IAtomContainer() {
+    void testGetMinMax_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -272,15 +271,15 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         double[] minmax = GeometryTools.getMinMax(ac);
-        Assert.assertEquals(minmax[0], 1d, .1);
-        Assert.assertEquals(minmax[1], 0d, .1);
-        Assert.assertEquals(minmax[2], 1d, .1);
-        Assert.assertEquals(minmax[3], 1d, .1);
+        Assertions.assertEquals(minmax[0], 1d, .1);
+        Assertions.assertEquals(minmax[1], 0d, .1);
+        Assertions.assertEquals(minmax[2], 1d, .1);
+        Assertions.assertEquals(minmax[3], 1d, .1);
     }
 
     /** @cdk.bug 2094881 */
     @Test
-    public void testGetMinMax2() {
+    void testGetMinMax2() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(-2, -1));
         Atom atom2 = new Atom("C");
@@ -289,14 +288,14 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         double[] minmax = GeometryTools.getMinMax(ac);
-        Assert.assertEquals(-5, minmax[0], .1);
-        Assert.assertEquals(-1, minmax[1], .1);
-        Assert.assertEquals(-2, minmax[2], .1);
-        Assert.assertEquals(-1, minmax[3], .1);
+        Assertions.assertEquals(-5, minmax[0], .1);
+        Assertions.assertEquals(-1, minmax[1], .1);
+        Assertions.assertEquals(-2, minmax[2], .1);
+        Assertions.assertEquals(-1, minmax[3], .1);
     }
 
     @Test
-    public void testGetRectangle2D_IAtomContainer() {
+    void testGetRectangle2D_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(2, 2));
         Atom atom2 = new Atom("C");
@@ -305,14 +304,14 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom1);
         container.addAtom(atom2);
         Rectangle2D rectangle = GeometryTools.getRectangle2D(container);
-        Assert.assertEquals(2.0, rectangle.getMinX(), 0.0);
-        Assert.assertEquals(3.0, rectangle.getWidth(), 0.0);
-        Assert.assertEquals(1.0, rectangle.getMinY(), 0.0);
-        Assert.assertEquals(1.0, rectangle.getHeight(), 0.0);
+        Assertions.assertEquals(2.0, rectangle.getMinX(), 0.0);
+        Assertions.assertEquals(3.0, rectangle.getWidth(), 0.0);
+        Assertions.assertEquals(1.0, rectangle.getMinY(), 0.0);
+        Assertions.assertEquals(1.0, rectangle.getHeight(), 0.0);
     }
 
     @Test
-    public void testRotate_IAtom_Point3d_Point3d_double() {
+    void testRotate_IAtom_Point3d_Point3d_double() {
         Atom atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 0));
         GeometryTools.rotate(atom1, new Point3d(2, 0, 0), new Point3d(2, 2, 0), 90);
@@ -320,16 +319,16 @@ public class GeometryToolsTest extends CDKTestCase {
     }
 
     @Test
-    public void testNormalize_Point3d() {
+    void testNormalize_Point3d() {
         Point3d p = new Point3d(1, 1, 0);
         GeometryTools.normalize(p);
-        Assert.assertEquals(p.x, 0.7, .1);
-        Assert.assertEquals(p.y, 0.7, .1);
-        Assert.assertEquals(p.z, 0.0, .1);
+        Assertions.assertEquals(p.x, 0.7, .1);
+        Assertions.assertEquals(p.y, 0.7, .1);
+        Assertions.assertEquals(p.z, 0.0, .1);
     }
 
     @Test
-    public void testGet2DCenter_IAtomContainer() {
+    void testGet2DCenter_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -338,12 +337,12 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         Point2d p = GeometryTools.get2DCenter(ac);
-        Assert.assertEquals(p.x, 1.0, .1);
-        Assert.assertEquals(p.y, 0.5, .1);
+        Assertions.assertEquals(p.x, 1.0, .1);
+        Assertions.assertEquals(p.y, 0.5, .1);
     }
 
     @Test
-    public void testGet2DCenterOfMass_IAtomContainer() {
+    void testGet2DCenterOfMass_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         atom1.setExactMass(12.0);
@@ -354,13 +353,13 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         Point2d p = GeometryTools.get2DCentreOfMass(ac);
-        Assert.assertNotNull(p);
-        Assert.assertEquals(p.x, 1.0, .1);
-        Assert.assertEquals(p.y, 0.5, .1);
+        Assertions.assertNotNull(p);
+        Assertions.assertEquals(p.x, 1.0, .1);
+        Assertions.assertEquals(p.y, 0.5, .1);
     }
 
     @Test
-    public void testGet2DCenter_arrayIAtom() {
+    void testGet2DCenter_arrayIAtom() {
         IAtomContainer container = new AtomContainer();
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
@@ -369,12 +368,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom1);
         container.addAtom(atom2);
         Point2d p = GeometryTools.get2DCenter(container.atoms());
-        Assert.assertEquals(p.x, 1.0, .1);
-        Assert.assertEquals(p.y, 0.5, .1);
+        Assertions.assertEquals(p.x, 1.0, .1);
+        Assertions.assertEquals(p.y, 0.5, .1);
     }
 
     @Test
-    public void testGet2DCenter_IRingSet() {
+    void testGet2DCenter_IRingSet() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -385,12 +384,12 @@ public class GeometryToolsTest extends CDKTestCase {
         IRingSet ringset = DefaultChemObjectBuilder.getInstance().newInstance(IRingSet.class);
         ringset.addAtomContainer(ac);
         Point2d p = GeometryTools.get2DCenter(ac);
-        Assert.assertEquals(p.x, 1.0, .1);
-        Assert.assertEquals(p.y, 0.5, .1);
+        Assertions.assertEquals(p.x, 1.0, .1);
+        Assertions.assertEquals(p.y, 0.5, .1);
     }
 
     @Test
-    public void testGet2DCenter_Iterator() {
+    void testGet2DCenter_Iterator() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -399,40 +398,40 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         Point2d p = GeometryTools.get2DCenter(ac.atoms());
-        Assert.assertEquals(p.x, 1.0, .1);
-        Assert.assertEquals(p.y, 0.5, .1);
+        Assertions.assertEquals(p.x, 1.0, .1);
+        Assertions.assertEquals(p.y, 0.5, .1);
     }
 
     @Test
-    public void testHas2DCoordinates_IAtom() {
+    void testHas2DCoordinates_IAtom() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
-        Assert.assertTrue(GeometryTools.has2DCoordinates(atom1));
+        Assertions.assertTrue(GeometryTools.has2DCoordinates(atom1));
 
         atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 1));
-        Assert.assertFalse(GeometryTools.has2DCoordinates(atom1));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates(atom1));
     }
 
     @Test
-    public void testHas2DCoordinates_IBond() {
+    void testHas2DCoordinates_IBond() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
         atom2.setPoint2d(new Point2d(1, 0));
         IBond bond = new Bond(atom1, atom2);
-        Assert.assertTrue(GeometryTools.has2DCoordinates(bond));
+        Assertions.assertTrue(GeometryTools.has2DCoordinates(bond));
 
         atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 1));
         atom2 = new Atom("C");
         atom2.setPoint3d(new Point3d(1, 0, 5));
         bond = new Bond(atom1, atom2);
-        Assert.assertFalse(GeometryTools.has2DCoordinates(bond));
+        Assertions.assertFalse(GeometryTools.has2DCoordinates(bond));
     }
 
     @Test
-    public void testHas2DCoordinatesNew_IAtomContainer() {
+    void testHas2DCoordinatesNew_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -440,7 +439,7 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertEquals(2, GeometryTools.has2DCoordinatesNew(container));
+        Assertions.assertEquals(2, GeometryTools.has2DCoordinatesNew(container));
 
         atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
@@ -449,7 +448,7 @@ public class GeometryToolsTest extends CDKTestCase {
         container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertEquals(1, GeometryTools.has2DCoordinatesNew(container));
+        Assertions.assertEquals(1, GeometryTools.has2DCoordinatesNew(container));
 
         atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 1));
@@ -458,11 +457,11 @@ public class GeometryToolsTest extends CDKTestCase {
         container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertEquals(0, GeometryTools.has2DCoordinatesNew(container));
+        Assertions.assertEquals(0, GeometryTools.has2DCoordinatesNew(container));
     }
 
     @Test
-    public void testHas3DCoordinates_IAtomContainer() {
+    void testHas3DCoordinates_IAtomContainer() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 1));
         Atom atom2 = new Atom("C");
@@ -470,7 +469,7 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertFalse(GeometryTools.has3DCoordinates(container));
+        Assertions.assertFalse(GeometryTools.has3DCoordinates(container));
 
         atom1 = new Atom("C");
         atom1.setPoint3d(new Point3d(1, 1, 1));
@@ -479,26 +478,25 @@ public class GeometryToolsTest extends CDKTestCase {
         container = new AtomContainer();
         container.addAtom(atom1);
         container.addAtom(atom2);
-        Assert.assertTrue(GeometryTools.has3DCoordinates(container));
+        Assertions.assertTrue(GeometryTools.has3DCoordinates(container));
     }
 
     @Test
-    public void testHas3DCoordinates_EmptyAtomContainer() {
+    void testHas3DCoordinates_EmptyAtomContainer() {
         IAtomContainer container = new AtomContainer();
-        Assert.assertFalse(GeometryTools.has3DCoordinates(container));
-        Assert.assertFalse(GeometryTools.has3DCoordinates((IAtomContainer) null));
+        Assertions.assertFalse(GeometryTools.has3DCoordinates(container));
+        Assertions.assertFalse(GeometryTools.has3DCoordinates((IAtomContainer) null));
     }
 
     @Test
-    public void get3DCoordinateCoverage_EmptyAtomContainer() {
+    void get3DCoordinateCoverage_EmptyAtomContainer() {
         IAtomContainer container = new AtomContainer();
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(container));
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE,
-                GeometryTools.get3DCoordinateCoverage((IAtomContainer) null));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(null));
     }
 
     @Test
-    public void get3DCoordinateCoverage_Partial() {
+    void get3DCoordinateCoverage_Partial() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -513,12 +511,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.PARTIAL, GeometryTools.get3DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.PARTIAL, GeometryTools.get3DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void get3DCoordinateCoverage_Full() {
+    void get3DCoordinateCoverage_Full() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -534,12 +532,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.FULL, GeometryTools.get3DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.FULL, GeometryTools.get3DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void get3DCoordinateCoverage_None_2D() {
+    void get3DCoordinateCoverage_None_2D() {
 
         IAtomContainer container = new AtomContainer();
 
@@ -555,12 +553,12 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addAtom(atom2);
         container.addAtom(atom3);
 
-        Assert.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(container));
+        Assertions.assertEquals(GeometryTools.CoordinateCoverage.NONE, GeometryTools.get3DCoordinateCoverage(container));
 
     }
 
     @Test
-    public void testTranslateAllPositive_IAtomContainer_HashMap() {
+    void testTranslateAllPositive_IAtomContainer_HashMap() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(-1, -1));
         Atom atom2 = new Atom("C");
@@ -569,14 +567,14 @@ public class GeometryToolsTest extends CDKTestCase {
         ac.addAtom(atom1);
         ac.addAtom(atom2);
         GeometryTools.translateAllPositive(ac);
-        Assert.assertEquals(atom1.getPoint2d().x, 0.0, 0.01);
-        Assert.assertEquals(atom1.getPoint2d().y, 0.0, 0.01);
-        Assert.assertEquals(atom2.getPoint2d().x, 2.0, 0.01);
-        Assert.assertEquals(atom2.getPoint2d().y, 1.0, 0.01);
+        Assertions.assertEquals(atom1.getPoint2d().x, 0.0, 0.01);
+        Assertions.assertEquals(atom1.getPoint2d().y, 0.0, 0.01);
+        Assertions.assertEquals(atom2.getPoint2d().x, 2.0, 0.01);
+        Assertions.assertEquals(atom2.getPoint2d().y, 1.0, 0.01);
     }
 
     @Test
-    public void testGetLength2D_IBond_HashMap() {
+    void testGetLength2D_IBond_HashMap() {
         Atom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(-1, -1));
         Atom atom2 = new Atom("C");
@@ -585,11 +583,11 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer ac = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         ac.addAtom(atom1);
         ac.addAtom(atom2);
-        Assert.assertEquals(GeometryTools.getLength2D(bond), 2.23, 0.01);
+        Assertions.assertEquals(GeometryTools.getLength2D(bond), 2.23, 0.01);
     }
 
     @Test
-    public void testGetClosestAtom_Multiatom() {
+    void testGetClosestAtom_Multiatom() {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(-1, -1));
         IAtom atom2 = new Atom("C");
@@ -600,13 +598,13 @@ public class GeometryToolsTest extends CDKTestCase {
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         acont.addAtom(atom3);
-        Assert.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom1));
-        Assert.assertEquals(atom1, GeometryTools.getClosestAtom(acont, atom2));
-        Assert.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom3));
+        Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom1));
+        Assertions.assertEquals(atom1, GeometryTools.getClosestAtom(acont, atom2));
+        Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom3));
     }
 
     @Test
-    public void testGetClosestAtom_Double_Double_IAtomContainer_IAtom() {
+    void testGetClosestAtom_Double_Double_IAtomContainer_IAtom() {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(1, 0));
         IAtom atom2 = new Atom("C");
@@ -614,15 +612,15 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer acont = new AtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
-        Assert.assertEquals(atom2, GeometryTools.getClosestAtom(1.0, 0.0, acont, atom1));
-        Assert.assertEquals(atom1, GeometryTools.getClosestAtom(1.0, 0.0, acont, null));
+        Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(1.0, 0.0, acont, atom1));
+        Assertions.assertEquals(atom1, GeometryTools.getClosestAtom(1.0, 0.0, acont, null));
     }
 
     /**
      * Tests if not the central atom is returned as closest atom.
      */
     @Test
-    public void testGetClosestAtom_IAtomContainer_IAtom() {
+    void testGetClosestAtom_IAtomContainer_IAtom() {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(-1, -1));
         IAtom atom2 = new Atom("C");
@@ -630,12 +628,12 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer acont = new AtomContainer();
         acont.addAtom(atom1);
         acont.addAtom(atom2);
-        Assert.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom1));
-        Assert.assertEquals(atom1, GeometryTools.getClosestAtom(acont, atom2));
+        Assertions.assertEquals(atom2, GeometryTools.getClosestAtom(acont, atom1));
+        Assertions.assertEquals(atom1, GeometryTools.getClosestAtom(acont, atom2));
     }
 
     @Test
-    public void testShiftContainerHorizontal_IAtomContainer_Rectangle2D_Rectangle2D_double() throws Exception {
+    void testShiftContainerHorizontal_IAtomContainer_Rectangle2D_Rectangle2D_double() throws Exception {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
@@ -643,7 +641,7 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer react1 = new AtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
-        IAtomContainer react2 = (IAtomContainer) react1.clone();
+        IAtomContainer react2 = react1.clone();
 
         // shift the second molecule right
         GeometryTools.shiftContainer(react2, GeometryTools.getRectangle2D(react2),
@@ -654,9 +652,9 @@ public class GeometryToolsTest extends CDKTestCase {
             atom1 = react1.getAtom(0);
             atom2 = react2.getAtom(0);
             // so, y coordinates should be the same
-            Assert.assertEquals(atom1.getPoint2d().y, atom2.getPoint2d().y, 0.0);
+            Assertions.assertEquals(atom1.getPoint2d().y, atom2.getPoint2d().y, 0.0);
             // but, x coordinates should not
-            Assert.assertTrue(atom1.getPoint2d().x < atom2.getPoint2d().x);
+            Assertions.assertTrue(atom1.getPoint2d().x < atom2.getPoint2d().x);
         }
     }
 
@@ -667,7 +665,7 @@ public class GeometryToolsTest extends CDKTestCase {
      * @throws Exception Thrown when the cloning failed.
      */
     @Test
-    public void testShiftContainerHorizontal_Two_vertical_molecules() throws Exception {
+    void testShiftContainerHorizontal_Two_vertical_molecules() throws Exception {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
@@ -675,7 +673,7 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtomContainer react1 = new AtomContainer();
         react1.addAtom(atom1);
         react1.addAtom(atom2);
-        IAtomContainer react2 = (IAtomContainer) react1.clone();
+        IAtomContainer react2 = react1.clone();
 
         // shift the second molecule right
         GeometryTools.shiftContainer(react2, GeometryTools.getRectangle2D(react2),
@@ -686,14 +684,14 @@ public class GeometryToolsTest extends CDKTestCase {
             atom1 = react1.getAtom(0);
             atom2 = react2.getAtom(0);
             // so, y coordinates should be the same
-            Assert.assertEquals(atom1.getPoint2d().y, atom2.getPoint2d().y, 0.0);
+            Assertions.assertEquals(atom1.getPoint2d().y, atom2.getPoint2d().y, 0.0);
             // but, x coordinates should not
-            Assert.assertTrue(atom1.getPoint2d().x < atom2.getPoint2d().x);
+            Assertions.assertTrue(atom1.getPoint2d().x < atom2.getPoint2d().x);
         }
     }
 
     @Test
-    public void testGetBondLengthAverage_IReaction() {
+    void testGetBondLengthAverage_IReaction() {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
@@ -704,7 +702,7 @@ public class GeometryToolsTest extends CDKTestCase {
         acont.addAtom(atom1);
         acont.addAtom(atom2);
         acont.addBond(0, 1, IBond.Order.SINGLE);
-        Assert.assertEquals(1.0, GeometryTools.getBondLengthAverage(reaction), 0.0);
+        Assertions.assertEquals(1.0, GeometryTools.getBondLengthAverage(reaction), 0.0);
     }
 
     /**
@@ -712,7 +710,7 @@ public class GeometryToolsTest extends CDKTestCase {
      * {@link IAtomContainer}s in the IReaction.
      */
     @Test
-    public void testGetBondLengthAverage_MultiReaction() {
+    void testGetBondLengthAverage_MultiReaction() {
         IReaction reaction = new Reaction();
 
         // mol 1
@@ -737,11 +735,11 @@ public class GeometryToolsTest extends CDKTestCase {
         acont.addAtom(atom2);
         acont.addBond(0, 1, IBond.Order.SINGLE);
 
-        Assert.assertEquals(2.0, GeometryTools.getBondLengthAverage(reaction), 0.0);
+        Assertions.assertEquals(2.0, GeometryTools.getBondLengthAverage(reaction), 0.0);
     }
 
     @Test
-    public void testShiftReactionVertical_IAtomContainer_Rectangle2D_Rectangle2D_double() throws Exception {
+    void testShiftReactionVertical_IAtomContainer_Rectangle2D_Rectangle2D_double() throws Exception {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(0, 1));
         IAtom atom2 = new Atom("C");
@@ -766,9 +764,9 @@ public class GeometryToolsTest extends CDKTestCase {
             atom1 = react1.getAtom(0);
             atom2 = react2.getAtom(0);
             // so, x coordinates should be the same
-            Assert.assertEquals(atom1.getPoint2d().x, atom2.getPoint2d().x, 0.0);
+            Assertions.assertEquals(atom1.getPoint2d().x, atom2.getPoint2d().x, 0.0);
             // but, y coordinates should not
-            Assert.assertTrue(atom1.getPoint2d().y < atom2.getPoint2d().y);
+            Assertions.assertTrue(atom1.getPoint2d().y < atom2.getPoint2d().y);
         }
     }
 
@@ -779,7 +777,7 @@ public class GeometryToolsTest extends CDKTestCase {
      * @throws Exception Thrown when the cloning failed.
      */
     @Test
-    public void testShiftReactionVertical_Two_horizontal_molecules() throws Exception {
+    void testShiftReactionVertical_Two_horizontal_molecules() throws Exception {
         IAtom atom1 = new Atom("C");
         atom1.setPoint2d(new Point2d(0, 0));
         IAtom atom2 = new Atom("C");
@@ -804,14 +802,14 @@ public class GeometryToolsTest extends CDKTestCase {
             atom1 = react1.getAtom(0);
             atom2 = react2.getAtom(0);
             // so, x coordinates should be the same
-            Assert.assertEquals(atom1.getPoint2d().x, atom2.getPoint2d().x, 0.0);
+            Assertions.assertEquals(atom1.getPoint2d().x, atom2.getPoint2d().x, 0.0);
             // but, y coordinates should not
-            Assert.assertTrue(atom1.getPoint2d().y < atom2.getPoint2d().y);
+            Assertions.assertTrue(atom1.getPoint2d().y < atom2.getPoint2d().y);
         }
     }
 
     @Test
-    public void testGetBestAlignmentForLabelXY() {
+    void testGetBestAlignmentForLabelXY() {
         final String TYPE = "C";
         IAtom zero = new Atom("O");
         zero.setPoint2d(new Point2d());
@@ -824,16 +822,16 @@ public class GeometryToolsTest extends CDKTestCase {
         IAtom nY = new Atom(TYPE);
         nY.setPoint2d(new Point2d(0, -1));
 
-        Assert.assertEquals(-1, alignmentTestHelper(zero, pX));
-        Assert.assertEquals(1, alignmentTestHelper(zero, nX));
-        Assert.assertEquals(-2, alignmentTestHelper(zero, pY));
-        Assert.assertEquals(2, alignmentTestHelper(zero, nY));
+        Assertions.assertEquals(-1, alignmentTestHelper(zero, pX));
+        Assertions.assertEquals(1, alignmentTestHelper(zero, nX));
+        Assertions.assertEquals(-2, alignmentTestHelper(zero, pY));
+        Assertions.assertEquals(2, alignmentTestHelper(zero, nY));
 
-        Assert.assertEquals(1, alignmentTestHelper(zero, pY, nY));
+        Assertions.assertEquals(1, alignmentTestHelper(zero, pY, nY));
     }
 
     @Test
-    public void medianBondLength() {
+    void medianBondLength() {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
@@ -845,18 +843,20 @@ public class GeometryToolsTest extends CDKTestCase {
         assertThat(GeometryTools.getBondLengthMedian(container), is(1.5));
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void medianBondLengthNoBonds() {
+    @Test
+    void medianBondLengthNoBonds() {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
         container.addAtom(atomAt(new Point2d(0, -1.5)));
         container.addAtom(atomAt(new Point2d(0, 5)));
-        GeometryTools.getBondLengthMedian(container);
+        Assertions.assertThrows(IllegalArgumentException.class, () -> {
+            GeometryTools.getBondLengthMedian(container);
+        });
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void medianBondLengthNoPoints() {
+    @Test
+    void medianBondLengthNoPoints() {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
@@ -865,11 +865,13 @@ public class GeometryToolsTest extends CDKTestCase {
         container.addBond(0, 1, IBond.Order.SINGLE);
         container.addBond(0, 2, IBond.Order.SINGLE);
         container.addBond(0, 3, IBond.Order.SINGLE);
-        GeometryTools.getBondLengthMedian(container);
+        Assertions.assertThrows(IllegalArgumentException.class, () -> {
+            GeometryTools.getBondLengthMedian(container);
+        });
     }
 
     @Test
-    public void medianBondLengthOneBond() {
+    void medianBondLengthOneBond() {
         IAtomContainer container = new AtomContainer();
         container.addAtom(atomAt(new Point2d(0, 0)));
         container.addAtom(atomAt(new Point2d(0, 1.5)));
