@@ -28,8 +28,8 @@ package org.openscience.cdk.smsd.algorithm.rgraph;
 import java.io.InputStream;
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.test.CDKTestCase;
@@ -60,12 +60,12 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
  * @author     Syed Asad Rahman
  * @cdk.require java1.5+
  */
-public class CDKMCSTest extends CDKTestCase {
+class CDKMCSTest extends CDKTestCase {
 
-    boolean standAlone = false;
+    private final boolean standAlone = false;
 
     @Test
-    public void testIsSubgraph_IAtomContainer_IAtomContainer() throws java.lang.Exception {
+    void testIsSubgraph_IAtomContainer_IAtomContainer() throws java.lang.Exception {
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         IAtomContainer frag1 = TestMoleculeFactory.makeCyclohexene(); //one double bond in ring
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -80,7 +80,7 @@ public class CDKMCSTest extends CDKTestCase {
         if (standAlone) {
             System.out.println("Cyclohexene is a subgraph of alpha-Pinen: " + CDKMCS.isSubgraph(mol, frag1, true));
         } else {
-            Assert.assertTrue(CDKMCS.isSubgraph(mol, frag1, true));
+            Assertions.assertTrue(CDKMCS.isSubgraph(mol, frag1, true));
         }
 
     }
@@ -90,7 +90,7 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSFBug1708336() throws Exception {
+    void testSFBug1708336() throws Exception {
         IChemObjectBuilder builder = DefaultChemObjectBuilder.getInstance();
         IAtomContainer atomContainer = builder.newInstance(IAtomContainer.class);
         atomContainer.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -119,11 +119,11 @@ public class CDKMCSTest extends CDKTestCase {
 
         List<List<CDKRMap>> list = CDKMCS.getSubgraphMaps(atomContainer, query, true);
 
-        Assert.assertTrue(list.isEmpty());
+        Assertions.assertTrue(list.isEmpty());
     }
 
     @Test
-    public void test2() throws java.lang.Exception {
+    void test2() throws java.lang.Exception {
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         IAtomContainer frag1 = TestMoleculeFactory.makeCyclohexane(); // no double bond in ring
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -134,12 +134,12 @@ public class CDKMCSTest extends CDKTestCase {
         if (standAlone) {
             System.out.println("Cyclohexane is a subgraph of alpha-Pinen: " + CDKMCS.isSubgraph(mol, frag1, true));
         } else {
-            Assert.assertTrue(!CDKMCS.isSubgraph(mol, frag1, true));
+            Assertions.assertTrue(!CDKMCS.isSubgraph(mol, frag1, true));
         }
     }
 
     @Test
-    public void test3() throws java.lang.Exception {
+    void test3() throws java.lang.Exception {
         IAtomContainer mol = TestMoleculeFactory.makeIndole();
         IAtomContainer frag1 = TestMoleculeFactory.makePyrrole();
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol);
@@ -154,22 +154,22 @@ public class CDKMCSTest extends CDKTestCase {
         if (standAlone) {
             System.out.println("Pyrrole is a subgraph of Indole: " + CDKMCS.isSubgraph(mol, frag1, true));
         } else {
-            Assert.assertTrue(CDKMCS.isSubgraph(mol, frag1, true));
+            Assertions.assertTrue(CDKMCS.isSubgraph(mol, frag1, true));
         }
     }
 
     @Test
-    public void testBasicQueryAtomContainer() throws Exception {
+    void testBasicQueryAtomContainer() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer atomContainer = sp.parseSmiles("CC(=O)OC(=O)C"); // acetic acid anhydride
         IAtomContainer SMILESquery = sp.parseSmiles("CC"); // acetic acid anhydride
         QueryAtomContainer query = QueryAtomContainerCreator.createBasicQueryContainer(SMILESquery);
 
-        Assert.assertTrue(CDKMCS.isSubgraph(atomContainer, query, true));
+        Assertions.assertTrue(CDKMCS.isSubgraph(atomContainer, query, true));
     }
 
     @Test
-    public void testGetSubgraphAtomsMaps_IAtomContainer() throws java.lang.Exception {
+    void testGetSubgraphAtomsMaps_IAtomContainer() throws java.lang.Exception {
         int[] result1 = {6, 5, 7, 8, 0};
         int[] result2 = {3, 4, 2, 1, 0};
 
@@ -188,19 +188,19 @@ public class CDKMCSTest extends CDKTestCase {
         List<CDKRMap> first = list.get(0);
         for (int i = 0; i < first.size(); i++) {
             CDKRMap rmap = first.get(i);
-            Assert.assertEquals(rmap.getId1(), result1[i]);
-            Assert.assertEquals(rmap.getId2(), result2[i]);
+            Assertions.assertEquals(rmap.getId1(), result1[i]);
+            Assertions.assertEquals(rmap.getId2(), result2[i]);
         }
     }
 
     @Test
-    public void testGetSubgraphMap_IAtomContainer_IAtomContainer() throws Exception {
+    void testGetSubgraphMap_IAtomContainer_IAtomContainer() throws Exception {
         String molfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         String queryfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         IAtomContainer mol = new AtomContainer();
         IAtomContainer temp = new AtomContainer();
-        QueryAtomContainer query1 = null;
-        QueryAtomContainer query2 = null;
+        QueryAtomContainer query1;
+        QueryAtomContainer query2;
 
         InputStream ins = this.getClass().getClassLoader().getResourceAsStream(molfile);
         MDLV2000Reader reader = new MDLV2000Reader(ins, Mode.STRICT);
@@ -215,10 +215,10 @@ public class CDKMCSTest extends CDKTestCase {
         query2 = QueryAtomContainerCreator.createBasicQueryContainer(atomContainer);
 
         List<CDKRMap> list = CDKMCS.getSubgraphMap(mol, query1, true);
-        Assert.assertEquals(11, list.size());
+        Assertions.assertEquals(11, list.size());
 
         list = CDKMCS.getSubgraphMap(mol, query2, true);
-        Assert.assertEquals(6, list.size());
+        Assertions.assertEquals(6, list.size());
 
     }
 
@@ -227,7 +227,7 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetOverlaps_IAtomContainer_IAtomContainer() throws Exception {
+    void testGetOverlaps_IAtomContainer_IAtomContainer() throws Exception {
         String file1 = "org/openscience/cdk/smsd/algorithm/5SD.mol";
         String file2 = "org/openscience/cdk/smsd/algorithm/ADN.mol";
         IAtomContainer mol1 = new AtomContainer();
@@ -249,12 +249,12 @@ public class CDKMCSTest extends CDKTestCase {
         Aromaticity.cdkLegacy().apply(mol2);
 
         List<IAtomContainer> list = CDKMCS.getOverlaps(mol1, mol2, true);
-        Assert.assertEquals(1, list.size());
-        Assert.assertEquals(11, (list.get(0)).getAtomCount());
+        Assertions.assertEquals(1, list.size());
+        Assertions.assertEquals(11, (list.get(0)).getAtomCount());
 
         list = CDKMCS.getOverlaps(mol2, mol1, true);
-        Assert.assertEquals(1, list.size());
-        Assert.assertEquals(11, (list.get(0)).getAtomCount());
+        Assertions.assertEquals(1, list.size());
+        Assertions.assertEquals(11, (list.get(0)).getAtomCount());
     }
 
     /**
@@ -262,7 +262,7 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSFBug999330() throws Exception {
+    void testSFBug999330() throws Exception {
         String file1 = "org/openscience/cdk/smsd/algorithm/5SD.mol";
         String file2 = "org/openscience/cdk/smsd/algorithm/ADN.mol";
         IAtomContainer mol1 = new AtomContainer();
@@ -273,7 +273,7 @@ public class CDKMCSTest extends CDKTestCase {
         InputStream ins2 = this.getClass().getClassLoader().getResourceAsStream(file2);
         new MDLV2000Reader(ins2, Mode.STRICT).read(mol2);
         AtomContainerAtomPermutor permutor = new AtomContainerAtomPermutor(mol2);
-        mol2 = new AtomContainer((AtomContainer) permutor.next());
+        mol2 = new AtomContainer(permutor.next());
 
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(mol1);
         CDKHydrogenAdder adder = CDKHydrogenAdder.getInstance(mol1.getBuilder());
@@ -287,14 +287,13 @@ public class CDKMCSTest extends CDKTestCase {
 
         List<IAtomContainer> list1 = CDKMCS.getOverlaps(mol1, mol2, true);
         List<IAtomContainer> list2 = CDKMCS.getOverlaps(mol2, mol1, true);
-        Assert.assertEquals(1, list1.size());
-        Assert.assertEquals(1, list2.size());
-        Assert.assertEquals((list1.get(0)).getAtomCount(),
-                (list2.get(0)).getAtomCount());
+        Assertions.assertEquals(1, list1.size());
+        Assertions.assertEquals(1, list2.size());
+        Assertions.assertEquals((list1.get(0)).getAtomCount(), (list2.get(0)).getAtomCount());
     }
 
     @Test
-    public void testItself() throws Exception {
+    void testItself() throws Exception {
         String smiles = "C1CCCCCCC1CC";
         QueryAtomContainer query = QueryAtomContainerCreator.createAnyAtomContainer(new SmilesParser(
                 DefaultChemObjectBuilder.getInstance()).parseSmiles(smiles), true);
@@ -310,29 +309,29 @@ public class CDKMCSTest extends CDKTestCase {
             System.out.println("QueryAtomContainer matched: " + matched);
         }
         if (!standAlone) {
-            Assert.assertTrue(matched);
+            Assertions.assertTrue(matched);
         }
     }
 
     @Test
-    public void testIsIsomorph_IAtomContainer_IAtomContainer() throws Exception {
+    void testIsIsomorph_IAtomContainer_IAtomContainer() throws Exception {
         AtomContainer ac1 = new AtomContainer();
         ac1.addAtom(new Atom("C"));
         AtomContainer ac2 = new AtomContainer();
         ac2.addAtom(new Atom("C"));
-        Assert.assertTrue(CDKMCS.isIsomorph(ac1, ac2, true));
-        Assert.assertTrue(CDKMCS.isSubgraph(ac1, ac2, true));
+        Assertions.assertTrue(CDKMCS.isIsomorph(ac1, ac2, true));
+        Assertions.assertTrue(CDKMCS.isSubgraph(ac1, ac2, true));
     }
 
     @Test
-    public void testAnyAtomAnyBondCase() throws Exception {
+    void testAnyAtomAnyBondCase() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("O1C=CC=C1");
         IAtomContainer queryac = sp.parseSmiles("C1CCCC1");
         QueryAtomContainer query = QueryAtomContainerCreator.createAnyAtomAnyBondContainer(queryac, false);
 
-        Assert.assertTrue("C1CCCC1 should be a subgraph of O1C=CC=C1", CDKMCS.isSubgraph(target, query, true));
-        Assert.assertTrue("C1CCCC1 should be a isomorph of O1C=CC=C1", CDKMCS.isIsomorph(target, query, true));
+        Assertions.assertTrue(CDKMCS.isSubgraph(target, query, true), "C1CCCC1 should be a subgraph of O1C=CC=C1");
+        Assertions.assertTrue(CDKMCS.isIsomorph(target, query, true), "C1CCCC1 should be a isomorph of O1C=CC=C1");
     }
 
     /**
@@ -340,7 +339,7 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testFirstArgumentMustNotBeAnQueryAtomContainer() throws Exception {
+    void testFirstArgumentMustNotBeAnQueryAtomContainer() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("O1C=CC=C1");
         IAtomContainer queryac = sp.parseSmiles("C1CCCC1");
@@ -348,7 +347,7 @@ public class CDKMCSTest extends CDKTestCase {
 
         try {
             CDKMCS.isSubgraph(query, target, true);
-            Assert.fail("The UniversalIsomorphism should check when the first arguments is a QueryAtomContainer");
+            Assertions.fail("The UniversalIsomorphism should check when the first arguments is a QueryAtomContainer");
         } catch (Exception e) {
             // OK, it must Assert.fail!
         }
@@ -359,20 +358,20 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSingleAtomMatching1() throws Exception {
+    void testSingleAtomMatching1() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("[H]");
         IAtomContainer queryac = sp.parseSmiles("[H]");
         QueryAtomContainer query = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(queryac);
 
         List<List<CDKRMap>> matches = CDKMCS.getIsomorphMaps(target, query, true);
-        Assert.assertEquals(1, matches.size());
-        Assert.assertEquals(1, matches.get(0).size());
+        Assertions.assertEquals(1, matches.size());
+        Assertions.assertEquals(1, matches.get(0).size());
         CDKRMap mapping = matches.get(0).get(0);
-        Assert.assertEquals(0, mapping.getId1());
-        Assert.assertEquals(0, mapping.getId2());
+        Assertions.assertEquals(0, mapping.getId1());
+        Assertions.assertEquals(0, mapping.getId2());
         List<List<CDKRMap>> atomMappings = CDKMCS.makeAtomsMapsOfBondsMaps(matches, target, query);
-        Assert.assertEquals(matches, atomMappings);
+        Assertions.assertEquals(matches, atomMappings);
     }
 
     /**
@@ -380,45 +379,45 @@ public class CDKMCSTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSingleAtomMatching2() throws Exception {
+    void testSingleAtomMatching2() throws Exception {
         SmilesParser sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
         IAtomContainer target = sp.parseSmiles("CNC");
         IAtomContainer queryac = sp.parseSmiles("C");
         QueryAtomContainer query = QueryAtomContainerCreator.createSymbolAndBondOrderQueryContainer(queryac);
 
         List<List<CDKRMap>> matches = CDKMCS.getIsomorphMaps(target, query, true);
-        Assert.assertEquals(2, matches.size());
-        Assert.assertEquals(1, matches.get(0).size());
-        Assert.assertEquals(1, matches.get(1).size());
+        Assertions.assertEquals(2, matches.size());
+        Assertions.assertEquals(1, matches.get(0).size());
+        Assertions.assertEquals(1, matches.get(1).size());
         CDKRMap map1 = matches.get(0).get(0);
         CDKRMap map2 = matches.get(1).get(0);
 
-        Assert.assertEquals(0, map1.getId1());
-        Assert.assertEquals(0, map1.getId2());
+        Assertions.assertEquals(0, map1.getId1());
+        Assertions.assertEquals(0, map1.getId2());
 
-        Assert.assertEquals(2, map2.getId1());
-        Assert.assertEquals(0, map2.getId2());
+        Assertions.assertEquals(2, map2.getId1());
+        Assertions.assertEquals(0, map2.getId2());
 
         List<List<CDKRMap>> atomMappings = CDKMCS.makeAtomsMapsOfBondsMaps(matches, target, query);
-        Assert.assertEquals(matches, atomMappings);
+        Assertions.assertEquals(matches, atomMappings);
     }
 
     /**
      * Test of getTimeManager method, of class CDKMCS.
      */
     @Test
-    public void testGetTimeManager() {
+    void testGetTimeManager() {
         TimeManager expResult = new TimeManager();
-        Assert.assertNotNull(expResult);
+        Assertions.assertNotNull(expResult);
     }
 
     /**
      * Test of setTimeManager method, of class CDKMCS.
      */
     @Test
-    public void testSetTimeManager() {
+    void testSetTimeManager() {
         TimeManager aTimeManager = new TimeManager();
         CDKMCS.setTimeManager(aTimeManager);
-        Assert.assertNotNull(CDKMCS.getTimeManager().getElapsedTimeInSeconds());
+        Assertions.assertNotNull(CDKMCS.getTimeManager());
     }
 }
