@@ -21,14 +21,12 @@
  */
 package org.openscience.cdk.smsd.algorithm.single;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.exception.CDKException;
@@ -51,8 +49,8 @@ import org.openscience.cdk.smsd.tools.MolHandler;
  */
 public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
 
-    @BeforeClass
-    public static void setMCSAlgorithm() {
+    @BeforeAll
+    static void setMCSAlgorithm() {
         AbstractMCSAlgorithmTest.setMCSAlgorithm(new SingleMappingHandler(true));
     }
 
@@ -61,7 +59,7 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
      * @throws Exception
      */
     @Test
-    public void testSet_IAtomContainer_IAtomContainer() throws Exception {
+    void testSet_IAtomContainer_IAtomContainer() throws Exception {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -73,7 +71,7 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol1 = new MolHandler(source, true, true);
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
-        assertNotNull(instance.getFirstAtomMapping());
+        Assertions.assertNotNull(instance.getFirstAtomMapping());
     }
 
     /**
@@ -82,7 +80,7 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
      * @throws IOException
      */
     @Test
-    public void testSet_String_String() throws CDKException, IOException {
+    void testSet_String_String() throws CDKException, IOException {
         String molfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         String queryfile = "org/openscience/cdk/smsd/algorithm/decalin.mol";
         IAtomContainer query = new AtomContainer();
@@ -99,14 +97,14 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         smsd1.init(query, target, true, true);
         smsd1.setChemFilters(true, true, true);
         double score = 1.0;
-        assertEquals(score, smsd1.getTanimotoSimilarity(), 0.0001);
+        Assertions.assertEquals(score, smsd1.getTanimotoSimilarity(), 0.0001);
     }
 
     /**
      * Test of set method, of class SingleMappingHandler.
      */
     @Test
-    public void testSet_MolHandler_MolHandler() {
+    void testSet_MolHandler_MolHandler() {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -120,7 +118,7 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         SingleMappingHandler instance = new SingleMappingHandler(removeHydrogen);
         instance.set(source1, target1);
         instance.searchMCS(true);
-        assertNotNull(instance.getFirstAtomMapping());
+        Assertions.assertNotNull(instance.getFirstAtomMapping());
     }
 
     /**
@@ -141,15 +139,15 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
         instance.searchMCS(true);
-        assertNotNull(instance.getAllMapping());
-        assertEquals(1, instance.getAllMapping().size());
+        Assertions.assertNotNull(instance.getAllMapping());
+        Assertions.assertEquals(1, instance.getAllMapping().size());
     }
 
     /**
      * Test of getAllMapping method, of class SingleMappingHandler.
      */
     @Test
-    public void testGetAllMapping() {
+    void testGetAllMapping() {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -162,14 +160,14 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
         instance.searchMCS(true);
-        assertNotNull(instance.getAllMapping());
+        Assertions.assertNotNull(instance.getAllMapping());
     }
 
     /**
      * Test of getFirstMapping method, of class SingleMappingHandler.
      */
     @Test
-    public void testGetFirstMapping() {
+    void testGetFirstMapping() {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -182,14 +180,14 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
         instance.searchMCS(true);
-        assertNotNull(instance.getFirstMapping());
+        Assertions.assertNotNull(instance.getFirstMapping());
     }
 
     /**
      * Test of getAllAtomMapping method, of class SingleMappingHandler.
      */
     @Test
-    public void testGetAllAtomMapping() {
+    void testGetAllAtomMapping() {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -202,14 +200,14 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
         instance.searchMCS(true);
-        assertNotNull(instance.getAllAtomMapping());
+        Assertions.assertNotNull(instance.getAllAtomMapping());
     }
 
     /**
      * Test of getFirstAtomMapping method, of class SingleMappingHandler.
      */
     @Test
-    public void testGetFirstAtomMapping() {
+    void testGetFirstAtomMapping() {
         IAtom atomSource = new Atom("R");
         IAtom atomTarget = new Atom("R");
         IAtomContainer source = new AtomContainer();
@@ -222,6 +220,6 @@ public class SingleMappingHandlerTest extends AbstractMCSAlgorithmTest {
         MolHandler mol2 = new MolHandler(target, true, true);
         instance.set(mol1, mol2);
         instance.searchMCS(true);
-        assertNotNull(instance.getFirstAtomMapping());
+        Assertions.assertNotNull(instance.getFirstAtomMapping());
     }
 }
