@@ -19,8 +19,8 @@
 package org.openscience.cdk.tools.diff;
 
 import org.hamcrest.MatcherAssert;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IElectronContainer;
 import org.openscience.cdk.tools.diff.tree.IDifference;
 
@@ -31,38 +31,38 @@ import static org.mockito.Mockito.when;
 /**
  * @cdk.module test-diff
  */
-public class ElectronContainerDiffTest {
+class ElectronContainerDiffTest {
 
     @Test
-    public void testMatchAgainstItself() {
+    void testMatchAgainstItself() {
         IElectronContainer atom1 = mock(IElectronContainer.class);
         String result = ElectronContainerDiff.diff(atom1, atom1);
-        Assert.assertEquals("", result);
+        Assertions.assertEquals("", result);
     }
 
     @Test
-    public void testDiff() {
+    void testDiff() {
         IElectronContainer ec1 = mock(IElectronContainer.class);
         IElectronContainer ec2 = mock(IElectronContainer.class);
         when(ec1.getElectronCount()).thenReturn(2);
         when(ec2.getElectronCount()).thenReturn(3);
 
         String result = ElectronContainerDiff.diff(ec1, ec2);
-        Assert.assertNotNull(result);
-        Assert.assertNotSame(0, result.length());
+        Assertions.assertNotNull(result);
+        Assertions.assertNotSame(0, result.length());
         MatcherAssert.assertThat(result, containsString("ElectronContainerDiff"));
         MatcherAssert.assertThat(result, containsString("eCount"));
         MatcherAssert.assertThat(result, containsString("2/3"));
     }
 
     @Test
-    public void testDifference() {
+    void testDifference() {
         IElectronContainer ec1 = mock(IElectronContainer.class);
         IElectronContainer ec2 = mock(IElectronContainer.class);
         when(ec1.getElectronCount()).thenReturn(2);
         when(ec2.getElectronCount()).thenReturn(3);
 
         IDifference difference = ElectronContainerDiff.difference(ec1, ec2);
-        Assert.assertNotNull(difference);
+        Assertions.assertNotNull(difference);
     }
 }
