@@ -41,7 +41,6 @@ import org.openscience.cdk.interfaces.IAtomContainerSet;
 import org.openscience.cdk.interfaces.IChemFile;
 import org.openscience.cdk.interfaces.IChemModel;
 import org.openscience.cdk.interfaces.IChemObject;
-import org.openscience.cdk.interfaces.IChemSequence;
 import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.io.formats.IResourceFormat;
 import org.openscience.cdk.io.formats.SDFFormat;
@@ -186,11 +185,11 @@ public class SDFWriter extends DefaultChemObjectWriter {
     @Override
     public boolean accepts(Class<? extends IChemObject> classObject) {
         Class<?>[] interfaces = classObject.getInterfaces();
-        for (int i = 0; i < interfaces.length; i++) {
-            if (IAtomContainer.class.equals(interfaces[i])) return true;
-            if (IChemFile.class.equals(interfaces[i])) return true;
-            if (IChemModel.class.equals(interfaces[i])) return true;
-            if (IAtomContainerSet.class.equals(interfaces[i])) return true;
+        for (Class<?> anInterface : interfaces) {
+            if (IAtomContainer.class.equals(anInterface)) return true;
+            if (IChemFile.class.equals(anInterface)) return true;
+            if (IChemModel.class.equals(anInterface)) return true;
+            if (IAtomContainerSet.class.equals(anInterface)) return true;
         }
         if (IAtomContainer.class.equals(classObject)) return true;
         if (IChemFile.class.equals(classObject)) return true;
@@ -276,7 +275,6 @@ public class SDFWriter extends DefaultChemObjectWriter {
             mdlWriter.addSettings(getSettings());
             mdlWriter.write(container);
             mdlWriter.close();
-            writer.write(stringWriter.toString());
 
             // write non-structural data (mol properties in our case)
             if (paramWriteData.isSet()) {
@@ -294,24 +292,22 @@ public class SDFWriter extends DefaultChemObjectWriter {
                                 Object val = sdFields.get(propKey);
 
                                 if (isPrimitiveDataValue(val)) {
-                                    writer.write("> <" + cleanHeaderKey + ">");
-                                    writer.write('\n');
+                                    stringWriter.append("> <" + cleanHeaderKey + ">\n");
                                     if (val != null) {
                                       String valStr = val.toString();
                                       int maxDataLen = 200; // set in the spec
                                       if (truncateData.isSet()) {
                                         for (String line : valStr.split("\n")) {
                                           if (line.length() > maxDataLen)
-                                            writer.write(line.substring(0, maxDataLen));
+                                            stringWriter.append(line.substring(0, maxDataLen));
                                           else
-                                            writer.write(valStr);
+                                            stringWriter.append(valStr);
                                         }
                                       } else {
-                                        writer.write(valStr);
+                                        stringWriter.append(valStr);
                                       }
                                     }
-                                    writer.write('\n');
-                                    writer.write('\n');
+                                    stringWriter.append("\n\n");
                                 } else {
 
                                     logger.info("Skipped property " + propKey + " because only primitive and string properties can be written by SDFWriter");
@@ -321,7 +317,8 @@ public class SDFWriter extends DefaultChemObjectWriter {
                     }
                 }
             }
-            writer.write("$$$$\n");
+            stringWriter.append("$$$$\n");
+            writer.write(stringWriter.toString());
         } catch (IOException exception) {
             throw new CDKException("Error while writing a SD file entry: " + exception.getMessage(), exception);
         }
@@ -382,7 +379,7 @@ public class SDFWriter extends DefaultChemObjectWriter {
      * A list of properties used by CDK algorithms which must never be
      * serialized into the SD file format.
      */
-    private static List<String> cdkInternalProperties = new ArrayList<String>();
+    private static final List<String> cdkInternalProperties = new ArrayList<>();
 
     static {
         cdkInternalProperties.add(InvPair.CANONICAL_LABEL);
@@ -408,8 +405,12 @@ public class SDFWriter extends DefaultChemObjectWriter {
         truncateData = addSetting(new BooleanIOSetting(OptTruncateLongData,
                                                        IOSetting.Importance.LOW,
                                                        "Truncate long data files >200 characters", "false"));
-        addSettings(new MDLV2000Writer().getSettings());
-        addSettings(new MDLV3000Writer().getSettings());
+        try (MDLV2000Writer mdlv2 = new MDLV2000Writer();
+             MDLV3000Writer mdlv3 = new MDLV3000Writer()) {
+            addSettings(mdlv2.getSettings());
+            addSettings(mdlv3.getSettings());
+        } catch (IOException ignored) {
+        }
     }
 
     public void setAlwaysV3000(boolean val) {
@@ -427,4 +428,8 @@ public class SDFWriter extends DefaultChemObjectWriter {
         }
     }
 
+    public void flush() throws IOException {
+	        writer.flush();
+    }
+
 }
