@@ -23,9 +23,9 @@
 package org.openscience.cdk.io;
 
 import org.hamcrest.MatcherAssert;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.Mapping;
 import org.openscience.cdk.Reaction;
@@ -53,24 +53,24 @@ import static org.hamcrest.Matchers.containsString;
  *
  * @see org.openscience.cdk.io.MDLRXNWriter
  */
-public class MDLRXNWriterTest extends ChemObjectIOTest {
+class MDLRXNWriterTest extends ChemObjectIOTest {
 
     private static IChemObjectBuilder builder;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         builder = DefaultChemObjectBuilder.getInstance();
         setChemObjectIO(new MDLRXNWriter());
     }
 
     @Test
-    public void testAccepts() throws Exception {
+    void testAccepts() throws Exception {
         MDLRXNWriter reader = new MDLRXNWriter();
-        Assert.assertTrue(reader.accepts(Reaction.class));
+        Assertions.assertTrue(reader.accepts(Reaction.class));
     }
 
     @Test
-    public void testRoundtrip() throws Exception {
+    void testRoundtrip() throws Exception {
         IReaction reaction = builder.newInstance(IReaction.class);
         IAtomContainer hydroxide = builder.newInstance(IAtomContainer.class);
         hydroxide.addAtom(builder.newInstance(IAtom.class, "O"));
@@ -85,27 +85,27 @@ public class MDLRXNWriterTest extends ChemObjectIOTest {
 
         // now serialize to MDL RXN
         StringWriter writer = new StringWriter(10000);
-        String file = "";
+        String file;
         MDLRXNWriter mdlWriter = new MDLRXNWriter(writer);
         mdlWriter.write(reaction);
         mdlWriter.close();
         file = writer.toString();
 
-        Assert.assertTrue(file.length() > 0);
+        Assertions.assertTrue(file.length() > 0);
 
         // now deserialize the MDL RXN output
         IReaction reaction2 = builder.newInstance(IReaction.class);
         MDLRXNReader reader = new MDLRXNReader(new StringReader(file));
-        reaction2 = (IReaction) reader.read(reaction2);
+        reaction2 = reader.read(reaction2);
         reader.close();
 
-        Assert.assertEquals(2, reaction2.getReactantCount());
-        Assert.assertEquals(1, reaction2.getProductCount());
-        Assert.assertEquals(1, reaction2.getMappingCount());
+        Assertions.assertEquals(2, reaction2.getReactantCount());
+        Assertions.assertEquals(1, reaction2.getProductCount());
+        Assertions.assertEquals(1, reaction2.getMappingCount());
     }
 
     @Test
-    public void testReactionSet_1() throws Exception {
+    void testReactionSet_1() throws Exception {
         IReaction reaction11 = builder.newInstance(IReaction.class);
         IAtomContainer hydroxide = builder.newInstance(IAtomContainer.class);
         hydroxide.addAtom(builder.newInstance(IAtom.class, "O"));
@@ -123,29 +123,29 @@ public class MDLRXNWriterTest extends ChemObjectIOTest {
 
         // now serialize to MDL RXN
         StringWriter writer = new StringWriter(10000);
-        String file = "";
+        String file;
         MDLRXNWriter mdlWriter = new MDLRXNWriter(writer);
         mdlWriter.write(reactionSet);
         mdlWriter.close();
         file = writer.toString();
 
-        Assert.assertTrue(file.length() > 0);
+        Assertions.assertTrue(file.length() > 0);
 
         // now deserialize the MDL RXN output
         IReaction reaction2 = builder.newInstance(IReaction.class);
         MDLRXNReader reader = new MDLRXNReader(new StringReader(file));
-        reaction2 = (IReaction) reader.read(reaction2);
+        reaction2 = reader.read(reaction2);
         reader.close();
 
-        Assert.assertEquals(2, reaction2.getReactantCount());
-        Assert.assertEquals(1, reaction2.getReactants().getAtomContainer(0).getAtomCount());
-        Assert.assertEquals(1, reaction2.getReactants().getAtomContainer(1).getAtomCount());
-        Assert.assertEquals(1, reaction2.getProductCount());
-        Assert.assertEquals(1, reaction2.getProducts().getAtomContainer(0).getAtomCount());
+        Assertions.assertEquals(2, reaction2.getReactantCount());
+        Assertions.assertEquals(1, reaction2.getReactants().getAtomContainer(0).getAtomCount());
+        Assertions.assertEquals(1, reaction2.getReactants().getAtomContainer(1).getAtomCount());
+        Assertions.assertEquals(1, reaction2.getProductCount());
+        Assertions.assertEquals(1, reaction2.getProducts().getAtomContainer(0).getAtomCount());
     }
 
     @Test
-    public void testReactionSet_2() throws Exception {
+    void testReactionSet_2() throws Exception {
         IReaction reaction11 = builder.newInstance(IReaction.class);
         IAtomContainer hydroxide = builder.newInstance(IAtomContainer.class);
         hydroxide.addAtom(builder.newInstance(IAtom.class, "O"));
@@ -177,28 +177,29 @@ public class MDLRXNWriterTest extends ChemObjectIOTest {
 
         // now serialize to MDL RXN
         StringWriter writer = new StringWriter(10000);
-        String file = "";
+        String file;
         MDLRXNWriter mdlWriter = new MDLRXNWriter(writer);
         mdlWriter.write(reactionSet);
         mdlWriter.close();
         file = writer.toString();
 
-        Assert.assertTrue(file.length() > 0);
+        Assertions.assertTrue(file.length() > 0);
 
         // now deserialize the MDL RXN output
         IReactionSet reactionSetF = builder.newInstance(IReactionSet.class);
         MDLRXNReader reader = new MDLRXNReader(new StringReader(file));
-        reactionSetF = (IReactionSet) reader.read(reactionSetF);
+        reactionSetF = reader.read(reactionSetF);
         reader.close();
 
-        Assert.assertEquals(2, reactionSetF.getReactionCount());
-        Assert.assertEquals(1, reactionSetF.getReaction(0).getReactants().getAtomContainer(0).getAtomCount());
-        Assert.assertEquals(1, reactionSetF.getReaction(0).getReactants().getAtomContainer(1).getAtomCount());
-        Assert.assertEquals(1, reactionSetF.getReaction(0).getProductCount());
-        Assert.assertEquals(1, reactionSetF.getReaction(0).getProducts().getAtomContainer(0).getAtomCount());
+        Assertions.assertEquals(2, reactionSetF.getReactionCount());
+        Assertions.assertEquals(1, reactionSetF.getReaction(0).getReactants().getAtomContainer(0).getAtomCount());
+        Assertions.assertEquals(1, reactionSetF.getReaction(0).getReactants().getAtomContainer(1).getAtomCount());
+        Assertions.assertEquals(1, reactionSetF.getReaction(0).getProductCount());
+        Assertions.assertEquals(1, reactionSetF.getReaction(0).getProducts().getAtomContainer(0).getAtomCount());
     }
 
-    @Test public void writeAgentsFromV3000() throws IOException, CDKException {
+    @Test
+    void writeAgentsFromV3000() throws IOException, CDKException {
         String rxnfile = "$RXN V3000\n" +
                 "\n" +
                 "  Mrv1810      020601212219\n" +
@@ -341,7 +342,8 @@ public class MDLRXNWriterTest extends ChemObjectIOTest {
                 "M  END"));
     }
 
-    @Test public void writeAgentsFromV2000() throws IOException, CDKException {
+    @Test
+    void writeAgentsFromV2000() throws IOException, CDKException {
         String rxnfile = "$RXN\n" +
                 "\n" +
                 "\n" +
