@@ -24,9 +24,9 @@
 package org.openscience.cdk.io;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.*;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
@@ -64,7 +64,6 @@ import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.openscience.cdk.CDKConstants.ISAROMATIC;
 
 /**
@@ -73,22 +72,22 @@ import static org.openscience.cdk.CDKConstants.ISAROMATIC;
  * @cdk.module test-io
  * @see org.openscience.cdk.io.MDLV2000Writer
  */
-public class MDLV2000WriterTest extends ChemObjectIOTest {
+class MDLV2000WriterTest extends ChemObjectIOTest {
 
     private static IChemObjectBuilder builder;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         builder = DefaultChemObjectBuilder.getInstance();
         setChemObjectIO(new MDLV2000Writer());
     }
 
     @Test
-    public void testAccepts() throws Exception {
+    void testAccepts() throws Exception {
         MDLV2000Writer reader = new MDLV2000Writer();
-        Assert.assertTrue(reader.accepts(ChemFile.class));
-        Assert.assertTrue(reader.accepts(ChemModel.class));
-        Assert.assertTrue(reader.accepts(AtomContainer.class));
+        Assertions.assertTrue(reader.accepts(ChemFile.class));
+        Assertions.assertTrue(reader.accepts(ChemModel.class));
+        Assertions.assertTrue(reader.accepts(AtomContainer.class));
     }
 
     /**
@@ -96,7 +95,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * @cdk.bug 1524466
      */
     @Test
-    public void testBug890456() throws Exception {
+    void testBug890456() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = new AtomContainer();
         molecule.addAtom(new PseudoAtom("*"));
@@ -106,14 +105,14 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         MDLV2000Writer mdlWriter = new MDLV2000Writer(writer);
         mdlWriter.write(molecule);
         mdlWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("M  END") != -1);
+        Assertions.assertTrue(writer.toString().contains("M  END"));
     }
 
     /**
      * @cdk.bug 1212219
      */
     @Test
-    public void testBug1212219() throws Exception {
+    void testBug1212219() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = new AtomContainer();
         Atom           atom     = new Atom("C");
@@ -125,11 +124,11 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.close();
         String output = writer.toString();
         //logger.debug("MDL output for testBug1212219: " + output);
-        Assert.assertTrue(output.indexOf("M  ISO  1   1  14") != -1);
+        Assertions.assertTrue(output.contains("M  ISO  1   1  14"));
     }
 
     @Test
-    public void testWriteValence() throws Exception {
+    void testWriteValence() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = TestMoleculeFactory.makeAlphaPinene();
         molecule.getAtom(0).setValency(1);
@@ -141,12 +140,12 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(molecule);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.indexOf("0  0  0  0  0  1  0  0  0  0  0  0") != -1);
-        Assert.assertTrue(output.indexOf("0  0  0  0  0 15  0  0  0  0  0  0") != -1);
+        Assertions.assertTrue(output.contains("0  0  0  0  0  1  0  0  0  0  0  0"));
+        Assertions.assertTrue(output.contains("0  0  0  0  0 15  0  0  0  0  0  0"));
     }
 
     @Test
-    public void nonDefaultValence_fe_iii() throws Exception {
+    void nonDefaultValence_fe_iii() throws Exception {
         IAtomContainer container = new AtomContainer();
         IAtom          fe1       = new Atom("Fe");
         fe1.setImplicitHydrogenCount(3);
@@ -156,11 +155,11 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(container);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.contains("Fe  0  0  0  0  0  3  0  0  0  0  0  0"));
+        Assertions.assertTrue(output.contains("Fe  0  0  0  0  0  3  0  0  0  0  0  0"));
     }
 
     @Test
-    public void testWriteAtomAtomMapping() throws Exception {
+    void testWriteAtomAtomMapping() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = TestMoleculeFactory.makeAlphaPinene();
         molecule.getAtom(0).setProperty(CDKConstants.ATOM_ATOM_MAPPING, 1);
@@ -169,15 +168,15 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(molecule);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.indexOf("0  0  0  0  0  0  0  0  0  1  0  0") != -1);
-        Assert.assertTrue(output.indexOf("0  0  0  0  0  0  0  0  0 15  0  0") != -1);
+        Assertions.assertTrue(output.contains("0  0  0  0  0  0  0  0  0  1  0  0"));
+        Assertions.assertTrue(output.contains("0  0  0  0  0  0  0  0  0 15  0  0"));
     }
 
     /**
      * Tests if String atom atom mappings are parsed correctly
      */
     @Test
-    public void testWriteStringAtomAtomMapping() throws Exception {
+    void testWriteStringAtomAtomMapping() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = TestMoleculeFactory.makeAlphaPinene();
         molecule.getAtom(0).setProperty(CDKConstants.ATOM_ATOM_MAPPING, "1");
@@ -186,15 +185,15 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(molecule);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.contains("0  0  0  0  0  0  0  0  0  1  0  0"));
-        Assert.assertTrue(output.contains("0  0  0  0  0  0  0  0  0 15  0  0"));
+        Assertions.assertTrue(output.contains("0  0  0  0  0  0  0  0  0  1  0  0"));
+        Assertions.assertTrue(output.contains("0  0  0  0  0  0  0  0  0 15  0  0"));
     }
 
     /**
      * Tests if non-valid atom atom mappings are ignored by the reader.
      */
     @Test
-    public void testWriteInvalidAtomAtomMapping() throws Exception {
+    void testWriteInvalidAtomAtomMapping() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = TestMoleculeFactory.makeAlphaPinene();
         molecule.getAtom(0).setProperty(CDKConstants.ATOM_ATOM_MAPPING, "1a");
@@ -207,7 +206,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
                                     + "0  0.*    0.0000    0.0000    0.0000 C   0  0  0  0  0  0  0  0  0 15  0  0.*", Pattern.MULTILINE
                                                                                                                        | Pattern.DOTALL);
         Matcher m = p.matcher(output);
-        Assert.assertTrue(m.matches());
+        Assertions.assertTrue(m.matches());
     }
 
     /**
@@ -222,7 +221,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * @cdk.bug 1778479
      */
     @Test
-    public void testBug1778479() throws Exception {
+    void testBug1778479() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
         IAtom          atom1    = builder.newInstance(IPseudoAtom.class);
@@ -236,12 +235,11 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(molecule);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertEquals("Test for zero length pseudo atom label in MDL file", -1,
-                            output.indexOf("0.0000    0.0000    0.0000     0  0  0  0  0  0  0  0  0  0  0  0"));
+        Assertions.assertEquals(-1, output.indexOf("0.0000    0.0000    0.0000     0  0  0  0  0  0  0  0  0  0  0  0"), "Test for zero length pseudo atom label in MDL file");
     }
 
     @Test
-    public void testNullFormalCharge() throws Exception {
+    void testNullFormalCharge() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
         IAtom          atom     = builder.newInstance(IAtom.class, "C");
@@ -255,12 +253,12 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         // test ensures that the writer does not throw an exception on
         // null formal charges, so a mere assert on output being non-zero
         // length is enough
-        Assert.assertNotNull(output);
-        Assert.assertNotSame(0, output.length());
+        Assertions.assertNotNull(output);
+        Assertions.assertNotSame(0, output.length());
     }
 
     @Test
-    public void testPrefer3DCoordinateOutput() throws Exception {
+    void testPrefer3DCoordinateOutput() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
         IAtom          atom     = builder.newInstance(IAtom.class, "C");
@@ -274,13 +272,13 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         String output = writer.toString();
         // the current behavior is that if both 2D and 3D coordinates
         // are available, the 3D is outputted, and the 2D not
-        Assert.assertTrue(output.contains("3.0"));
-        Assert.assertTrue(output.contains("4.0"));
-        Assert.assertTrue(output.contains("5.0"));
+        Assertions.assertTrue(output.contains("3.0"));
+        Assertions.assertTrue(output.contains("4.0"));
+        Assertions.assertTrue(output.contains("5.0"));
     }
 
     @Test
-    public void testForce2DCoordinates() throws Exception {
+    void testForce2DCoordinates() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
         IAtom          atom     = builder.newInstance(IAtom.class, "C");
@@ -299,12 +297,12 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         String output = writer.toString();
         // the current behavior is that if both 2D and 3D coordinates
         // are available, the 3D is outputted, and the 2D not
-        Assert.assertTrue(output.contains("1.0"));
-        Assert.assertTrue(output.contains("2.0"));
+        Assertions.assertTrue(output.contains("1.0"));
+        Assertions.assertTrue(output.contains("2.0"));
     }
 
     @Test
-    public void testUndefinedStereo() throws Exception {
+    void testUndefinedStereo() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         mol.getBond(0).setStereo(IBond.Stereo.UP_OR_DOWN);
         mol.getBond(1).setStereo(IBond.Stereo.E_OR_Z);
@@ -313,23 +311,26 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(mol);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.indexOf("1  2  2  4  0  0  0") > -1);
-        Assert.assertTrue(output.indexOf("2  3  1  3  0  0  0") > -1);
+        Assertions.assertTrue(output.contains("1  2  2  4  0  0  0"));
+        Assertions.assertTrue(output.contains("2  3  1  3  0  0  0"));
     }
 
-    @Test(expected = CDKException.class)
-    public void testUnsupportedBondOrder() throws Exception {
+    @Test
+    void testUnsupportedBondOrder() throws Exception {
         IAtomContainer molecule = new AtomContainer();
         molecule.addAtom(new Atom("C"));
         molecule.addAtom(new Atom("C"));
         molecule.addBond(new Bond(molecule.getAtom(0), molecule.getAtom(1), Order.QUADRUPLE));
         MDLV2000Writer mdlWriter = new MDLV2000Writer(new StringWriter());
-        mdlWriter.write(molecule);
+        Assertions.assertThrows(CDKException.class,
+                                () -> {
+                                    mdlWriter.write(molecule);
+                                });
         mdlWriter.close();
     }
 
     @Test
-    public void testTwoFragmentsWithTitle() throws Exception {
+    void testTwoFragmentsWithTitle() throws Exception {
         IAtomContainer mol1 = TestMoleculeFactory.makeAlphaPinene();
         mol1.setTitle("title1");
         IAtomContainer mol2 = TestMoleculeFactory.makeAlphaPinene();
@@ -343,14 +344,14 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(model);
         mdlWriter.close();
         String output = writer.toString();
-        Assert.assertTrue(output.contains("title1; title2"));
+        Assertions.assertTrue(output.contains("title1; title2"));
     }
 
     /**
      * Test correct output of R-groups, using the hash (#) and a separate RGP line.
      */
     @Test
-    public void testRGPLine() throws Exception {
+    void testRGPLine() throws Exception {
         StringWriter   writer   = new StringWriter();
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
         IPseudoAtom    atom1    = builder.newInstance(IPseudoAtom.class);
@@ -376,15 +377,15 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.close();
         String output = writer.toString();
 
-        Assert.assertTrue("Test for R#", -1 != output.indexOf("R#"));
-        Assert.assertTrue("Test for RGP line", -1 != output.indexOf("M  RGP  1   1  12"));
+        Assertions.assertTrue(output.contains("R#"), "Test for R#");
+        Assertions.assertTrue(output.contains("M  RGP  1   1  12"), "Test for RGP line");
     }
 
     /**
      * Test writing of comments made on individual atoms into an Atom Value lines.
      */
     @Test
-    public void testAtomValueLine() throws Exception {
+    void testAtomValueLine() throws Exception {
         IAtom carbon = builder.newInstance(IAtom.class, "C");
         carbon.setProperty(CDKConstants.COMMENT, "Carbon comment");
         IAtom oxygen = builder.newInstance(IAtom.class, "O");
@@ -401,8 +402,8 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.write(molecule);
         mdlWriter.close();
 
-        Assert.assertTrue(writer.toString().indexOf("V    1 Oxygen comment") != -1);
-        Assert.assertTrue(writer.toString().indexOf("V    2 Carbon comment") != -1);
+        Assertions.assertTrue(writer.toString().contains("V    1 Oxygen comment"));
+        Assertions.assertTrue(writer.toString().contains("V    2 Carbon comment"));
 
     }
 
@@ -413,7 +414,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * @throws Exception
      */
     @Test
-    public void testAromaticBondType4() throws Exception {
+    void testAromaticBondType4() throws Exception {
 
         IAtomContainer benzene = TestMoleculeFactory.makeBenzene();
         for (IAtom atom : benzene.atoms()) {
@@ -427,7 +428,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         MDLV2000Writer mdlWriter = new MDLV2000Writer(writer);
         mdlWriter.write(benzene);
         mdlWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("1  2  1  0  0  0  0") != -1);
+        Assertions.assertTrue(writer.toString().contains("1  2  1  0  0  0  0"));
 
         writer = new StringWriter();
         mdlWriter = new MDLV2000Writer(writer);
@@ -438,11 +439,11 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mdlWriter.customizeJob();
         mdlWriter.write(benzene);
         mdlWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("1  2  4  0  0  0  0") != -1);
+        Assertions.assertTrue(writer.toString().contains("1  2  4  0  0  0  0"));
     }
 
     @Test
-    public void testAtomParity() throws CDKException, IOException {
+    void testAtomParity() throws CDKException, IOException {
 
         InputStream    in       = getClass().getResourceAsStream("mol_testAtomParity.mol");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
@@ -455,13 +456,13 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         writer.write(molecule);
         writer.close();
 
-        Assert.assertTrue(sw.toString().contains(
+        Assertions.assertTrue(sw.toString().contains(
             "   -1.1749    0.1436    0.0000 C   0  0  1  0  0  0  0  0  0  0  0  0"));
 
     }
 
     @Test
-    public void testWritePseudoAtoms() throws Exception {
+    void testWritePseudoAtoms() throws Exception {
         InputStream    in       = getClass().getResourceAsStream("pseudoatoms.sdf");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
         IAtomContainer molecule = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
@@ -474,8 +475,8 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         mwriter.close();
 
         String output = writer.toString();
-        Assert.assertTrue(output.indexOf("Gln") != -1);
-        Assert.assertTrue(output.indexOf("Leu") != -1);
+        Assertions.assertTrue(output.contains("Gln"));
+        Assertions.assertTrue(output.contains("Leu"));
     }
 
     /**
@@ -483,7 +484,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * @cdk.bug 1263
      */
     @Test
-    public void testWritePseudoAtoms_LongLabel() throws Exception {
+    void testWritePseudoAtoms_LongLabel() throws Exception {
 
         IChemObjectBuilder builder   = DefaultChemObjectBuilder.getInstance();
         IAtomContainer     container = builder.newInstance(IAtomContainer.class);
@@ -501,8 +502,8 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
 
         String output = sw.toString();
 
-        Assert.assertTrue(output.contains("A    2"));
-        Assert.assertTrue(output.contains("tRNA"));
+        Assertions.assertTrue(output.contains("A    2"));
+        Assertions.assertTrue(output.contains("tRNA"));
 
     }
 
@@ -510,7 +511,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * Checks that null atom labels are handled correctly.
      */
     @Test
-    public void testWritePseudoAtoms_nullLabel() throws Exception {
+    void testWritePseudoAtoms_nullLabel() throws Exception {
 
         IChemObjectBuilder builder   = DefaultChemObjectBuilder.getInstance();
         IAtomContainer     container = builder.newInstance(IAtomContainer.class);
@@ -528,7 +529,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         writer.close();
 
         String output = sw.toString();
-        Assert.assertTrue(output.contains("R"));
+        Assertions.assertTrue(output.contains("R"));
 
     }
 
@@ -538,7 +539,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
      * @throws Exception
      */
     @Test
-    public void testRGPLine_Multiline() throws Exception {
+    void testRGPLine_Multiline() throws Exception {
 
         IChemObjectBuilder builder   = DefaultChemObjectBuilder.getInstance();
         IAtomContainer     container = builder.newInstance(IAtomContainer.class);
@@ -552,14 +553,14 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         writer.close();
 
         String output = sw.toString();
-        Assert.assertTrue(output.contains("M  RGP  8   1   1   2   2   3   3   4   4   5   5   6   6   7   7   8   8"));
-        Assert.assertTrue(output.contains("M  RGP  8   9   9  10  10  11  11  12  12  13  13  14  14  15  15  16  16"));
-        Assert.assertTrue(output.contains("M  RGP  3  17  17  18  18  19  19"));
+        Assertions.assertTrue(output.contains("M  RGP  8   1   1   2   2   3   3   4   4   5   5   6   6   7   7   8   8"));
+        Assertions.assertTrue(output.contains("M  RGP  8   9   9  10  10  11  11  12  12  13  13  14  14  15  15  16  16"));
+        Assertions.assertTrue(output.contains("M  RGP  3  17  17  18  18  19  19"));
 
     }
 
     @Test
-    public void testAlias_TruncatedLabel() throws Exception {
+    void testAlias_TruncatedLabel() throws Exception {
 
         IChemObjectBuilder builder   = DefaultChemObjectBuilder.getInstance();
         IAtomContainer     container = builder.newInstance(IAtomContainer.class);
@@ -575,14 +576,14 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
 
         String output = sw.toString();
 
-        Assert.assertTrue(output.contains("This is a very long label - almost too long. it should be cut here ->"));
+        Assertions.assertTrue(output.contains("This is a very long label - almost too long. it should be cut here ->"));
         // make sure the full label wasn't output
-        Assert.assertFalse(output.contains(label));
+        Assertions.assertFalse(output.contains(label));
 
     }
 
     @Test
-    public void testSingleSingletRadical() throws Exception {
+    void testSingleSingletRadical() throws Exception {
 
         InputStream    in       = getClass().getResourceAsStream("singleSingletRadical.mol");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
@@ -602,7 +603,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void testSingleDoubletRadical() throws Exception {
+    void testSingleDoubletRadical() throws Exception {
 
         InputStream    in       = getClass().getResourceAsStream("singleDoubletRadical.mol");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
@@ -623,7 +624,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void testSingleTripletRadical() throws Exception {
+    void testSingleTripletRadical() throws Exception {
 
         InputStream    in       = getClass().getResourceAsStream("singleTripletRadical.mol");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
@@ -643,7 +644,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void testMultipleRadicals() throws Exception {
+    void testMultipleRadicals() throws Exception {
 
         InputStream    in       = getClass().getResourceAsStream("multipleRadicals.mol");
         MDLV2000Reader reader   = new MDLV2000Reader(in);
@@ -666,7 +667,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void testSgroupAtomListWrapping() throws Exception {
+    void testSgroupAtomListWrapping() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeEthylPropylPhenantren();
 
         Sgroup sgroup = new Sgroup();
@@ -685,7 +686,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupRepeatUnitRoundTrip() throws Exception {
+    void sgroupRepeatUnitRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-sru.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -698,7 +699,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupBracketStylesRoundTrip() throws Exception {
+    void sgroupBracketStylesRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-sru-bracketstyles.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -710,7 +711,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupUnorderedMixtureRoundTrip() throws Exception {
+    void sgroupUnorderedMixtureRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-unord-mixture.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -722,7 +723,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupCopolymerRoundTrip() throws Exception {
+    void sgroupCopolymerRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-ran-copolymer.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -734,7 +735,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupExpandedAbbreviationRoundTrip() throws Exception {
+    void sgroupExpandedAbbreviationRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("triphenyl-phosphate-expanded.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -746,7 +747,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupParentAtomListRoundTrip() throws Exception {
+    void sgroupParentAtomListRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("ChEBI_81539.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -758,7 +759,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void sgroupOrderedMixtureRoundTrip() throws Exception {
+    void sgroupOrderedMixtureRoundTrip() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-ord-mixture.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -771,7 +772,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void roundtripAtomParityExpH() throws Exception {
+    void roundtripAtomParityExpH() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("tetrahedral-parity-withExpH.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -782,7 +783,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void roundtripAtomParityImplH() throws Exception {
+    void roundtripAtomParityImplH() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("tetrahedral-parity-withImplH.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -793,7 +794,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void roundtripAtomParityImplModified() throws Exception {
+    void roundtripAtomParityImplModified() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("tetrahedral-parity-withImplH.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -806,8 +807,8 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         }
     }
 
-    @Test(expected = CDKException.class)
-    public void aromaticBondTypes() throws Exception {
+    @Test
+    void aromaticBondTypes() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -815,13 +816,16 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         bond.setIsAromatic(true);
         mol.addBond(bond);
         StringWriter sw = new StringWriter();
-        try (MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
-            mdlw.write(mol);
-        }
+        Assertions.assertThrows(CDKException.class,
+                                () -> {
+                                    try (MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
+                                        mdlw.write(mol);
+                                    }
+                                });
     }
 
     @Test
-    public void aromaticBondTypesEnabled() throws Exception {
+    void aromaticBondTypesEnabled() throws Exception {
         IAtomContainer mol = builder.newInstance(IAtomContainer.class);
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
         mol.addAtom(builder.newInstance(IAtom.class, "C"));
@@ -837,7 +841,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeDimensionField() throws Exception {
+    void writeDimensionField() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -852,7 +856,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeDimensionField3D() throws Exception {
+    void writeDimensionField3D() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -867,7 +871,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeMoreThan8Radicals() throws Exception {
+    void writeMoreThan8Radicals() throws Exception {
         IAtomContainer mol = builder.newAtomContainer();
         for (int i = 0; i < 20; i++) {
             IAtom atom = builder.newAtom();
@@ -884,7 +888,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeCarbon12() throws Exception {
+    void writeCarbon12() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -899,7 +903,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void ignoreCarbon12() throws Exception {
+    void ignoreCarbon12() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -916,7 +920,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeCarbon13AtomProps() throws Exception {
+    void writeCarbon13AtomProps() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -931,7 +935,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeChargeAtomProps() throws Exception {
+    void writeChargeAtomProps() throws Exception {
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -946,7 +950,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void skipDefaultProps() throws Exception {
+    void skipDefaultProps() throws Exception {
         StringWriter sw = new StringWriter();
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("tetrahedral-parity-withImplH.mol"));
              MDLV2000Writer mdlw = new MDLV2000Writer(sw)) {
@@ -970,7 +974,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void writeParentAtomSgroupAsList() throws Exception{
+    void writeParentAtomSgroupAsList() throws Exception{
         IAtomContainer mol  = builder.newAtomContainer();
         IAtom          atom = builder.newAtom();
         atom.setSymbol("C");
@@ -995,7 +999,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void roundTripWithNotAtomList() throws Exception {
+    void roundTripWithNotAtomList() throws Exception {
         try (InputStream in = getClass().getResourceAsStream("query_notatomlist.mol");
              MDLV2000Reader mdlr = new MDLV2000Reader(in)) {
 
@@ -1012,7 +1016,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         }
     }
     @Test
-    public void roundTripWithAtomList() throws Exception {
+    void roundTripWithAtomList() throws Exception {
         try (InputStream in = getClass().getResourceAsStream("query_atomlist.mol");
              MDLV2000Reader mdlr = new MDLV2000Reader(in)) {
 
@@ -1030,7 +1034,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
         }
     }
     @Test
-    public void roundTripWithMultipleLegacyAtomLists() throws Exception {
+    void roundTripWithMultipleLegacyAtomLists() throws Exception {
         try (InputStream in = getClass().getResourceAsStream("query_manylegacyatomlist.mol");
              MDLV2000Reader mdlr = new MDLV2000Reader(in)) {
 
@@ -1053,7 +1057,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void dataSgroupRoundTrip() {
+    void dataSgroupRoundTrip() {
       String path = "hbr_acoh_mix.mol";
       try (InputStream in = getClass().getResourceAsStream(path)) {
         MDLV2000Reader     mdlr    = new MDLV2000Reader(in);
@@ -1069,12 +1073,12 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
                      CoreMatchers.containsString("M  SED   3 33%"));
         }
       } catch (IOException | CDKException e) {
-        Assert.fail(e.getMessage());
+        Assertions.fail(e.getMessage());
       }
     }
 
     @Test
-    public void testNoChiralFlag() throws Exception {
+    void testNoChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112282D          \n" +
                 "\n" +
@@ -1104,7 +1108,7 @@ public class MDLV2000WriterTest extends ChemObjectIOTest {
     }
 
     @Test
-    public void testChiralFlag() throws Exception {
+    void testChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112282D          \n" +
                 "\n" +
