@@ -24,14 +24,14 @@
 package org.openscience.cdk.io;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IBond;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
-import org.openscience.cdk.interfaces.IStereoElement;
 import org.openscience.cdk.interfaces.ITetrahedralChirality;
 import org.openscience.cdk.io.listener.PropertiesListener;
 import org.openscience.cdk.sgroup.Sgroup;
@@ -54,15 +54,13 @@ import java.util.List;
 import java.util.Properties;
 
 import static org.hamcrest.CoreMatchers.containsString;
-import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 
-public class MDLV3000WriterTest {
+class MDLV3000WriterTest {
 
     @Test
-    public void outputValencyWhenNeeded() throws IOException, CDKException {
+    void outputValencyWhenNeeded() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("Na"));
         mol.addAtom(new Atom("Na"));
@@ -74,7 +72,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void outputFormalCharge() throws IOException, CDKException {
+    void outputFormalCharge() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("O"));
         mol.addAtom(new Atom("C"));
@@ -88,7 +86,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void outputMassNumber() throws IOException, CDKException {
+    void outputMassNumber() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("H"));
         mol.addAtom(new Atom("C"));
@@ -103,7 +101,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void outputRadical() throws IOException, CDKException {
+    void outputRadical() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.getAtom(0).setImplicitHydrogenCount(3);
@@ -112,8 +110,8 @@ public class MDLV3000WriterTest {
         assertThat(res, CoreMatchers.containsString("M  V30 1 C 0 0 0 0 RAD=2 VAL=3\n"));
     }
 
-    @Test(expected = CDKException.class)
-    public void nullBondOrder() throws IOException, CDKException {
+    @Test
+    void nullBondOrder() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("H"));
         mol.addAtom(new Atom("C"));
@@ -121,11 +119,14 @@ public class MDLV3000WriterTest {
         mol.getAtom(0).setImplicitHydrogenCount(0);
         mol.getAtom(0).setMassNumber(2);
         mol.getAtom(1).setImplicitHydrogenCount(3);
-        writeToStr(mol);
+        Assertions.assertThrows(CDKException.class,
+                                () -> {
+                                    writeToStr(mol);
+                                });
     }
 
-    @Test(expected = CDKException.class)
-    public void unsetBondOrder() throws IOException, CDKException {
+    @Test
+    void unsetBondOrder() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("H"));
         mol.addAtom(new Atom("C"));
@@ -133,11 +134,14 @@ public class MDLV3000WriterTest {
         mol.getAtom(0).setImplicitHydrogenCount(0);
         mol.getAtom(0).setMassNumber(2);
         mol.getAtom(1).setImplicitHydrogenCount(3);
-        writeToStr(mol);
+        Assertions.assertThrows(CDKException.class,
+                                () -> {
+                                    writeToStr(mol);
+                                });
     }
 
     @Test
-    public void solidWedgeBonds() throws IOException, CDKException {
+    void solidWedgeBonds() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("O"));
@@ -149,7 +153,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void hashedWedgeBonds() throws IOException, CDKException {
+    void hashedWedgeBonds() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("O"));
@@ -161,7 +165,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void solidWedgeInvBonds() throws IOException, CDKException {
+    void solidWedgeInvBonds() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("O"));
@@ -173,7 +177,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void hashedWedgeInvBonds() throws IOException, CDKException {
+    void hashedWedgeInvBonds() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("O"));
@@ -185,7 +189,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeLeadingZero() throws IOException, CDKException {
+    void writeLeadingZero() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         Atom           atom   = new Atom("C");
         atom.setPoint2d(new Point2d(0.5, 1.2));
@@ -194,7 +198,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeParity() throws IOException, CDKException {
+    void writeParity() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("O"));
         mol.addAtom(new Atom("C"));
@@ -224,7 +228,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeParityHNotLast() throws IOException, CDKException {
+    void writeParityHNotLast() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("O"));
         mol.addAtom(new Atom("C"));
@@ -256,7 +260,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeParityImplH() throws IOException, CDKException {
+    void writeParityImplH() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("O"));
         mol.addAtom(new Atom("C"));
@@ -283,7 +287,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeParityImplHInverted() throws IOException, CDKException {
+    void writeParityImplHInverted() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("O"));
         mol.addAtom(new Atom("C"));
@@ -310,7 +314,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeSRUs() throws IOException, CDKException {
+    void writeSRUs() throws IOException, CDKException {
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
         mol.addAtom(new Atom("C"));
@@ -339,7 +343,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeMultipleGroup() throws IOException, CDKException {
+    void writeMultipleGroup() throws IOException, CDKException {
         final int repeatAtoms = 50;
         IAtomContainer mol = new AtomContainer();
         mol.addAtom(new Atom("C"));
@@ -372,7 +376,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void roundTripSRU() throws IOException, CDKException {
+    void roundTripSRU() throws IOException, CDKException {
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-sru-bracketstyles.mol"))) {
             IAtomContainer mol = mdlr.read(new AtomContainer(0, 0, 0, 0));
             String res = writeToStr(mol);
@@ -386,7 +390,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void roundTripExpandedAbbrv() throws IOException, CDKException {
+    void roundTripExpandedAbbrv() throws IOException, CDKException {
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("triphenyl-phosphate-expanded.mol"))) {
             IAtomContainer mol = mdlr.read(new AtomContainer(0, 0, 0, 0));
             String res = writeToStr(mol);
@@ -397,7 +401,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void roundTripOrderMixtures() throws IOException, CDKException {
+    void roundTripOrderMixtures() throws IOException, CDKException {
         try (MDLV2000Reader mdlr = new MDLV2000Reader(getClass().getResourceAsStream("sgroup-ord-mixture.mol"))) {
             IAtomContainer mol = mdlr.read(new AtomContainer(0, 0, 0, 0));
             String res = writeToStr(mol);
@@ -413,7 +417,8 @@ public class MDLV3000WriterTest {
         }
     }
 
-    @Test public void positionalVariationRoundTrip() throws Exception {
+    @Test
+    void positionalVariationRoundTrip() throws Exception {
         try (MDLV3000Reader mdlr = new MDLV3000Reader(getClass().getResourceAsStream("multicenterBond.mol"))) {
             IAtomContainer mol = mdlr.read(new AtomContainer(0, 0, 0, 0));
             String res = writeToStr(mol);
@@ -422,7 +427,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeDimensionField() throws Exception {
+    void writeDimensionField() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         IAtomContainer mol = builder.newAtomContainer();
         IAtom atom = builder.newAtom();
@@ -438,7 +443,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeDimensionField3D() throws Exception {
+    void writeDimensionField3D() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         IAtomContainer mol = builder.newAtomContainer();
         IAtom atom = builder.newAtom();
@@ -454,7 +459,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void writeCustomTitle() throws Exception {
+    void writeCustomTitle() throws Exception {
         IChemObjectBuilder builder = SilentChemObjectBuilder.getInstance();
         IAtomContainer mol = builder.newAtomContainer();
         IAtom atom = builder.newAtom();
@@ -482,7 +487,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void testNoChiralFlag() throws Exception {
+    void testNoChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112362D          \n" +
                 "\n" +
@@ -522,7 +527,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void testChiralFlag() throws Exception {
+    void testChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112362D          \n" +
                 "\n" +
@@ -562,7 +567,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void testStereoRac1() throws Exception {
+    void testStereoRac1() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052113162D          \n" +
                 "\n" +
@@ -605,7 +610,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void testStereoRel1() throws Exception {
+    void testStereoRel1() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052113162D          \n" +
                 "\n" +
@@ -647,7 +652,7 @@ public class MDLV3000WriterTest {
     }
 
     @Test
-    public void testStereoRac1And() throws Exception {
+    void testStereoRac1And() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02062121432D          \n" +
                 "\n" +
