@@ -24,14 +24,14 @@
  */
 package org.openscience.cdk.io;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.CDKConstants;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.PseudoAtom;
-import org.openscience.cdk.test.SlowTest;
+import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -57,22 +57,22 @@ import java.util.Map;
  * @cdk.module test-io
  * @author Mark Rijnbeek
  */
-public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
+class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
 
-    public RGroupQueryReaderTest() {}
+    RGroupQueryReaderTest() {}
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(RGroupQueryReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(RGroupQueryReaderTest.class);
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         setSimpleChemObjectReader(new RGroupQueryReader(), "rgfile.1.mol");
     }
 
     @Test
-    public void testAccepts() {
+    void testAccepts() {
         RGroupQueryReader reader = new RGroupQueryReader();
-        Assert.assertFalse(reader.accepts(AtomContainer.class));
-        Assert.assertTrue(reader.accepts(RGroupQuery.class));
+        Assertions.assertFalse(reader.accepts(AtomContainer.class));
+        Assertions.assertTrue(reader.accepts(RGroupQuery.class));
     }
 
     /**
@@ -82,11 +82,11 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * @throws Exception
      */
     @Test
-    public void testRGFileFormat() throws Exception {
+    void testRGFileFormat() throws Exception {
         String filename = "rgfile.1.mol";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         IChemFormat format = new FormatFactory().guessFormat(new BufferedInputStream(ins));
-        Assert.assertEquals(format.getClass(), RGroupQueryFormat.class);
+        Assertions.assertEquals(format.getClass(), RGroupQueryFormat.class);
     }
 
     /**
@@ -94,29 +94,29 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * Simple R-group query file.
      */
     @Test
-    public void testRgroupQueryFile1() throws Exception {
+    void testRgroupQueryFile1() throws Exception {
         String filename = "rgfile.1.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 7);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 7);
 
         for (IAtom at : rGroupQuery.getAllRgroupQueryAtoms()) {
             if (at instanceof PseudoAtom) {
-                Assert.assertEquals(((PseudoAtom) at).getLabel(), "R1");
+                Assertions.assertEquals(((PseudoAtom) at).getLabel(), "R1");
                 Map<IAtom, Map<Integer, IBond>> rootApo = rGroupQuery.getRootAttachmentPoints();
                 Map<Integer, IBond> apoBonds = rootApo.get(at);
-                Assert.assertEquals(apoBonds.size(), 1);
+                Assertions.assertEquals(apoBonds.size(), 1);
                 // Assert that the root attachment is the bond between R1 and P
                 for (IBond bond : rGroupQuery.getRootStructure().bonds()) {
                     if (bond.contains(at)) {
-                        Assert.assertEquals(bond, apoBonds.get(1));
+                        Assertions.assertEquals(bond, apoBonds.get(1));
                         for (IAtom atInApo : bond.atoms()) {
-                            Assert.assertTrue(atInApo.getSymbol().equals("R") || atInApo.getSymbol().equals("P"));
+                            Assertions.assertTrue(atInApo.getAtomicNumber() == IElement.Wildcard || atInApo.getAtomicNumber() == IElement.P);
                         }
                     }
                 }
@@ -125,36 +125,36 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
 
         Iterator<Integer> itr = rGroupQuery.getRGroupDefinitions().keySet().iterator();
         int val_1 = itr.next();
-        Assert.assertEquals(val_1, 1);
+        Assertions.assertEquals(val_1, 1);
         IRGroupList rList = rGroupQuery.getRGroupDefinitions().get(val_1);
-        Assert.assertEquals(rList.getOccurrence(), "0,1-3");
+        Assertions.assertEquals(rList.getOccurrence(), "0,1-3");
 
         List<IRGroup> rGroups = rList.getRGroups();
-        Assert.assertEquals(rGroups.get(0).getFirstAttachmentPoint().getSymbol(), "N");
-        Assert.assertEquals(rGroups.get(1).getFirstAttachmentPoint().getSymbol(), "O");
-        Assert.assertEquals(rGroups.get(2).getFirstAttachmentPoint().getSymbol(), "S");
+        Assertions.assertEquals(rGroups.get(0).getFirstAttachmentPoint().getSymbol(), "N");
+        Assertions.assertEquals(rGroups.get(1).getFirstAttachmentPoint().getSymbol(), "O");
+        Assertions.assertEquals(rGroups.get(2).getFirstAttachmentPoint().getSymbol(), "S");
 
-        Assert.assertNull(rGroups.get(0).getSecondAttachmentPoint());
-        Assert.assertNull(rGroups.get(1).getSecondAttachmentPoint());
-        Assert.assertNull(rGroups.get(2).getSecondAttachmentPoint());
+        Assertions.assertNull(rGroups.get(0).getSecondAttachmentPoint());
+        Assertions.assertNull(rGroups.get(1).getSecondAttachmentPoint());
+        Assertions.assertNull(rGroups.get(2).getSecondAttachmentPoint());
 
         List<IAtomContainer> configurations = rGroupQuery.getAllConfigurations();
-        Assert.assertEquals(configurations.size(), 4);
+        Assertions.assertEquals(configurations.size(), 4);
 
         //RestH is set to true for R1, so with zero substitutes, the phosphor should get the restH flag set to true.
         boolean restH_Identified = false;
         for (IAtomContainer atc : configurations) {
             if (atc.getAtomCount() == 6) {
                 for (IAtom atom : atc.atoms()) {
-                    if (atom.getSymbol().equals("P")) {
-                        Assert.assertNotNull(atom.getProperty(CDKConstants.REST_H));
-                        Assert.assertEquals(atom.getProperty(CDKConstants.REST_H), true);
+                    if (atom.getAtomicNumber() == IElement.P) {
+                        Assertions.assertNotNull(atom.getProperty(CDKConstants.REST_H));
+                        Assertions.assertEquals(atom.getProperty(CDKConstants.REST_H), true);
                         restH_Identified = true;
                     }
                 }
             }
         }
-        Assert.assertTrue(restH_Identified);
+        Assertions.assertTrue(restH_Identified);
     }
 
     /**
@@ -162,63 +162,63 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * More elaborate R-group query file.
      */
     @Test
-    public void testRgroupQueryFile2() throws Exception {
+    void testRgroupQueryFile2() throws Exception {
         String filename = "rgfile.2.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 3);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 14);
-        Assert.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 4);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 3);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 14);
+        Assertions.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 4);
 
         List<IAtom> rGroupQueryAtoms = rGroupQuery.getAllRgroupQueryAtoms();
-        Assert.assertEquals(rGroupQueryAtoms.size(), 4);
+        Assertions.assertEquals(rGroupQueryAtoms.size(), 4);
 
         rGroupQueryAtoms = rGroupQuery.getRgroupQueryAtoms(1);
-        Assert.assertEquals(rGroupQueryAtoms.size(), 1);
+        Assertions.assertEquals(rGroupQueryAtoms.size(), 1);
 
         for (IAtom at : rGroupQuery.getAllRgroupQueryAtoms()) {
             if (at instanceof PseudoAtom) {
-                Assert.assertTrue(RGroupQuery.isValidRgroupQueryLabel(((PseudoAtom) at).getLabel()));
+                Assertions.assertTrue(RGroupQuery.isValidRgroupQueryLabel(((PseudoAtom) at).getLabel()));
                 int rgroupNum = new Integer((((PseudoAtom) at).getLabel()).substring(1));
-                Assert.assertTrue(rgroupNum == 1 || rgroupNum == 2 || rgroupNum == 11);
+                Assertions.assertTrue(rgroupNum == 1 || rgroupNum == 2 || rgroupNum == 11);
                 switch (rgroupNum) {
                     case 1: {
                         //Test: R1 has two attachment points, defined by AAL
                         Map<IAtom, Map<Integer, IBond>> rootApo = rGroupQuery.getRootAttachmentPoints();
                         Map<Integer, IBond> apoBonds = rootApo.get(at);
-                        Assert.assertEquals(apoBonds.size(), 2);
-                        Assert.assertEquals(apoBonds.get(1).getOther(at).getSymbol(), "N");
-                        Assert.assertTrue(apoBonds.get(2).getOther(at).getSymbol().equals("C"));
+                        Assertions.assertEquals(apoBonds.size(), 2);
+                        Assertions.assertEquals(apoBonds.get(1).getOther(at).getSymbol(), "N");
+                        Assertions.assertEquals(IElement.C, (int) apoBonds.get(2).getOther(at).getAtomicNumber());
                         //Test: Oxygens are the 2nd APO's for R1
                         IRGroupList rList = rGroupQuery.getRGroupDefinitions().get(1);
-                        Assert.assertEquals(rList.getRGroups().size(), 2);
+                        Assertions.assertEquals(rList.getRGroups().size(), 2);
                         List<IRGroup> rGroups = rList.getRGroups();
-                        Assert.assertEquals(rGroups.get(0).getSecondAttachmentPoint().getSymbol(), "O");
-                        Assert.assertEquals(rGroups.get(1).getSecondAttachmentPoint().getSymbol(), "O");
-                        Assert.assertFalse(rList.isRestH());
+                        Assertions.assertEquals(rGroups.get(0).getSecondAttachmentPoint().getSymbol(), "O");
+                        Assertions.assertEquals(rGroups.get(1).getSecondAttachmentPoint().getSymbol(), "O");
+                        Assertions.assertFalse(rList.isRestH());
                     }
                         break;
                     case 2: {
                         IRGroupList rList = rGroupQuery.getRGroupDefinitions().get(2);
-                        Assert.assertEquals(rList.getRGroups().size(), 2);
-                        Assert.assertEquals(rList.getOccurrence(), "0,2");
-                        Assert.assertEquals(rList.getRequiredRGroupNumber(), 11);
-                        Assert.assertFalse(rList.isRestH());
+                        Assertions.assertEquals(rList.getRGroups().size(), 2);
+                        Assertions.assertEquals(rList.getOccurrence(), "0,2");
+                        Assertions.assertEquals(rList.getRequiredRGroupNumber(), 11);
+                        Assertions.assertFalse(rList.isRestH());
                     }
                         break;
                     case 11: {
                         IRGroupList rList = rGroupQuery.getRGroupDefinitions().get(11);
-                        Assert.assertEquals(rList.getRGroups().size(), 1);
-                        Assert.assertEquals(rList.getRequiredRGroupNumber(), 0);
-                        Assert.assertTrue(rList.isRestH());
+                        Assertions.assertEquals(rList.getRGroups().size(), 1);
+                        Assertions.assertEquals(rList.getRequiredRGroupNumber(), 0);
+                        Assertions.assertTrue(rList.isRestH());
 
                         List<IRGroup> rGroups = rList.getRGroups();
-                        Assert.assertEquals(rGroups.get(0).getFirstAttachmentPoint().getSymbol(), "Pt");
-                        Assert.assertEquals(rGroups.get(0).getSecondAttachmentPoint(), null);
+                        Assertions.assertEquals(rGroups.get(0).getFirstAttachmentPoint().getSymbol(), "Pt");
+                        Assertions.assertEquals(rGroups.get(0).getSecondAttachmentPoint(), null);
                     }
                         break;
                 }
@@ -226,7 +226,7 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
         }
 
         List<IAtomContainer> configurations = rGroupQuery.getAllConfigurations();
-        Assert.assertEquals(configurations.size(), 12);
+        Assertions.assertEquals(configurations.size(), 12);
 
         //Test restH values
         int countRestHForSmallestConfigurations = 0;
@@ -235,13 +235,13 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
                 for (IAtom atom : atc.atoms()) {
                     if (atom.getProperty(CDKConstants.REST_H) != null) {
                         countRestHForSmallestConfigurations++;
-                        if (atom.getSymbol().equals("P"))
-                            Assert.assertEquals(atom.getProperty(CDKConstants.REST_H), true);
+                        if (atom.getAtomicNumber() == IElement.P)
+                            Assertions.assertEquals(atom.getProperty(CDKConstants.REST_H), true);
                     }
                 }
             }
         }
-        Assert.assertEquals(countRestHForSmallestConfigurations, 6);
+        Assertions.assertEquals(countRestHForSmallestConfigurations, 6);
 
     }
 
@@ -250,33 +250,33 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * This R-group query has R1 bound double twice, and has AAL lines to parse.
      */
     @Test
-    public void testRgroupQueryFile3() throws Exception {
+    void testRgroupQueryFile3() throws Exception {
         String filename = "rgfile.3.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 10);
-        Assert.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 2);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 10);
+        Assertions.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 2);
 
-        Assert.assertEquals(rGroupQuery.getAllConfigurations().size(), 8);
+        Assertions.assertEquals(rGroupQuery.getAllConfigurations().size(), 8);
 
         //Test correctness AAL lines
         for (IAtom at : rGroupQuery.getRgroupQueryAtoms(1)) {
             if (at instanceof PseudoAtom) {
-                Assert.assertEquals(((PseudoAtom) at).getLabel(), "R1");
+                Assertions.assertEquals(((PseudoAtom) at).getLabel(), "R1");
 
                 Map<Integer, IBond> apoBonds = rGroupQuery.getRootAttachmentPoints().get(at);
-                Assert.assertEquals(apoBonds.size(), 2);
+                Assertions.assertEquals(apoBonds.size(), 2);
 
                 IAtom boundAtom1 = apoBonds.get(1).getOther(at);
-                Assert.assertTrue(boundAtom1.getSymbol().equals("Te") || boundAtom1.getSymbol().equals("S"));
+                Assertions.assertTrue(boundAtom1.getAtomicNumber() == IElement.Te || boundAtom1.getAtomicNumber() == IElement.S);
 
                 IAtom boundAtom2 = apoBonds.get(2).getOther(at);
-                Assert.assertTrue(boundAtom2.getSymbol().equals("Po") || boundAtom2.getSymbol().equals("O"));
+                Assertions.assertTrue(boundAtom2.getAtomicNumber() == IElement.Po || boundAtom2.getAtomicNumber() == IElement.O);
             }
         }
 
@@ -284,7 +284,7 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
         // pseudo atom, but because it is not numbered it is not part of any
         // query condition.
         List<IAtom> allrGroupQueryAtoms = rGroupQuery.getAllRgroupQueryAtoms();
-        Assert.assertEquals(allrGroupQueryAtoms.size(), 2);
+        Assertions.assertEquals(allrGroupQueryAtoms.size(), 2);
     }
 
     /**
@@ -292,34 +292,34 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * This R-group query has its R# atom detached, no bounds.
      */
     @Test
-    public void testRgroupQueryFile4() throws Exception {
+    void testRgroupQueryFile4() throws Exception {
         String filename = "rgfile.4.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 6);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 6);
 
         List<IAtom> allrGroupQueryAtoms = rGroupQuery.getAllRgroupQueryAtoms();
-        Assert.assertEquals(allrGroupQueryAtoms.size(), 1);
+        Assertions.assertEquals(allrGroupQueryAtoms.size(), 1);
         IRGroupList rList = rGroupQuery.getRGroupDefinitions().get(1);
-        Assert.assertEquals(rList.getRGroups().size(), 2);
-        Assert.assertEquals(rList.getRequiredRGroupNumber(), 0);
-        Assert.assertFalse(rList.isRestH());
-        Assert.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 0);
-        Assert.assertTrue(rGroupQuery.areSubstituentsDefined());
+        Assertions.assertEquals(rList.getRGroups().size(), 2);
+        Assertions.assertEquals(rList.getRequiredRGroupNumber(), 0);
+        Assertions.assertFalse(rList.isRestH());
+        Assertions.assertEquals(rGroupQuery.getRootAttachmentPoints().size(), 0);
+        Assertions.assertTrue(rGroupQuery.areSubstituentsDefined());
 
-        Assert.assertEquals(rGroupQuery.getAllConfigurations().size(), 2);
+        Assertions.assertEquals(rGroupQuery.getAllConfigurations().size(), 2);
 
         // This query has a detached R-group, test for empty attachment points
         List<IRGroup> rGroups = rList.getRGroups();
-        Assert.assertEquals(rGroups.get(0).getFirstAttachmentPoint(), null);
-        Assert.assertEquals(rGroups.get(0).getSecondAttachmentPoint(), null);
-        Assert.assertEquals(rGroups.get(1).getFirstAttachmentPoint(), null);
-        Assert.assertEquals(rGroups.get(1).getSecondAttachmentPoint(), null);
+        Assertions.assertEquals(rGroups.get(0).getFirstAttachmentPoint(), null);
+        Assertions.assertEquals(rGroups.get(0).getSecondAttachmentPoint(), null);
+        Assertions.assertEquals(rGroups.get(1).getFirstAttachmentPoint(), null);
+        Assertions.assertEquals(rGroups.get(1).getSecondAttachmentPoint(), null);
     }
 
     /**
@@ -328,19 +328,19 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * to test mainly for getting all valid configurations.
      */
     @Test
-    @Category(SlowTest.class)
-    public void testRgroupQueryFile5() throws Exception {
+    @Tag("SlowTest")
+    void testRgroupQueryFile5() throws Exception {
         String filename = "rgfile.5.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 4);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 4);
 
         //Test combinatorial explosion: R5 has many different configurations
-        Assert.assertEquals(rGroupQuery.getAllConfigurations().size(), 17820);
+        Assertions.assertEquals(rGroupQuery.getAllConfigurations().size(), 17820);
     }
 
     /**
@@ -348,28 +348,31 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * This RGFile is incomplete, RGP lines are missing. We still want to
      * accept it (Symyx/ChemAxon software accepts it too).
      */
-    @Test(expected = CDKException.class)
-    public void testRgroupQueryFile6() throws Exception {
+    @Test
+    void testRgroupQueryFile6() throws Exception {
         String filename = "rgfile.6.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 3);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 14);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 3);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 14);
 
         // This file has missing $RGP blocks. You could argue that this is
         // thus not a legal query (ie missing query specifications)
-        Assert.assertFalse(rGroupQuery.areSubstituentsDefined());
+        Assertions.assertFalse(rGroupQuery.areSubstituentsDefined());
 
         //Getting for all configurations won't happen, because not all groups were set
-        rGroupQuery.getAllConfigurations(); // Will raise exception
+        Assertions.assertThrows(CDKException.class,
+                                () -> {
+                                    rGroupQuery.getAllConfigurations(); // Will raise exception
+                                });
 
     }
 
-    /**
+                                /**
      * Test parsing of RGFile rgfile.7.mol.
      * This RGFile has APO lines with value 3: both attachment points.<P>
      *
@@ -377,17 +380,17 @@ public class RGroupQueryReaderTest extends SimpleChemObjectReaderTest {
      * The parser should not trip over this, and make nice configurations.
      */
     @Test
-    public void testRgroupQueryFile7() throws Exception {
+    void testRgroupQueryFile7() throws Exception {
         String filename = "rgfile.7.mol";
         logger.info("Testing: " + filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
         RGroupQueryReader reader = new RGroupQueryReader(ins);
-        RGroupQuery rGroupQuery = (RGroupQuery) reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
+        RGroupQuery rGroupQuery = reader.read(new RGroupQuery(DefaultChemObjectBuilder.getInstance()));
         reader.close();
-        Assert.assertNotNull(rGroupQuery);
-        Assert.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
-        Assert.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 9);
-        Assert.assertEquals(rGroupQuery.getAllConfigurations().size(), 20);
+        Assertions.assertNotNull(rGroupQuery);
+        Assertions.assertEquals(rGroupQuery.getRGroupDefinitions().size(), 1);
+        Assertions.assertEquals(rGroupQuery.getRootStructure().getAtomCount(), 9);
+        Assertions.assertEquals(rGroupQuery.getAllConfigurations().size(), 20);
 
     }
 
