@@ -30,9 +30,9 @@ import java.util.Properties;
 
 import org.hamcrest.CoreMatchers;
 import org.hamcrest.Matchers;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.AtomContainerSet;
@@ -50,15 +50,13 @@ import org.openscience.cdk.silent.SilentChemObjectBuilder;
 import org.openscience.cdk.smiles.InvPair;
 import org.openscience.cdk.templates.TestMoleculeFactory;
 import org.openscience.cdk.test.io.ChemObjectWriterTest;
+import org.openscience.cdk.tools.LoggingToolFactory;
 
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.openscience.cdk.CDKConstants.ISAROMATIC;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-
 /**
  * TestCase for the writer MDL SD file writer.
  *
@@ -66,26 +64,26 @@ import static org.junit.Assert.assertTrue;
  *
  * @see org.openscience.cdk.io.SDFWriter
  */
-public class SDFWriterTest extends ChemObjectWriterTest {
+class SDFWriterTest extends ChemObjectWriterTest {
 
     private static IChemObjectBuilder builder;
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         builder = DefaultChemObjectBuilder.getInstance();
         setChemObjectWriter(new SDFWriter());
     }
 
     @Test
-    public void testAccepts() throws Exception {
+    void testAccepts() throws Exception {
         SDFWriter reader = new SDFWriter();
-        Assert.assertTrue(reader.accepts(ChemFile.class));
-        Assert.assertTrue(reader.accepts(ChemModel.class));
-        Assert.assertTrue(reader.accepts(AtomContainerSet.class));
+        Assertions.assertTrue(reader.accepts(ChemFile.class));
+        Assertions.assertTrue(reader.accepts(ChemModel.class));
+        Assertions.assertTrue(reader.accepts(AtomContainerSet.class));
     }
 
     @Test
-    public void testWrite_IAtomContainerSet_Properties_Off() throws Exception {
+    void testWrite_IAtomContainerSet_Properties_Off() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer molecule = new AtomContainer();
@@ -101,14 +99,14 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         sdfWriter.write(molSet);
         sdfWriter.close();
         String result = writer.toString();
-        Assert.assertFalse(result.contains("<foo>"));
+        Assertions.assertFalse(result.contains("<foo>"));
     }
 
     /**
      * @cdk.bug 2827745
      */
     @Test
-    public void testWrite_IAtomContainerSet() throws Exception {
+    void testWrite_IAtomContainerSet() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = builder.newInstance(IAtomContainerSet.class);
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
@@ -118,11 +116,11 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.write(molSet);
         sdfWriter.close();
-        Assert.assertNotSame(0, writer.toString().length());
+        Assertions.assertNotSame(0, writer.toString().length());
     }
 
     @Test
-    public void testWrite_IAtomContainerSet_Properties() throws Exception {
+    void testWrite_IAtomContainerSet_Properties() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer molecule = new AtomContainer();
@@ -133,12 +131,12 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.write(molSet);
         sdfWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("<foo>") != -1);
-        Assert.assertTrue(writer.toString().indexOf("bar") != -1);
+        Assertions.assertTrue(writer.toString().contains("<foo>"));
+        Assertions.assertTrue(writer.toString().contains("bar"));
     }
 
     @Test
-    public void testWrite_IAtomContainerSet_CDKProperties() throws Exception {
+    void testWrite_IAtomContainerSet_CDKProperties() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer molecule = new AtomContainer();
@@ -149,11 +147,11 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.write(molSet);
         sdfWriter.close();
-        Assert.assertTrue(writer.toString().indexOf(InvPair.CANONICAL_LABEL) == -1);
+        Assertions.assertTrue(!writer.toString().contains(InvPair.CANONICAL_LABEL));
     }
 
     @Test
-    public void testWrite_IAtomContainerSet_SingleMolecule() throws Exception {
+    void testWrite_IAtomContainerSet_SingleMolecule() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer molecule = new AtomContainer();
@@ -163,11 +161,11 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.write(molSet);
         sdfWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("$$$$") != -1);
+        Assertions.assertTrue(writer.toString().contains("$$$$"));
     }
 
     @Test
-    public void testWrite_IAtomContainerSet_MultIAtomContainer() throws Exception {
+    void testWrite_IAtomContainerSet_MultIAtomContainer() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainerSet molSet = new AtomContainerSet();
         IAtomContainer molecule = new AtomContainer();
@@ -180,11 +178,11 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.write(molSet);
         sdfWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("$$$$") != -1);
+        Assertions.assertTrue(writer.toString().contains("$$$$"));
     }
 
     @Test
-    public void testWrite_IAtomContainer_MultIAtomContainer() throws Exception {
+    void testWrite_IAtomContainer_MultIAtomContainer() throws Exception {
         StringWriter writer = new StringWriter();
         SDFWriter sdfWriter = new SDFWriter(writer);
 
@@ -199,15 +197,15 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         sdfWriter.write(molecule);
 
         sdfWriter.close();
-        Assert.assertTrue(writer.toString().indexOf("foo") != -1);
-        Assert.assertTrue(writer.toString().indexOf("bar") != -1);
-        Assert.assertTrue(writer.toString().indexOf("toys") != -1);
-        Assert.assertTrue(writer.toString().indexOf("r-us") != -1);
-        Assert.assertTrue(writer.toString().indexOf("$$$$") != -1);
+        Assertions.assertTrue(writer.toString().contains("foo"));
+        Assertions.assertTrue(writer.toString().contains("bar"));
+        Assertions.assertTrue(writer.toString().contains("toys"));
+        Assertions.assertTrue(writer.toString().contains("r-us"));
+        Assertions.assertTrue(writer.toString().contains("$$$$"));
     }
 
     @Test
-    public void invalidSDfileHeaderTags() throws Exception {
+    void invalidSDfileHeaderTags() throws Exception {
         StringWriter writer = new StringWriter();
         SDFWriter sdfWriter = new SDFWriter(writer);
 
@@ -221,7 +219,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void chooseFormatToWrite() throws Exception {
+    void chooseFormatToWrite() throws Exception {
         StringWriter writer = new StringWriter();
         SDFWriter sdfWriter = new SDFWriter(writer);
 
@@ -245,7 +243,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void chooseFormatToWrite2() throws Exception {
+    void chooseFormatToWrite2() throws Exception {
         StringWriter writer = new StringWriter();
         SDFWriter sdfWriter = new SDFWriter(writer);
         sdfWriter.setAlwaysV3000(true);
@@ -273,7 +271,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
      * @cdk.bug 3392485
      */
     @Test
-    public void testIOPropPropagation() throws Exception {
+    void testIOPropPropagation() throws Exception {
         IAtomContainer mol = TestMoleculeFactory.makeBenzene();
         for (IAtom atom : mol.atoms()) {
             atom.setFlag(ISAROMATIC, true);
@@ -293,11 +291,11 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         writer.close();
 
         String output = strWriter.toString();
-        Assert.assertTrue(output.contains("4  0  0  0  0"));
+        Assertions.assertTrue(output.contains("4  0  0  0  0"));
     }
 
     @Test
-    public void testPropertyOutput_All() throws CDKException, IOException {
+    void testPropertyOutput_All() throws CDKException, IOException {
         IAtomContainer adenine = TestMoleculeFactory.makeAdenine();
         StringWriter sw = new StringWriter();
         SDFWriter sdf = new SDFWriter(sw);
@@ -306,12 +304,12 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         sdf.write(adenine);
         sdf.close();
         String out = sw.toString();
-        assertTrue(out.contains("> <one>"));
-        assertTrue(out.contains("> <two>"));
+        Assertions.assertTrue(out.contains("> <one>"));
+        Assertions.assertTrue(out.contains("> <two>"));
     }
 
     @Test
-    public void testPropertyOutput_one() throws CDKException, IOException {
+    void testPropertyOutput_one() throws CDKException, IOException {
         IAtomContainer adenine = TestMoleculeFactory.makeAdenine();
         StringWriter sw = new StringWriter();
         SDFWriter sdf = new SDFWriter(sw, Collections.singleton("one"));
@@ -320,12 +318,12 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         sdf.write(adenine);
         sdf.close();
         String out = sw.toString();
-        assertTrue(out.contains("> <one>"));
-        assertFalse(out.contains("> <two>"));
+        Assertions.assertTrue(out.contains("> <one>"));
+        Assertions.assertFalse(out.contains("> <two>"));
     }
 
     @Test
-    public void testPropertyOutput_two() throws CDKException, IOException {
+    void testPropertyOutput_two() throws CDKException, IOException {
         IAtomContainer adenine = TestMoleculeFactory.makeAdenine();
         StringWriter sw = new StringWriter();
         SDFWriter sdf = new SDFWriter(sw, Collections.singleton("two"));
@@ -334,26 +332,26 @@ public class SDFWriterTest extends ChemObjectWriterTest {
         sdf.write(adenine);
         sdf.close();
         String out = sw.toString();
-        assertTrue(out.contains("> <two>"));
-        assertFalse(out.contains("> <one>"));
+        Assertions.assertTrue(out.contains("> <two>"));
+        Assertions.assertFalse(out.contains("> <one>"));
     }
 
     @Test
-    public void testPropertyOutput_none() throws CDKException, IOException {
+    void testPropertyOutput_none() throws CDKException, IOException {
         IAtomContainer adenine = TestMoleculeFactory.makeAdenine();
         StringWriter sw = new StringWriter();
-        SDFWriter sdf = new SDFWriter(sw, Collections.<String> emptySet());
+        SDFWriter sdf = new SDFWriter(sw, Collections.emptySet());
         adenine.setProperty("one", "a");
         adenine.setProperty("two", "b");
         sdf.write(adenine);
         sdf.close();
         String out = sw.toString();
-        assertFalse(out.contains("> <two>"));
-        assertFalse(out.contains("> <one>"));
+        Assertions.assertFalse(out.contains("> <two>"));
+        Assertions.assertFalse(out.contains("> <one>"));
     }
 
     @Test
-    public void setProgramName() {
+    void setProgramName() {
         StringWriter sw = new StringWriter();
         try (SDFWriter sdfw = new SDFWriter(sw)) {
             sdfw.getSetting(MDLV2000Writer.OptWriteDefaultProperties)
@@ -368,7 +366,8 @@ public class SDFWriterTest extends ChemObjectWriterTest {
 
             sdfw.write(TestMoleculeFactory.make123Triazole());
         } catch (IOException | CDKException e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(SDFWriterTest.class)
+                              .warn("Unexpected Error:", e);
         }
         String sdf = sw.toString();
         for (String mol : sdf.split("\\$\\$\\$\\$", 2)) {
@@ -377,7 +376,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void optionallyTruncateLongProperties() {
+    void optionallyTruncateLongProperties() {
         StringWriter sw = new StringWriter();
         try (SDFWriter sdfw = new SDFWriter(sw)) {
             sdfw.getSetting(MDLV2000Writer.OptWriteDefaultProperties)
@@ -398,7 +397,8 @@ public class SDFWriterTest extends ChemObjectWriterTest {
                             "ThisIsAVeryLongFieldThatShouldBeWrapped");
             sdfw.write(mol);
         } catch (IOException | CDKException e) {
-            e.printStackTrace();
+            LoggingToolFactory.createLoggingTool(SDFWriterTest.class)
+                              .warn("Unexpected Error:", e);
         }
         String sdf = sw.toString();
         assertThat(sdf,
@@ -407,7 +407,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
 
 
     @Test
-    public void testNoChiralFlag() throws Exception {
+    void testNoChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112362D          \n" +
                 "\n" +
@@ -447,7 +447,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void testChiralFlag() throws Exception {
+    void testChiralFlag() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052112362D          \n" +
                 "\n" +
@@ -484,7 +484,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void testStereoRac1() throws Exception {
+    void testStereoRac1() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052113162D          \n" +
                 "\n" +
@@ -524,7 +524,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void testStereoRel1() throws Exception {
+    void testStereoRel1() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02052113162D          \n" +
                 "\n" +
@@ -566,7 +566,7 @@ public class SDFWriterTest extends ChemObjectWriterTest {
     }
 
     @Test
-    public void testStereoRac1And() throws Exception {
+    void testStereoRac1And() throws Exception {
         final String input = "\n" +
                 "  Mrv1810 02062121432D          \n" +
                 "\n" +
