@@ -26,19 +26,17 @@ import java.io.BufferedReader;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.StringReader;
-import java.util.Iterator;
 import java.util.List;
 import java.util.zip.GZIPInputStream;
 
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Assumptions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Tag;
 import org.openscience.cdk.ChemFile;
 import org.openscience.cdk.ChemModel;
 import org.openscience.cdk.ChemObject;
-import org.openscience.cdk.test.SlowTest;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainerSet;
@@ -59,21 +57,21 @@ import org.openscience.cdk.tools.manipulator.ChemModelManipulator;
  *
  * @see org.openscience.cdk.io.Mol2Reader
  */
-public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
+class Mol2ReaderTest extends SimpleChemObjectReaderTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(Mol2ReaderTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(Mol2ReaderTest.class);
 
-    @BeforeClass
-    public static void setup() {
+    @BeforeAll
+    static void setup() {
         setSimpleChemObjectReader(new Mol2Reader(), "fromWebsite.mol2");
     }
 
     @Test
-    public void testAccepts() {
+    void testAccepts() {
         Mol2Reader reader = new Mol2Reader();
-        Assert.assertTrue(reader.accepts(ChemFile.class));
-        Assert.assertTrue(reader.accepts(ChemModel.class));
-        Assert.assertTrue(reader.accepts(AtomContainer.class));
+        Assertions.assertTrue(reader.accepts(ChemFile.class));
+        Assertions.assertTrue(reader.accepts(ChemModel.class));
+        Assertions.assertTrue(reader.accepts(AtomContainer.class));
     }
 
     /**
@@ -81,7 +79,7 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
      * <a href="http://www.tripos.com/custResources/mol2Files/mol2_format3.html">Tripos example</a>.
      */
     @Test
-    public void testExampleFromWebsite() throws Exception {
+    void testExampleFromWebsite() throws Exception {
         String filename = "fromWebsite.mol2";
         logger.info("Testing: ", filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -89,38 +87,38 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
         ChemFile chemFile = (ChemFile) reader.read((ChemObject) new ChemFile());
         reader.close();
 
-        Assert.assertNotNull(chemFile);
-        Assert.assertEquals(1, chemFile.getChemSequenceCount());
+        Assertions.assertNotNull(chemFile);
+        Assertions.assertEquals(1, chemFile.getChemSequenceCount());
         org.openscience.cdk.interfaces.IChemSequence seq = chemFile.getChemSequence(0);
-        Assert.assertNotNull(seq);
-        Assert.assertEquals(1, seq.getChemModelCount());
+        Assertions.assertNotNull(seq);
+        Assertions.assertEquals(1, seq.getChemModelCount());
         org.openscience.cdk.interfaces.IChemModel model = seq.getChemModel(0);
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
 
         IAtomContainerSet som = model.getMoleculeSet();
-        Assert.assertNotNull(som);
-        Assert.assertEquals(1, som.getAtomContainerCount());
+        Assertions.assertNotNull(som);
+        Assertions.assertEquals(1, som.getAtomContainerCount());
         IAtomContainer m = som.getAtomContainer(0);
-        Assert.assertNotNull(m);
-        Assert.assertEquals(12, m.getAtomCount());
-        Assert.assertEquals(12, m.getBondCount());
+        Assertions.assertNotNull(m);
+        Assertions.assertEquals(12, m.getAtomCount());
+        Assertions.assertEquals(12, m.getBondCount());
 
-        Assert.assertEquals("C.ar", m.getAtom(0).getAtomTypeName());
-        Assert.assertEquals("C", m.getAtom(0).getSymbol());
-        Assert.assertEquals("H", m.getAtom(6).getAtomTypeName());
-        Assert.assertEquals("H", m.getAtom(6).getSymbol());
+        Assertions.assertEquals("C.ar", m.getAtom(0).getAtomTypeName());
+        Assertions.assertEquals("C", m.getAtom(0).getSymbol());
+        Assertions.assertEquals("H", m.getAtom(6).getAtomTypeName());
+        Assertions.assertEquals("H", m.getAtom(6).getSymbol());
     }
 
     @Test
-    public void testReadingIDs() throws Exception {
+    void testReadingIDs() throws Exception {
         String filename = "fromWebsite.mol2";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(ins);
-        IAtomContainer molecule = (IAtomContainer) reader.read(new AtomContainer());
+        IAtomContainer molecule = reader.read(new AtomContainer());
         reader.close();
-        Assert.assertNotNull(molecule);
-        IAtomContainer reference = (IAtomContainer) molecule.clone();
-        Assert.assertEquals("C1", reference.getAtom(0).getID());
+        Assertions.assertNotNull(molecule);
+        IAtomContainer reference = molecule.clone();
+        Assertions.assertEquals("C1", reference.getAtom(0).getID());
     }
 
     /**
@@ -128,10 +126,10 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
      *
      * @throws Exception if an error occurs
      */
-    @Category(SlowTest.class)
+    @Tag("SlowTest")
     @Test
-    public void testNCIfeb03_2D() throws Exception {
-        Assume.assumeTrue(runSlowTests());
+    void testNCIfeb03_2D() throws Exception {
+        Assumptions.assumeTrue(runSlowTests());
 
         String filename = "NCI_feb03_2D.mol2.gz";
         InputStream in = new GZIPInputStream(Mol2ReaderTest.class.getResourceAsStream(filename));
@@ -151,8 +149,8 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
     }
 
     @Test
-    public void testMultiMol() throws Exception {
-        Assume.assumeTrue(runSlowTests());
+    void testMultiMol() throws Exception {
+        Assumptions.assumeTrue(runSlowTests());
         String filename = "actives.mol2";
         logger.info("Testing: ", filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -160,14 +158,14 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
         IChemFile chemFile = reader.read(new ChemFile());
         reader.close();
         List<IAtomContainer> mols = ChemFileManipulator.getAllAtomContainers(chemFile);
-        Assert.assertEquals(30, mols.size());
-        Assert.assertEquals(25, mols.get(0).getAtomCount());
-        Assert.assertEquals(24, mols.get(29).getAtomCount());
+        Assertions.assertEquals(30, mols.size());
+        Assertions.assertEquals(25, mols.get(0).getAtomCount());
+        Assertions.assertEquals(24, mols.get(29).getAtomCount());
     }
 
     @Test
-    public void testMultiMolButSingle() throws Exception {
-        Assume.assumeTrue(runSlowTests());
+    void testMultiMolButSingle() throws Exception {
+        Assumptions.assumeTrue(runSlowTests());
         String filename = "fromWebsite.mol2";
         logger.info("Testing: ", filename);
         InputStream ins = this.getClass().getResourceAsStream(filename);
@@ -175,25 +173,25 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
         IChemFile chemFile = reader.read(new ChemFile());
         reader.close();
         List<IAtomContainer> mols = ChemFileManipulator.getAllAtomContainers(chemFile);
-        Assert.assertEquals(1, mols.size());
-        Assert.assertEquals(12, mols.get(0).getAtomCount());
+        Assertions.assertEquals(1, mols.size());
+        Assertions.assertEquals(12, mols.get(0).getAtomCount());
 
     }
 
     @Test
-    public void testIAtomContainer() throws Exception {
+    void testIAtomContainer() throws Exception {
         String filename = "fromWebsite.mol2";
         InputStream in = Mol2ReaderTest.class.getResourceAsStream(filename);
         Mol2Reader reader = new Mol2Reader(in);
-        IAtomContainer mol = (IAtomContainer) reader.read(new AtomContainer());
+        IAtomContainer mol = reader.read(new AtomContainer());
         reader.close();
-        Assert.assertNotNull(mol);
-        Assert.assertEquals(12, mol.getAtomCount());
-        Assert.assertEquals(12, mol.getBondCount());
+        Assertions.assertNotNull(mol);
+        Assertions.assertEquals(12, mol.getAtomCount());
+        Assertions.assertEquals(12, mol.getBondCount());
     }
 
     @Test
-    public void testBug1714794() throws Exception {
+    void testBug1714794() throws Exception {
         String problematicMol2 = "@<TRIPOS>MOLECULE\n" + "mol_197219.smi\n" + " 129 135 0 0 0\n" + "SMALL\n"
                 + "GASTEIGER\n" + "Energy = 0\n" + "\n" + "@<TRIPOS>ATOM\n"
                 + "      1 N1          0.0000    0.0000    0.0000 N.am    1  <1>        -0.2782\n"
@@ -371,42 +369,40 @@ public class Mol2ReaderTest extends SimpleChemObjectReaderTest {
                 + "   130   122   124    1\n" + "   131   122   125    1\n" + "   132    91   126    1\n"
                 + "   133   126   127    1\n" + "   134     4   128    1\n" + "   135   128   129    1\n";
         Mol2Reader r = new Mol2Reader(new StringReader(problematicMol2));
-        IChemModel model = (IChemModel) r.read(SilentChemObjectBuilder.getInstance().newInstance(IChemModel.class));
+        IChemModel model = r.read(SilentChemObjectBuilder.getInstance().newInstance(IChemModel.class));
         r.close();
-        Assert.assertNotNull(model);
+        Assertions.assertNotNull(model);
         List<IAtomContainer> containers = ChemModelManipulator.getAllAtomContainers(model);
-        Assert.assertEquals(1, containers.size());
+        Assertions.assertEquals(1, containers.size());
         IAtomContainer molecule = containers.get(0);
-        Assert.assertNotNull(molecule);
-        Assert.assertEquals(129, molecule.getAtomCount());
-        Assert.assertEquals(135, molecule.getBondCount());
-        Iterator<IAtom> atoms = molecule.atoms().iterator();
-        while (atoms.hasNext()) {
-            IAtom atom = atoms.next();
-            Assert.assertNotNull(atom.getAtomTypeName());
+        Assertions.assertNotNull(molecule);
+        Assertions.assertEquals(129, molecule.getAtomCount());
+        Assertions.assertEquals(135, molecule.getBondCount());
+        for (IAtom atom : molecule.atoms()) {
+            Assertions.assertNotNull(atom.getAtomTypeName());
         }
     }
 
     private void checkMol(StringBuilder buf) throws Exception {
         StringReader sr = new StringReader(buf.toString());
         Mol2Reader reader = new Mol2Reader(sr);
-        IChemFile mol = (IChemFile) reader.read(SilentChemObjectBuilder.getInstance().newInstance(IChemFile.class));
+        IChemFile mol = reader.read(SilentChemObjectBuilder.getInstance().newInstance(IChemFile.class));
         reader.close();
-        Assert.assertTrue(mol.getChemSequenceCount() > 0);
-        Assert.assertTrue(mol.getChemSequence(0).getChemModelCount() > 0);
-        Assert.assertTrue(mol.getChemSequence(0).getChemModel(0).getMoleculeSet().getAtomContainerCount() > 0);
-        Assert.assertTrue(mol.getChemSequence(0).getChemModel(0).getMoleculeSet().getAtomContainer(0).getAtomCount() > 0);
+        Assertions.assertTrue(mol.getChemSequenceCount() > 0);
+        Assertions.assertTrue(mol.getChemSequence(0).getChemModelCount() > 0);
+        Assertions.assertTrue(mol.getChemSequence(0).getChemModel(0).getMoleculeSet().getAtomContainerCount() > 0);
+        Assertions.assertTrue(mol.getChemSequence(0).getChemModel(0).getMoleculeSet().getAtomContainer(0).getAtomCount() > 0);
     }
 
     // CL --> Cl, NA --> Na etc.. /cdk/bug/1346
     @Test
-    public void unrecognisedAtomTypes() throws Exception {
+    void unrecognisedAtomTypes() throws Exception {
         Mol2Reader mol2Reader = null;
         try {
             mol2Reader = new Mol2Reader(getClass().getResourceAsStream("CLMW1.mol2"));
             IAtomContainer container = mol2Reader.read(new AtomContainer());
             for (IAtom atom : container.atoms())
-                Assert.assertNotNull(atom.getAtomicNumber());
+                Assertions.assertNotNull(atom.getAtomicNumber());
         } finally {
             if (mol2Reader != null) mol2Reader.close();
         }
