@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class CRK2DFormatTest extends ChemFormatTest {
+class CRK2DFormatTest extends ChemFormatTest {
 
-    public CRK2DFormatTest() {
+    CRK2DFormatTest() {
         super.setChemFormat((IChemFormat) CRK2DFormat.getInstance());
     }
 
