@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class FingerprintFormatTest extends ChemFormatTest {
+class FingerprintFormatTest extends ChemFormatTest {
 
-    public FingerprintFormatTest() {
+    FingerprintFormatTest() {
         super.setChemFormat((IChemFormat) FingerprintFormat.getInstance());
     }
 
