@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class Gaussian98FormatTest extends ChemFormatMatcherTest {
+class Gaussian98FormatTest extends ChemFormatMatcherTest {
 
-    public Gaussian98FormatTest() {
+    Gaussian98FormatTest() {
         super.setChemFormatMatcher((IChemFormatMatcher) Gaussian98Format.getInstance());
     }
 
