@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class MPQCFormatTest extends ChemFormatTest {
+class MPQCFormatTest extends ChemFormatTest {
 
-    public MPQCFormatTest() {
+    MPQCFormatTest() {
         super.setChemFormat((IChemFormat) MPQCFormat.getInstance());
     }
 
