@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class NWChemFormatTest extends ChemFormatMatcherTest {
+class NWChemFormatTest extends ChemFormatMatcherTest {
 
-    public NWChemFormatTest() {
+    NWChemFormatTest() {
         super.setChemFormatMatcher((IChemFormatMatcher) NWChemFormat.getInstance());
     }
 
