@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class PQSChemFormatTest extends ChemFormatTest {
+class PQSChemFormatTest extends ChemFormatTest {
 
-    public PQSChemFormatTest() {
+    PQSChemFormatTest() {
         super.setChemFormat((IChemFormat) PQSChemFormat.getInstance());
     }
 
