@@ -25,10 +25,10 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class SVGFormatTest extends ResourceFormatTest {
+class SVGFormatTest extends ResourceFormatTest {
 
-    public SVGFormatTest() {
-        super.setResourceFormat((IResourceFormat) SVGFormat.getInstance());
+    SVGFormatTest() {
+        super.setResourceFormat(SVGFormat.getInstance());
     }
 
 }
