@@ -25,9 +25,9 @@ package org.openscience.cdk.io.formats;
 /**
  * @cdk.module test-ioformats
  */
-public class YasaraFormatTest extends ChemFormatTest {
+class YasaraFormatTest extends ChemFormatTest {
 
-    public YasaraFormatTest() {
+    YasaraFormatTest() {
         super.setChemFormat((IChemFormat) YasaraFormat.getInstance());
     }
 
