@@ -28,9 +28,8 @@ import java.io.IOException;
 import java.io.StringWriter;
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Test;
-
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.test.CDKTestCase;
@@ -53,15 +52,15 @@ import org.xmlcml.cml.element.CMLAtom;
 /**
  * @cdk.module test-libiomd
  */
-public class MDMoleculeTest extends CDKTestCase {
+class MDMoleculeTest extends CDKTestCase {
 
-    private ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDMoleculeTest.class);
+    private final ILoggingTool logger = LoggingToolFactory.createLoggingTool(MDMoleculeTest.class);
 
     /**
      * @cdk.bug 1748257
      */
     @Test
-    public void testBug1748257() {
+    void testBug1748257() {
 
         MDMolecule mol = new MDMolecule();
         mol.addAtom(new Atom("C")); // 0
@@ -79,7 +78,7 @@ public class MDMoleculeTest extends CDKTestCase {
 
         Convertor convertor = new Convertor(false, "");
         CMLAtom cmlatom = convertor.cdkAtomToCMLAtom(mol, mol.getAtom(2));
-        Assert.assertEquals(cmlatom.getHydrogenCount(), 0);
+        Assertions.assertEquals(cmlatom.getHydrogenCount(), 0);
     }
 
     /**
@@ -87,7 +86,7 @@ public class MDMoleculeTest extends CDKTestCase {
      *
      */
     @Test
-    public void testMDMolecule() {
+    void testMDMolecule() {
 
         MDMolecule mol = new MDMolecule();
         mol.addAtom(new Atom("C")); // 0
@@ -122,16 +121,16 @@ public class MDMoleculeTest extends CDKTestCase {
         mol.addResidue(res2);
 
         //Test residue creation
-        Assert.assertEquals(res1.getParentMolecule(), mol);
-        Assert.assertEquals(res2.getParentMolecule(), mol);
-        Assert.assertEquals(res1.getAtomCount(), 3);
-        Assert.assertEquals(res2.getAtomCount(), 3);
-        Assert.assertEquals(res1.getName(), "myResidue1");
-        Assert.assertEquals(res2.getName(), "myResidue2");
-        Assert.assertNotNull(mol.getResidues());
-        Assert.assertEquals(mol.getResidues().size(), 2);
-        Assert.assertEquals(mol.getResidues().get(0), res1);
-        Assert.assertEquals(mol.getResidues().get(1), res2);
+        Assertions.assertEquals(res1.getParentMolecule(), mol);
+        Assertions.assertEquals(res2.getParentMolecule(), mol);
+        Assertions.assertEquals(res1.getAtomCount(), 3);
+        Assertions.assertEquals(res2.getAtomCount(), 3);
+        Assertions.assertEquals(res1.getName(), "myResidue1");
+        Assertions.assertEquals(res2.getName(), "myResidue2");
+        Assertions.assertNotNull(mol.getResidues());
+        Assertions.assertEquals(mol.getResidues().size(), 2);
+        Assertions.assertEquals(mol.getResidues().get(0), res1);
+        Assertions.assertEquals(mol.getResidues().get(1), res2);
 
         //Create 2 chargegroups
         AtomContainer ac3 = new AtomContainer();
@@ -149,20 +148,20 @@ public class MDMoleculeTest extends CDKTestCase {
         mol.addChargeGroup(chg2);
 
         //Test chargegroup creation
-        Assert.assertEquals(chg1.getParentMolecule(), mol);
-        Assert.assertEquals(chg2.getParentMolecule(), mol);
-        Assert.assertEquals(chg1.getAtomCount(), 2);
-        Assert.assertEquals(chg2.getAtomCount(), 4);
+        Assertions.assertEquals(chg1.getParentMolecule(), mol);
+        Assertions.assertEquals(chg2.getParentMolecule(), mol);
+        Assertions.assertEquals(chg1.getAtomCount(), 2);
+        Assertions.assertEquals(chg2.getAtomCount(), 4);
 
-        Assert.assertNotNull(mol.getChargeGroups());
-        Assert.assertEquals(mol.getChargeGroups().size(), 2);
-        Assert.assertEquals(mol.getChargeGroups().get(0), chg1);
-        Assert.assertEquals(mol.getChargeGroups().get(1), chg2);
+        Assertions.assertNotNull(mol.getChargeGroups());
+        Assertions.assertEquals(mol.getChargeGroups().size(), 2);
+        Assertions.assertEquals(mol.getChargeGroups().get(0), chg1);
+        Assertions.assertEquals(mol.getChargeGroups().get(1), chg2);
 
     }
 
     @Test
-    public void testMDMoleculeCustomizationRoundtripping() throws Exception {
+    void testMDMoleculeCustomizationRoundtripping() throws Exception {
         StringWriter writer = new StringWriter();
 
         CMLWriter cmlWriter = new CMLWriter(writer);
@@ -181,38 +180,38 @@ public class MDMoleculeTest extends CDKTestCase {
 
         CMLReader reader = new CMLReader(new ByteArrayInputStream(serializedMol.getBytes()));
         reader.registerConvention("md:mdMolecule", new MDMoleculeConvention(new ChemFile()));
-        IChemFile file = (IChemFile) reader.read(new ChemFile());
+        IChemFile file = reader.read(new ChemFile());
         reader.close();
         List containers = ChemFileManipulator.getAllAtomContainers(file);
-        Assert.assertEquals(1, containers.size());
+        Assertions.assertEquals(1, containers.size());
 
         Object molecule2 = containers.get(0);
-        Assert.assertTrue(molecule2 instanceof MDMolecule);
+        Assertions.assertTrue(molecule2 instanceof MDMolecule);
         MDMolecule mdMol = (MDMolecule) molecule2;
 
-        Assert.assertEquals(6, mdMol.getAtomCount());
-        Assert.assertEquals(6, mdMol.getBondCount());
+        Assertions.assertEquals(6, mdMol.getAtomCount());
+        Assertions.assertEquals(6, mdMol.getBondCount());
 
         List residues = mdMol.getResidues();
-        Assert.assertEquals(2, residues.size());
-        Assert.assertEquals(3, ((Residue) residues.get(0)).getAtomCount());
-        Assert.assertEquals(3, ((Residue) residues.get(1)).getAtomCount());
-        Assert.assertEquals("myResidue1", ((Residue) residues.get(0)).getName());
-        Assert.assertEquals("myResidue2", ((Residue) residues.get(1)).getName());
-        Assert.assertEquals(0, ((Residue) residues.get(0)).getNumber());
-        Assert.assertEquals(1, ((Residue) residues.get(1)).getNumber());
+        Assertions.assertEquals(2, residues.size());
+        Assertions.assertEquals(3, ((Residue) residues.get(0)).getAtomCount());
+        Assertions.assertEquals(3, ((Residue) residues.get(1)).getAtomCount());
+        Assertions.assertEquals("myResidue1", ((Residue) residues.get(0)).getName());
+        Assertions.assertEquals("myResidue2", ((Residue) residues.get(1)).getName());
+        Assertions.assertEquals(0, ((Residue) residues.get(0)).getNumber());
+        Assertions.assertEquals(1, ((Residue) residues.get(1)).getNumber());
 
         List chargeGroup = mdMol.getChargeGroups();
-        Assert.assertEquals(2, chargeGroup.size());
-        Assert.assertEquals(2, ((ChargeGroup) chargeGroup.get(0)).getAtomCount());
-        Assert.assertEquals(4, ((ChargeGroup) chargeGroup.get(1)).getAtomCount());
-        Assert.assertNotNull(((ChargeGroup) chargeGroup.get(0)).getSwitchingAtom());
-        Assert.assertEquals("a2", ((ChargeGroup) chargeGroup.get(0)).getSwitchingAtom().getID());
-        Assert.assertNotNull(((ChargeGroup) chargeGroup.get(1)).getSwitchingAtom());
-        Assert.assertEquals("a5", ((ChargeGroup) chargeGroup.get(1)).getSwitchingAtom().getID());
+        Assertions.assertEquals(2, chargeGroup.size());
+        Assertions.assertEquals(2, ((ChargeGroup) chargeGroup.get(0)).getAtomCount());
+        Assertions.assertEquals(4, ((ChargeGroup) chargeGroup.get(1)).getAtomCount());
+        Assertions.assertNotNull(((ChargeGroup) chargeGroup.get(0)).getSwitchingAtom());
+        Assertions.assertEquals("a2", ((ChargeGroup) chargeGroup.get(0)).getSwitchingAtom().getID());
+        Assertions.assertNotNull(((ChargeGroup) chargeGroup.get(1)).getSwitchingAtom());
+        Assertions.assertEquals("a5", ((ChargeGroup) chargeGroup.get(1)).getSwitchingAtom().getID());
 
-        Assert.assertEquals(2, ((ChargeGroup) chargeGroup.get(0)).getNumber());
-        Assert.assertEquals(3, ((ChargeGroup) chargeGroup.get(1)).getNumber());
+        Assertions.assertEquals(2, ((ChargeGroup) chargeGroup.get(0)).getNumber());
+        Assertions.assertEquals(3, ((ChargeGroup) chargeGroup.get(1)).getNumber());
 
         writer = new StringWriter();
 
@@ -229,12 +228,12 @@ public class MDMoleculeTest extends CDKTestCase {
         logger.debug(serializedMDMol);
         logger.debug("******************************");
 
-        Assert.assertEquals(serializedMol, serializedMDMol);
+        Assertions.assertEquals(serializedMol, serializedMDMol);
 
     }
 
     @Test
-    public void testMDMoleculeCustomization() {
+    void testMDMoleculeCustomization() {
         StringWriter writer = new StringWriter();
 
         CMLWriter cmlWriter = new CMLWriter(writer);
@@ -247,7 +246,7 @@ public class MDMoleculeTest extends CDKTestCase {
         } catch (CDKException | IOException exception) {
             logger.error("Error while creating an CML2 file: ", exception.getMessage());
             logger.debug(exception);
-            Assert.fail(exception.getMessage());
+            Assertions.fail(exception.getMessage());
         }
         String cmlContent = writer.toString();
         logger.debug("****************************** testMDMoleculeCustomization()");
@@ -256,19 +255,19 @@ public class MDMoleculeTest extends CDKTestCase {
         //        System.out.println("****************************** testMDMoleculeCustomization()");
         //        System.out.println(cmlContent);
         //        System.out.println("******************************");
-        Assert.assertTrue(cmlContent.indexOf("xmlns:md") != -1);
-        Assert.assertTrue(cmlContent.indexOf("md:residue\"") != -1);
-        Assert.assertTrue(cmlContent.indexOf("md:resNumber\"") != -1);
-        Assert.assertTrue(cmlContent.indexOf("md:chargeGroup\"") != -1);
-        Assert.assertTrue(cmlContent.indexOf("md:cgNumber\"") != -1);
-        Assert.assertTrue(cmlContent.indexOf("md:switchingAtom\"") != -1);
+        Assertions.assertTrue(cmlContent.contains("xmlns:md"));
+        Assertions.assertTrue(cmlContent.contains("md:residue\""));
+        Assertions.assertTrue(cmlContent.contains("md:resNumber\""));
+        Assertions.assertTrue(cmlContent.contains("md:chargeGroup\""));
+        Assertions.assertTrue(cmlContent.contains("md:cgNumber\""));
+        Assertions.assertTrue(cmlContent.contains("md:switchingAtom\""));
     }
 
     /**
      * Create a benzene molecule with 2 residues and 2 charge groups
      * @return
      */
-    public MDMolecule makeMDBenzene() {
+    MDMolecule makeMDBenzene() {
 
         MDMolecule mol = new MDMolecule();
         mol.addAtom(new Atom("C")); // 0
