@@ -1,7 +1,7 @@
 package org.openscience.cdk.libio.cml;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IPDBAtom;
@@ -16,12 +16,12 @@ import java.io.StringWriter;
  * @author John May
  * @cdk.module test-pdbcml
  */
-public class PDBAtomCustomizerTest {
+class PDBAtomCustomizerTest {
 
-    private static ILoggingTool logger = LoggingToolFactory.createLoggingTool(PDBAtomCustomizerTest.class);
+    private static final ILoggingTool logger = LoggingToolFactory.createLoggingTool(PDBAtomCustomizerTest.class);
 
     @Test
-    public void testPDBAtomCustomization() throws Exception {
+    void testPDBAtomCustomization() throws Exception {
         StringWriter writer = new StringWriter();
         IAtomContainer molecule = new AtomContainer();
         IPDBAtom atom = new PDBAtom("C");
@@ -37,6 +37,6 @@ public class PDBAtomCustomizerTest {
         logger.debug("****************************** testPDBAtomCustomization()");
         logger.debug(cmlContent);
         logger.debug("******************************");
-        Assert.assertTrue(cmlContent.indexOf("<scalar dictRef=\"pdb:resName") != -1);
+        Assertions.assertTrue(cmlContent.contains("<scalar dictRef=\"pdb:resName"));
     }
 }
