@@ -272,8 +272,8 @@ final class BeamToCDK {
             int v = e.other(u);
 
             // find a directional bond for either end
-            Edge first  = null;
-            Edge second = null;
+            Edge first;
+            Edge second;
 
             // if either atom is not incident to a directional label there
             // is no configuration
@@ -362,8 +362,8 @@ final class BeamToCDK {
                     int vPos = Arrays.binarySearch(nbrs, 0, 3, v);
                     int uPos = Arrays.binarySearch(nbrs, 3, 6, u);
 
-                    int uhi = 0, ulo = 0;
-                    int vhi = 0, vlo = 0;
+                    int uhi, ulo;
+                    int vhi, vlo;
 
                     uhi = nbrs[(vPos + 1) % 3];
                     ulo = nbrs[(vPos + 2) % 3];
@@ -434,8 +434,8 @@ final class BeamToCDK {
             if (b == Bond.UP || b == Bond.DOWN) {
                 if (first == null)
                     first = e;
-                else if (((first.either() == e.either()) == (first.bond() == b)))
-                    return null;
+                else if (first.bond(u) == e.bond(u))
+                    return null; // inconsistent e.g. C/C=C(/C)/C
             }
         }
         return first;
