@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.charges;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.interfaces.IBond;
@@ -34,15 +34,15 @@ import org.openscience.cdk.tools.manipulator.AtomContainerManipulator;
 *
 * @cdk.module test-charges
 */
-public class ElectronegativityTest extends CDKTestCase {
+class ElectronegativityTest extends CDKTestCase {
 
-    private IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
-    private LonePairElectronChecker lpcheck = new LonePairElectronChecker();
+    private final IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
+    private final LonePairElectronChecker lpcheck = new LonePairElectronChecker();
 
     /**
      * Constructor of the ElectronegativityTest.
      */
-    public ElectronegativityTest() {
+    ElectronegativityTest() {
         super();
     }
 
@@ -52,9 +52,9 @@ public class ElectronegativityTest extends CDKTestCase {
      *
      */
     @Test
-    public void testElectronegativity() {
+    void testElectronegativity() {
 
-        Assert.assertNotNull(new Electronegativity());
+        Assertions.assertNotNull(new Electronegativity());
     }
 
     /**
@@ -63,9 +63,9 @@ public class ElectronegativityTest extends CDKTestCase {
      *
      */
     @Test
-    public void testElectronegativity_Int_Int() {
+    void testElectronegativity_Int_Int() {
 
-        Assert.assertNotNull(new Electronegativity(6, 50));
+        Assertions.assertNotNull(new Electronegativity(6, 50));
     }
 
     /**
@@ -77,7 +77,7 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testCalculateSigmaElectronegativity_IAtomContainer_IAtom() throws Exception {
+    void testCalculateSigmaElectronegativity_IAtomContainer_IAtom() throws Exception {
         double[] testResult = {11.308338, 8.7184094, 7.5289848, 7.5289848, 7.5289848};
         Electronegativity pe = new Electronegativity();
 
@@ -91,7 +91,7 @@ public class ElectronegativityTest extends CDKTestCase {
         lpcheck.saturate(molecule);
 
         for (int i = 0; i < molecule.getAtomCount(); i++)
-            Assert.assertEquals(testResult[i], pe.calculateSigmaElectronegativity(molecule, molecule.getAtom(i)), 0.001);
+            Assertions.assertEquals(testResult[i], pe.calculateSigmaElectronegativity(molecule, molecule.getAtom(i)), 0.001);
 
     }
 
@@ -104,7 +104,7 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testCalculateSigmaElectronegativity_IAtomContainer_IAtom_Int_Int() throws Exception {
+    void testCalculateSigmaElectronegativity_IAtomContainer_IAtom_Int_Int() throws Exception {
         double[] testResult = {11.308338, 8.7184094, 7.5289848, 7.5289848, 7.5289848};
         Electronegativity pe = new Electronegativity();
 
@@ -118,8 +118,7 @@ public class ElectronegativityTest extends CDKTestCase {
         lpcheck.saturate(molecule);
 
         for (int i = 0; i < molecule.getAtomCount(); i++) {
-            Assert.assertEquals(testResult[i],
-                    pe.calculateSigmaElectronegativity(molecule, molecule.getAtom(i), 6, 50), 0.001);
+            Assertions.assertEquals(testResult[i], pe.calculateSigmaElectronegativity(molecule, molecule.getAtom(i), 6, 50), 0.001);
 
         }
     }
@@ -131,10 +130,10 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetMaxIterations() throws Exception {
+    void testGetMaxIterations() throws Exception {
 
         Electronegativity pe = new Electronegativity();
-        Assert.assertSame(6, pe.getMaxIterations());
+        Assertions.assertSame(6, pe.getMaxIterations());
     }
 
     /**
@@ -144,10 +143,10 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testGetMaxResonStruc() throws Exception {
+    void testGetMaxResonStruc() throws Exception {
 
         Electronegativity pe = new Electronegativity();
-        Assert.assertSame(50, pe.getMaxResonStruc());
+        Assertions.assertSame(50, pe.getMaxResonStruc());
     }
 
     /**
@@ -157,12 +156,12 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSetMaxIterations_Int() throws Exception {
+    void testSetMaxIterations_Int() throws Exception {
 
         Electronegativity pe = new Electronegativity();
         int maxIter = 10;
         pe.setMaxIterations(maxIter);
-        Assert.assertSame(maxIter, pe.getMaxIterations());
+        Assertions.assertSame(maxIter, pe.getMaxIterations());
     }
 
     /**
@@ -172,11 +171,11 @@ public class ElectronegativityTest extends CDKTestCase {
      * @throws Exception
      */
     @Test
-    public void testSetMaxResonStruc_Int() throws Exception {
+    void testSetMaxResonStruc_Int() throws Exception {
 
         Electronegativity pe = new Electronegativity();
         int maxRes = 10;
         pe.setMaxResonStruc(maxRes);
-        Assert.assertSame(maxRes, pe.getMaxResonStruc());
+        Assertions.assertSame(maxRes, pe.getMaxResonStruc());
     }
 }
