@@ -18,8 +18,8 @@
  */
 package org.openscience.cdk.charges;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.ChemFile;
@@ -50,10 +50,10 @@ import static org.hamcrest.CoreMatchers.not;
  *@author     chhoppe
  *@cdk.created    2004-11-04
  */
-public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
+class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
 
-    private IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
-    private LonePairElectronChecker lpcheck = new LonePairElectronChecker();
+    private final IChemObjectBuilder      builder = SilentChemObjectBuilder.getInstance();
+    private final LonePairElectronChecker lpcheck = new LonePairElectronChecker();
 
     /**
      *  A unit test for JUnit with methylenfluoride
@@ -61,7 +61,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *  @cdk.inchi InChI=1/CH3F/c1-2/h1H3
      */
     @Test
-    public void testCalculateCharges_IAtomContainer() throws Exception {
+    void testCalculateCharges_IAtomContainer() throws Exception {
         double[] testResult = {0.07915, -0.25264, 0.05783, 0.05783, 0.05783};
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
@@ -78,7 +78,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
         peoe.calculateCharges(molecule);
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             //logger.debug("Charge for atom:"+i+" S:"+mol.getAtomAt(i).getSymbol()+" Charge:"+mol.getAtomAt(i).getCharge());
-            Assert.assertEquals(testResult[i], molecule.getAtom(i).getCharge(), 0.01);
+            Assertions.assertEquals(testResult[i], molecule.getAtom(i).getCharge(), 0.01);
         }
     }
 
@@ -86,7 +86,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testAssignGasteigerMarsiliSigmaPartialCharges_IAtomContainer_Boolean() throws Exception {
+    void testAssignGasteigerMarsiliSigmaPartialCharges_IAtomContainer_Boolean() throws Exception {
         double[] testResult = {0.07915, -0.25264, 0.05783, 0.05783, 0.05783};
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
@@ -103,7 +103,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
         peoe.assignGasteigerMarsiliSigmaPartialCharges(molecule, true);
         for (int i = 0; i < molecule.getAtomCount(); i++) {
             //logger.debug("Charge for atom:"+i+" S:"+mol.getAtomAt(i).getSymbol()+" Charge:"+mol.getAtomAt(i).getCharge());
-            Assert.assertEquals(testResult[i], molecule.getAtom(i).getCharge(), 0.01);
+            Assertions.assertEquals(testResult[i], molecule.getAtom(i).getCharge(), 0.01);
         }
 
     }
@@ -112,7 +112,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testAssignGasteigerSigmaMarsiliFactors_IAtomContainer() throws Exception {
+    void testAssignGasteigerSigmaMarsiliFactors_IAtomContainer() throws Exception {
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
 
         IAtomContainer molecule = builder.newInstance(IAtomContainer.class);
@@ -137,11 +137,11 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetMaxGasteigerIters() throws Exception {
+    void testGetMaxGasteigerIters() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
 
-        Assert.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
+        Assertions.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
 
     }
 
@@ -149,11 +149,11 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetMaxGasteigerDamp() throws Exception {
+    void testGetMaxGasteigerDamp() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
 
-        Assert.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
+        Assertions.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
 
     }
 
@@ -161,11 +161,11 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetChiCatHydrogen() throws Exception {
+    void testGetChiCatHydrogen() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
 
-        Assert.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
+        Assertions.assertEquals(20, peoe.getMaxGasteigerIters(), 0.01);
 
     }
 
@@ -173,10 +173,10 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testGetStepSize() throws Exception {
+    void testGetStepSize() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
-        Assert.assertEquals(5, peoe.getStepSize());
+        Assertions.assertEquals(5, peoe.getStepSize());
 
     }
 
@@ -184,12 +184,12 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testSetMaxGasteigerIters_Double() throws Exception {
+    void testSetMaxGasteigerIters_Double() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
         double MX_ITERATIONS = 10;
         peoe.setMaxGasteigerIters(MX_ITERATIONS);
-        Assert.assertEquals(MX_ITERATIONS, peoe.getMaxGasteigerIters(), 0.01);
+        Assertions.assertEquals(MX_ITERATIONS, peoe.getMaxGasteigerIters(), 0.01);
 
     }
 
@@ -197,12 +197,12 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testSetMaxGasteigerDamp_Double() throws Exception {
+    void testSetMaxGasteigerDamp_Double() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
         double MX_DAMP = 1;
         peoe.setMaxGasteigerDamp(MX_DAMP);
-        Assert.assertEquals(MX_DAMP, peoe.getMaxGasteigerDamp(), 0.01);
+        Assertions.assertEquals(MX_DAMP, peoe.getMaxGasteigerDamp(), 0.01);
 
     }
 
@@ -210,12 +210,12 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testSetChiCatHydrogen_Double() throws Exception {
+    void testSetChiCatHydrogen_Double() throws Exception {
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
         double DEOC_HYDROGEN = 22;
         peoe.setChiCatHydrogen(DEOC_HYDROGEN);
-        Assert.assertEquals(DEOC_HYDROGEN, peoe.getChiCatHydrogen(), 0.01);
+        Assertions.assertEquals(DEOC_HYDROGEN, peoe.getChiCatHydrogen(), 0.01);
 
     }
 
@@ -223,16 +223,16 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
      *
      */
     @Test
-    public void testSetStepSize() throws Exception {
+    void testSetStepSize() throws Exception {
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
         int STEP_SIZE = 22;
         peoe.setStepSize(STEP_SIZE);
-        Assert.assertEquals(STEP_SIZE, peoe.getStepSize());
+        Assertions.assertEquals(STEP_SIZE, peoe.getStepSize());
 
     }
 
-    @Test(expected = CDKException.class)
-    public void testUndefinedPartialCharge() throws Exception {
+    @Test
+    void testUndefinedPartialCharge() throws Exception {
         String filename = "burden_undefined.sdf";
         InputStream ins = this.getClass().getResourceAsStream(filename);
         ISimpleChemObjectReader reader = new MDLV2000Reader(ins);
@@ -241,7 +241,7 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
         List<IAtomContainer> cList = ChemFileManipulator.getAllAtomContainers(content);
         IAtomContainer ac = cList.get(0);
 
-        Assert.assertNotNull(ac);
+        Assertions.assertNotNull(ac);
         addExplicitHydrogens(ac);
         AtomContainerManipulator.percieveAtomTypesAndConfigureAtoms(ac);
         Aromaticity.cdkLegacy().apply(ac);
@@ -251,6 +251,8 @@ public class GasteigerMarsiliPartialChargesTest extends CDKTestCase {
         lpcheck.saturate(ac);
 
         GasteigerMarsiliPartialCharges peoe = new GasteigerMarsiliPartialCharges();
-        peoe.calculateCharges(ac);
+        Assertions.assertThrows(CDKException.class, () -> {
+            peoe.calculateCharges(ac);
+        });
     }
 }
