@@ -18,11 +18,10 @@
  */
 package org.openscience.cdk.formula.rules;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.DefaultChemObjectBuilder;
-import org.openscience.cdk.exception.CDKException;
 import org.openscience.cdk.interfaces.IMolecularFormula;
 import org.openscience.cdk.interfaces.IChemObjectBuilder;
 import org.openscience.cdk.tools.manipulator.MolecularFormulaManipulator;
@@ -30,15 +29,15 @@ import org.openscience.cdk.tools.manipulator.MolecularFormulaManipulator;
 /**
  * @cdk.module test-formula
  */
-public class NitrogenRuleTest extends FormulaRuleTest {
+class NitrogenRuleTest extends FormulaRuleTest {
 
     private static IChemObjectBuilder builder;
 
     /**
     *  The JUnit setup method
     */
-    @BeforeClass
-    public static void setUp() throws Exception {
+    @BeforeAll
+    static void setUp() throws Exception {
         builder = DefaultChemObjectBuilder.getInstance();
         setRule(NitrogenRule.class);
     }
@@ -49,10 +48,10 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testNitrogenRule() throws ClassNotFoundException, CDKException, Exception {
+    void testNitrogenRule() throws Exception {
 
         IRule rule = new NitrogenRule();
-        Assert.assertNotNull(rule);
+        Assertions.assertNotNull(rule);
 
     }
 
@@ -62,11 +61,11 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testDefault() throws ClassNotFoundException, CDKException, Exception {
+    void testDefault() throws Exception {
 
         IRule rule = new NitrogenRule();
         Object[] objects = rule.getParameters();
-        Assert.assertNull(objects);
+        Assertions.assertNull(objects);
 
     }
 
@@ -76,13 +75,13 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testSetParameters() throws ClassNotFoundException, CDKException, Exception {
+    void testSetParameters() throws Exception {
 
         IRule rule = new NitrogenRule();
         rule.setParameters(null);
 
         Object[] objects = rule.getParameters();
-        Assert.assertNull(objects);
+        Assertions.assertNull(objects);
 
     }
 
@@ -92,13 +91,13 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testDefaultValidFalse() throws ClassNotFoundException, CDKException, Exception {
+    void testDefaultValidFalse() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C2H4", builder);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -107,14 +106,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testDefaultValidFalse_SetParam() throws ClassNotFoundException, CDKException, Exception {
+    void testDefaultValidFalse_SetParam() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C2H11N4O4", builder);
         formula.setCharge(1);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -123,14 +122,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testDefaultValidTrue() throws ClassNotFoundException, CDKException, Exception {
+    void testDefaultValidTrue() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C4H13N1O5", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -139,14 +138,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC45H75NO15() throws ClassNotFoundException, CDKException, Exception {
+    void testC45H75NO15() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C45H75NO15", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -155,14 +154,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC45H71N7O10() throws ClassNotFoundException, CDKException, Exception {
+    void testC45H71N7O10() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C45H71N7O10", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -171,14 +170,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC49H75NO12() throws ClassNotFoundException, CDKException, Exception {
+    void testC49H75NO12() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C49H75NO12", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -187,14 +186,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC50H95NO10() throws ClassNotFoundException, CDKException, Exception {
+    void testC50H95NO10() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C50H95NO10", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -203,14 +202,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC47H75N5O10() throws ClassNotFoundException, CDKException, Exception {
+    void testC47H75N5O10() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C47H75N5O10", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -219,14 +218,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testC36H42N2O23() throws ClassNotFoundException, CDKException, Exception {
+    void testC36H42N2O23() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("C36H42N2O23", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -235,14 +234,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testN() throws ClassNotFoundException, CDKException, Exception {
+    void testN() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("NH3", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -251,14 +250,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testNPlus() throws ClassNotFoundException, CDKException, Exception {
+    void testNPlus() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMajorIsotopeMolecularFormula("NH4", builder);
         formula.setCharge(1);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -267,14 +266,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testNominalMass() throws ClassNotFoundException, CDKException, Exception {
+    void testNominalMass() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMolecularFormula("C25H53NO7P", builder);
         formula.setCharge(1);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -283,14 +282,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testDoubleCharge() throws ClassNotFoundException, CDKException, Exception {
+    void testDoubleCharge() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMolecularFormula("C22H34N2S2", builder);
         formula.setCharge(2);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -299,14 +298,14 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testWithFe() throws ClassNotFoundException, CDKException, Exception {
+    void testWithFe() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMolecularFormula("C40H46FeN6O8S2", builder);
         formula.setCharge(2);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 
     /**
@@ -315,13 +314,13 @@ public class NitrogenRuleTest extends FormulaRuleTest {
      *
      */
     @Test
-    public void testWithCo() throws ClassNotFoundException, CDKException, Exception {
+    void testWithCo() throws Exception {
 
         IRule rule = new NitrogenRule();
 
         IMolecularFormula formula = MolecularFormulaManipulator.getMolecularFormula("C43H50CoN4O16", builder);
         formula.setCharge(0);
 
-        Assert.assertEquals(1.0, rule.validate(formula), 0.0001);
+        Assertions.assertEquals(1.0, rule.validate(formula), 0.0001);
     }
 }
