@@ -25,7 +25,8 @@
 package org.openscience.cdk.hash.stereo;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IAtomType;
@@ -40,7 +41,6 @@ import java.util.List;
 
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 import static org.openscience.cdk.interfaces.IBond.Stereo.DOWN;
@@ -50,10 +50,10 @@ import static org.openscience.cdk.interfaces.IBond.Stereo.NONE;
  * @author John May
  * @cdk.module test-hash
  */
-public class GeometricTetrahedralEncoderFactoryTest {
+class GeometricTetrahedralEncoderFactoryTest {
 
     @Test
-    public void testCreate_2D() throws Exception {
+    void testCreate_2D() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(5);
@@ -113,14 +113,14 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
         GeometricParity geometricParity = getGeometricParity(extractEncoders(encoder).get(0));
 
-        assertTrue(geometricParity instanceof Tetrahedral2DParity);
+        Assertions.assertTrue(geometricParity instanceof Tetrahedral2DParity);
 
         assertThat(coords2D(geometricParity), CoreMatchers.is(new Point2d[]{p2, p3, p4, p5}));
 
     }
 
     @Test
-    public void testCreate_2D_Implicit() throws Exception {
+    void testCreate_2D_Implicit() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(4);
@@ -173,7 +173,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
         GeometricParity geometricParity = getGeometricParity(extractEncoders(encoder).get(0));
 
-        assertTrue(geometricParity instanceof Tetrahedral2DParity);
+        Assertions.assertTrue(geometricParity instanceof Tetrahedral2DParity);
 
         assertThat(coords2D(geometricParity), CoreMatchers.is(new Point2d[]{p2, p3, p4, p1 // p1 is from central atom
                 }));
@@ -181,7 +181,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
     }
 
     @Test
-    public void testCreate_3D() throws Exception {
+    void testCreate_3D() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(5);
@@ -241,14 +241,14 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
         GeometricParity geometricParity = getGeometricParity(extractEncoders(encoder).get(0));
 
-        assertTrue(geometricParity instanceof Tetrahedral3DParity);
+        Assertions.assertTrue(geometricParity instanceof Tetrahedral3DParity);
 
         assertThat(coords3D(geometricParity), CoreMatchers.is(new Point3d[]{p2, p3, p4, p5}));
 
     }
 
     @Test
-    public void testCreate_3D_Implicit() throws Exception {
+    void testCreate_3D_Implicit() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(4);
@@ -300,7 +300,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
         GeometricParity geometricParity = getGeometricParity(extractEncoders(encoder).get(0));
 
-        assertTrue(geometricParity instanceof Tetrahedral3DParity);
+        Assertions.assertTrue(geometricParity instanceof Tetrahedral3DParity);
 
         assertThat(coords3D(geometricParity), CoreMatchers.is(new Point3d[]{p2, p3, p4, p1 // p1 = central atom
                 }));
@@ -308,7 +308,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
     }
 
     @Test
-    public void testCreate_NonSP3() throws Exception {
+    void testCreate_NonSP3() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(5);
@@ -363,7 +363,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
     }
 
     @Test
-    public void testCreate_NoStereoBonds() throws Exception {
+    void testCreate_NoStereoBonds() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(5);
@@ -419,7 +419,7 @@ public class GeometricTetrahedralEncoderFactoryTest {
     }
 
     @Test
-    public void testCreate_WrongDegree() throws Exception {
+    void testCreate_WrongDegree() throws Exception {
 
         IAtomContainer container = mock(IAtomContainer.class);
         when(container.getAtomCount()).thenReturn(5);
@@ -476,14 +476,12 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
     private static Point2d[] coords2D(GeometricParity parity) {
         if (parity instanceof Tetrahedral2DParity) {
-            Field field = null;
+            Field field;
             try {
                 field = parity.getClass().getDeclaredField("coordinates");
                 field.setAccessible(true);
                 return (Point2d[]) field.get(parity);
-            } catch (NoSuchFieldException e) {
-                System.err.println(e.getMessage());
-            } catch (IllegalAccessException e) {
+            } catch (NoSuchFieldException | IllegalAccessException e) {
                 System.err.println(e.getMessage());
             }
         }
@@ -492,14 +490,12 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
     private static Point3d[] coords3D(GeometricParity parity) {
         if (parity instanceof Tetrahedral3DParity) {
-            Field field = null;
+            Field field;
             try {
                 field = parity.getClass().getDeclaredField("coordinates");
                 field.setAccessible(true);
                 return (Point3d[]) field.get(parity);
-            } catch (NoSuchFieldException e) {
-                System.err.println(e.getMessage());
-            } catch (IllegalAccessException e) {
+            } catch (NoSuchFieldException | IllegalAccessException e) {
                 System.err.println(e.getMessage());
             }
         }
@@ -508,14 +504,12 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
     private static GeometricParity getGeometricParity(StereoEncoder encoder) {
         if (encoder instanceof GeometryEncoder) {
-            Field field = null;
+            Field field;
             try {
                 field = encoder.getClass().getDeclaredField("geometric");
                 field.setAccessible(true);
                 return (GeometricParity) field.get(encoder);
-            } catch (NoSuchFieldException e) {
-                System.err.println(e.getMessage());
-            } catch (IllegalAccessException e) {
+            } catch (NoSuchFieldException | IllegalAccessException e) {
                 System.err.println(e.getMessage());
             }
         }
@@ -524,14 +518,12 @@ public class GeometricTetrahedralEncoderFactoryTest {
 
     private static List<StereoEncoder> extractEncoders(StereoEncoder encoder) {
         if (encoder instanceof MultiStereoEncoder) {
-            Field field = null;
+            Field field;
             try {
                 field = encoder.getClass().getDeclaredField("encoders");
                 field.setAccessible(true);
                 return (List<StereoEncoder>) field.get(encoder);
-            } catch (NoSuchFieldException e) {
-                System.err.println(e.getMessage());
-            } catch (IllegalAccessException e) {
+            } catch (NoSuchFieldException | IllegalAccessException e) {
                 System.err.println(e.getMessage());
             }
         }
