@@ -22,9 +22,9 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.test.CDKTestCase;
 import org.openscience.cdk.DefaultChemObjectBuilder;
 import org.openscience.cdk.interfaces.IAtomContainer;
@@ -48,10 +48,10 @@ import static org.hamcrest.MatcherAssert.assertThat;
  * @cdk.created September 4, 2003
  * @cdk.require java1.4+
  */
-public class TemplateHandlerTest extends CDKTestCase {
+class TemplateHandlerTest extends CDKTestCase {
 
     public boolean                           standAlone = false;
-    private static ILoggingTool              logger     = LoggingToolFactory
+    private static final ILoggingTool              logger     = LoggingToolFactory
                                                                 .createLoggingTool(TemplateHandlerTest.class);
 
     private static SmilesParser              sp         = null;
@@ -60,8 +60,8 @@ public class TemplateHandlerTest extends CDKTestCase {
     /**
      *  The JUnit setup method
      */
-    @BeforeClass
-    public static void setUp() throws Exception {
+    @BeforeAll
+    static void setUp() throws Exception {
         sdg = new StructureDiagramGenerator();
         sp = new SmilesParser(DefaultChemObjectBuilder.getInstance());
     }
@@ -72,54 +72,54 @@ public class TemplateHandlerTest extends CDKTestCase {
      *@exception  Exception  Description of the Exception
      */
     @Test
-    public void testInit() throws Exception {
+    void testInit() throws Exception {
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
 
-        Assert.assertEquals(5, th.getTemplateCount());
+        Assertions.assertEquals(5, th.getTemplateCount());
     }
 
     @Test
-    public void testDetection() throws Exception {
+    void testDetection() throws Exception {
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
         String smiles = "CC12C3(C6CC6)C4(C)C1C5(C(CC)C)C(C(CC)C)2C(C)3C45CC(C)C";
         IAtomContainer mol = sp.parseSmiles(smiles);
-        Assert.assertTrue(th.mapTemplates(mol));
+        Assertions.assertTrue(th.mapTemplates(mol));
     }
 
     /**
      * Tests if a template matches if just an element is non-carbon.
      */
     @Test
-    public void testOtherElements() throws Exception {
-        boolean itIsInThere = false;
+    void testOtherElements() throws Exception {
+        boolean itIsInThere;
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
         IAtomContainer mol = TestMoleculeFactory.makeSteran();
         itIsInThere = th.mapTemplates(mol);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
         mol.getAtom(0).setSymbol("N");
         itIsInThere = th.mapTemplates(mol);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
     }
 
     /**
      * Tests if a template matches if just and bond order is changed.
      */
     @Test
-    public void testOtherBondOrder() throws Exception {
-        boolean itIsInThere = false;
+    void testOtherBondOrder() throws Exception {
+        boolean itIsInThere;
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
         IAtomContainer mol = TestMoleculeFactory.makeSteran();
         itIsInThere = th.mapTemplates(mol);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
         mol.getBond(0).setOrder(IBond.Order.DOUBLE);
         itIsInThere = th.mapTemplates(mol);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
     }
 
     @Test
-    public void testAddMolecule() throws Exception {
+    void testAddMolecule() throws Exception {
         logger.debug("***TestAddMolecule***");
-        boolean itIsInThere = false;
+        boolean itIsInThere;
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         sdg.setMolecule(mol);
@@ -130,18 +130,18 @@ public class TemplateHandlerTest extends CDKTestCase {
         IAtomContainer smilesMol = sp.parseSmiles(smiles);
         itIsInThere = th.mapTemplates(smilesMol);
         logger.debug("Alpha-Pinene found by templateMapper: " + itIsInThere);
-        Assert.assertFalse(itIsInThere);
+        Assertions.assertFalse(itIsInThere);
         th.addMolecule(mol);
         logger.debug("now adding template for alpha-Pinen and trying again.");
         itIsInThere = th.mapTemplates(smilesMol);
         logger.debug("Alpha-Pinene found by templateMapper: " + itIsInThere);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
     }
 
     @Test
-    public void testRemoveMolecule() throws Exception {
+    void testRemoveMolecule() throws Exception {
         logger.debug("***TestRemoveMolecule***");
-        boolean itIsInThere = false;
+        boolean itIsInThere;
         TemplateHandler th = new TemplateHandler(DefaultChemObjectBuilder.getInstance());
         IAtomContainer mol = TestMoleculeFactory.makeAlphaPinene();
         sdg.setMolecule(mol);
@@ -152,17 +152,17 @@ public class TemplateHandlerTest extends CDKTestCase {
         IAtomContainer smilesMol = sp.parseSmiles(smiles);
         itIsInThere = th.mapTemplates(smilesMol);
         logger.debug("Alpha-Pinene found by templateMapper: " + itIsInThere);
-        Assert.assertFalse(itIsInThere);
+        Assertions.assertFalse(itIsInThere);
         th.addMolecule(mol);
         logger.debug("now adding template for alpha-Pinen and trying again.");
         itIsInThere = th.mapTemplates(smilesMol);
         logger.debug("Alpha-Pinene found by templateMapper: " + itIsInThere);
-        Assert.assertTrue(itIsInThere);
+        Assertions.assertTrue(itIsInThere);
         logger.debug("now removing template for alpha-Pinen again and trying again.");
         th.removeMolecule(mol);
         itIsInThere = th.mapTemplates(smilesMol);
         logger.debug("Alpha-Pinene found by templateMapper: " + itIsInThere);
-        Assert.assertFalse(itIsInThere);
+        Assertions.assertFalse(itIsInThere);
 
     }
 
@@ -170,14 +170,14 @@ public class TemplateHandlerTest extends CDKTestCase {
      * Loads a molecule with two adamantanes and one cubane
      * substructure and tests whether all are found.
      */
-    public void getMappedSubstructures_IAtomContainer() throws Exception {
+    void getMappedSubstructures_IAtomContainer() throws Exception {
         // Set up molecule reader
         String filename = "data/mdl/diadamantane-cubane.mol";
         InputStream ins = this.getClass().getClassLoader().getResourceAsStream(filename);
         ISimpleChemObjectReader molReader = new MDLReader(ins, Mode.STRICT);
 
         // Read molecule
-        IAtomContainer molecule = (IAtomContainer) molReader.read(DefaultChemObjectBuilder.getInstance().newInstance(
+        IAtomContainer molecule = molReader.read(DefaultChemObjectBuilder.getInstance().newInstance(
                 IAtomContainer.class));
 
         // Map templates
@@ -185,10 +185,11 @@ public class TemplateHandlerTest extends CDKTestCase {
         IAtomContainerSet mappedStructures = th.getMappedSubstructures(molecule);
 
         // Do the Assert.assertion
-        Assert.assertEquals("3 mapped templates", 3, mappedStructures.getAtomContainerCount());
+        Assertions.assertEquals(3, mappedStructures.getAtomContainerCount(), "3 mapped templates");
     }
 
-    @Test public void convert() throws IOException {
+    @Test
+    void convert() throws IOException {
         TemplateHandler templateHandler = new TemplateHandler(SilentChemObjectBuilder.getInstance());
         ByteArrayOutputStream bout = new ByteArrayOutputStream();
         templateHandler.toIdentityTemplateLibrary().store(bout);
