@@ -18,10 +18,10 @@
  */
 package org.openscience.cdk.atomtype;
 
-import org.junit.Assert;
-import org.junit.FixMethodOrder;
-import org.junit.Test;
-import org.junit.runners.MethodSorters;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.MethodOrderer;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestMethodOrder;
 import org.openscience.cdk.Atom;
 import org.openscience.cdk.AtomContainer;
 import org.openscience.cdk.DefaultChemObjectBuilder;
@@ -43,8 +43,8 @@ import java.util.Map;
  *
  * @cdk.module test-structgen
  */
-@FixMethodOrder(MethodSorters.NAME_ASCENDING)
-public class StructGenMatcherTest extends AbstractAtomTypeTest {
+@TestMethodOrder(MethodOrderer.MethodName.class)
+class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     private final static String          ATOMTYPE_LIST = "structgen_atomtypes.owl";
 
@@ -54,7 +54,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     @Override
     public String getAtomTypeListName() {
         return ATOMTYPE_LIST;
-    };
+    }
 
     @Override
     public AtomTypeFactory getFactory() {
@@ -66,16 +66,16 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
         return new StructGenMatcher();
     }
 
-    private static Map<String, Integer> testedAtomTypes = new HashMap<String, Integer>();
+    private static final Map<String, Integer> testedAtomTypes = new HashMap<>();
 
     @Test
-    public void testStructGenMatcher() throws Exception {
+    void testStructGenMatcher() throws Exception {
         StructGenMatcher matcher = new StructGenMatcher();
-        Assert.assertNotNull(matcher);
+        Assertions.assertNotNull(matcher);
     }
 
     @Test
-    public void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
+    void testFindMatchingAtomType_IAtomContainer_IAtom() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         atom.setImplicitHydrogenCount(4);
@@ -83,13 +83,13 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
         StructGenMatcher atm = new StructGenMatcher();
         IAtomType matched = atm.findMatchingAtomType(mol, atom);
-        Assert.assertNotNull(matched);
+        Assertions.assertNotNull(matched);
 
-        Assert.assertEquals("C", matched.getSymbol());
+        Assertions.assertEquals("C", matched.getSymbol());
     }
 
     @Test
-    public void testN3() throws Exception {
+    void testN3() throws Exception {
         IAtomContainer mol = new AtomContainer();
         Atom atom = new Atom("N");
         atom.setImplicitHydrogenCount(3);
@@ -97,13 +97,13 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
         StructGenMatcher atm = new StructGenMatcher();
         IAtomType matched = atm.findMatchingAtomType(mol, atom);
-        Assert.assertNotNull(matched);
+        Assertions.assertNotNull(matched);
 
-        Assert.assertEquals("N", matched.getSymbol());
+        Assertions.assertEquals("N", matched.getSymbol());
     }
 
     @Test
-    public void testFlourine() throws Exception {
+    void testFlourine() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         atom1.setImplicitHydrogenCount(0);
@@ -127,7 +127,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testChlorine() throws Exception {
+    void testChlorine() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         atom1.setImplicitHydrogenCount(0);
@@ -151,7 +151,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testBromine() throws Exception {
+    void testBromine() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         atom1.setImplicitHydrogenCount(0);
@@ -175,7 +175,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testIodine() throws Exception {
+    void testIodine() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         atom1.setImplicitHydrogenCount(0);
@@ -199,7 +199,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testLithium() throws Exception {
+    void testLithium() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Li");
         IAtom atom2 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "F");
@@ -220,7 +220,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * Tests As3, Cl1
      */
     @Test
-    public void testArsenic() throws Exception {
+    void testArsenic() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom atom1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "As");
         atom1.setImplicitHydrogenCount(0);
@@ -248,7 +248,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * Tests C4, O2
      */
     @Test
-    public void testOxygen1() throws Exception {
+    void testOxygen1() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom carbon = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -284,7 +284,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * Tests O2, H1
      */
     @Test
-    public void testOxygen2() throws Exception {
+    void testOxygen2() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
         IAtom o2 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -324,7 +324,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * Tests P4, S2, Cl1
      */
     @Test
-    public void testP4() throws Exception {
+    void testP4() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom p = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "P");
         IAtom cl1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Cl");
@@ -367,7 +367,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * Tests P3, O2, C4
      */
     @Test
-    public void testP3() throws Exception {
+    void testP3() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom p = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "P");
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -415,7 +415,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Test Na1, Cl1 */
     @Test
-    public void testNa1() throws Exception {
+    void testNa1() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom na = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Na");
         IAtom cl = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Cl");
@@ -436,7 +436,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Test Si4, C4, Cl1 */
     @Test
-    public void testSi4() throws Exception {
+    void testSi4() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom si = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Si");
         IAtom c1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
@@ -479,7 +479,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests S2, H1 */
     @Test
-    public void testS2() throws Exception {
+    void testS2() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom s = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "S");
         s.setImplicitHydrogenCount(2);
@@ -518,7 +518,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests S3, O2 */
     @Test
-    public void testS3() throws Exception {
+    void testS3() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom s = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "S");
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -549,7 +549,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests S4, Cl1 */
     @Test
-    public void testS4() throws Exception {
+    void testS4() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom s = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "S");
         mol.addAtom(s);
@@ -574,7 +574,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests S4, O2 */
     @Test
-    public void testS4oxide() throws Exception {
+    void testS4oxide() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom s = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "S");
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -612,7 +612,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests N3, O2 */
     @Test
-    public void testN3acid() throws Exception {
+    void testN3acid() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom n = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "N");
         IAtom o = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -642,7 +642,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testN3cyanide() throws Exception {
+    void testN3cyanide() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom n = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "N");
         IAtom c1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "C");
@@ -676,7 +676,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Tests N5, O2, C4 */
     @Test
-    public void testN5() throws Exception {
+    void testN5() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom n = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "N");
         IAtom o1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -716,7 +716,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
 
     /* Test B3, F1 */
     @Test
-    public void testB3() throws Exception {
+    void testB3() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom b = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "B");
         IAtom f1 = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "F");
@@ -752,7 +752,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
     }
 
     @Test
-    public void testSe2() throws Exception {
+    void testSe2() throws Exception {
         IAtomContainer mol = DefaultChemObjectBuilder.getInstance().newInstance(IAtomContainer.class);
         IAtom se = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "Se");
         IAtom o = DefaultChemObjectBuilder.getInstance().newInstance(IAtom.class, "O");
@@ -782,7 +782,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
      * annotation).
      */
     @Test
-    public void utestCountTestedAtomTypes() {
+    void utestCountTestedAtomTypes() {
         AtomTypeFactory factory = AtomTypeFactory.getInstance(
                 "org/openscience/cdk/config/data/structgen_atomtypes.xml", SilentChemObjectBuilder.getInstance());
 
@@ -793,7 +793,7 @@ public class StructGenMatcherTest extends AbstractAtomTypeTest {
                 if (!testedAtomTypes.containsKey(expectedType.getAtomTypeName()))
                     errorMessage += " " + expectedType.getAtomTypeName();
             }
-            Assert.assertEquals(errorMessage, factory.getAllAtomTypes().length, testedAtomTypes.size());
+            Assertions.assertEquals(factory.getAllAtomTypes().length, testedAtomTypes.size(), errorMessage);
         }
     }
 
